/* This file is generated with usbsnoop2libusb.pl from a usbsnoop log file. */
/* Latest version of the script should be in http://iki.fi/lindi/usb/usbsnoop2libusb.pl */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#include <signal.h>
#include <ctype.h>
#include <usb.h>
#if 0
 #include <linux/usbdevice_fs.h>
 #define LIBUSB_AUGMENT
 #include "libusb_augment.h"
#endif

struct usb_dev_handle *devh;

void release_usb_device(int dummy) {
    int ret;
    ret = usb_release_interface(devh, 0);
    if (!ret)
	printf("failed to release interface: %d\n", ret);
    usb_close(devh);
    if (!ret)
	printf("failed to close interface: %d\n", ret);
    exit(1);
}

void list_devices() {
    struct usb_bus *bus;
    for (bus = usb_get_busses(); bus; bus = bus->next) {
	struct usb_device *dev;
	
	for (dev = bus->devices; dev; dev = dev->next)
	    printf("0x%04x 0x%04x\n",
		   dev->descriptor.idVendor,
		   dev->descriptor.idProduct);
    }
}    

struct usb_device *find_device(int vendor, int product) {
    struct usb_bus *bus;
    
    for (bus = usb_get_busses(); bus; bus = bus->next) {
	struct usb_device *dev;
	
	for (dev = bus->devices; dev; dev = dev->next) {
	    if (dev->descriptor.idVendor == vendor
		&& dev->descriptor.idProduct == product)
		return dev;
	}
    }
    return NULL;
}

void print_bytes(char *bytes, int len) {
    int i;
    if (len > 0) {
	for (i=0; i<len; i++) {
	    printf("%02x ", (int)((unsigned char)bytes[i]));
	}
	printf("\"");
        for (i=0; i<len; i++) {
	    printf("%c", isprint(bytes[i]) ? bytes[i] : '.');
        }
        printf("\"");
    }
}

void wait() {
    int ret1, ret2 = 0;
    char buf[65535],buf2[1];
    buf2[0] = 0;

    usleep(4*1000);
    while( !buf2[0] ) {
        memcpy(buf, "\x8b\x05\x8b\x05", 0x0000004);
        ret1 = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
        printf("Wait: control msg returned %d, bytes: ", ret1);
        print_bytes(buf, ret1);
        printf("\n");
        usleep(4*1000);
        ret1 = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
        printf("Wait: control msg returned %d, bytes: ", ret1);
        print_bytes(buf, ret1);
        printf("\n");
        usleep(4*1000);
        memcpy(buf, "\x8b\x04\x8b\x04", 0x0000004);
        ret2 = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
        printf("Wait: control msg returned %d, bytes: ", ret2);
        print_bytes(buf, ret2);
        printf("\n");
        usleep(4*1000);
        ret2 = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf2, 0x0000001, 1000);
        printf("Wait: control msg returned %d, bytes: ", ret2);
        print_bytes(buf2, ret2);
        printf("\n");
    }
    usleep(4*1000);
}

#define BPL 7656 //2551*3

FILE *file;
char  realbuff[50000];
int buffsize = 0;

void buff( char *buff, int size ) {
    if( !size ) return;
    char tmp[50000];
    memmove( realbuff + buffsize , buff, size );

    buffsize += size;

    //somtimes with garbage in the end of file...
    while( ( buffsize - 1 ) >= BPL ) {
        printf( "dbg: %i\n", buffsize );
        char tmpline[ BPL ];
        memmove( tmpline, realbuff, BPL );
        int j = 1;
        for( j; j < BPL; j += 3 ) {
            tmpline[ BPL - j - 1 ] = realbuff[ j + 3 ];
            tmpline[ BPL - j - 2 ] = realbuff[ j + 2 ];
            tmpline[ BPL - j - 3 ] = realbuff[ j + 1 ];
        }
        fwrite( tmpline, BPL, 1, file );
        memmove( tmp, realbuff + BPL, buffsize );
        buffsize -= BPL;
        memcpy( realbuff, tmp, buffsize );
    }
}


int main(int argc, char **argv) {
    int ret, vendor, product;
    struct usb_device *dev;
    char buf[65535], *endptr;
#if 0
    usb_urb *isourb;
    struct timeval isotv;
    char isobuf[32768];
#endif

    usb_init();
    usb_set_debug(255);
    usb_find_busses();
    usb_find_devices();

    if (argc!=3) {
	printf("usage: %s vendorID productID\n", argv[0]);
	printf("ID numbers of currently attached devices:\n");
	list_devices();
	exit(1);
    }
    vendor = strtol(argv[1], &endptr, 16);
    if (*endptr != '\0') {
	printf("invalid vendor id\n");
	exit(1);
    }
    product = strtol(argv[2], &endptr, 16);
    if (*endptr != '\0') {
	printf("invalid product id\n");
	exit(1);
    }
    dev = find_device(vendor, product);
    assert(dev);

    devh = usb_open(dev);
    assert(devh);
    
    signal(SIGTERM, release_usb_device);

/*    ret = usb_get_driver_np(devh, 0, buf, sizeof(buf));
    printf("usb_get_driver_np returned %d\n", ret);
    if (ret == 0) {
	printf("interface 0 already claimed by driver \"%s\", attempting to detach it\n", buf);
	ret = usb_detach_kernel_driver_np(devh, 0);
	printf("usb_detach_kernel_driver_np returned %d\n", ret);
    }
*/    ret = usb_claim_interface(devh, 0);
    if (ret != 0) {
	printf("claim failed with error %d\n", ret);
		exit(1);
    }
    
    ret = usb_set_altinterface(devh, 0);
    assert(ret >= 0);

    file = fopen( "img.pnm", "wb" );
    fputs( "P6\n2552 3510\n255\n", file );

memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("38 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x01\xa6\xe0\x08\x01\x02\x04\x08\x10\x20\x40\x80\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("39 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
memcpy(buf, "\x02\xa6\xe0\x08\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("40 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("41 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(1*1000);
memcpy(buf, "\x02\xa0\x05\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("42 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("43 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x8b\x1f\x8b\x1f", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("44 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("45 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1e\x8b\x1e", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("46 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("47 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1d\x8b\x1d", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("48 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("49 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1c\x8b\x1c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("50 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("51 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("52 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("53 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("54 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("55 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("56 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("57 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("58 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("59 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("60 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("61 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("62 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1c\x8b\x1c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("63 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("64 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("65 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("66 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("67 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("68 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("69 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("70 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("71 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("72 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("73 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("74 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("75 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("76 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x94\x31\x92\x57", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("77 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("78 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2500*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("79 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x01\xa6\xe0\x08\x01\x02\x04\x08\x10\x20\x40\x80\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("80 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
memcpy(buf, "\x02\xa6\xe0\x08\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("81 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("82 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa0\x05\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("83 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("84 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x8b\x1f\x8b\x1f", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("85 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("86 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1e\x8b\x1e", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("87 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("88 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1d\x8b\x1d", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("89 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("90 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1c\x8b\x1c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("91 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("92 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("93 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(36*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("94 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("95 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("96 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("97 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(43*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("98 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("99 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("100 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("101 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("102 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("103 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("104 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("105 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("106 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("107 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("108 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("109 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("110 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(13*1000);
memcpy(buf, "\x02\xa0\x10\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("111 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("112 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x02\xa0\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("113 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("114 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(75*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("115 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("116 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("117 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("118 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("119 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("120 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("121 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("122 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("123 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("124 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("125 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("126 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x87\xf1\x87\xa5\x87\x91\x87\x81\x87\x11\x87\xf0", 0x000000c);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000000c, 1000);
printf("127 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x21\xf4\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("128 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\xf3\xf3\xf3", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("129 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\xf3\xf3\xf3", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("130 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(12*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("131 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("132 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1f\x8b\x1f", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("133 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("134 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1e\x8b\x1e", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("135 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("136 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1d\x8b\x1d", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("137 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("138 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1c\x8b\x1c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("139 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("140 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("141 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("142 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("143 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("144 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("145 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("146 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("147 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("148 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x94\x31\x92\x57", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("149 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x86\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("150 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("151 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("152 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("153 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("154 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("155 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("156 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("157 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("158 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x94\x31\x92\x57", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("159 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("160 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(27*1000);
memcpy(buf, "\x02\xa8\x10\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("161 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("162 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa8\x30\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("163 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("164 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa8\x50\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("165 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("166 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa8\x70\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("167 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("168 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa8\x90\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("169 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("170 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa8\xb0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("171 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("172 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa8\xd0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("173 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("174 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa8\xf0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("175 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("176 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xaa\x10\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("177 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("178 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xaa\x30\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("179 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("180 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xaa\x50\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("181 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("182 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xaa\x70\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("183 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("184 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xaa\x90\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("185 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("186 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x02\xa0\x2b\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("187 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("188 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(22*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("189 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("190 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("191 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("192 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("193 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("194 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("195 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("196 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("197 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x94\x31\x92\x57", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("198 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("199 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(666*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("200 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("201 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("202 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("203 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("204 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("205 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("206 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("207 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("208 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(61*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("209 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x02\xa0\x05\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("210 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("211 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("212 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("213 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("214 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("215 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("216 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("217 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("218 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("219 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("220 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("221 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("222 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x87\xf1\x87\xa5\x87\x91\x87\x81\x87\x11\x87\xf0", 0x000000c);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000000c, 1000);
printf("223 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x21\xf4\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("224 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\xf3\xf3\xf3", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("225 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\xf3\xf3\xf3", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("226 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(12*1000);
memcpy(buf, "\x82\x00\x83\x38\x84\x8e\x85\xe3", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("227 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("228 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30", 0x000002a);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000002a, 1000);
printf("229 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("230 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\x02\xa0\x60\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("231 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("232 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa0\x80\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("233 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("234 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa6\xa0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("235 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("236 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa6\xc0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("237 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("238 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa0\xa0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("239 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("240 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa0\xc0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("241 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("242 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa0\xe0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("243 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("244 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa2\x00\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("245 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("246 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa2\x20\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("247 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("248 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa2\x40\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("249 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("250 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa2\x60\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("251 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("252 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa2\x80\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("253 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("254 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(1*1000);
memcpy(buf, "\x02\xa2\xa0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("255 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("256 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa2\xc0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("257 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("258 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa2\xe0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("259 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("260 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa4\x00\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("261 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("262 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa4\x20\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("263 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("264 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa4\x40\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("265 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("266 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa4\x60\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("267 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("268 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa4\x80\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("269 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("270 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa4\xa0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("271 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("272 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa4\xc0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("273 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("274 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa4\xe0\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("275 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("276 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa6\x00\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("277 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("278 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa6\x20\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("279 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("280 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa6\x40\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("281 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("282 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa6\x60\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("283 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("284 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xa6\x80\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("285 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("286 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xaa\xb0\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("287 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("288 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x02\xac\x11\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("289 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("290 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xac\x31\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("291 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("292 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xac\x51\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("293 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("294 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xac\x71\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("295 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("296 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xac\x91\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("297 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("298 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xac\xb1\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("299 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("300 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xac\xd1\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("301 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("302 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xac\xf1\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("303 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("304 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xae\x11\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("305 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("306 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xae\x31\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("307 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("308 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xae\x51\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("309 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("310 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xae\x71\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("311 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("312 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(1*1000);
memcpy(buf, "\x02\xae\x91\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("313 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(49*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("314 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(1*1000);
memcpy(buf, "\x02\xae\xb1\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("315 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(49*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("316 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xae\xd1\x20\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("317 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(48*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("318 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(1*1000);
memcpy(buf, "\x02\xae\xf1\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("319 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(13*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("320 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x02\xae\xf7\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("321 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("322 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("323 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("324 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x74\x00\x78\x00\x82\x00\x83\x38\x84\x8e\x85\xe3\x86\x01\x88\x80\x89\x80\x90\x64\x8e\x00\x92\x57\x93\x0a\x95\x27\x96\x21\x97\xf0\x98\xbe\x99\x30\xb2\x14\xb3\x01\xb8\x00\xb9\x00\xba\x00\xbb\x00\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("325 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xcc\x00\xd0\x07\xd1\x00\xd2\x00\xd3\x00\xd4\x00\xd5\x00\xd6\x00\xd7\x00\xd8\x05\xdb\x00\xdc\x01\xde\x01\xea\x2c\xeb\x01\xf8\x01", 0x000002a);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000002a, 1000);
printf("326 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("327 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x6c\x1c\xd0\x00\xd1\x00\xd2\x00\xd3\x00\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xd8\xff\xd9\xff\xda\xff\xdb\xff\xdc\xff\xdd\xff\xde\xff\xdf\xff\xe0\xff\xe1\xff\xe2\xff\xe3\xff\xe4\xff\xe5\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("328 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xe6\xff\xe7\xff\xe8\xff\xe9\xff\xea\xff\xeb\xff\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30", 0x000001c);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000001c, 1000);
printf("329 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("330 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("331 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xd0\x01\xd1\x09\xd2\x11\xd3\x19\xd4\x21\xd5\x29\xd6\x31\xd7\x39", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000010, 1000);
printf("332 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("333 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x79\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("334 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("335 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("336 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("337 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("338 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("339 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("340 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("341 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("342 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("343 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x10\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("344 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("345 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("346 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("347 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("348 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("349 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("350 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x10", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("351 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("352 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("353 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x20\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("354 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("355 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("356 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("357 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("358 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("359 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("360 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(27*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x20", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("361 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("362 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("363 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x30\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("364 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("365 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("366 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("367 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("368 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("369 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("370 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x30", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("371 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(21*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("372 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("373 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x40\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("374 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("375 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("376 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("377 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("378 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("379 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("380 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(27*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("381 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("382 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("383 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x50\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("384 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("385 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("386 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("387 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("388 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("389 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("390 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(27*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x50", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("391 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("392 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("393 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x60\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("394 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("395 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("396 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("397 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("398 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("399 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("400 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(28*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x60", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("401 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("402 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("403 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x70\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("404 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("405 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("406 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("407 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("408 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("409 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("410 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x70", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("411 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("412 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("413 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x80\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("414 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("415 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("416 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("417 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("418 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("419 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("420 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x80", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("421 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("422 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("423 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x90\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("424 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("425 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("426 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("427 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("428 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("429 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("430 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\x90", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("431 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("432 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("433 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\xa0\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("434 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("435 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x08\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("436 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("437 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x0000800);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000800, 1122);
printf("438 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("439 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("440 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x79\xa0", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("441 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x08\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("442 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000800, 1122);
printf("443 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x79\x40\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("444 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x00000d0, 0x0000000, buf, 0x0000001, 1000);
printf("445 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x90\x7e\x01\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("446 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
memcpy(buf, "\x00\xf0\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("447 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x000f000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x000f000, 4686);
printf("448 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(96*1000);
memcpy(buf, "\x00\xa0\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("449 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80\x01\x02\x04\x08\x10\x20\x40\x80", 0x000a000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x000a000, 3457);
printf("450 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(41*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("451 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("452 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(27*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\xc8\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("453 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x90\x01\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("454 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("455 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009400, 3273);
printf("456 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x80\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x06\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("457 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(22*1000);
memcpy(buf, "\x00\x06\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("458 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x29\x23\xbe\x84\xe1\x6c\xd6\xae\x52\x90\x49\xf1\xf1\xbb\xe9\xeb\xb3\xa6\xdb\x3c\x87\x0c\x3e\x99\x24\x5e\x0d\x1c\x06\xb7\x47\xde\xb3\x12\x4d\xc8\x43\xbb\x8b\xa6\x1f\x03\x5a\x7d\x09\x38\x25\x1f\x5d\xd4\xcb\xfc\x96\xf5\x45\x3b\x13\x0d\x89\x0a\x1c\xdb\xae\x32\x20\x9a\x50\xee\x40\x78\x36\xfd\x12\x49\x32\xf6\x9e\x7d\x49\xdc\xad\x4f\x14\xf2\x44\x40\x66\xd0\x6b\xc4\x30\xb7\x32\x3b\xa1\x22\xf6\x22\x91\x9d\xe1\x8b\x1f\xda\xb0\xca\x99\x02\xb9\x72\x9d\x49\x2c\x80\x7e\xc5\x99\xd5\xe9\x80\xb2\xea\xc9\xcc\x53\xbf\x67\xd6\xbf\x14\xd6\x7e\x2d\xdc\x8e\x66\x83\xef\x57\x49\x61\xff\x69\x8f\x61\xcd\xd1\x1e\x9d\x9c\x16\x72\x72\xe6\x1d\xf0\x84\x4f\x4a\x77\x02\xd7\xe8\x39\x2c\x53\xcb\xc9\x12\x1e\x33\x74\x9e\x0c\xf4\xd5\xd4\x9f\xd4\xa4\x59\x7e\x35\xcf\x32\x22\xf4\xcc\xcf\xd3\x90\x2d\x48\xd3\x8f\x75\xe6\xd9\x1d\x2a\xe5\xc0\xf7\x2b\x78\x81\x87\x44\x0e\x5f\x50\x00\xd4\x61\x8d\xbe\x7b\x05\x15\x07\x3b\x33\x82\x1f\x18\x70\x92\xda\x64\x54\xce\xb1\x85\x3e\x69\x15\xf8\x46\x6a\x04\x96\x73\x0e\xd9\x16\x2f\x67\x68\xd4\xf7\x4a\x4a\xd0\x57\x68\x76\xfa\x16\xbb\x11\xad\xae\x24\x88\x79\xfe\x52\xdb\x25\x43\xe5\x3c\xf4\x45\xd3\xd8\x28\xce\x0b\xf5\xc5\x60\x59\x3d\x97\x27\x8a\x59\x76\x2d\xd0\xc2\xc9\xcd\x68\xd4\x49\x6a\x79\x25\x08\x61\x40\x14\xb1\x3b\x6a\xa5\x11\x28\xc1\x8c\xd6\xa9\x0b\x87\x97\x8c\x2f\xf1\x15\x1d\x9a\x95\xc1\x9b\xe1\xc0\x7e\xe9\xa8\x9a\xa7\x86\xc2\xb5\x54\xbf\x9a\xe7\xd9\x23\xd1\x55\x90\x38\x28\xd1\xd9\x6c\xa1\x66\x5e\x4e\xe1\x30\x9c\xfe\xd9\x71\x9f\xe2\xa5\xe2\x0c\x9b\xb4\x47\x65\x38\x2a\x46\x89\xa9\x82\x79\x7a\x76\x78\xc2\x63\xb1\x26\xdf\xda\x29\x6d\x3e\x62\xe0\x96\x12\x34\xbf\x39\xa6\x3f\x89\x5e\xf1\x6d\x0e\xe3\x6c\x28\xa1\x1e\x20\x1d\xcb\xc2\x03\x3f\x41\x07\x84\x0f\x14\x05\x65\x1b\x28\x61\xc9\xc5\xe7\x2c\x8e\x46\x36\x08\xdc\xf3\xa8\x8d\xfe\xbe\xf2\xeb\x71\xff\xa0\xd0\x3b\x75\x06\x8c\x7e\x87\x78\x73\x4d\xd0\xbe\x82\xbe\xdb\xc2\x46\x41\x2b\x8c\xfa\x30\x7f\x70\xf0\xa7\x54\x86\x32\x95\xaa\x5b\x68\x13\x0b\xe6\xfc\xf5\xca\xbe\x7d\x9f\x89\x8a\x41\x1b\xfd\xb8\x4f\x68\xf6\x72\x7b\x14\x99\xcd\xd3\x0d\xf0\x44\x3a\xb4\xa6\x66\x53\x33\x0b\xcb\xa1\x10\x5e\x4c\xec\x03\x4c\x73\xe6\x05\xb4\x31\x0e\xaa\xad\xcf\xd5\xb0\xca\x27\xff\xd8\x9d\x14\x4d\xf4\x79\x27\x59\x42\x7c\x9c\xc1\xf8\xcd\x8c\x87\x20\x23\x64\xb8\xa6\x87\x95\x4c\xb0\x5a\x8d\x4e\x2d\x99\xe7\x3d\xb1\x60\xde\xb1\x80\xad\x08\x41\xe9\x67\x41\xa5\xd5\x9f\xe4\x18\x9f\x15\x42\x00\x26\xfe\x4c\xd1\x21\x04\x93\x2f\xb3\x8f\x73\x53\x40\x43\x8a\xaf\x7e\xca\x6f\xd5\xcf\xd3\xa1\x95\xce\x5a\xbe\x65\x27\x2a\xf6\x07\xad\xa1\xbe\x65\xa6\xb4\xc9\xc0\x69\x32\x34\x09\x2c\x4d\x01\x8f\x17\x56\xc6\xdb\x9d\xc8\xa6\xd8\x0b\x88\x81\x38\x61\x6b\x68\x12\x62\xf9\x54\xd0\xe7\x71\x17\x48\x78\x0d\x92\x29\x1d\x86\x29\x99\x72\xdb\x74\x1c\xfa\x4f\x37\xb8\xb5\xb0\x95\x57\xf5\xdf\x80\x6c\x6d\x8d\x74\xd9\x8b\x43\x65\x11\x08\xa5\xf6\x79\xbd\xf7\xeb\x15\xb8\xe0\xe1\x60\x8f\x6e\x3c\x7b\xf4\x5b\x62\x8a\x8a\x8f\x27\x5c\xf7\xe5\x87\x4a\x3b\x32\x9b\x61\x40\x84\xc6\xc3\xb1\xa7\x30\x4a\x10\xee\x75\x6f\x03\x2f\x9e\x6a\xef\x10\x50\x9b\xc8\x81\x43\x29\x28\x8a\xf6\xe9\x9e\x47\xa1\x81\x48\x31\x6c\xcd\xa4\x9e\xde\x81\xa3\x8c\x98\x10\xff\x9a\x43\xcd\xcf\x57\xc7\x50\x59\xbf\xbd\x1c\x27\x03\x28\x7f\x5d\x89\x5f\xb9\x49\x34\x4e\x60\x3c\xe5\xde\x02\x98\x42\xb2\x0d\x2b\xb6\x14\xec\xbb\xb8\x2f\x73\xe2\x51\x7e\x7d\x1d\xd8\x84\xd3\x1f\x01\xbe\x50\x6b\x16\xd6\x43\x21\x83\x19\x15\x18\x98\x2b\x2c\x2e\x8b\xf9\x0e\xdc\xbc\xf0\xca\x0e\x3d\x6d\x94\x31\x92\x74\xaf\x8d\xb5\xa4\x90\xd5\x5e\x6a\x40\xfc\x80\x76\x02\x4b\x17\x6b\x36\xb1\x21\xdb\x7d\x5a\xea\x72\x1e\x82\x8d\x71\xa8\x8c\xb8\x5e\xd9\x4e\xaf\xfa\xbf\xb0\x94\x74\x1d\x75\xe5\xdc\x10\x58\x46\xda\xf2\x5b\x81\xa0\x7f\x5c\xcb\x1d\x36\xe9\x49\x74\x02\x55\xd2\xac\x1a\x0b\xf7\xa9\x26\x23\x40\x5b\xa3\x33\xb9\x35\x88\x68\xad\xe1\x2a\xd5\xb2\x32\x5d\x0a\xe5\x5a\xdc\xe9\x77\x5d\xeb\xb5\x69\xc5\x3a\x6c\x93\x98\x0d\x57\xeb\x87\x9a\xdf\x04\x68\xb2\xa2\xd5\xe6\xa4\xc6\xbc\x77\x5f\x8d\xc3\x8f\xd6\x2a\x21\x14\xa9\xd4\x04\x11\x01\x18\x8d\xae\xbb\x73\x1c\x60\xca\x20\xcf\x5d\xd6\x2f\x45\x53\x29\xd7\xa8\x59\xcc\x0d\xea\x26\xed\x55\x4e\x80\x84\xd9\x2b\xf8\x37\xb8\xed\xd5\x7a\xa0\x5c\x4e\xfa\x9f\x21\xfc\x3c\x36\x85\x8e\x81\xb0\x7d\xbf\xee\xb1\xe4\x85\xe9\x12\x07\x8b\xc6\xec\x66\xe2\xa3\xf3\xb9\xf4\x90\x06\x32\xb9\xf4\x04\x02\x2d\x2c\xe0\x1e\x01\x74\xf8\x43\x90\x0b\xa2\x37\x16\x92\x08\x53\x1c\xb5\x37\x3e\x37\x0e\x72\xfb\xf2\x46\xcc\x26\x09\x7e\xf6\x7a\xd8\xed\x55\x97\x12\xca\x57\x02\xb6\x6c\x08\x6e\x3f\xb0\xe0\x3a\x1c\x9b\xdf\x3a\x5f\x40\xdd\xba\xb9\xe4\x1b\xc0\xa6\x61\x1d\x92\xe5\xc8\xbc\x78\x2b\x4a\x77\xc3\x18\x59\x0a\x0e\x6a\x0a\x42\xc4\x71\xbe\x0f\xe3\xc3\x01\xdb\xff\x30\xb2\x1a\x89\xf8\x65\x22\x51\x3c\x05\x3d\x4a\xb3\xbe\xfd\x8d\x9e\x19\xd0\xa1\xfe\x69\xd4\xfa\x04\x67\xed\xbf\xc9\x19\x14\xd1\x3f\xf8\xf2\x08\x68\x51\xad\xc0\xc5\xec\x02\x94\x12\xec\x94\x69\x30\xf6\x83\xaf\x63\x95\x41\xe3\xbd\xdd\xa1\x58\xda\x4f\x31\x38\xce\xfd\xca\xc5\x5c\xef\x65\xe5\x69\xc4\x30\xde\xaf\x9c\xe2\x5e\xb6\x36\x4b\xbe\x00\x56\x2f\x87\x84\x6a\x54\x36\x5f\x6c\xda\x3c\xc5\x0a\xcb\x49\x3d\x05\xf3\xca\x0e\xd7\xf2\xb1\xf4\x98\x8f\x74\x18\x22\x4f\x58\x3f\x74\x47\xef\x42\x54\x2e\xdf\xbe\x39\xb6\xe6\x0c\x67\x1c\x1b\x74\x5c\xfe\x77\x9d\x6b\x6e\x93\x48\xa7\x44\xb3\x3e\x02\xb8\x04\x87\xb6\x30\x22\xdd\xe4\x56\xdd\x61\x7b\x6e\x3d\x8c\x5c\xe7\xc4\x67\xbc\x2f\xf2\xff\xc9\xcc\x0f\x13\x90\xa9\x24\x11\x1e\xad\x4b\x41\xe5\x92\x28\x3f\x62\xf5\xb8\xae\xfd\xa9\x49\x2b\x31\x51\xca\x80\xec\x2e\x45\x1a\x39\x35\xaa\xbe\x1c\x65\xce\x77\xbd\x57\xb3\xd3\xc9\x17\x0a\x4e\x16\x32\xf6\x0f\x86\x10\x13\xd2\x2d\x84\xb7\x26\xb6\xa2\x78\xd8\x02\xd1\xee\xaf\x13\x21\xba\x59\x29\xde\xc6\xa6\x2a\x65\xcf\xf4\x47\x36\x21\xeb\xdd\x4b\xa2\x6a\x99\xa8\x12\xc0\xe0\x34\x91\x20\x6e\xc7\x62\x4f\x3d\x84\xee\xa0\xa8\x69\x0c\x22\xd0\x24\x7f\x18\x3f\x28\xc0\xa9\xcb\x01\xff\xd9\xbd\xe4\x64\xb8\x33\x8b\x9a\xd9\xc3\x40\x8e\x06\x61\x37\x74\x32\x83\x20\x0c\xaf\x83\xfd\x23\xa2\x44\x31\x5c\xb3\x18\xda\x30\x09\xe1\x61\x34\x75\x77\x50\x9a\xed\x4a\x63\xfb\x3d\x49\xe1\x54\xf9\x02\x2c\x4e\xb6\x0a\x97\xc2\x79\x9f\x79\x7c\x70\x8c\x80\x3f\xe0\x4d\x47\x0a\x5f\x74\x2a\x9a\x43\x4b\x59\x30\x5a\xbb\x2b\x94\xdc\x6c\xb5\x5a\x9d\x2e\x9c\x64\x87\x98\x27\xa8\x48\xee\x98\x33\x48\x48\xbd\x6e\xde\xf1\xc2\xa1\xc3\x0e\x49\xb5\xc7\x80\xbc\x3e\xc2\x0b\xe2", 0x0000600);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000600, 1092);
printf("459 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("460 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("461 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x80\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x03\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("462 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x06\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("463 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000600, 1092);
printf("464 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xa0\x00\xa1\x08\xa2\x80\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x06\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("465 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(22*1000);
memcpy(buf, "\x00\x06\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("466 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\xb9\xce\xb7\xb1\x11\xb3\x76\x64\x69\xa3\x08\xcd\x15\x28\x1c\xeb\xe9\x5a\xb8\xbf\xb7\x55\xda\x5c\x13\xea\x60\x3e\x59\x95\x25\xdc\xf2\xaf\x6d\x80\xd2\xe5\x83\x57\x45\xe9\xa0\xc4\xec\x67\x0f\xfa\x02\x3b\x8f\xca\xe4\xe1\xf9\xb9\xd1\x2d\x22\x56\xee\x3c\x03\xcb\x8d\xaa\x17\xb1\xae\x05\x05\x29\xc6\x82\x7f\x28\xc0\xef\x6a\x12\x42\xe9\x3f\x8b\x31\x4f\xb1\x8a\x77\xf7\x90\xae\x04\x9f\xed\xd6\x12\x26\x7f\xec\xae\xfc\x45\x01\x74\xd7\x6d\x9f\x9a\xa7\x75\x5a\x30\xcd\x90\xa9\xa5\x87\x4b\xf4\x8e\xaf\x70\xee\xa3\xa6\x2a\x25\x0a\x8b\x6b\xd8\xd9\xb0\x8b\x08\xd6\x4e\x32\xd1\x81\x77\x77\xfb\x54\x4d\x49\xcd\x49\x72\x0e\x21\x9d\xbf\x8b\xbe\xd3\x39\x04\xe1\xfd\x40\xa4\x1d\x37\x0a\x1f\x65\x74\x50\x95\x68\x7d\x47\xba\x1d\x36\xd2\x34\x9e\x23\xf6\x44\x39\x2c\x8e\xa9\xc4\x9d\x40\xc1\x32\x71\xaf\xf2\x64\xd0\xf2\x48\x41\xd6\x46\x5f\x09\x96\xff\x84\xe6\x5f\xc5\x17\xc5\x3e\xfc\x33\x63\xc3\x84\x92\xab\x08\xa3\xaa\x3f\xf0\x3f\x1c\x55\xad\x51\x4f\xc4\x85\x96\x58\x5e\xd5\x88\x1e\x81\x56\x8c\xbb\xe9\x9f\x6d\x25\xc8\xeb\x09\x0d\x19\x1d\x4a\x07\x31\x01\x58\xec\x97\xd5\x0d\x7c\x15\x08\xaa\x48\x0f\x41\xc8\xd0\x14\xa3\x91\xe8\xb3\x50\x2f\x60\x90\x2b\x85\xe3\xb7\xe3\x1d\x20\x2f\x2d\x62\x28\xd3\x50\x10\x17\x5d\xe7\xe8\xf7\xc4\xe2\xa8\xe1\xc8\xcf\x3a\x65\xca\x58\x2c\x2d\xe2\x0c\x60\xdc\x2c\x62\x05\x3c\x62\xfa\xc5\x99\xb0\x27\x40\x68\xc3\xab\xba\x2d\x24\xc1\x10\x9b\xc4\x61\xf1\xfc\xd8\xbf\x4a\xd3\xe6\x15\x02\xc0\x20\xa2\xe8\xa5\xf2\xf2\xea\x07\xd7\x61\x87\xb7\x70\xdb\x87\xb1\xd7\xe5\xe9\x44\x31\xe1\x1d\x73\x82\x8d\x73\x9c\xc6\xce\xd4\x57\x3d\xac\xb0\xa1\x06\x9d\x37\x3a\xef\x06\xcc\x4b\x8c\xff\xb6\x4c\x86\x57\x19\x25\x36\xd7\x25\x93\x72\xcb\x8e\xce\xa7\xbf\x3c\x69\x28\x87\x43\x79\xc6\x82\x15\xf9\xa1\x1f\xf7\x6d\x3e\x9f\xb1\xc6\xd9\x1d\x8a\x86\xfc\xcc\x73\x24\x50\x81\x83\xb2\xb4\x71\xa3\xbd\x8c\x3b\x8b\x75\x5b\x29\xed\x0d\x95\xb2\xef\x65\xae\x44\xdf\xe7\x77\x41\x22\xaf\xaa\x48\x6e\xee\xc3\xb5\x3a\x90\x12\x6b\x72\x1c\x0f\xd1\x6e\xdc\xed\x1a\x25\x3f\x72\xca\x9e\x7b\x05\x75\xa8\x76\x09\xca\xcb\xe7\x69\xd1\x7e\xb8\x74\x71\x9a\xb0\xec\x35\x0f\x4e\x59\x50\xd6\xf8\xa3\xde\x27\x55\xe0\x6c\xeb\xf7\x6b\xbb\x74\x3d\x36\xc1\x6c\x77\x61\xf1\x0b\x4c\x0b\xbc\x8d\x59\x68\x58\xe4\x1b\x13\xc0\xaa\x0f\xa6\xfc\x59\x17\x89\xa2\xbe\x20\x07\x9d\xab\x02\xa7\x2d\xed\xa7\xb9\x2f\x7d\x70\x2f\x9f\xfb\xd4\xae\x5b\x57\x4b\xe5\x29\xd2\x6a\x1e\xfc\x25\x4f\x12\x73\xff\x3f\x02\xa3\xb5\x8e\x03\x16\x35\xbf\x9a\x13\x3d\xed\x88\x20\xca\x6a\xe7\xc6\xd2\xa5\x76\x94\x35\x51\x32\x67\xf2\xc3\x26\xe8\x96\x9c\x83\x55\xfb\xa9\xf3\x85\x2e\x07\x2b\x26\xb1\x8b\xbf\x4a\xe3\x60\x3b\x22\xbc\xf2\x6f\x08\xbd\x0b\x0a\xc3\x27\x3c\x6b\x07\x6c\x7f\xb3\x3c\xe3\x1a\x1f\x80\xbf\xc7\x95\xef\x42\x11\x7c\x22\x2e\x01\xd1\xf5\x7d\xfa\x77\x8e\x51\xe2\xcf\x9b\x2e\x82\x89\xda\x67\x30\xba\xdf\xd6\xab\x2e\x12\xd0\x46\xff\xf7\x58\x49\x66\xb2\x93\x94\xd2\xca\x7d\x85\x37\x2d\xd9\x1c\xa9\x74\x6e\x5d\x29\x69\x70\xf6\xbf\xc6\x3d\x22\xc9\x40\x4a\xcd\x92\xc4\x5c\xf9\x26\x01\xfb\x60\x65\x26\x23\x5b\x57\xed\x3e\x02\xbf\xd8\x4f\x95\xf3\xba\x70\x1b\xea\x7a\x7e\x48\x97\x14\x13\xa4\x75\xe0\xb4\xea\x64\x17\x4c\xae\xb3\x93\xd9\x43\x7e\xd6\x66\xdc\x3a\x4e\x39\xf1\x8e\xd8\x4d\xe5\x64\x82\x03\xe5\x41\x95\x14\x13\xd1\xd3\xca\xe4\xc7\xfd\x70\xc6\xe4\x98\x07\x07\x54\xf1\x3a\xf2\x41\x5f\x94\x3b\xa3\xc8\xf1\x9d\x55\x66\x32\xc1\x6e\xcb\x35\x62\xce\x23\x05\xaf\xf7\xba\x4d\xf0\x1f\xbe\x13\x6d\x83\x45\xa2\x8b\xfd\x91\xc8\x39\xd9\x93\x42\x8a\xe5\xaf\x75\xa3\xc7\xbf\x5f\xd8\x93\x5a\xcc\x12\x9d\x56\xcd\x74\x8c\x8b\x66\x3e\xb0\xda\x87\xf1\x96\x6f\x3d\xb4\xd9\x42\x2a\xf6\x3a\xe4\x33\x55\xf3\x78\x78\xbe\x49\xff\x89\xd6\x61\xda\xd7\x99\x54\x89\x68\x41\x85\xb9\xcf\x6a\x33\x7e\x5c\x73\x4a\xdd\x90\x27\x7f\x8d\xd3\x9d\x9b\xfe\x69\x5c\x17\x9b\xa3\xc3\xea\x4d\x52\xa9\x9f\x40\x81\x40\xaa\xe9\x64\x3f\xfc\x48\x8b\x40\xd5\x6a\x5b\x66\xda\x33\xbf\x44\x67\x5a\x1b\xfa\x26\xb5\x82\xa1\xe1\xb7\x28\xea\x94\x37\x1a\x01\xc7\x72\x2c\xb8\x1a\x54\x33\xe1\x22\xf3\x75\xfb\x73\x5d\x5e\x12\xfe\x93\x75\xe0\x9e\xd5\x8e\x38\xed\x20\x40\xa5\x5c\xf6\x99\x4e\x83\x5d\x11\x1c\xb5\x2a\xbd\x1f\xd8\x7f\xc5\x2e\x73\x93\x18\xce\x09\xb1\x5e\x56\xa6\x84\x2f\x50\xb7\x91\x82\x21\x1e\x05\x68\xed\x86\xb1\xfa\xb5\xf4\x53\x8f\xc2\x9f\x17\x33\x47\x02\x5d\x55\x42\x2f\xbd\xc0\xa3\x66\x48\xcd\xb0\xe6\x11\xd6\xa8\x03\xed\xed\xa6\x79\x76\xce\xc9\x00\x56\x13\x92\x21\xc2\xa7\x8d\x47\x44\x7d\x34\x19\xbe\x82\x10\x07\xac\xd0\x21\x23\xa9\x24\x80\x33\x35\x92\x43\x04\xb5\x77\xa1\x01\xbb\xb0\x57\x03\x88\x09\x49\x6b\xcf\xf8\x6d\x6f\xbc\x8c\xe5\xb1\x35\xa0\x6b\x16\x60\x54\xf2\xd5\x65\xbe\x8a\xce\x75\xdc\x85\x1e\x0b\xcd\xd8\xf0\x71\x41\xc4\x95\x87\x2f\xb5\xd8\xc0\xc6\x6a\x8b\x6d\xa5\x56\x66\x3e\x4e\x46\x12\x05\xd8\x45\x80\xbe\xe5\xbc\x7f\xcd\xd4\xde\x8e\x86\x38\x43\xee\xf2\x88\xd3\xfc\xd0\x18\xe6\xbe\xdb\x47\xaa\xbc\x4b\xfa\xc4\x11\x9e\x4a\x3a\xc1\x98\x7a\x90\x4d\x89\x2c\x31\x85\xce\xd4\x11\x9e\x9a\x6c\x91\x84\xf7\x6a\xa3\x71\x07\xef\x2e\xbf\x90\x41\xb4\xfb\xb7\x7b\x32\x3a\x0c\x83\x47\xb0\xc7\x3d\x99\x7e\x51\xfe\x75\xcc\x07\x44\xb5\x18\x3a\xa4\xe7\xcd\x7a\x03\xab\x18\x14\x09\x5d\xf7\xd9\xd3\xf4\x93\x21\xe8\x2a\xcf\x10\x6f\xde\x21\x18\x9f\xb6\xa1\xbf\x76\x08\x5f\xa3\xae\xfb\xfa\xbb\xed\xe9\x6e\xdf\x3c\x08\x2e\x8b\xba\x4a\x73\xe0\x91\x81\xd3\xeb\x2a\xc7\x15\x2a\x9d\x1d\x44\x4c\x6c\x52\x02\x39\x70\x27\x1f\x52\x13\xb0\x6a\xfa\xc0\xfd\xc7\x55\x98\xfa\x82\x4f\x67\x94\xe3\xe1\xd6\x1d\x03\x90\xe2\xf2\xdd\x36\x8c\x5b\xa8\x04\xd2\xb2\x65\xc8\xdf\xc8\xb4\x6c\x7f\x84\xeb\xbf\xd5\xcd\x69\x79\x50\xaa\x28\x79\xdb\xa8\x92\x50\x54\x7d\x96\x03\x40\xea\xfa\x0d\xbd\xe6\xf3\xa4\xb7\xf8\xf3\x3d\x5f\xe5\xc2\x52\xd9\x8b\xd0\x63\x35\x0d\xca\x3b\xa1\x30\x6b\x74\xdd\x05\x95\x3d\xef\xc9\xa0\x5b\x17\x09\xf2\x6e\x05\x09\xcf\x76\x4a\x67\x73\x95\x0d\xfc\x5e\x17\xff\x03\xf0\xaf\x91\x7d\x35\x03\x64\xd4\x02\x6b\x00\xbe\x41\xf6\xca\x64\x89\xaf\x30\xc4\xf2\x1e\x27\x53\x27\x11\xd7\xe7\xbc\x9c\x94\xd5\xc2\x5e\x11\x56\x99\x06\xd0\x30\x06\x16\xdd\x92\x85\xe7\xbc\x3f\xe1\xed\xa0\xee\x01\x3d\xde\xf1\x05\x4c\xa0\x16\x92\xfa\xde\xcb\x69\xcf\x8a\x85\x3f\x84\x0b\x62\xc9\xc5\xed\x0d\x16\x35\xd7\xe2\x21\xb3\xbd\x52\xa7\xdc\x56\x89\x36\xd0\xd1\x4f\x87\x39\xc4\x2c\x0d\x8a\x65\xd0\xce\x85\xfc\xb1\x72\x00\x98\xf6\x99\xe8\x01\x94\x72\x86\xef\xb7\x8a\x01\x79\x63\xe1\x25\xd0\x5b\x43\x62\x2d\x42\xd5", 0x0000600);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000600, 1092);
printf("467 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("468 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("469 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\xa0\x00\xa1\x08\xa2\x80\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x03\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("470 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x06\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("471 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000600, 1092);
printf("472 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x9a\x00\x9a\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("473 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x02\x0f", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("474 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("475 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("476 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("477 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x32\xfd\x28\xfe\x23\xa6\x4d\xf6\x00\x96\x21\xe4\x01\xe2\x32\xe3\x00\xe4\x00\x95\x27\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("478 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("479 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("480 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(50*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("481 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("482 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("483 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("484 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("485 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("486 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("487 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("488 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("489 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("490 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("491 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("492 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("493 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("494 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("495 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x7f\x0d\x44\x0d\x16\x0d\xef\x0c\xcd\x0c\xae\x0c\x92\x0c\x78\x0c\x5f\x0c\x48\x0c\x31\x0c\x1c\x0c\x08\x0c\xf4\x0b\xe1\x0b\xcf\x0b\xbd\x0b\xac\x0b\x9b\x0b\x8b\x0b\x7b\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x8a\x0b\xa9\x0b\xc8\x0b\xe6\x0b\x05\x0c\x24\x0c\x43\x0c\x61\x0c\x80\x0c\x9f\x0c\xbe\x0c\xdc\x0c\xfb\x0c\x1a\x0d\x38\x0d\x57\x0d\x76\x0d\x95\x0d\xb3\x0d\xd2\x0d\xf1\x0d\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x7f\x0d\x44\x0d\x16\x0d\xef\x0c\xcd\x0c\xae\x0c\x92\x0c\x78\x0c\x5f\x0c\x48\x0c\x31\x0c\x1c\x0c\x08\x0c\xf4\x0b\xe1\x0b\xcf\x0b\xbd\x0b\xac\x0b\x9b\x0b\x8b\x0b\x7b\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x8a\x0b\xa9\x0b\xc8\x0b\xe6\x0b\x05\x0c\x24\x0c\x43\x0c\x61\x0c\x80\x0c\x9f\x0c\xbe\x0c\xdc\x0c\xfb\x0c\x1a\x0d\x38\x0d\x57\x0d\x76\x0d\x95\x0d\xb3\x0d\xd2\x0d\xf1\x0d\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("496 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("497 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("498 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(18*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("499 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("500 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("501 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x9a\x00\x9a\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("502 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x01\x02\x0f\x04\x00\x06\x00\x08\x00\x0a\x00\x0c\x64\x0e\x64\x10\x64\x12\x64", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("503 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("504 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x55\x6f\x0e\x70\x50\x71\x55\x72\x0e\x73\xe8\x74\x57\x75\x0e\x76\xf0\x77\x57\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x2b\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("505 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x2d\x84\x0e\x85\x48\x86\x7f\x87\x0e\x88\x50\x89\x7f\x8a\x0e\x8b\xe8\x8c\x81\x8d\x0e\x8e\xf0\x8f\x81\x90\x0e\x9a\x00\x9b\x15\x9d\x01\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x2a\xa3\x0e\xa4\x00\xa5\x54\xa6\x0e\xa7\xff\xa8\x29\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("506 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\x53\xac\x0e\xad\xff\xae\x7d\xaf\x0e\xb0\x50\xb1\x01\xb9\x7f\xba\x0a\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x00\xf5\x05\xf6\x35\xf7\x01\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x2a", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("507 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("508 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("509 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("510 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x60\x00\x61\x00\x62\x00\x63\x00\x64\x00\x65\x00\x66\x00\x67\x00\x68\x00\x69\x00\x6a\x00\x6b\x00\x6c\x00\x6d\x00\x6e\x00\x6f\x00\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("511 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("512 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("513 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("514 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x58\x00\x5e\xff\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x00\x8e\x00\x90\x64\x91\x00\x94\x30\x95\xa7\x96\x23\x9b\x3d\x9d\x3f\x9e\x00\x9f\x40\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x41\xab\x00\xae\x85\xaf\x0e\xb0\x08\xb1\x07\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("515 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x2c\xe1\x01\xe2\x00\xe3\x00\xe4\x00\xe5\xc8\xe6\x00\xe7\x01\xe8\x00\xe9\x01\xea\x2c\xeb\x01\xec\x20\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("516 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x30\xef\x20\xf0\xee\xf1\x01\xf2\x00\xf3\x0c\xf5\x11\xf6\x00\xf7\x03\xf8\x02\xf9\xdd\xfa\x37\xfb\x0e\xfc\x00\xfd\x6c\xfe\x0b\xff\xfc", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("517 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(154*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("518 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\x96\x7d\x00\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("539 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x2c\x01\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("540 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000100, 1015);
printf("541 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("542 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x7c\x00\x7d\x40\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("543 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(12*1000);
memcpy(buf, "\x00\x80\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("544 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0008000, 2966);
printf("545 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(207*1000);
memcpy(buf, "\x7c\x30\x7d\x35\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("546 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(13*1000);
memcpy(buf, "\x60\x6a\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("547 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0006a40, 2632);
printf("548 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(190*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("549 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("550 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("551 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("552 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("553 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("554 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x01\xa0\x56\x02\x00\xf4\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("555 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x01\xa0\x3e\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("556 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x01\xa0\x18\x01\x40\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("557 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(29*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("558 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("559 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("560 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x9d\x3f\x79\x40", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("561 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xfc\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x04\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("562 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\x00\x04\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("563 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\x28\x23\x28\x23\x28\x23\x28\x23\x28\x23\x69\x21\xb0\x20\x22\x20\xab\x1f\x42\x1f\xe2\x1e\x8b\x1e\x39\x1e\xed\x1d\xa4\x1d\x5f\x1d\x1d\x1d\xde\x1c\xa2\x1c\x67\x1c\x2e\x1c\xf7\x1b\xc2\x1b\x8e\x1b\x5c\x1b\x2a\x1b\xfa\x1a\xcb\x1a\x9d\x1a\x70\x1a\x44\x1a\x18\x1a\xee\x19\xc4\x19\x9b\x19\x73\x19\x4b\x19\x24\x19\xfd\x18\xd7\x18\xb2\x18\x8d\x18\x68\x18\x44\x18\x21\x18\xfe\x17\xdb\x17\xb9\x17\x97\x17\x76\x17\x55\x17\x34\x17\x13\x17\xf3\x16\xd4\x16\xb4\x16\x95\x16\x76\x16\x58\x16\x3a\x16\x1c\x16\xfe\x15\xe1\x15\xc3\x15\xa6\x15\x8a\x15\x6d\x15\x51\x15\x35\x15\x19\x15\xfe\x14\xe2\x14\xc7\x14\xac\x14\x91\x14\x77\x14\x5c\x14\x42\x14\x28\x14\x0e\x14\xf5\x13\xdb\x13\xc2\x13\xa9\x13\x90\x13\x77\x13\x5e\x13\x45\x13\x2d\x13\x15\x13\xfd\x12\xe5\x12\xcd\x12\xb5\x12\x9d\x12\x86\x12\x6f\x12\x58\x12\x40\x12\x29\x12\x13\x12\xfc\x11\xe5\x11\xcf\x11\xb8\x11\xa2\x11\x8c\x11\x76\x11\x60\x11\x4a\x11\x35\x11\x1f\x11\x09\x11\xf4\x10\xdf\x10\xc9\x10\xb4\x10\x9f\x10\x8a\x10\x75\x10\x61\x10\x4c\x10\x37\x10\x23\x10\x0e\x10\xfa\x0f\xe6\x0f\xd2\x0f\xbe\x0f\xaa\x0f\x96\x0f\x82\x0f\x6e\x0f\x5a\x0f\x47\x0f\x33\x0f\x20\x0f\x0c\x0f\xf9\x0e\xe6\x0e\xd3\x0e\xc0\x0e\xad\x0e\x9a\x0e\x87\x0e\x74\x0e\x61\x0e\x4e\x0e\x3c\x0e\x29\x0e\x17\x0e\x04\x0e\xf2\x0d\xe0\x0d\xcd\x0d\xbb\x0d\xa9\x0d\x97\x0d\x85\x0d\x73\x0d\x61\x0d\x4f\x0d\x3e\x0d\x2c\x0d\x1a\x0d\x09\x0d\xf7\x0c\xe5\x0c\xd4\x0c\xc3\x0c\xb1\x0c\xa0\x0c\x8f\x0c\x7e\x0c\x6c\x0c\x5b\x0c\x4a\x0c\x39\x0c\x28\x0c\x17\x0c\x07\x0c\xf6\x0b\xe5\x0b\xd4\x0b\xc4\x0b\xb3\x0b\xa3\x0b\x92\x0b\x82\x0b\x71\x0b\x61\x0b\x50\x0b\x40\x0b\x30\x0b\x20\x0b\x0f\x0b\xff\x0a\xef\x0a\xdf\x0a\xcf\x0a\xbf\x0a\xaf\x0a\x9f\x0a\x90\x0a\x80\x0a\x70\x0a\x60\x0a\x51\x0a\x41\x0a\x31\x0a\x22\x0a\x12\x0a\x03\x0a\xf3\x09\xe4\x09\xd5\x09\xc5\x09\xb6\x09\xa7\x09\x97\x09\x88\x09\x79\x09\x6a\x09\x5b\x09\x4c\x09\x3d\x09\x2e\x09\x1f\x09\x10\x09\x01\x09\xf2\x08\xe3\x08\xd4\x08\xc6\x08\xb7\x08\xa8\x08\x9a\x08\x8b\x08\x7c\x08\x6e\x08\x5f\x08\x51\x08\x42\x08\x34\x08\x25\x08\x17\x08\x09\x08\xfa\x07\xec\x07\xde\x07\xd0\x07\xd0\x07\xd0\x07\xd0\x07\xd0\x07\xd0\x07\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000400);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000400, 1061);
printf("564 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("565 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("566 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\xa0\x00\xa1\xfc\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x02\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("567 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x04\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("568 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000400, 1061);
printf("569 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\xa0\x00\xa1\xfe\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x02\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("570 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(15*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("571 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\xd0\x07\xd0\x07\xd0\x07\xd0\x07\xd0\x07\x0e\x09\x4c\x0a\x8a\x0b\xc8\x0c\x06\x0e\x45\x0f\x83\x10\xc1\x11\xff\x12\x3d\x14\x7c\x15\xba\x16\xf8\x17\x36\x19\x74\x1a\xb2\x1b\xf1\x1c\x2f\x1e\x6d\x1f\xab\x20\xe9\x21\x28\x23\x28\x23\x28\x23\x28\x23\x28\x23\x28\x23\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x74\xb9\xf5\x77\x1d\x2e\xf9\x77\xff\xff\xff\xff\x74\xe4\x12\x00\x78\xe4\x12\x00\x00\x40\x00\x00\x00\x10\x72\x02\x00\x10\x72\x02\x00\x00\x15\x00\x00\x00\x72\x02\x6c\xe4\x12\x00\x91\x92\xf5\x77\x00\x00\x72\x02\x00\x10\x72\x02\x00\x70\x01\x00\x00\x00\x15\x00\x00\x10\x72\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x73\x02\x00\x00\x00\x00\xc0\x00\xb8\x02\x00\x00\x00\x00\x00\x00\x00\x00\x20\x0f\x72\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x3c\xe5\x12\x00\x7a\x8d\xf5\x77\xbe\x8e\xf5\x77\x08\x06\x15\x00\x37\x90\xf5\x77\x00\x00\x00\x00\x08\x00\x00\x00\x08\x10\x72\x02\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x84\xe4\x12\x00\x88\xe4\x12\x00\x80\xed\x12\x00\x80\xed\x12\x00\x09\x48\xe9\x77\x08\x32\xe8\x77\xff\xff\xff\xff\x15\x56\xe7\x77\x4a\xc8\x31\x05\xbc\x04\x00\x00\x0c\x20\x00\x80\xe8\xe4\x12\x00\x10\x00\x00\x00\x4b\xe5\x12\x00\x01\x00\x00\x00\xf8\xe4\x12\x00\x00\x00\x00\x00\x58\xe5\x12\x00\x14\x70\x36\x05\x07\x00\x00\x00\x00\x10\x72\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xbf\x02\x18\xe5\x12\x00\x72\xc5\x31\x05\xbc\x04\x00\x00\x00\x2e\x00\x00\x78\xea\x00\x00\x01\x00\x00\x00\x00\x10\x72\x02\x38\xe5\x01\x00\x00\x00\x01\x01\x00\x00\x15\x00\x80\xe4\x12\x00\x00\x00\x00\x00\x74\xe5\x12\x00\xf0\x88\xfa\x77\x88\x1c\xf5\x77\xff\xff\xff\xff\x37\x90\xf5\x77\x8b\x58\xe7\x77\x00\x00\x15\x00\x00\x00\x00\x00\x79\x58\xe7\x77\x00\x00\x00\x00\x08\x00\x00\x00\xea\x1b\xe6\x77\xea\x1b\xe6\x77\xc0\x6f\x31\x05\x00\x00\x00\x00", 0x0000200);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000200, 1030);
printf("572 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("573 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("574 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\xa0\x00\xa1\xfe\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("575 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("576 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("577 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\xa6\x41\xf6\x00\xe0\x00\xe1\x01\xe2\x58\xe3\x02\xe4\x00\xe5\x20\xf3\x02\xea\x00\xeb\x00\x95\x87\xfd\xd0\xfe\x07\x96\x21\xf4\x01", 0x0000020);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000020, 1000);
printf("578 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("579 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("580 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("581 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("582 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("583 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("584 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("585 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("586 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("587 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("588 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("589 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("590 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("591 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("592 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("593 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("594 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("595 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("596 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("597 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("598 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("599 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("600 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x95\xa7", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("601 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("602 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("603 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("604 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("605 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("606 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("607 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x00\x00\x86\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("608 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x01\xa0\x05\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("609 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("610 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("611 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("612 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("613 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("614 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("615 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("616 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("617 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x94\x31\x92\x57", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("618 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("619 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("620 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x82\x00\x83\x38\x84\x8e\x85\xe3", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("621 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("622 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30", 0x000002a);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000002a, 1000);
printf("623 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("624 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("625 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("626 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("627 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("628 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("629 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x21\xf4\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("630 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\xf3\xf3\xf3", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("631 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\xf3\xf3\xf3", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("632 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x02\xa0\x05\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("633 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("634 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("635 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("636 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("637 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("638 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("639 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\xf3\x32\xfd\x94\xfe\x11\xa6\x4d\xf6\x00\x96\x21\xe4\x01\xe2\x32\xe3\x00\xe4\x00\x95\xa7\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("640 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("641 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("642 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(53*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("643 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("644 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("645 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("646 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("647 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("648 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("649 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("650 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("651 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x96\x01\x96\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("652 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x9a\x00\x9a\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("653 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x01\x02\x0f\x04\x00\x06\x00\x08\x00\x0a\x00\x0c\x64\x0e\x64\x10\x64\x12\x64", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("654 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("655 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("656 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("657 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x03\x96\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("658 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("659 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(18*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("660 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("661 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("662 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("663 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("664 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("665 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("666 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x9a\x00\x9a\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("667 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x01\x02\x0f\x04\x00\x06\x00\x08\x00\x0a\x00\x0c\x64\x0e\x64\x10\x64\x12\x64", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("668 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("669 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x55\x6f\x0e\x70\x50\x71\x55\x72\x0e\x73\xe8\x74\x57\x75\x0e\x76\xf0\x77\x57\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x2b\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("670 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x2d\x84\x0e\x85\x48\x86\x7f\x87\x0e\x88\x50\x89\x7f\x8a\x0e\x8b\xe8\x8c\x81\x8d\x0e\x8e\xf0\x8f\x81\x90\x0e\x9a\x00\x9b\x15\x9d\x01\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x2a\xa3\x0e\xa4\x00\xa5\x54\xa6\x0e\xa7\xff\xa8\x29\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("671 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\x53\xac\x0e\xad\xff\xae\x7d\xaf\x0e\xb0\x50\xb1\x01\xb9\xff\xba\x14\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x00\xf5\x00\xf6\xfe\xf7\x14\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x2a", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("672 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("673 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("674 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("675 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x00\x61\x00\x62\x00\x63\x00\x64\x00\x65\x00\x66\x00\x67\x00\x68\x00\x69\x00\x6a\x00\x6b\x00\x6c\x00\x6d\x00\x6e\x00\x6f\x00\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("676 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("677 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("678 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("679 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x00\x8e\x00\x90\xa0\x91\x00\x94\x30\x95\xa7\x96\x03\x9b\x3d\x9d\x3f\x9e\x00\x9f\x80\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x40\xab\x00\xae\x48\xaf\x22\xb0\x08\xb1\x07\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("680 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x02\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x01\xe1\x00\xe2\x00\xe3\x00\xe4\x00\xe5\x01\xe6\x00\xe7\x00\xe8\x00\xe9\x00\xea\x2c\xeb\x01\xec\x01\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("681 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x01\xef\x01\xf0\x14\xf1\x00\xf2\x00\xf3\x0c\xf5\x12\xf6\x00\xf7\x00\xf8\x02\xf9\x03\xfa\x36\xfb\xfb\xfc\x00\xfd\x46\xfe\x22\xff\xfc", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("682 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(145*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("683 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\xbe\x7d\x7d\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("688 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\xfb\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("689 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fb40, 4859);
printf("690 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(88*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("691 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("692 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("693 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("694 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x96\x03\x96\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("695 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x9a\x00\x9a\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("696 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x01\x02\x0f\x04\x00\x06\x00\x08\x00\x0a\x00\x0c\xfa\x0e\xfa\x10\xfa\x12\xfa", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("697 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("698 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(21*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("699 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("700 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00", 0x0000006);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000006, 1000);
printf("701 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("702 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\xbe\x7d\x7d\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("707 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\xfb\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("708 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fb40, 4859);
printf("709 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(87*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("710 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(12*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("711 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(21*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("712 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("713 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x9a\x02\x9a\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("714 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x01\x02\x0f", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("715 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
memcpy(buf, "\x90\xa0\x91\xa0", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("716 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("717 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2001*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("718 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("719 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("720 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("721 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("722 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("723 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("724 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("725 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("726 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("727 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("728 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("729 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("730 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x01\xa0\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("731 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("732 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("733 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("734 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("735 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("736 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("737 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("738 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa0\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("739 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("740 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("741 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x55\x6f\x0e\x70\x50\x71\x55\x72\x0e\x73\xe8\x74\x57\x75\x0e\x76\xf0\x77\x57\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x2b\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("742 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x2d\x84\x0e\x85\x48\x86\x7f\x87\x0e\x88\x50\x89\x7f\x8a\x0e\x8b\xe8\x8c\x81\x8d\x0e\x8e\xf0\x8f\x81\x90\x0e\x9a\x00\x9b\x15\x9d\x01\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x2a\xa3\x0e\xa4\x00\xa5\x54\xa6\x0e\xa7\xff\xa8\x29\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("743 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\x53\xac\x0e\xad\xff\xae\x7d\xaf\x0e\xb0\x50\xb1\x01\xb9\xff\xba\x14\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x00\xf5\x00\xf6\xfe\xf7\x14\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x2a", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("744 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("745 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("746 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("747 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x00\x61\x00\x62\x00\x63\x00\x64\x00\x65\x00\x66\x00\x67\x00\x68\x00\x69\x00\x6a\x00\x6b\x00\x6c\x00\x6d\x00\x6e\x00\x6f\x00\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("748 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("749 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("750 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("751 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x00\x8e\x00\x90\xa0\x91\x00\x94\x30\x95\xa7\x96\x23\x9b\x3d\x9d\x3f\x9e\x00\x9f\x80\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x40\xab\x00\xae\x48\xaf\x22\xb0\x08\xb1\x07\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("752 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x02\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x01\xe1\x00\xe2\x00\xe3\x00\xe4\x00\xe5\x01\xe6\x00\xe7\x00\xe8\x00\xe9\x00\xea\x2c\xeb\x01\xec\x01\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("753 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x01\xef\x01\xf0\x14\xf1\x00\xf2\x00\xf3\x0c\xf5\x12\xf6\x00\xf7\x00\xf8\x02\xf9\x03\xfa\x36\xfb\xfb\xfc\x00\xfd\x46\xfe\x22\xff\xfc", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("754 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(150*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("755 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\xbe\x7d\x7d\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("760 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\xfb\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("761 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(43*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fb40, 4859);
printf("762 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(87*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("763 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("764 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("765 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("766 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("767 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2006*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("768 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("769 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("770 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00", 0x0000006);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000006, 1000);
printf("771 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("772 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\xbe\x7d\x7d\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("777 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\xfb\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("778 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(29*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fb40, 4859);
printf("779 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("780 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(12*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("781 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("782 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("783 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("784 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2006*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("785 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("786 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("787 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00", 0x0000006);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000006, 1000);
printf("788 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("789 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\xbe\x7d\x7d\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("798 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x7c\xfb\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("799 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fb40, 4859);
printf("800 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(86*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("801 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("802 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("803 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("804 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x90\x64\x91\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("805 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(1004*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("806 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2005*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("807 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("808 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("809 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("810 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("811 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("812 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("813 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("814 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("815 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("816 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("817 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("818 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("819 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x01\xa0\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("820 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("821 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("822 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("823 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("824 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("825 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("826 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("827 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa0\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("828 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("829 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("830 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x55\x6f\x0e\x70\x50\x71\x55\x72\x0e\x73\xe8\x74\x57\x75\x0e\x76\xf0\x77\x57\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x2b\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("831 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x2d\x84\x0e\x85\x48\x86\x7f\x87\x0e\x88\x50\x89\x7f\x8a\x0e\x8b\xe8\x8c\x81\x8d\x0e\x8e\xf0\x8f\x81\x90\x0e\x9a\x00\x9b\x15\x9d\x01\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x2a\xa3\x0e\xa4\x00\xa5\x54\xa6\x0e\xa7\xff\xa8\x29\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("832 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\x53\xac\x0e\xad\xff\xae\x7d\xaf\x0e\xb0\x50\xb1\x01\xb9\xff\xba\x14\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x00\xf5\x00\xf6\xfe\xf7\x14\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x2a", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("833 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("834 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("835 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("836 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x00\x61\x00\x62\x00\x63\x00\x64\x00\x65\x00\x66\x00\x67\x00\x68\x00\x69\x00\x6a\x00\x6b\x00\x6c\x00\x6d\x00\x6e\x00\x6f\x00\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("837 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("838 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("839 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("840 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x00\x8e\x00\x90\xa0\x91\x00\x94\x30\x95\xa7\x96\x23\x9b\x3d\x9d\x3f\x9e\x00\x9f\x80\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x40\xab\x00\xae\x48\xaf\x22\xb0\x08\xb1\x07\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("841 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x02\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x01\xe1\x00\xe2\x00\xe3\x00\xe4\x00\xe5\x01\xe6\x00\xe7\x00\xe8\x00\xe9\x00\xea\x2c\xeb\x01\xec\x01\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("842 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x01\xef\x01\xf0\x14\xf1\x00\xf2\x00\xf3\x0c\xf5\x12\xf6\x00\xf7\x00\xf8\x02\xf9\x03\xfa\x36\xfb\xfb\xfc\x00\xfd\x46\xfe\x22\xff\xfc", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("843 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(150*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("844 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\xbe\x7d\x7d\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("849 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\xfb\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("850 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fb40, 4859);
printf("851 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(87*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("852 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("853 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("854 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("855 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("856 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2007*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("857 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("858 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("859 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00", 0x0000006);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000006, 1000);
printf("860 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("861 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\xbe\x7d\x7d\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("866 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\xfb\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("867 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(29*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fb40, 4859);
printf("868 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(88*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("869 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("870 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("871 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("872 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("873 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2006*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("874 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("875 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("876 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00", 0x0000006);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000006, 1000);
printf("877 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("878 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\xbe\x7d\x7d\x7e\x00\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("887 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\xfb\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("888 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fb40, 4859);
printf("889 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("890 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("891 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("892 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("893 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("894 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(704*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("895 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("896 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("897 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("898 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("899 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("900 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x46\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("901 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("902 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("903 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("904 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("905 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("906 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("907 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x01\xa0\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("908 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("909 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("910 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("911 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("912 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("913 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("914 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("915 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa0\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("916 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("917 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("918 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x55\x6f\x0e\x70\x50\x71\x55\x72\x0e\x73\xe8\x74\x57\x75\x0e\x76\xf0\x77\x57\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x2b\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("919 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x2d\x84\x0e\x85\x48\x86\x7f\x87\x0e\x88\x50\x89\x7f\x8a\x0e\x8b\xe8\x8c\x81\x8d\x0e\x8e\xf0\x8f\x81\x90\x0e\x9a\x00\x9b\x15\x9d\x01\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x2a\xa3\x0e\xa4\x00\xa5\x54\xa6\x0e\xa7\xff\xa8\x29\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("920 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\x53\xac\x0e\xad\xff\xae\x7d\xaf\x0e\xb0\x50\xb1\x01\xb9\xff\xba\x14\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x00\xf5\x00\xf6\xfe\xf7\x14\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x2a", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("921 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("922 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("923 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("924 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x00\x61\x00\x62\x00\x63\x00\x64\x00\x65\x00\x66\x00\x67\x00\x68\x00\x69\x00\x6a\x00\x6b\x00\x6c\x00\x6d\x00\x6e\x00\x6f\x00\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("925 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("926 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("927 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("928 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x00\x8e\x00\x90\x64\x91\x00\x94\x30\x95\xa7\x96\x23\x9b\x3d\x9d\x3f\x9e\x00\x9f\x80\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x41\xab\x00\xae\x08\xaf\x00\xb0\x08\xb1\x07\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("929 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x02\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x2c\xe1\x01\xe2\x00\xe3\x00\xe4\x00\xe5\xc8\xe6\x00\xe7\x00\xe8\x00\xe9\x00\xea\x2c\xeb\x01\xec\x08\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("930 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x18\xef\x08\xf0\x6a\xf1\x00\xf2\x00\xf3\x0c\xf5\x12\xf6\x00\xf7\x00\xf8\x02\xf9\x03\xfa\x36\xfb\xfb\xfc\x00\xfd\x46\xfe\x22\xff\xfc", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("931 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(150*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("932 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\x00\x7d\x00\x7e\x04\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("961 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x00\x00\x08\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("962 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("963 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("964 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("965 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("966 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("967 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("968 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("969 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("970 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(91*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0002000, 1491);
printf("971 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\x01\x7d\x9d\x7e\x03\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("972 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(8*1000);
memcpy(buf, "\x02\x3a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("973 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("974 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("975 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("976 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("977 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("978 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("979 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("980 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0005600, 2320);
printf("981 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(25*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("982 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("983 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("984 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("985 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("986 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("987 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("988 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("989 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("990 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("991 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("992 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("993 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("994 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x21\xfd\xb8\xfe\x0b\xa6\x41\xf6\x00\xea\x00\xeb\xf0\xe2\x4c\xe3\x00\xe4\x00\xe0\x00\xe1\x00\xe5\x00\x96\x21\xf4\x01", 0x000001e);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000001e, 1000);
printf("995 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("996 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("997 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(49*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("998 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("999 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1000 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1001 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1002 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1003 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1004 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1005 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1006 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1007 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1008 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1009 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(57*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1010 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1011 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1012 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1013 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("1014 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(18*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("1015 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\xea\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("1016 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("1017 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("1018 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(18*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("1019 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1020 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("1021 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1022 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x01\xa0\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1023 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1024 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1025 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1026 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1027 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1028 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1029 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1030 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa0\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1031 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1032 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1033 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x55\x6f\x0e\x70\x50\x71\x55\x72\x0e\x73\xe8\x74\x57\x75\x0e\x76\xf0\x77\x57\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x2b\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1034 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x2d\x84\x0e\x85\x48\x86\x7f\x87\x0e\x88\x50\x89\x7f\x8a\x0e\x8b\xe8\x8c\x81\x8d\x0e\x8e\xf0\x8f\x81\x90\x0e\x9a\x00\x9b\x15\x9d\x01\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x2a\xa3\x0e\xa4\x00\xa5\x54\xa6\x0e\xa7\xff\xa8\x29\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1035 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\x53\xac\x0e\xad\xff\xae\x7d\xaf\x0e\xb0\x50\xb1\x01\xb9\xff\xba\x14\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x00\xf5\x00\xf6\xfe\xf7\x14\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x2a", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1036 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1037 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1038 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1039 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x00\x61\x00\x62\x00\x63\x00\x64\x00\x65\x00\x66\x00\x67\x00\x68\x00\x69\x00\x6a\x00\x6b\x00\x6c\x00\x6d\x00\x6e\x00\x6f\x00\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1040 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1041 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("1042 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1043 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x00\x8e\x00\x90\x64\x91\x00\x94\x30\x95\xa7\x96\x23\x9b\x3d\x9d\x3f\x9e\x00\x9f\x80\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x41\xab\x00\xae\x08\xaf\x00\xb0\x10\xb1\x0e\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1044 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x02\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x2c\xe1\x01\xe2\x00\xe3\x00\xe4\x00\xe5\xc8\xe6\x00\xe7\x00\xe8\x00\xe9\x00\xea\x2c\xeb\x01\xec\x08\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1045 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x18\xef\x08\xf0\xa6\xf1\x00\xf2\x00\xf3\x0c\xf5\x12\xf6\x00\xf7\x00\xf8\x02\xf9\x03\xfa\x36\xfb\xfb\xfc\x00\xfd\xea\xfe\x41\xff\xfc", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("1046 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(150*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1047 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\x00\x7d\x00\x7e\x04\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("1096 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x08\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1097 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1098 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1099 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1100 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(144*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1101 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1102 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1103 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1104 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1105 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0002000, 1491);
printf("1106 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x08\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1107 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1108 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1109 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1110 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1111 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1112 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1113 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1114 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1115 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0002000, 1491);
printf("1116 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x08\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1117 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(26*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1118 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1119 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1120 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1121 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1122 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1123 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1124 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1125 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0002000, 1491);
printf("1126 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x7c\x23\x7d\xfb\x7e\x02\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("1127 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x46\xf6\x05\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1128 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1129 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(124*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1130 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1131 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1132 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1133 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1134 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(89*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000e40, 1218);
printf("1135 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("1136 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(11*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1137 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1138 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1139 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x23\x96\x23", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1140 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(207*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1141 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1142 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1143 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x22\xfd\x94\xfe\x11\xa6\x41\xf6\x00\x96\x21\xe4\x01\xe2\x40\xe3\x1f\xe4\x00\x95\xa7\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("1144 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1145 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1146 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1147 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1148 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1149 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1150 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1151 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1152 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1153 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1154 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1155 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1156 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1157 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1158 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1159 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1160 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1161 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1162 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(46*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1163 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1164 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1165 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1166 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1167 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1168 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1169 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1170 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1171 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(51*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1172 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1173 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1174 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x32\xfd\x94\xfe\x11\xa6\x4d\xf6\x00\x96\x21\xe4\x01\xe2\x32\xe3\x00\xe4\x00\x95\xa7\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("1175 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1176 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1177 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(50*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1178 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1179 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1180 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1181 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1182 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1183 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1184 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1185 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1186 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(62*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x80\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x06\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("1187 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(18*1000);
memcpy(buf, "\x00\x06\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("1188 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\xff\x03\xff\x07\xff\x0b\xff\x0f\xff\x13\xff\x17\xff\x1b\xff\x1f\xff\x23\xff\x27\xff\x2b\xff\x2f\xff\x33\xff\x37\xff\x3b\xff\x3f\xff\x43\xff\x47\xfe\x4b\x47\x4f\x32\x51\x0f\x53\xe0\x54\xa6\x56\x60\x58\x10\x5a\xb7\x5b\x54\x5d\xe9\x5e\x76\x60\xfb\x61\x79\x63\xf0\x64\x61\x66\xcb\x67\x30\x69\x8e\x6a\xe7\x6b\x3b\x6d\x8a\x6e\xd4\x6f\x19\x71\x5a\x72\x96\x73\xce\x74\x03\x76\x33\x77\x60\x78\x89\x79\xae\x7a\xd0\x7b\xef\x7c\x0b\x7e\x23\x7f\x38\x80\x4b\x81\x5b\x82\x68\x83\x72\x84\x79\x85\x7f\x86\x81\x87\x81\x88\x7f\x89\x7a\x8a\x74\x8b\x6b\x8c\x60\x8d\x52\x8e\x43\x8f\x32\x90\x1f\x91\x0a\x92\xf3\x92\xda\x93\xbf\x94\xa3\x95\x85\x96\x65\x97\x44\x98\x21\x99\xfc\x99\xd6\x9a\xae\x9b\x85\x9c\x5b\x9d\x2f\x9e\x01\x9f\xd2\x9f\xa2\xa0\x70\xa1\x3d\xa2\x09\xa3\xd4\xa3\x9d\xa4\x65\xa5\x2c\xa6\xf1\xa6\xb6\xa7\x79\xa8\x3b\xa9\xfc\xa9\xbc\xaa\x7b\xab\x39\xac\xf6\xac\xb1\xad\x6c\xae\x26\xaf\xde\xaf\x96\xb0\x4d\xb1\x03\xb2\xb7\xb2\x6b\xb3\x1e\xb4\xd1\xb4\x82\xb5\x32\xb6\xe2\xb6\x90\xb7\x3e\xb8\xeb\xb8\x97\xb9\x43\xba\xed\xba\x97\xbb\x40\xbc\xe8\xbc\x90\xbd\x36\xbe\xdc\xbe\x82\xbf\x26\xc0\xca\xc0\x6d\xc1\x0f\xc2\xb1\xc2\x52\xc3\xf3\xc3\x92\xc4\x31\xc5\xd0\xc5\x6d\xc6\x0a\xc7\xa7\xc7\x43\xc8\xde\xc8\x79\xc9\x13\xca\xac\xca\x45\xcb\xdd\xcb\x75\xcc\x0c\xcd\xa2\xcd\x38\xce\xce\xce\x62\xcf\xf7\xcf\x8b\xd0\x1e\xd1\xb0\xd1\x43\xd2\xd4\xd2\x65\xd3\xf6\xd3\x86\xd4\x16\xd5\xa5\xd5\x34\xd6\xc2\xd6\x4f\xd7\xdd\xd7\x69\xd8\xf6\xd8\x81\xd9\x0d\xda\x98\xda\x22\xdb\xac\xdb\x36\xdc\xbf\xdc\x47\xdd\xcf\xdd\x57\xde\xdf\xde\x66\xdf\xec\xdf\x72\xe0\xf8\xe0\x7d\xe1\x02\xe2\x87\xe2\x0b\xe3\x8e\xe3\x12\xe4\x95\xe4\x17\xe5\x99\xe5\x1b\xe6\x9d\xe6\x1e\xe7\x9e\xe7\x1e\xe8\x9e\xe8\x1e\xe9\x9d\xe9\x1c\xea\x9a\xea\x19\xeb\x96\xeb\x14\xec\x91\xec\x0e\xed\x8a\xed\x06\xee\x82\xee\xfd\xee\x79\xef\xf3\xef\x6e\xf0\xe8\xf0\x62\xf1\xdb\xf1\x54\xf2\xcd\xf2\x46\xf3\xbe\xf3\x36\xf4\xae\xf4\x25\xf5\x9c\xf5\x13\xf6\x89\xf6\xff\xf6\x75\xf7\xeb\xf7\x60\xf8\xd5\xf8\x4a\xf9\xbe\xf9\x32\xfa\xa6\xfa\x1a\xfb\x8d\xfb\x00\xfc\x73\xfc\xe5\xfc\x58\xfd\xca\xfd\x3b\xfe\xad\xfe\x1e\xff\x8f\xff\x00\x00\xff\x03\xff\x07\xff\x0b\xff\x0f\xff\x13\xff\x17\xff\x1b\xff\x1f\xff\x23\xff\x27\xff\x2b\xff\x2f\xff\x33\xff\x37\xff\x3b\xff\x3f\xff\x43\xff\x47\xfe\x4b\x47\x4f\x32\x51\x0f\x53\xe0\x54\xa6\x56\x60\x58\x10\x5a\xb7\x5b\x54\x5d\xe9\x5e\x76\x60\xfb\x61\x79\x63\xf0\x64\x61\x66\xcb\x67\x30\x69\x8e\x6a\xe7\x6b\x3b\x6d\x8a\x6e\xd4\x6f\x19\x71\x5a\x72\x96\x73\xce\x74\x03\x76\x33\x77\x60\x78\x89\x79\xae\x7a\xd0\x7b\xef\x7c\x0b\x7e\x23\x7f\x38\x80\x4b\x81\x5b\x82\x68\x83\x72\x84\x79\x85\x7f\x86\x81\x87\x81\x88\x7f\x89\x7a\x8a\x74\x8b\x6b\x8c\x60\x8d\x52\x8e\x43\x8f\x32\x90\x1f\x91\x0a\x92\xf3\x92\xda\x93\xbf\x94\xa3\x95\x85\x96\x65\x97\x44\x98\x21\x99\xfc\x99\xd6\x9a\xae\x9b\x85\x9c\x5b\x9d\x2f\x9e\x01\x9f\xd2\x9f\xa2\xa0\x70\xa1\x3d\xa2\x09\xa3\xd4\xa3\x9d\xa4\x65\xa5\x2c\xa6\xf1\xa6\xb6\xa7\x79\xa8\x3b\xa9\xfc\xa9\xbc\xaa\x7b\xab\x39\xac\xf6\xac\xb1\xad\x6c\xae\x26\xaf\xde\xaf\x96\xb0\x4d\xb1\x03\xb2\xb7\xb2\x6b\xb3\x1e\xb4\xd1\xb4\x82\xb5\x32\xb6\xe2\xb6\x90\xb7\x3e\xb8\xeb\xb8\x97\xb9\x43\xba\xed\xba\x97\xbb\x40\xbc\xe8\xbc\x90\xbd\x36\xbe\xdc\xbe\x82\xbf\x26\xc0\xca\xc0\x6d\xc1\x0f\xc2\xb1\xc2\x52\xc3\xf3\xc3\x92\xc4\x31\xc5\xd0\xc5\x6d\xc6\x0a\xc7\xa7\xc7\x43\xc8\xde\xc8\x79\xc9\x13\xca\xac\xca\x45\xcb\xdd\xcb\x75\xcc\x0c\xcd\xa2\xcd\x38\xce\xce\xce\x62\xcf\xf7\xcf\x8b\xd0\x1e\xd1\xb0\xd1\x43\xd2\xd4\xd2\x65\xd3\xf6\xd3\x86\xd4\x16\xd5\xa5\xd5\x34\xd6\xc2\xd6\x4f\xd7\xdd\xd7\x69\xd8\xf6\xd8\x81\xd9\x0d\xda\x98\xda\x22\xdb\xac\xdb\x36\xdc\xbf\xdc\x47\xdd\xcf\xdd\x57\xde\xdf\xde\x66\xdf\xec\xdf\x72\xe0\xf8\xe0\x7d\xe1\x02\xe2\x87\xe2\x0b\xe3\x8e\xe3\x12\xe4\x95\xe4\x17\xe5\x99\xe5\x1b\xe6\x9d\xe6\x1e\xe7\x9e\xe7\x1e\xe8\x9e\xe8\x1e\xe9\x9d\xe9\x1c\xea\x9a\xea\x19\xeb\x96\xeb\x14\xec\x91\xec\x0e\xed\x8a\xed\x06\xee\x82\xee\xfd\xee\x79\xef\xf3\xef\x6e\xf0\xe8\xf0\x62\xf1\xdb\xf1\x54\xf2\xcd\xf2\x46\xf3\xbe\xf3\x36\xf4\xae\xf4\x25\xf5\x9c\xf5\x13\xf6\x89\xf6\xff\xf6\x75\xf7\xeb\xf7\x60\xf8\xd5\xf8\x4a\xf9\xbe\xf9\x32\xfa\xa6\xfa\x1a\xfb\x8d\xfb\x00\xfc\x73\xfc\xe5\xfc\x58\xfd\xca\xfd\x3b\xfe\xad\xfe\x1e\xff\x8f\xff\x00\x00\xff\x03\xff\x07\xff\x0b\xff\x0f\xff\x13\xff\x17\xff\x1b\xff\x1f\xff\x23\xff\x27\xff\x2b\xff\x2f\xff\x33\xff\x37\xff\x3b\xff\x3f\xff\x43\xff\x47\xfe\x4b\x47\x4f\x32\x51\x0f\x53\xe0\x54\xa6\x56\x60\x58\x10\x5a\xb7\x5b\x54\x5d\xe9\x5e\x76\x60\xfb\x61\x79\x63\xf0\x64\x61\x66\xcb\x67\x30\x69\x8e\x6a\xe7\x6b\x3b\x6d\x8a\x6e\xd4\x6f\x19\x71\x5a\x72\x96\x73\xce\x74\x03\x76\x33\x77\x60\x78\x89\x79\xae\x7a\xd0\x7b\xef\x7c\x0b\x7e\x23\x7f\x38\x80\x4b\x81\x5b\x82\x68\x83\x72\x84\x79\x85\x7f\x86\x81\x87\x81\x88\x7f\x89\x7a\x8a\x74\x8b\x6b\x8c\x60\x8d\x52\x8e\x43\x8f\x32\x90\x1f\x91\x0a\x92\xf3\x92\xda\x93\xbf\x94\xa3\x95\x85\x96\x65\x97\x44\x98\x21\x99\xfc\x99\xd6\x9a\xae\x9b\x85\x9c\x5b\x9d\x2f\x9e\x01\x9f\xd2\x9f\xa2\xa0\x70\xa1\x3d\xa2\x09\xa3\xd4\xa3\x9d\xa4\x65\xa5\x2c\xa6\xf1\xa6\xb6\xa7\x79\xa8\x3b\xa9\xfc\xa9\xbc\xaa\x7b\xab\x39\xac\xf6\xac\xb1\xad\x6c\xae\x26\xaf\xde\xaf\x96\xb0\x4d\xb1\x03\xb2\xb7\xb2\x6b\xb3\x1e\xb4\xd1\xb4\x82\xb5\x32\xb6\xe2\xb6\x90\xb7\x3e\xb8\xeb\xb8\x97\xb9\x43\xba\xed\xba\x97\xbb\x40\xbc\xe8\xbc\x90\xbd\x36\xbe\xdc\xbe\x82\xbf\x26\xc0\xca\xc0\x6d\xc1\x0f\xc2\xb1\xc2\x52\xc3\xf3\xc3\x92\xc4\x31\xc5\xd0\xc5\x6d\xc6\x0a\xc7\xa7\xc7\x43\xc8\xde\xc8\x79\xc9\x13\xca\xac\xca\x45\xcb\xdd\xcb\x75\xcc\x0c\xcd\xa2\xcd\x38\xce\xce\xce\x62\xcf\xf7\xcf\x8b\xd0\x1e\xd1\xb0\xd1\x43\xd2\xd4\xd2\x65\xd3\xf6\xd3\x86\xd4\x16\xd5\xa5\xd5\x34\xd6\xc2\xd6\x4f\xd7\xdd\xd7\x69\xd8\xf6\xd8\x81\xd9\x0d\xda\x98\xda\x22\xdb\xac\xdb\x36\xdc\xbf\xdc\x47\xdd\xcf\xdd\x57\xde\xdf\xde\x66\xdf\xec\xdf\x72\xe0\xf8\xe0\x7d\xe1\x02\xe2\x87\xe2\x0b\xe3\x8e\xe3\x12\xe4\x95\xe4\x17\xe5\x99\xe5\x1b\xe6\x9d\xe6\x1e\xe7\x9e\xe7\x1e\xe8\x9e\xe8\x1e\xe9\x9d\xe9\x1c\xea\x9a\xea\x19\xeb\x96\xeb\x14\xec\x91\xec\x0e\xed\x8a\xed\x06\xee\x82\xee\xfd\xee\x79\xef\xf3\xef\x6e\xf0\xe8\xf0\x62\xf1\xdb\xf1\x54\xf2\xcd\xf2\x46\xf3\xbe\xf3\x36\xf4\xae\xf4\x25\xf5\x9c\xf5\x13\xf6\x89\xf6\xff\xf6\x75\xf7\xeb\xf7\x60\xf8\xd5\xf8\x4a\xf9\xbe\xf9\x32\xfa\xa6\xfa\x1a\xfb\x8d\xfb\x00\xfc\x73\xfc\xe5\xfc\x58\xfd\xca\xfd\x3b\xfe\xad\xfe\x1e\xff\x8f\xff", 0x0000600);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000600, 1092);
printf("1189 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("1190 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("1191 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(16*1000);
memcpy(buf, "\xa0\x00\xa1\x08\xa2\x80\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x06\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("1192 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x00\x06\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("1193 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x47\x10\x8b\x21\x6b\x32\x18\x43\xda\x52\x9c\x62\x5d\x72\x10\x82\x4f\x91\x8f\xa0\xce\xaf\x0e\xbf\x4d\xce\x39\xde\x91\xf7\x00\x00\x3f\x10\x09\x22\xd8\x32\x78\x43\x5d\x53\x43\x63\x28\x73\xfa\x82\x6b\x92\xdc\xa1\x4d\xb1\xbe\xc0\x2f\xd0\xf0\xdf\xfb\xf7\x00\x00\x0a\x10\x03\x22\x02\x33\xc4\x43\xa5\x53\x87\x63\x68\x73\x32\x83\x96\x92\xfa\xa1\x5e\xb1\xc2\xc0\x26\xd0\xe4\xdf\xf8\xf7\x00\x00\xf0\x0f\xe9\x21\xe4\x32\x9d\x43\x5b\x53\x19\x63\xd7\x72\x8d\x82\x17\x92\xa2\xa1\x2c\xb1\xb6\xc0\x40\xd0\x08\xe0\x01\xf8\x00\x00\xd3\x0f\xe8\x21\xd8\x32\x8a\x43\x46\x53\x03\x63\xc0\x72\x74\x82\xed\x91\x66\xa1\xe0\xb0\x59\xc0\xd2\xcf\xa7\xdf\xea\xf7\x00\x00\xbb\x0f\xb8\x21\x94\x32\x34\x43\xd1\x52\x6f\x62\x0c\x72\xab\x81\x5a\x91\x08\xa1\xb7\xb0\x66\xc0\x14\xd0\xf2\xdf\xfc\xf7\x00\x00\xad\x0f\xc0\x21\x96\x32\x32\x43\xd3\x52\x73\x62\x14\x72\xb3\x81\x3d\x91\xc7\xa0\x51\xb0\xdb\xbf\x65\xcf\x53\xdf\xd5\xf7\x00\x00\x85\x0f\x49\x21\x2a\x32\xd8\x42\x83\x52\x2d\x62\xd7\x71\x84\x81\x47\x91\x0b\xa1\xce\xb0\x92\xc0\x55\xd0\x2d\xe0\x0a\xf8\x00\x00\x7d\x0f\x39\x21\x21\x32\xd5\x42\x77\x52\x19\x62\xbb\x71\x5b\x81\xdc\x90\x5d\xa0\xde\xaf\x5f\xbf\xe0\xce\xde\xde\xb9\xf7\x00\x00\x7d\x0f\x2c\x21\x42\x32\x13\x43\xac\x52\x45\x62\xde\x71\x79\x81\x26\x91\xd2\xa0\x7f\xb0\x2c\xc0\xd8\xcf\xc1\xdf\xf0\xf7\x00\x00\x7d\x0f\x1f\x21\x35\x32\x07\x43\x95\x52\x23\x62\xb1\x71\x3d\x81\xb2\x90\x28\xa0\x9d\xaf\x12\xbf\x88\xce\x8a\xde\xa5\xf7\x00\x00\x68\x0f\x07\x21\x24\x32\xfd\x42\x8a\x52\x17\x62\xa4\x71\x32\x81\xd6\x90\x79\xa0\x1d\xb0\xc1\xbf\x64\xcf\x5e\xdf\xd8\xf7\x00\x00\x67\x0f\x21\x21\x58\x32\x44\x43\xf3\x52\xa1\x62\x50\x72\xfa\x81\x80\x91\x06\xa1\x8c\xb0\x12\xc0\x98\xcf\x7c\xdf\xdf\xf7\x00\x00\x67\x0f\x8b\x21\x78\x32\x26\x43\xbd\x52\x55\x62\xec\x71\x84\x81\x24\x91\xc4\xa0\x64\xb0\x04\xc0\xa4\xcf\x91\xdf\xe4\xf7\x00\x00\xe3\x0f\xbb\x21\xbf\x32\x78\x43\x07\x53\x97\x62\x27\x72\xb7\x81\x4a\x91\xdd\xa0\x70\xb0\x03\xc0\x96\xcf\x80\xdf\xe0\xf7\x00\x00\xda\x0f\x67\x21\x41\x32\xda\x42\x30\x52\x87\x61\xdd\x70\x33\x80\xdf\x8f\x8b\x9f\x37\xaf\xe3\xbe\x8f\xce\xad\xde\xad\xf7\x00\x00\xed\x0f\x56\x21\x1f\x32\xba\x42\x57\x52\xf4\x61\x92\x71\x2c\x81\x94\x90\xfc\x9f\x65\xaf\xcd\xbe\x36\xce\x3a\xde\x91\xf7\x00\x00\xe7\x0f\x8e\x21\x7f\x32\x33\x43\xdd\x52\x87\x62\x30\x72\xda\x81\x81\x91\x29\xa1\xd1\xb0\x79\xc0\x21\xd0\xfa\xdf\xfe\xf7\x00\x00\xb0\x0f\x88\x21\x97\x32\x60\x43\x08\x53\xaf\x62\x57\x72\xfe\x81\x9e\x91\x3d\xa1\xdd\xb0\x7c\xc0\x1c\xd0\xf3\xdf\xfc\xf7\x00\x00\xa5\x0f\x6d\x21\x97\x32\x6d\x43\xfb\x52\x89\x62\x17\x72\xa9\x81\x60\x91\x18\xa1\xcf\xb0\x87\xc0\x3e\xd0\x17\xe0\x05\xf8\x00\x00\x58\x0f\x4b\x21\x5b\x32\x24\x43\xaf\x52\x3a\x62\xc5\x71\x4e\x81\xc6\x90\x3d\xa0\xb5\xaf\x2c\xbf\xa4\xce\xa4\xde\xab\xf7\x00\x00\x4a\x0f\x1a\x21\x19\x32\xda\x42\x5c\x52\xde\x61\x60\x71\xe3\x80\x7e\x90\x19\xa0\xb4\xaf\x4e\xbf\xe9\xce\xf2\xde\xbe\xf7\x00\x00\x36\x0f\x1f\x21\x17\x32\xd1\x42\x50\x52\xcf\x61\x4e\x71\xcd\x80\x44\x90\xbb\x9f\x33\xaf\xaa\xbe\x21\xce\x2f\xde\x8f\xf7\x00\x00\x1e\x0f\x0e\x21\xfc\x31\xb3\x42\x37\x52\xba\x61\x3d\x71\xc2\x80\x7e\x90\x3a\xa0\xf5\xaf\xb1\xbf\x6d\xcf\x6f\xdf\xdc\xf7\x00\x00\x1b\x0f\x03\x21\xc5\x31\x5e\x42\xf4\x51\x89\x61\x1f\x71\xb4\x80\x41\x90\xcd\x9f\x59\xaf\xe5\xbe\x72\xce\x83\xde\xa3\xf7\x00\x00\x23\x0f\x1b\x21\x01\x32\xb7\x42\x65\x52\x13\x62\xc0\x71\x70\x81\x33\x91\xf7\xa0\xba\xb0\x7d\xc0\x41\xd0\x1d\xe0\x06\xf8\x00\x00\x24\x0f\x10\x21\x03\x32\xc6\x42\x82\x52\x3d\x62\xf9\x71\xb0\x81\x36\x91\xbd\xa0\x43\xb0\xc9\xbf\x4f\xcf\x3f\xdf\xd0\xf7\x00\x00\x11\x0f\x0d\x21\x2d\x32\x0d\x43\xc2\x52\x77\x62\x2c\x72\xe1\x81\x9d\x91\x59\xa1\x15\xb1\xd1\xc0\x8d\xd0\x56\xe0\x14\xf8\x00\x00\x07\x0f\xff\x20\x23\x32\x09\x43\xc7\x52\x85\x62\x43\x72\xfd\x81\x92\x91\x27\xa1\xbd\xb0\x52\xc0\xe7\xcf\xc4\xdf\xf1\xf7\x00\x00\x0d\x0f\x3f\x21\x50\x32\x23\x43\xe1\x52\x9f\x62\x5d\x72\x1b\x82\xdf\x91\xa2\xa1\x66\xb1\x29\xc1\xed\xd0\xa3\xe0\x26\xf8\x00\x00\x32\x0f\x6c\x21\x78\x32\x4b\x43\x27\x53\x03\x63\xdf\x72\xae\x82\x34\x92\xba\xa1\x40\xb1\xc7\xc0\x4d\xd0\x10\xe0\x03\xf8\x00\x00\x3a\x0f\x4a\x21\x34\x32\xea\x42\x9a\x52\x4b\x62\xfb\x71\xa9\x81\x3c\x91\xd0\xa0\x64\xb0\xf7\xbf\x8b\xcf\x77\xdf\xde\xf7\x00\x00\x79\x0f\x8f\x20\x31\x31\xb5\x41\x0b\x51\x61\x60\xb6\x6f\x0c\x7f\xe6\x8e\xcc\x9e\xb2\xae\x98\xbe\x7e\xce\xb9\xde\xb0\xf7\x00\x00\x79\x0f\xab\x20\x5b\x31\xe6\x41\x37\x51\x88\x60\xd9\x6f\x2a\x7f\x44\x8f\x6d\x9f\x96\xaf\xc0\xbf\xe9\xcf\xfd\xdf\xfe\xf7\x00\x00\x68\x0f\xbc\x20\x87\x31\x27\x42\x8b\x51\xee\x60\x52\x70\xb6\x7f\xbc\x8f\xc9\x9f\xd5\xaf\xe2\xbf\xee\xcf\xf7\xdf\xfd\xf7\x00\x00\x51\x0f\x95\x20\x5e\x31\xfd\x41\x40\x51\x83\x60\xc7\x6f\x0a\x7f\x2a\x8f\x5f\x9f\x93\xaf\xc8\xbf\xfc\xcf\x10\xe0\x03\xf8\x00\x00\x4c\x0f\xb0\x20\x72\x31\x09\x42\x50\x51\x96\x60\xdd\x6f\x23\x7f\x22\x8f\x2f\x9f\x3c\xaf\x49\xbf\x57\xcf\x7e\xdf\xe0\xf7\x00\x00\x3a\x0f\x7f\x20\x34\x31\xc3\x41\xf4\x50\x24\x60\x54\x6f\x85\x7e\xb9\x8e\x10\x9f\x67\xaf\xbe\xbf\x15\xd0\x2f\xe0\x0a\xf8\x00\x00\x60\x0f\x09\x21\x74\x31\xbf\x41\xe3\x50\x07\x60\x2b\x6f\x4f\x7e\x57\x8e\x82\x9e\xac\xae\xd7\xbe\x01\xcf\x45\xdf\xd2\xf7\x00\x00\x3c\x0f\x8e\x20\x00\x31\x5b\x41\x91\x50\xc7\x5f\xfd\x6e\x32\x7e\x75\x8e\xe3\x9e\x52\xaf\xc0\xbf\x2e\xd0\x49\xe0\x11\xf8\x00\x00\x40\x0f\xad\x20\x0e\x31\x5b\x41\x89\x50\xb8\x5f\xe6\x6e\x15\x7e\x29\x8e\x63\x9e\x9e\xae\xd9\xbe\x14\xcf\x5b\xdf\xd7\xf7\x00\x00\x2b\x0f\x97\x20\x1e\x31\x89\x41\xb0\x50\xd8\x5f\xff\x6e\x27\x7e\x66\x8e\xd3\x9e\x40\xaf\xad\xbf\x1a\xd0\x3a\xe0\x0d\xf8\x00\x00\x2f\x0f\x7f\x20\xfe\x30\x61\x41\x63\x50\x66\x5f\x68\x6e\x6a\x7d\x3e\x8d\x43\x9d\x49\xad\x4e\xbd\x54\xcd\xc5\xdd\x75\xf7\x00\x00\xe0\x0e\x6c\x20\xea\x30\x4e\x41\x5b\x50\x67\x5f\x74\x6e\x81\x7d\x82\x8d\xbb\x9d\xf5\xad\x2e\xbe\x67\xce\xce\xde\xb5\xf7\x00\x00\xee\x0e\x90\x20\x34\x31\xb2\x41\xbc\x50\xc6\x5f\xd1\x6e\xdb\x7d\xe9\x8d\x2a\x9e\x6a\xae\xaa\xbe\xeb\xce\x3c\xdf\xd0\xf7\x00\x00\xc7\x0e\xdf\x20\x42\x31\x87\x41\x7e\x50\x76\x5f\x6d\x6e\x65\x7d\x9d\x8d\x23\x9e\xa9\xae\x2f\xbf\xb5\xcf\xf6\xdf\xfd\xf7\x00\x00\x1d\x0f\x10\x21\x68\x31\xa5\x41\xbb\x50\xd0\x5f\xe6\x6e\xfc\x7d\x0d\x8e\x4b\x9e\x8a\xae\xc8\xbe\x06\xcf\x52\xdf\xd5\xf7\x00\x00\x14\x0f\xbc\x20\x06\x31\x3b\x41\x32\x50\x2a\x5f\x21\x6e\x18\x7d\x22\x8d\x78\x9d\xcd\xad\x22\xbe\x78\xce\xe8\xde\xbb\xf7", 0x0000600);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0000600, 1092);
printf("1194 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("1195 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("1196 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(24*1000);
memcpy(buf, "\xa0\x00\xa1\x40\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x6c\x7d\x0c\x7e\x01\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("1197 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x00\xf0\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("1198 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
memcpy(buf, "\x78\x01\x15\x00\x98\xf2\x1a\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\x00\x00\x4b\x14\x00\x00\xe9\x14\x00\x00\x80\x15\xe5\x07\xff\xff\xd8\x07\xff\xff\xd8\x07\xff\xff\xdd\x07\xff\xff\xd7\x07\xff\xff\xdd\x07\xff\xff\xdb\x07\xff\xff\xdc\x07\xff\xff\xd5\x07\xff\xff\xdd\x07\xff\xff\xdc\x07\xff\xff\xdf\x07\xff\xff\xdc\x07\xff\xff\xd1\x07\xff\xff\xd7\x07\xff\xff\xdb\x07\xff\xff\xd8\x07\xff\xff\xc8\x07\xff\xff\xd1\x07\xff\xff\xd2\x07\xff\xff\xd5\x07\xff\xff\xce\x07\xff\xff\xd9\x07\xff\xff\xd3\x07\xff\xff\xd2\x07\xff\xff\xd4\x07\xff\xff\xd3\x07\xff\xff\xc9\x07\xff\xff\xd1\x07\xff\xff\xd1\x07\xff\xff\xcc\x07\xff\xff\xd0\x07\xff\xff\xcf\x07\xff\xff\xd5\x07\xff\xff\xd6\x07\xff\xff\xcf\x07\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xce\x07\xff\xff\xd7\x07\xff\xff\xca\x07\xff\xff\xc6\x07\xff\xff\xd2\x07\xff\xff\xc6\x07\xff\xff\xbd\x07\xff\xff\xca\x07\xff\xff\xc7\x07\xff\xff\xbf\x07\xff\xff\xc8\x07\xff\xff\xbb\x07\xff\xff\xc4\x07\xff\xff\xbf\x07\xff\xff\xca\x07\xff\xff\xb9\x07\xff\xff\xb6\x07\xff\xff\xbf\x07\xff\xff\xbe\x07\xff\xff\xb6\x07\xff\xff\xc3\x07\xff\xff\xbd\x07\xff\xff\xbd\x07\xff\xff\xbb\x07\xff\xff\xb1\x07\xff\xff\xb4\x07\xff\xff\xb6\x07\xff\xff\xb3\x07\xff\xff\xb9\x07\xff\xff\xbc\x07\xff\xff\xbe\x07\xff\xff\xbc\x07\xff\xff\xb9\x07\xff\xff\xb9\x07\x48\xf5\xc6\x07\xf2\xf4\xbe\x07\xff\xff\xb7\x07\xf8\xee\xb6\x07\x99\xe8\xc0\x07\x99\xfb\xb8\x07\x3e\xe5\xb3\x07\x94\xe3\xba\x07\x4e\xf2\xbd\x07\xab\xdc\xb5\x07\xcd\xda\xbe\x07\xe0\xe9\xad\x07\x49\xd8\xb5\x07\x4b\xd5\xbc\x07\x7e\xe2\xaf\x07\x23\xcd\xa8\x07\x6e\xca\xaf\x07\x58\xd8\xb0\x07\xa0\xc8\xaf\x07\x47\xc4\xb3\x07\xf1\xd0\xa0\x07\x8e\xbe\xa4\x07\x6a\xbe\xb2\x07\x2f\xcb\xa2\x07\x21\xbc\xa9\x07\x52\xb7\xb1\x07\x01\xc5\xa3\x07\x72\xb7\xa9\x07\xa5\xb5\xa6\x07\x23\xc1\xab\x07\xee\xb4\xaf\x07\x96\xb1\xa1\x07\xd3\xbd\x9d\x07\x1f\xb3\xa0\x07\x71\xb2\xa9\x07\x13\xbc\x9a\x07\xd9\xb1\x9f\x07\xeb\xb0\x9c\x07\x3a\xba\xa3\x07\x80\xb3\xa0\x07\x2d\xaf\xa5\x07\xb5\xb9\xa5\x07\x2e\xad\xa8\x07\x7e\xaa\x9f\x07\x55\xb5\x97\x07\x08\xa9\x9e\x07\x9a\xa8\xab\x07\x03\xb3\x9b\x07\xc8\xa6\x9f\x07\x50\xa5\xa6\x07\x33\xae\x88\x07\xd8\xa6\x90\x07\xc9\xa5\x9b\x07\xaa\xab\x99\x07\xc7\xa1\x90\x07\xe3\x9f\x9a\x07\x81\xaa\xa2\x07\xe5\xa3\x9c\x07\x61\xa0\x9c\x07\x57\xaa\xa0\x07\x5d\xa1\xa0\x07\xca\x9f\x9f\x07\x58\xa8\x9b\x07\xe9\x9d\x9d\x07\xd6\x9b\x9d\x07\x3b\xa4\x9e\x07\x98\x9a\x9c\x07\xe7\x9a\xa0\x07\xd9\xa0\x96\x07\xb2\x96\x92\x07\x22\x95\x9a\x07\x1f\x9e\x9f\x07\x42\x95\x9d\x07\x8e\x93\x9c\x07\x6f\x9b\x89\x07\x11\x93\x93\x07\xd7\x92\x98\x07\xc5\x99\x9d\x07\x88\x91\x98\x07\x4c\x90\xa1\x07\x26\x99\x8f\x07\xb8\x92\x8f\x07\x96\x8e\x9d\x07\x48\x99\x9e\x07\x26\x91\x92\x07\x4c\x8f\x92\x07\x11\x95\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8e\x07\xfd\x8c\x8d\x07\xaf\x8a\x9c\x07\x69\x93\x94\x07\x75\x8a\x90\x07\x20\x88\x8d\x07\xb8\x90\x90\x07\xd9\x89\x9a\x07\x8d\x87\x97\x07\x0b\x8f\x8d\x07\xa0\x86\x85\x07\x8e\x85\x8f\x07\xf0\x8d\x8e\x07\x0d\x86\x94\x07\x73\x85\x9b\x07\x84\x8d\xa0\x07\xdf\x88\x9c\x07\x50\x85\x9d\x07\xf0\x8d\x93\x07\xe0\x84\x99\x07\x06\x82\x98\x07\xeb\x8b\x8b\x07\x1c\x83\x88\x07\x50\x80\x95\x07\xcd\x87\x95\x07\x74\x80\x8f\x07\x37\x7e\x91\x07\xf4\x85\x94\x07\xd0\x7d\x95\x07\x24\x7d\x9f\x07\x3f\x85\x88\x07\x41\x7e\x8c\x07\xb0\x7c\x9b\x07\xc0\x82\x8e\x07\xfe\x7c\x85\x07\x3e\x7a\x8f\x07\x6e\x82\x93\x07\xdf\x7d\x91\x07\xe1\x7a\x93\x07\xec\x81\x98\x07\xb0\x79\x97\x07\x8d\x77\x98\x07\xb3\x7e\x89\x07\x16\x77\x86\x07\x09\x75\x89\x07\xd5\x7b\x83\x07\x8d\x76\x7e\x07\x3e\x74\x83\x07\x08\x7b\x8e\x07\xb4\x73\x91\x07\xca\x71\x91\x07\xbc\x78\x93\x07\x18\x73\x82\x07\x59\x70\x90\x07\x38\x77\x80\x07\xbc\x71\x79\x07\xa0\x6f\x80\x07\x3d\x76\x87\x07\xac\x72\x87\x07\xab\x70\x88\x07\x1b\x76\x89\x07\x39\x71\x83\x07\x4f\x6f\x96\x07\xe6\x76\x8b\x07\x41\x6d\x78\x07\xb5\x6c\x86\x07\xae\x71\x82\x07\xc5\x6b\x84\x07\xe3\x6a\x8d\x07\xe3\x6f\x89\x07\xd0\x69\x8d\x07\x25\x69\x8a\x07\x3b\x6f\x7d\x07\x1b\x69\x80\x07\x61\x67\x91\x07\x8e\x6d\x8b\x07\xd1\x68\x85\x07\xea\x65\x8a\x07\x0f\x6c\x84\x07\xc2\x67\x85\x07\x27\x67\x89\x07\xf3\x6b\x6a\x07\xfe\x69\x6d\x07\x87\x67\x84\x07\xfe\x6b\x81\x07\x91\x65\x91\x07\x0e\x65\x92\x07\x1e\x6a\x83\x07\x88\x64\x84\x07\xae\x62\x81\x07\x98\x67\x82\x07\xf1\x62\x7e\x07\x86\x61\x81\x07\x74\x66\x7d\x07\xb6\x60\x7b\x07\xc0\x5f\x84\x07\xb9\x65\x7b\x07\x23\x60\x7e\x07\xd2\x5e\x88\x07\x38\x65\x7d\x07\xe5\x5f\x7a\x07\x2a\x5e\x7d\x07\x7a\x64\x73\x07\xc9\x60\x6e\x07\xa6\x5e\x8a\x07\x88\x65\x75\x07\x2f\x5e\x73\x07\xf9\x5d\x88\x07\x97\x62\x79\x07\xd7\x5c\x7e\x07\x65\x5c\x88\x07\xb1\x60\x75\x07\x22\x5d\x72\x07\x6a\x5b\x82\x07\xe7\x5f\x75\x07\x01\x5c\x79\x07\x76\x5b\x82\x07\xf5\x5e\x7b\x07\xc0\x59\x75\x07\x58\x59\x81\x07\xad\x5e\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x7d\x07\xe5\x58\x6f\x07\x09\x59\x84\x07\x3c\x5e\x84\x07\xbc\x59\x73\x07\xea\x58\x87\x07\x05\x5e\x7a\x07\x8c\x58\x7e\x07\x3f\x58\x7b\x07\x5a\x5b\x79\x07\xca\x57\x78\x07\xa7\x55\x79\x07\x3c\x5a\x6b\x07\xcd\x55\x69\x07\xcf\x54\x86\x07\x94\x59\x6e\x07\x9e\x54\x72\x07\x9a\x54\x82\x07\x67\x58\x73\x07\x25\x54\x77\x07\xff\x52\x7f\x07\xc6\x57\x71\x07\x39\x53\x79\x07\x71\x52\x82\x07\xfb\x56\x6f\x07\xe4\x52\x70\x07\x3b\x52\x7a\x07\x2b\x57\x71\x07\x45\x52\x7a\x07\xd4\x51\x83\x07\x7c\x56\x79\x07\xc6\x51\x74\x07\x4b\x50\x87\x07\x0f\x55\x7d\x07\x5b\x50\x72\x07\x80\x4f\x78\x07\xab\x53\x62\x07\x19\x50\x65\x07\x3d\x4f\x77\x07\xd4\x52\x78\x07\x2d\x4f\x80\x07\x97\x4e\x80\x07\x54\x52\x6e\x07\xe6\x4d\x70\x07\x9f\x4d\x82\x07\x2d\x52\x69\x07\x9e\x4e\x75\x07\xab\x4d\x83\x07\x6b\x52\x72\x07\x5c\x4e\x72\x07\x76\x4c\x74\x07\x0c\x51\x75\x07\x42\x4d\x71\x07\x4b\x4b\x77\x07\xd7\x4f\x5d\x07\x55\x4c\x56\x07\x02\x4b\x70\x07\x9d\x4e\x67\x07\xd3\x4c\x62\x07\x20\x4a\x69\x07\x11\x4e\x68\x07\x60\x4b\x5a\x07\x21\x49\x75\x07\x46\x4d\x65\x07\x95\x4a\x59\x07\xee\x48\x63\x07\xe5\x4c\x5f\x07\xdf\x49\x5b\x07\x50\x49\x6e\x07\xed\x4b\x55\x07\xfd\x49\x5a\x07\x31\x49\x6c\x07\x2f\x4d\x67\x07\xc6\x48\x62\x07\xb3\x47\x6d\x07\x6c\x4b\x60\x07\xef\x48\x61\x07\x8d\x46\x6a\x07\x18\x4a\x55\x07\x82\x47\x55\x07\x17\x46\x68\x07\xb6\x48\x60\x07\xbd\x46\x5c\x07\x78\x45\x62\x07\x72\x48\x4a\x07\xbd\x46\x4f\x07\xda\x44\x60\x07\xfc\x47\x60\x07\x4d\x46\x5e\x07\x83\x44\x65\x07\xbe\x47\x56\x07\xdc\x45\x4a\x07\xf4\x43\x5d\x07\x98\x47\x56\x07\xc5\x44\x56\x07\x94\x43\x61\x07\x12\x47\x57\x07\xc6\x43\x58\x07\x55\x43\x5c\x07\xdd\x45\x50\x07\xbf\x43\x51\x07\xa4\x42\x5c\x07\x4e\x45\x54\x07\x90\x44\x57\x07\xd9\x41\x56\x07\x81\x45\x52\x07\x00\x45\x41\x07\x9d\x41\x60\x07\xfb\x44\x51\x07\x57\x44\x49\x07\xa0\x41\x5c\x07\x07\x45\x4d\x07\xef\x43\x47\x07\x6e\x41\x61\x07\xee\x44\x51\x07\xaf\x42\x4b\x07\xdd\x40\x5a\x07\x48\x44\x4f\x07\x1c\x41\x59\x07\x68\x40\x59\x07\x83\x43\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x42\x07\x85\x40\x52\x07\x6f\x40\x55\x07\x9a\x42\x51\x07\xe1\x3f\x4e\x07\xaa\x3f\x53\x07\x4c\x42\x44\x07\xcb\x3f\x47\x07\x97\x3f\x5a\x07\x88\x42\x66\x07\x1d\x41\x52\x07\xa8\x3f\x5c\x07\x11\x42\x42\x07\x2b\x41\x43\x07\xce\x3f\x53\x07\xe4\x42\x4d\x07\x68\x40\x41\x07\xad\x3e\x57\x07\x77\x41\x4b\x07\x8c\x3f\x3e\x07\x52\x3d\x49\x07\xa0\x40\x4f\x07\xdf\x3e\x3f\x07\x21\x3d\x54\x07\x18\x40\x4e\x07\x6b\x3e\x3c\x07\x25\x3d\x51\x07\x13\x40\x2a\x07\xfe\x3d\x21\x07\xcb\x3c\x56\x07\x9f\x3f\x39\x07\x1f\x3d\x3e\x07\xe1\x3c\x4e\x07\xea\x3e\x40\x07\x0e\x3d\x3e\x07\x74\x3c\x4c\x07\x79\x3f\x3e\x07\x2a\x3d\x3c\x07\xb9\x3c\x4d\x07\x0a\x3f\x45\x07\x13\x3c\x45\x07\x88\x3b\x54\x07\x7d\x3e\x47\x07\xf7\x3b\x49\x07\x1b\x3b\x53\x07\x7f\x3d\x44\x07\xcc\x3b\x36\x07\xcf\x3a\x50\x07\x06\x3d\x2a\x07\xa5\x3b\x30\x07\xc2\x3a\x47\x07\x11\x3d\x41\x07\xd9\x3a\x48\x07\x3c\x3a\x3b\x07\xf0\x3c\x33\x07\x79\x3b\x31\x07\xef\x3a\x3c\x07\xc5\x3c\x31\x07\xbd\x3b\x26\x07\xab\x3a\x48\x07\x3a\x3d\x39\x07\x43\x3a\x40\x07\xd0\x39\x4a\x07\x36\x3c\x2b\x07\x73\x3a\x25\x07\xed\x39\x4e\x07\xe4\x3b\x29\x07\xee\x39\x23\x07\x25\x39\x45\x07\xdf\x3a\x3d\x07\xe1\x38\x41\x07\x12\x39\x4a\x07\xf3\x3a\x2e\x07\x48\x39\x26\x07\xa6\x38\x48\x07\x7e\x3a\x32\x07\x6f\x39\x28\x07\x2c\x38\x3c\x07\x47\x3a\x2f\x07\x57\x39\x41\x07\xc9\x38\x52\x07\xbc\x3a\x33\x07\x7d\x38\x39\x07\x43\x38\x47\x07\x96\x39\x34\x07\x95\x38\x25\x07\xb0\x37\x46\x07\x80\x39\x2a\x07\x6e\x38\x16\x07\x26\x37\x40\x07\x11\x39\x22\x07\xf0\x37\x19\x07\x0e\x37\x3d\x07\xe0\x38\x2f\x07\x97\x37\x27\x07\x93\x36\x48\x07\xef\x38\x3b\x07\x5c\x37\x38\x07\x7a\x36\x40\x07\xd7\x38\x41\x07\x2c\x38\x33\x07\xbc\x36\x4e\x07\x2c\x39\x36\x07\x20\x37\x2c\x07\x49\x36\x3c\x07\x6a\x38\x16\x07\x9c\x36\x1c\x07\x53\x36\x3c\x07\xb2\x37\x3d\x07\x54\x36\x31\x07\xc0\x35\x49\x07\xd4\x37\x32\x07\x6b\x36\x33\x07\x63\x36\x47\x07\xb1\x37\x27\x07\x07\x37\x20\x07\x50\x35\x45\x07\x9b\x37\x29\x07\x90\x37\x26\x07\x2d\x35\x30\x07\x73\x37\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x25\x07\x8d\x38\x22\x07\x2e\x35\x3e\x07\x0f\x38\x3d\x07\xfe\x36\x37\x07\x32\x35\x43\x07\xba\x37\x26\x07\xa2\x35\x22\x07\xf0\x34\x3a\x07\xbf\x36\x3e\x07\xcc\x35\x30\x07\x7f\x34\x40\x07\x97\x36\x2a\x07\x70\x35\x15\x07\x25\x34\x33\x07\xda\x35\x2d\x07\x12\x35\x2c\x07\xa3\x34\x33\x07\xba\x35\x33\x07\xe2\x34\x31\x07\x10\x34\x40\x07\x10\x36\x2a\x07\x8f\x35\x28\x07\xfb\x33\x3d\x07\x3a\x36\x1a\x07\x31\x35\x21\x07\x22\x34\x35\x07\x23\x36\x30\x07\xb6\x34\x2f\x07\x6f\x33\x39\x07\xa3\x35\x28\x07\xa8\x33\x1d\x07\x62\x33\x29\x07\xb8\x34\x22\x07\xc8\x33\x1f\x07\x06\x33\x3d\x07\x24\x35\x14\x07\x89\x33\x0e\x07\x11\x33\x2d\x07\xbe\x34\x2f\x07\xab\x33\x24\x07\x9c\x32\x3d\x07\x75\x34\x33\x07\x10\x34\x1a\x07\xd0\x32\x35\x07\xd4\x34\x22\x07\x23\x34\x18\x07\x2f\x33\x36\x07\xd8\x34\x20\x07\xbe\x33\x1d\x07\x50\x32\x33\x07\xf5\x33\x1f\x07\x19\x33\x24\x07\x2e\x32\x34\x07\x72\x33\x1e\x07\x99\x32\x26\x07\x36\x32\x33\x07\x28\x33\x1a\x07\xe4\x32\x1d\x07\x89\x31\x2f\x07\xef\x32\x29\x07\x3f\x32\x22\x07\x77\x31\x2a\x07\xba\x32\x22\x07\xdd\x32\x22\x07\xc5\x31\x32\x07\x40\x33\x16\x07\x99\x33\x17\x07\x45\x32\x2e\x07\x3b\x33\x27\x07\xb3\x32\x1f\x07\xab\x31\x31\x07\xd6\x32\x1b\x07\x37\x32\x18\x07\x40\x31\x34\x07\xa9\x32\x1b\x07\xcf\x31\x22\x07\x10\x31\x33\x07\xef\x31\x23\x07\x02\x32\x26\x07\xb2\x30\x33\x07\x2f\x32\x1c\x07\xe2\x31\x16\x07\xd2\x30\x29\x07\xdc\x31\x0e\x07\xe3\x31\x10\x07\xd0\x30\x2b\x07\xdd\x31\x22\x07\x03\x32\x26\x07\xf9\x30\x35\x07\x2b\x32\x14\x07\x12\x32\x11\x07\xb6\x30\x28\x07\x6f\x31\x17\x07\xef\x30\x1d\x07\x52\x30\x29\x07\xf6\x30\x13\x07\x45\x31\x13\x07\x48\x30\x20\x07\xfa\x30\x19\x07\x82\x31\x12\x07\xee\x2f\x2d\x07\x2e\x31\x19\x07\x09\x31\x1d\x07\x2b\x30\x29\x07\x15\x31\x08\x07\x10\x31\x05\x07\xf0\x2f\x34\x07\x6f\x31\x17\x07\x6a\x31\x21\x07\xc4\x2f\x25\x07\x2d\x31\x1c\x07\x55\x31\x10\x07\x22\x30\x27\x07\x21\x31\x1b\x07\xc9\x30\x1a\x07\x15\x30\x2a\x07\xc3\x30\x27\x07\xab\x30\x17\x07\xa8\x2f\x2c\x07\x1c\x31\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x1a\x07\x9a\x30\x16\x07\x9a\x2f\x2b\x07\x8d\x30\x1b\x07\xb7\x30\x10\x07\x80\x2f\x2d\x07\xe3\x30\x18\x07\x8d\x30\x0a\x07\x71\x2f\x26\x07\xb6\x30\x25\x07\x13\x31\x1e\x07\x97\x2f\x2b\x07\xd6\x30\x15\x07\x75\x31\xf8\x06\xb1\x2f\x24\x07\xda\x30\x1f\x07\x8e\x30\x1b\x07\x9e\x2f\x36\x07\xc6\x30\x10\x07\x75\x30\x0b\x07\x64\x2f\x1f\x07\x5b\x30\x0c\x07\x46\x30\x07\x07\x49\x2f\x1f\x07\x18\x30\x14\x07\x3c\x30\x16\x07\x30\x2f\x1f\x07\x07\x30\x0f\x07\x2b\x30\x16\x07\x3a\x2f\x1f\x07\xec\x2f\x19\x07\xd0\x30\x17\x07\x24\x30\x21\x07\x1f\x30\x22\x07\x75\x30\x1c\x07\x62\x2f\x2a\x07\x52\x30\x0b\x07\x14\x30\x0b\x07\xda\x2e\x17\x07\xd4\x2f\x03\x07\xd9\x2f\xf8\x06\x79\x2e\x1c\x07\x66\x2f\xf8\x06\xbf\x2f\xed\x06\x5f\x2e\x14\x07\x2e\x2f\xf3\x06\xf3\x2f\xe8\x06\x06\x2f\x1b\x07\xf2\x2e\x1a\x07\x7b\x2f\x18\x07\x58\x2e\x24\x07\x24\x2f\x04\x07\xb5\x2f\x01\x07\xaf\x2e\x1f\x07\x28\x2f\x22\x07\x7c\x30\x14\x07\xe8\x2e\x26\x07\xa5\x2f\x0b\x07\xa6\x2f\x0f\x07\xbd\x2e\x1b\x07\x3d\x2f\x13\x07\xd9\x2f\x04\x07\xd5\x2e\x20\x07\x18\x2f\x13\x07\x49\x2f\x15\x07\x5b\x2e\x19\x07\x09\x2f\x19\x07\x77\x2f\x11\x07\xa0\x2e\x24\x07\x2a\x2f\x20\x07\x54\x2f\x19\x07\x39\x2e\x1d\x07\x6e\x2f\x1d\x07\xa5\x2f\x13\x07\xc6\x2e\x23\x07\x25\x2f\x12\x07\xd4\x2f\x16\x07\xd5\x2e\x20\x07\xc2\x2f\x12\x07\xa0\x2f\x0e\x07\xa9\x2e\x1e\x07\x4f\x2f\x0b\x07\x88\x2f\x01\x07\x78\x2e\x1a\x07\x14\x2f\x05\x07\xb5\x2f\xfa\x06\x83\x2e\x10\x07\x3d\x2f\x06\x07\x15\x2f\x05\x07\xf6\x2d\x21\x07\xed\x2e\x0d\x07\x0d\x2f\x0e\x07\x4a\x2e\x24\x07\xe1\x2e\x16\x07\x9d\x2f\x10\x07\x89\x2e\x1c\x07\x53\x2f\x07\x07\x40\x30\x0c\x07\xc4\x2e\x24\x07\x86\x2f\x15\x07\xd2\x2f\x19\x07\xb4\x2e\x1c\x07\x7f\x2f\x1e\x07\x81\x2f\x1f\x07\x6f\x2e\x1b\x07\xe7\x2e\x15\x07\x4b\x2f\x06\x07\xec\x2d\x1d\x07\xc7\x2e\x09\x07\x04\x2f\x0a\x07\xe5\x2d\x1a\x07\x60\x2e\x19\x07\x28\x2f\x08\x07\xf2\x2d\x20\x07\x6e\x2e\x19\x07\xfc\x2e\x0e\x07\xb1\x2d\x11\x07\x65\x2e\x24\x07\x89\x2f\x11\x07\x4b\x2e\x16\x07\x78\x2e\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x09\x07\x25\x2f\x11\x07\x1b\x2e\x14\x07\x80\x2e\x14\x07\x63\x2e\x0c\x07\x4e\x2d\x18\x07\xf1\x2d\xfc\x06\x7c\x2e\xf4\x06\x5b\x2d\x18\x07\x0f\x2e\xf6\x06\x78\x2e\xfa\x06\x54\x2d\x11\x07\x03\x2e\xfc\x06\x07\x2e\xfa\x06\x30\x2d\x10\x07\xb6\x2d\x08\x07\x1e\x2e\x00\x07\x3b\x2d\x11\x07\xc9\x2d\x0d\x07\x86\x2e\x03\x07\x1c\x2d\x18\x07\xc9\x2d\x15\x07\x6b\x2e\x12\x07\xbd\x2d\x2a\x07\xfc\x2d\x17\x07\x42\x2e\x0f\x07\x1c\x2d\x1b\x07\x0f\x2e\x0f\x07\x50\x2e\x03\x07\xdc\x2c\x22\x07\xe9\x2d\x07\x07\x18\x2e\xf4\x06\xd5\x2c\x20\x07\xa9\x2d\x11\x07\xe2\x2d\x03\x07\x01\x2d\x0c\x07\x2f\x2d\x0d\x07\xca\x2d\x08\x07\xc8\x2c\x0e\x07\x62\x2d\x04\x07\x19\x2e\xf5\x06\x88\x2c\x12\x07\x31\x2d\xf1\x06\x71\x2e\xf6\x06\x17\x2d\x10\x07\x5b\x2d\x17\x07\x36\x2e\x0b\x07\xf2\x2c\x0b\x07\xee\x2c\x09\x07\xac\x2d\xf9\x06\x55\x2c\x0f\x07\x85\x2c\x0b\x07\xc2\x2d\x0b\x07\x65\x2c\x06\x07\x7c\x2c\x15\x07\xc7\x2d\x05\x07\x31\x2c\x13\x07\x08\x2d\x06\x07\xc9\x2d\xf9\x06\x55\x2c\x08\x07\xbe\x2c\xf9\x06\xbe\x2d\x01\x07\x2e\x2c\x00\x07\xc8\x2c\x08\x07\x31\x2e\xf9\x06\xa0\x2c\x0c\x07\x18\x2d\x05\x07\x5c\x2e\xf3\x06\x9f\x2c\x14\x07\x0a\x2d\x0d\x07\xd6\x2d\xff\x06\x71\x2c\x0d\x07\x19\x2d\x0b\x07\xc0\x2d\x06\x07\x82\x2c\x08\x07\xde\x2c\x05\x07\xa6\x2d\xf5\x06\x77\x2c\x0f\x07\xb6\x2c\x00\x07\x9f\x2d\x00\x07\xb6\x2c\x0d\x07\xbf\x2c\x03\x07\xc0\x2d\xfd\x06\x90\x2c\x07\x07\xe5\x2c\x03\x07\x49\x2e\xfb\x06\xd8\x2c\x03\x07\x4c\x2d\xf8\x06\x0c\x2e\xf7\x06\xf4\x2c\x0d\x07\x3b\x2d\xfe\x06\xbb\x2d\xff\x06\x5d\x2c\x07\x07\x04\x2d\xfc\x06\xa1\x2d\xff\x06\x92\x2c\x07\x07\xba\x2c\x20\x07\xce\x2d\x0c\x07\x7f\x2c\x07\x07\xdb\x2c\x09\x07\xdc\x2d\x04\x07\x93\x2c\x09\x07\xce\x2c\x15\x07\xe1\x2d\x00\x07\xad\x2c\x12\x07\x1e\x2d\x11\x07\x84\x2e\x06\x07\xcf\x2c\x10\x07\x39\x2d\x08\x07\x9a\x2e\xff\x06\xea\x2c\x0a\x07\x76\x2d\x06\x07\x1e\x2e\xfa\x06\xc6\x2c\x1b\x07\x35\x2d\xf1\x06\xee\x2d\xe2\x06\xc5\x2c\x05\x07\x0c\x2d\xe0\x06\x8c\x2e\xd9\x06\xf7\x2c\x08\x07\xd4\x2c\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x07\x01\x2e\xf2\x06\xb7\x2c\x05\x07\x1a\x2d\x02\x07\xc7\x2d\xff\x06\xac\x2c\x06\x07\x3d\x2d\x0b\x07\x07\x2e\xfb\x06\x42\x2c\x09\x07\x35\x2d\xfd\x06\x00\x2e\xf5\x06\x5f\x2c\x0c\x07\x04\x2d\xf1\x06\xc8\x2d\xe3\x06\x44\x2c\xfc\x06\xd4\x2c\x04\x07\x9f\x2d\x04\x07\xfe\x2b\x03\x07\xdd\x2c\xff\x06\x24\x2d\xef\x06\x0c\x2c\x06\x07\x9f\x2c\xfc\x06\x53\x2d\xf5\x06\xf1\x2b\x09\x07\x9c\x2c\xe0\x06\xb4\x2d\xe3\x06\x2a\x2c\x10\x07\x98\x2c\xec\x06\x41\x2d\xe8\x06\xcc\x2b\x00\x07\x95\x2c\x02\x07\x70\x2d\xfb\x06\x94\x2b\x03\x07\x4b\x2c\x09\x07\x3f\x2d\x05\x07\x7c\x2b\x1f\x07\x7c\x2c\x01\x07\x1a\x2d\xf5\x06\x48\x2b\x14\x07\x2e\x2c\xea\x06\x71\x2c\xdd\x06\x24\x2b\xf7\x06\xb1\x2b\xc3\x06\x48\x2c\xba\x06\x10\x2b\xc9\x06\x0e\x2b\x98\x06\xe9\x2c\x9b\x06\xa7\x2a\x9e\x06\xad\x29\x76\x06\xe8\x27\x6d\x06\xa5\x26\x65\x06\x8d\x24\xb3\x06\xae\x27\xa7\x06\x10\x27\xa7\x06\x70\x25\xc7\x06\x27\x28\xb6\x06\xeb\x26\xc7\x06\x3b\x26\xdb\x06\x14\x28\xd6\x06\xe2\x26\xd8\x06\x3a\x26\xec\x06\xa1\x28\xe7\x06\x83\x27\xe4\x06\xca\x26\xd9\x06\x0d\x29\xd8\x06\xa8\x27\xe7\x06\xfc\x26\xea\x06\xe4\x28\xd8\x06\xa6\x27\xde\x06\xf2\x26\xdb\x06\x07\x29\xd6\x06\xb6\x27\xd3\x06\xe2\x26\xe4\x06\x32\x29\xda\x06\xc3\x27\xd8\x06\xb5\x26\xdc\x06\x82\x28\xd9\x06\xc2\x27\xd4\x06\xea\x26\xdf\x06\x80\x28\xdf\x06\x56\x27\xd1\x06\x8c\x26\xe0\x06\x92\x28\xd7\x06\x84\x27\xdb\x06\xbb\x26\xd0\x06\xc2\x28\xd1\x06\xeb\x27\xcf\x06\xf4\x26\xce\x06\xef\x28\xcd\x06\xb9\x27\xd7\x06\xd7\x26\xd2\x06\xff\x28\xd2\x06\xd4\x27\xe1\x06\x03\x27\xe2\x06\xbc\x28\xde\x06\xed\x27\xd5\x06\x11\x27\xd8\x06\xbd\x28\xce\x06\x22\x28\xd9\x06\x41\x27\xd9\x06\x75\x28\xd1\x06\x8f\x27\xe6\x06\xeb\x26\xdf\x06\x65\x28\xde\x06\xb3\x27\xdd\x06\xed\x26\xcf\x06\xba\x28\xce\x06\xec\x27\xdb\x06\x17\x27\xd6\x06\x85\x28\xd1\x06\xc0\x27\xd9\x06\x06\x27\xbc\x06\x5b\x28\xc8\x06\xef\x27\xda\x06\x21\x27\xd9\x06\x9e\x28\xdb\x06\x07\x28\xd2\x06\x2d\x27\xd4\x06\x69\x28\xd7\x06\x15\x28\xd5\x06\xf6\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe3\x06\x86\x28\xdc\x06\xc1\x27\xd6\x06\xd4\x26\xe5\x06\x60\x28\xd8\x06\xb8\x27\xd1\x06\x92\x26\xce\x06\x7e\x28\xd8\x06\x25\x28\xe3\x06\x00\x27\xdb\x06\x58\x28\xe0\x06\xc3\x27\xd3\x06\x20\x27\xe4\x06\x5e\x28\xe2\x06\xd6\x27\xd7\x06\xe9\x26\xdc\x06\x52\x28\xe7\x06\xf4\x27\xd9\x06\xf8\x26\xd2\x06\xad\x28\xc4\x06\xa4\x27\xda\x06\x06\x27\xdd\x06\x9a\x28\xe3\x06\x8f\x27\xe2\x06\xea\x26\xe6\x06\x03\x28\xdf\x06\x6b\x27\xce\x06\x53\x26\xcf\x06\x04\x28\xdd\x06\xc1\x27\xd4\x06\xcc\x26\xde\x06\x40\x28\xca\x06\x9b\x27\xd9\x06\xc5\x26\xd5\x06\x70\x28\xcd\x06\xc6\x27\xda\x06\xd8\x26\xe0\x06\x99\x28\xd2\x06\xe3\x27\xdd\x06\xde\x26\xe2\x06\x7f\x28\xcf\x06\xed\x27\xd3\x06\xe7\x26\xe3\x06\x6e\x28\xda\x06\x8a\x27\xd8\x06\xda\x26\xde\x06\x6c\x28\xd5\x06\x4b\x27\xdd\x06\x54\x26\xe8\x06\x61\x28\xe4\x06\x84\x27\xde\x06\x9b\x26\xdb\x06\xa0\x28\xde\x06\xdc\x27\xdb\x06\xa9\x26\xdd\x06\x5d\x28\xd3\x06\xb9\x27\xd2\x06\xb8\x26\xe6\x06\x77\x28\xe2\x06\xb0\x27\xcf\x06\x8b\x26\xe4\x06\x8d\x28\xdc\x06\xd3\x27\xda\x06\xde\x26\xd5\x06\xb5\x28\xd9\x06\xe4\x27\xdc\x06\xd8\x26\xe4\x06\x91\x28\xe4\x06\xae\x27\xe1\x06\x5e\x26\xe2\x06\xa9\x28\xd4\x06\x9a\x27\xd8\x06\xd8\x26\xeb\x06\xc3\x28\xce\x06\x9e\x27\xd9\x06\xdf\x26\xd5\x06\x88\x28\xd2\x06\x3e\x28\xd6\x06\x1b\x27\xe0\x06\x6e\x28\xea\x06\xdf\x27\xe3\x06\xea\x26\xd8\x06\x5c\x28\xdc\x06\xf0\x27\xe3\x06\xde\x26\xe4\x06\x94\x28\xea\x06\x31\x28\xda\x06\xe2\x26\xdd\x06\x16\x28\xd6\x06\xb9\x27\xe1\x06\xd7\x26\xe3\x06\x7d\x28\xe7\x06\xde\x27\xdf\x06\x7f\x26\xe8\x06\x1c\x28\xe3\x06\x0f\x28\xe3\x06\x09\x27\xdf\x06\x58\x28\xea\x06\xe1\x27\xe4\x06\x08\x27\xdc\x06\x61\x28\xc9\x06\xda\x27\xd2\x06\xe9\x26\xd0\x06\x71\x28\xd1\x06\xee\x27\xd9\x06\xc4\x26\xd8\x06\x4e\x28\xc8\x06\xbd\x27\xe8\x06\xd6\x26\xdf\x06\x58\x28\xd7\x06\x92\x27\xd8\x06\x93\x26\xe0\x06\x0e\x28\xd7\x06\x81\x27\xe2\x06\x85\x26\xe7\x06\x42\x28\xe0\x06\xa9\x27\xdd\x06\xd1\x26\xdb\x06\x6e\x28\xd7\x06\xab\x27\xd5\x06\xbd\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdf\x06\x51\x28\xdf\x06\x94\x27\xdb\x06\xcd\x26\xde\x06\x1e\x28\xd7\x06\xe4\x27\xda\x06\xe2\x26\xe7\x06\x3e\x28\xe4\x06\x10\x28\xe2\x06\x16\x27\xd4\x06\xda\x28\xc7\x06\xa7\x27\xd7\x06\xfa\x26\xe6\x06\x88\x28\xdc\x06\x99\x27\xe3\x06\xaa\x26\xe1\x06\x80\x28\xdd\x06\xe7\x27\xde\x06\xef\x26\xec\x06\x7e\x28\xe5\x06\x14\x28\xdb\x06\xea\x26\xd3\x06\xa6\x28\xcd\x06\xa1\x27\xe0\x06\xe0\x26\xe1\x06\x6c\x28\xde\x06\xd4\x27\xd3\x06\xc0\x26\xdb\x06\xa9\x28\xda\x06\xc9\x27\xdb\x06\xfa\x26\xe4\x06\x80\x28\xdd\x06\xe7\x27\xe2\x06\x91\x26\xd0\x06\x18\x28\xd9\x06\x85\x27\xcf\x06\x91\x26\xb8\x06\x88\x28\xb3\x06\xd0\x27\xcf\x06\xe4\x26\xd3\x06\x48\x28\xd4\x06\x1b\x28\xdf\x06\xfe\x26\xdf\x06\x85\x28\xd9\x06\xe2\x27\xd1\x06\x99\x26\xdd\x06\x68\x28\xe6\x06\xb6\x27\xe4\x06\xcd\x26\xdb\x06\x88\x28\xdc\x06\x00\x28\xd5\x06\xd5\x26\xc7\x06\x94\x28\xc0\x06\x28\x28\xca\x06\xcc\x26\xe9\x06\xfe\x28\xe1\x06\xb9\x27\xd8\x06\xb5\x26\xe1\x06\x8d\x28\xd3\x06\xda\x27\xd5\x06\xe0\x26\xd8\x06\x69\x28\xdd\x06\x09\x28\xda\x06\xcd\x26\xd9\x06\x77\x28\xce\x06\x0d\x28\xd9\x06\xb3\x26\xda\x06\x52\x28\xea\x06\xf6\x27\xe1\x06\x8c\x26\xd3\x06\xcb\x28\xd1\x06\xc9\x27\xc7\x06\x77\x26\xda\x06\x73\x28\xdd\x06\xc2\x27\xd1\x06\x60\x26\xd6\x06\x01\x28\xe1\x06\xaf\x27\xc5\x06\xc2\x25\xb7\x06\x0e\x28\xb8\x06\xbf\x27\xd1\x06\xf4\x25\xd4\x06\xdd\x27\xdc\x06\x55\x27\xd3\x06\xb4\x25\xdf\x06\x2d\x28\xcf\x06\x51\x27\xc9\x06\x7b\x25\xc3\x06\x36\x28\xc5\x06\xa6\x27\xd9\x06\xc6\x25\xda\x06\x13\x28\xde\x06\x5d\x27\xcb\x06\xca\x25\xcd\x06\x0f\x28\xda\x06\xb7\x27\xd7\x06\x0a\x26\xd5\x06\x86\x27\xd4\x06\x03\x27\xcf\x06\xc4\x25\xe0\x06\x63\x27\xd6\x06\xc8\x26\xce\x06\x8f\x25\xd5\x06\xb7\x27\xcf\x06\x47\x27\xc8\x06\xfc\x25\xdc\x06\x02\x28\xe2\x06\x7a\x27\xda\x06\x3f\x26\xd7\x06\x5a\x28\xc9\x06\x95\x27\xd8\x06\x6c\x26\xc5\x06\x20\x28\xbc\x06\xbb\x27\xe1\x06\x49\x26\xdf\x06\x75\x28\xd0\x06\x89\x27\xdf\x06\x73\x26\xd7\x06\x25\x28\xd9\x06\x89\x27\xc7\x06\x11\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd8\x06\xcc\x28\xc3\x06\x54\x27\xc9\x06\xe6\x25\xdb\x06\x9a\x28\xdc\x06\x88\x27\xdb\x06\x3e\x26\xd5\x06\x48\x28\xc9\x06\x5d\x27\xcc\x06\x6c\x26\xcf\x06\x41\x28\xd3\x06\xc6\x27\xd4\x06\x83\x26\xda\x06\x67\x28\xd3\x06\xd7\x27\xc6\x06\xbd\x26\xcf\x06\x7a\x28\xc1\x06\xaf\x27\xd3\x06\x99\x26\xdd\x06\xe1\x27\xd2\x06\x5d\x27\xc9\x06\x3c\x26\xd5\x06\xc5\x27\xc2\x06\x22\x27\xd6\x06\xf4\x25\xe5\x06\x50\x28\xd8\x06\x8c\x27\xce\x06\x3f\x26\xd3\x06\x57\x28\xcc\x06\x99\x27\xcc\x06\x4e\x26\xd4\x06\x3f\x28\xcd\x06\x7d\x27\xd1\x06\x4a\x26\xd5\x06\x44\x28\xe1\x06\x44\x27\xd7\x06\x6a\x26\xd3\x06\x33\x28\xd0\x06\x9a\x27\xc9\x06\x5d\x26\xd1\x06\xfa\x27\xd2\x06\xa2\x27\xd1\x06\x58\x26\xd8\x06\xcd\x27\xce\x06\x32\x27\xd0\x06\x02\x26\xd6\x06\xdd\x27\xde\x06\x71\x27\xcd\x06\x3a\x26\xd0\x06\xbc\x27\xca\x06\x3c\x27\xc8\x06\x30\x26\xcd\x06\xf4\x27\xd4\x06\x44\x27\xdc\x06\x43\x26\xdf\x06\xf6\x27\xdf\x06\x63\x27\xd7\x06\x20\x26\xe1\x06\x14\x28\xd4\x06\x27\x27\xc4\x06\x19\x26\xdc\x06\x12\x28\xdd\x06\x28\x27\xd6\x06\x1e\x26\xd8\x06\xa9\x27\xc9\x06\xf0\x26\xd1\x06\xed\x25\xc8\x06\x92\x27\xc0\x06\x1e\x27\xc6\x06\xad\x25\xcf\x06\xfc\x27\xca\x06\x6f\x27\xcb\x06\x05\x26\xd0\x06\xf7\x27\xd4\x06\x37\x27\xdf\x06\x47\x26\xce\x06\xf3\x27\xc2\x06\x0a\x27\xd3\x06\xf6\x25\xd9\x06\x57\x28\xd5\x06\x58\x27\xd4\x06\x18\x26\xdd\x06\x38\x28\xd5\x06\x17\x27\xe0\x06\xfe\x25\xd5\x06\x76\x28\xd1\x06\x28\x27\xc4\x06\xfc\x25\xcb\x06\xfd\x27\xcd\x06\x0b\x27\xcc\x06\xd6\x25\xc4\x06\xcc\x28\xc5\x06\xb6\x27\xd8\x06\x8c\x26\xe7\x06\x8b\x29\xd6\x06\x4b\x27\xd6\x06\x91\x26\xe1\x06\x9b\x29\xcf\x06\x5b\x27\xd2\x06\xb1\x26\xde\x06\xe4\x28\xd0\x06\x7c\x27\xca\x06\x6b\x26\xd4\x06\x4c\x28\xd3\x06\xbd\x27\xdc\x06\x81\x26\xba\x06\x96\x28\xb4\x06\x80\x27\xd2\x06\x91\x26\xdf\x06\x02\x28\xdb\x06\x3a\x27\xdd\x06\x51\x26\xd5\x06\x21\x28\xd6\x06\x92\x27\xd0\x06\x9d\x26\xc0\x06\x73\x28\xc2\x06\xde\x27\xbb\x06\xf2\x26\xd0\x06\xef\x27\xd9\x06\xad\x27\xca\x06\xa4\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbc\x06\x89\x28\xb6\x06\xfc\x27\xaa\x06\x05\x27\xc5\x06\x4e\x28\xc2\x06\xfb\x27\xd2\x06\xa0\x26\xdb\x06\xe4\x27\xdc\x06\x57\x27\xda\x06\x6c\x26\xd2\x06\x6e\x27\xc9\x06\xfa\x26\xce\x06\xe4\x25\xd0\x06\xa5\x27\xd1\x06\x6c\x27\xd6\x06\x6b\x26\xd6\x06\xdf\x27\xe4\x06\x7a\x27\xdc\x06\x59\x26\xd3\x06\xd3\x27\xcd\x06\x63\x27\xd0\x06\x7d\x26\xdd\x06\xf7\x27\xe3\x06\xa6\x27\xd8\x06\x67\x26\xd4\x06\xf7\x27\xdb\x06\x85\x27\xcd\x06\x9f\x26\xda\x06\xe9\x27\xdc\x06\x67\x27\xd2\x06\x6a\x26\xc7\x06\x6f\x27\xbe\x06\xe5\x26\xcd\x06\x9b\x25\xbf\x06\x8e\x27\xc6\x06\x2e\x27\xc8\x06\x15\x26\xd5\x06\xeb\x27\xd9\x06\x8c\x27\xda\x06\x54\x26\xdc\x06\x00\x28\xd0\x06\x43\x27\xd9\x06\x3b\x26\xcf\x06\x37\x28\xcf\x06\x67\x27\xd3\x06\x09\x26\xd0\x06\x53\x28\xce\x06\x74\x27\xd1\x06\x11\x26\xde\x06\xa6\x28\xdb\x06\x9a\x27\xd6\x06\x0e\x26\xc8\x06\x21\x28\xc2\x06\x57\x27\xcc\x06\xf6\x25\xd2\x06\xf6\x27\xd5\x06\x59\x27\xd6\x06\x55\x26\xb6\x06\x20\x28\xbb\x06\x99\x27\xd6\x06\x8a\x26\xc5\x06\x4d\x28\xbe\x06\xe6\x27\xcd\x06\x6f\x26\xd2\x06\x25\x28\xcf\x06\x6d\x27\xda\x06\x6f\x26\xe0\x06\xc3\x28\xd9\x06\x91\x27\xd7\x06\xa4\x26\xcf\x06\x83\x28\xdc\x06\x8d\x27\xd2\x06\x83\x26\xc6\x06\xeb\x28\xc2\x06\x94\x27\xd3\x06\x8c\x26\xd9\x06\xdd\x28\xd8\x06\x51\x27\xd8\x06\x57\x26\xe1\x06\x2e\x29\xdf\x06\x80\x27\xdc\x06\xa3\x26\xe1\x06\xfc\x28\xd6\x06\xfc\x27\xd2\x06\x92\x26\xe0\x06\x79\x28\xda\x06\x9e\x27\xc8\x06\x75\x26\xe6\x06\x66\x28\xde\x06\x6e\x27\xd7\x06\x66\x26\xd0\x06\x7a\x28\xcf\x06\x6d\x27\xcc\x06\xbe\x26\xd6\x06\x8d\x28\xc3\x06\x38\x27\xc9\x06\x3e\x26\xe8\x06\x57\x28\xda\x06\x37\x27\xdb\x06\x01\x26\xd2\x06\xc8\x28\xc3\x06\x6e\x27\xc9\x06\x3b\x26\xd8\x06\x59\x29\xd2\x06\x51\x27\xd6\x06\xb1\x26\xd4\x06\x48\x29\xc6\x06\x55\x27\xda\x06\xb9\x26\xde\x06\xa4\x29\xce\x06\x43\x27\xcd\x06\xbb\x26\xe7\x06\x50\x29\xdc\x06\x64\x27\xe0\x06\x9f\x26\xdd\x06\x91\x28\xcf\x06\x69\x27\xd6\x06\x8f\x26\xd7\x06\x37\x28\xd5\x06\x09\x27\xd5\x06\x1b\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd0\x06\xa8\x28\xd6\x06\x2e\x27\xcf\x06\x70\x26\xd0\x06\xb1\x28\xc5\x06\x12\x27\xc7\x06\x63\x26\xd8\x06\xb4\x28\xc7\x06\x88\x27\xcd\x06\x55\x26\xce\x06\xf3\x28\xc8\x06\x70\x27\xc1\x06\x50\x26\xe1\x06\xc6\x28\xd7\x06\x55\x27\xd0\x06\x85\x26\xcb\x06\x9c\x28\xd6\x06\x5c\x27\xc4\x06\x6e\x26\xe5\x06\x8f\x28\xe5\x06\x4d\x27\xd3\x06\x47\x26\xcf\x06\x57\x28\xc9\x06\x6a\x27\xd9\x06\x9f\x26\xd6\x06\x5c\x28\xd4\x06\x92\x27\xd6\x06\x6a\x26\xd1\x06\xec\x28\xc1\x06\x77\x27\xcd\x06\x75\x26\xe1\x06\xa1\x28\xdc\x06\x7d\x27\xcb\x06\x64\x26\xd6\x06\xcd\x28\xd1\x06\x4e\x27\xc4\x06\x69\x26\xe2\x06\xea\x28\xdf\x06\x8d\x27\xd2\x06\x90\x26\xd2\x06\xe0\x28\xd5\x06\x55\x27\xcb\x06\x6f\x26\xdc\x06\x04\x29\xd0\x06\x1e\x27\xca\x06\x2b\x26\xbc\x06\x9a\x28\xb5\x06\x61\x27\xc4\x06\x89\x26\xe1\x06\x18\x28\xd4\x06\x76\x27\xd2\x06\x57\x26\xd5\x06\x24\x28\xd3\x06\x30\x27\xcc\x06\x33\x26\xeb\x06\x76\x28\xd3\x06\x2e\x27\xde\x06\x74\x26\xd9\x06\x48\x28\xd8\x06\x4a\x27\xd4\x06\x86\x26\xd2\x06\xca\x27\xca\x06\x08\x27\xcd\x06\x34\x26\xad\x06\xe6\x27\x9a\x06\x52\x27\xb7\x06\xdf\x25\xdc\x06\xe0\x27\xd6\x06\x56\x27\xd1\x06\x0a\x26\xd1\x06\x82\x28\xbe\x06\x5a\x27\xcd\x06\x37\x26\xc7\x06\x6f\x28\xc3\x06\x31\x27\xbf\x06\x3c\x26\xbe\x06\x3d\x28\xb9\x06\x55\x27\xc6\x06\x29\x26\xd2\x06\x42\x28\xc5\x06\x39\x27\xd0\x06\x82\x26\xdd\x06\xa2\x28\xd0\x06\x33\x27\xd4\x06\x7a\x26\xdd\x06\x6d\x28\xc7\x06\x2e\x27\xcf\x06\x38\x26\xc6\x06\x6b\x28\xc3\x06\x4b\x27\xc7\x06\x3f\x26\xd3\x06\x80\x28\xcf\x06\x90\x27\xcd\x06\x61\x26\xd9\x06\x71\x28\xd2\x06\x27\x27\xd8\x06\x85\x26\xd6\x06\x40\x28\xcd\x06\x3c\x27\xc9\x06\x54\x26\xba\x06\xb1\x28\xb0\x06\x4a\x27\xbe\x06\x35\x26\xd2\x06\x96\x28\xd6\x06\x71\x27\xca\x06\x57\x26\xcb\x06\x42\x28\xcc\x06\x06\x27\xc9\x06\xe5\x25\xd7\x06\xb5\x28\xda\x06\x38\x27\xcc\x06\x24\x26\xce\x06\xd8\x28\xc8\x06\x26\x27\xc1\x06\xa3\x25\xd0\x06\x84\x28\xcb\x06\x03\x27\xc4\x06\x96\x25\xcd\x06\x58\x28\xcf\x06\x03\x27\xc8\x06\x57\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbf\x06\x1b\x28\xbf\x06\xfb\x26\xd4\x06\xa3\x25\xdc\x06\x14\x28\xd4\x06\x3b\x27\xd0\x06\xdf\x25\xdf\x06\x20\x28\xc8\x06\xab\x26\xce\x06\x7f\x25\xd0\x06\x36\x28\xd0\x06\x90\x26\xc2\x06\x86\x25\xd5\x06\x5e\x28\xbb\x06\xcf\x26\xc9\x06\x69\x25\xcb\x06\x74\x28\xc4\x06\xeb\x26\xb9\x06\x78\x25\xe7\x06\xbe\x28\xdc\x06\xc3\x26\xca\x06\x8b\x25\xca\x06\x99\x28\xbf\x06\xeb\x26\xcf\x06\x8b\x25\xd9\x06\x1b\x28\xd5\x06\x16\x27\xd5\x06\xbe\x25\xce\x06\xc9\x27\xc1\x06\xb4\x26\xd1\x06\x8a\x25\xd5\x06\x10\x28\xc9\x06\x7c\x26\xba\x06\x3a\x25\xc5\x06\x29\x28\xc7\x06\x87\x26\xcc\x06\xc0\x25\xd3\x06\x33\x28\xd7\x06\xdb\x26\xc3\x06\x86\x25\xd3\x06\x8b\x28\xcc\x06\xe2\x26\xc8\x06\x6d\x25\xd4\x06\x71\x28\xd2\x06\xaa\x26\xc0\x06\x78\x25\xcd\x06\x7c\x28\xc7\x06\xb8\x26\xbe\x06\x7e\x25\xd9\x06\xf7\x27\xd4\x06\xcb\x26\xd2\x06\x74\x25\xb1\x06\xbc\x27\xab\x06\x92\x26\xd5\x06\x3b\x25\xd2\x06\xb4\x27\xd9\x06\xe5\x26\xcd\x06\xbc\x25\xd3\x06\xf5\x27\xc3\x06\xf9\x26\xc8\x06\x8e\x25\xc3\x06\x31\x28\xbc\x06\xea\x26\xc6\x06\xe3\x25\xcb\x06\x40\x28\xc4\x06\xfc\x26\xcb\x06\xdd\x25\xd9\x06\x1b\x28\xd7\x06\x0c\x27\xd2\x06\xec\x25\xd3\x06\xc9\x27\xc8\x06\xcf\x26\xcd\x06\x9a\x25\xd1\x06\x92\x27\xcd\x06\x22\x26\xc6\x06\x2b\x25\xd1\x06\x94\x27\xbf\x06\x1f\x26\xcb\x06\x6e\x25\xd8\x06\xd7\x27\xca\x06\xc5\x26\xd0\x06\xcd\x25\xce\x06\xcc\x27\xd7\x06\xce\x26\xd0\x06\x9f\x25\xc4\x06\x1c\x28\xc2\x06\xc2\x26\xbe\x06\x29\x26\xd7\x06\x5d\x28\xc9\x06\xb1\x26\xd4\x06\xee\x25\xc4\x06\x1a\x28\xc1\x06\xe4\x26\xc0\x06\xb3\x25\xd0\x06\xbd\x27\xcc\x06\x69\x26\xc9\x06\x59\x25\xbe\x06\xbe\x27\xbc\x06\x92\x26\xc6\x06\xa4\x25\xad\x06\x1e\x28\xa9\x06\xdd\x26\xd1\x06\x29\x26\xd4\x06\x1b\x28\xc5\x06\xd3\x26\xd8\x06\xf1\x25\xd3\x06\xc6\x27\xcf\x06\x17\x27\xc6\x06\xc7\x25\xd9\x06\xbe\x27\xd5\x06\x08\x27\xc1\x06\x1b\x26\xe4\x06\xc5\x27\xd3\x06\xa2\x26\xdb\x06\x37\x26\xc9\x06\xad\x27\xd1\x06\x48\x26\xd0\x06\x71\x25\xd1\x06\xb7\x27\xc9\x06\x78\x26\xca\x06\xc5\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcb\x06\xbd\x27\xc3\x06\xda\x26\xc2\x06\xf6\x25\xc9\x06\x13\x28\xb4\x06\x01\x27\xad\x06\xf4\x25\xe4\x06\xdf\x27\xc5\x06\xa5\x26\xcd\x06\xd2\x25\xc9\x06\x8a\x27\xda\x06\xfc\x26\xc9\x06\xd7\x25\xca\x06\xad\x27\xbd\x06\xdd\x26\xd9\x06\xa8\x25\xc0\x06\xf3\x26\xc5\x06\x1f\x26\xc7\x06\x56\x25\xc4\x06\x08\x27\xc2\x06\x87\x26\xc9\x06\x6a\x25\xc7\x06\xa5\x27\xbf\x06\xb3\x26\xcd\x06\xbc\x25\xd4\x06\x09\x28\xd4\x06\xb8\x26\xd0\x06\x9c\x25\xc1\x06\x70\x27\xc0\x06\xaa\x26\xd1\x06\xc3\x25\xd1\x06\xa3\x27\xbf\x06\x84\x26\xc6\x06\xc8\x25\xd1\x06\x9a\x27\xcb\x06\x56\x26\xd9\x06\x8d\x25\xca\x06\xc2\x26\xca\x06\x04\x26\xbe\x06\x40\x25\xc3\x06\x9b\x26\xbf\x06\xf0\x25\xbf\x06\x20\x25\xb4\x06\x81\x27\xb3\x06\x8c\x26\xc9\x06\x72\x25\xbf\x06\xa6\x27\xab\x06\x55\x26\xc5\x06\x63\x25\xc8\x06\x43\x27\xc7\x06\x6e\x26\xca\x06\x7f\x25\xc3\x06\x61\x27\xac\x06\x96\x26\xbf\x06\x2a\x25\xbf\x06\x51\x27\xb8\x06\x21\x26\xc3\x06\x19\x25\xc0\x06\x45\x27\xb8\x06\x08\x26\xa9\x06\xd6\x24\xd4\x06\x1e\x27\xbb\x06\x72\x25\xcc\x06\x68\x24\xd7\x06\xfb\x26\xd2\x06\x35\x26\xc9\x06\x8d\x24\xd3\x06\x3a\x27\xd2\x06\x39\x26\xc8\x06\x60\x24\xbe\x06\x8e\x27\xbd\x06\x37\x26\xc9\x06\x88\x24\xd8\x06\x5a\x27\xca\x06\x36\x26\xcb\x06\xde\x24\xb2\x06\x62\x27\xa6\x06\xbb\x26\xc6\x06\x30\x25\xd3\x06\x1a\x27\xc8\x06\x93\x26\xcc\x06\x54\x25\xc5\x06\xba\x26\xc0\x06\xe5\x25\xc9\x06\xea\x24\xce\x06\x46\x27\xc8\x06\x76\x26\xd1\x06\x7a\x25\xd6\x06\x65\x27\xc1\x06\xc0\x26\xb5\x06\x6f\x25\xc9\x06\x70\x27\xca\x06\xb0\x26\xc0\x06\x66\x25\xbc\x06\x4d\x27\xbf\x06\xa6\x26\xb7\x06\x36\x25\xd3\x06\x70\x27\xc0\x06\xc0\x26\xc7\x06\x16\x25\xcb\x06\x68\x27\xd2\x06\xf9\x26\xbc\x06\x27\x25\xb1\x06\xb1\x27\xac\x06\x9a\x26\xc4\x06\xcb\x24\xcf\x06\xa6\x27\xca\x06\xd6\x26\xc2\x06\x4d\x25\xd7\x06\xb1\x27\xd4\x06\xf2\x26\xcd\x06\x55\x25\xcc\x06\xe6\x27\xb9\x06\xcf\x26\xc6\x06\x8d\x25\x99\x06\x98\x28\x92\x06\x36\x27\xa5\x06\x0c\x26\xd9\x06\x39\x28\xd6\x06\x0a\x27\xd3\x06\xb6\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb0\x06\x44\x28\xb6\x06\x45\x27\xae\x06\x2b\x26\xc5\x06\x72\x27\xc1\x06\x60\x26\xb9\x06\x59\x25\xcd\x06\xee\x27\xbe\x06\x8f\x26\xd1\x06\x94\x25\xce\x06\x15\x28\xbe\x06\xcd\x26\xc3\x06\xf6\x25\xc3\x06\x1c\x28\xc5\x06\xec\x26\xc9\x06\xfc\x25\xc2\x06\x43\x28\xaa\x06\xff\x26\xcf\x06\xef\x25\xd8\x06\x6e\x28\xca\x06\xd3\x26\xcd\x06\x0c\x26\xd1\x06\x59\x28\xce\x06\xfc\x26\xcf\x06\x21\x26\xcd\x06\xf5\x27\xc6\x06\xbe\x26\xc9\x06\xbb\x25\xb8\x06\x00\x28\xb6\x06\x9f\x26\xbb\x06\x73\x25\xc8\x06\x1b\x28\xbb\x06\xef\x26\xca\x06\xda\x25\xd4\x06\x4a\x28\xcc\x06\xc7\x26\xcc\x06\xea\x25\xc9\x06\xdd\x28\xb9\x06\xc7\x26\xcf\x06\x24\x26\xdc\x06\xc4\x28\xc6\x06\x19\x27\xd5\x06\x41\x26\xd9\x06\x15\x29\xc8\x06\x62\x27\xd1\x06\x41\x26\xc3\x06\x8f\x28\xc3\x06\xc9\x26\xc7\x06\xe1\x25\xd2\x06\x2f\x28\xc5\x06\xad\x26\xc8\x06\xb5\x25\xb8\x06\x78\x28\xb4\x06\xe8\x26\xc2\x06\x12\x26\xc6\x06\x86\x28\xc8\x06\xea\x26\xc8\x06\x15\x26\xd0\x06\x86\x28\xd9\x06\xe8\x26\xd5\x06\x0a\x26\xb8\x06\x66\x28\xab\x06\x1e\x27\xc3\x06\x0e\x26\xc4\x06\x88\x28\xbd\x06\x0a\x27\xcf\x06\x54\x26\xd5\x06\x9a\x28\xcd\x06\x4c\x27\xd9\x06\x19\x26\xd2\x06\x5f\x28\xb9\x06\x93\x26\xca\x06\xd8\x25\xc7\x06\x7f\x28\xc0\x06\xf8\x26\xd2\x06\x48\x26\xc7\x06\x8a\x28\xc6\x06\x80\x27\xc7\x06\x88\x26\xd2\x06\x71\x28\xd3\x06\x4b\x27\xca\x06\x52\x26\xcb\x06\xe9\x27\xcf\x06\x62\x27\xdd\x06\x20\x26\xd3\x06\x08\x29\xc5\x06\x4b\x27\xb3\x06\x62\x25\x00\x00\x68\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x69\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x6a\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\x1a\x15\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\x18\x15\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\x16\x15\x00\x00\xa2\x15\xf9\x06\x09\x2d\xef\x06\xeb\x2a\xe9\x06\xa4\x29\xe6\x06\x5f\x2c\xe1\x06\x47\x2b\xe9\x06\xb9\x2a\xf2\x06\xb0\x2c\xe9\x06\x7d\x2b\xf5\x06\xd5\x2a\xf0\x06\xce\x2c\xf5\x06\xe5\x2b\xe1\x06\x07\x2b\x08\x07\x33\x2d\xf5\x06\x86\x2b\xf7\x06\x96\x2b\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf0\x06\x70\x2d\xde\x06\x16\x2b\xef\x06\xfa\x2a\xea\x06\x31\x2d\xe3\x06\x26\x2b\xf3\x06\x13\x2b\xf7\x06\xf5\x2c\xe4\x06\x1e\x2b\xf1\x06\x7a\x2a\xef\x06\xd5\x2c\xe3\x06\xc3\x2a\xe9\x06\x76\x2a\xf4\x06\xac\x2c\xef\x06\x2c\x2b\xea\x06\xf4\x2a\xff\x06\xf6\x2c\xf3\x06\x01\x2b\xef\x06\x70\x2a\xe9\x06\x30\x2d\xd9\x06\xdf\x2a\xee\x06\x60\x2a\xec\x06\x90\x2d\xdf\x06\x23\x2b\xfb\x06\x05\x2b\xef\x06\x2c\x2d\xed\x06\x2b\x2b\xef\x06\x13\x2b\xf0\x06\x36\x2d\xeb\x06\xfa\x2a\xef\x06\x02\x2b\xfb\x06\x22\x2d\xeb\x06\x36\x2b\xf5\x06\xeb\x2a\xeb\x06\x3e\x2d\xe9\x06\x26\x2b\xf4\x06\xf9\x2a\xf2\x06\x29\x2d\xf0\x06\x50\x2b\xec\x06\xd7\x2a\xfa\x06\x65\x2d\xee\x06\xc7\x2b\xeb\x06\x2a\x2b\x02\x07\xce\x2c\xf7\x06\x08\x2b\xf1\x06\xa9\x2a\xf3\x06\x23\x2d\xf4\x06\x25\x2b\xfb\x06\xe2\x2a\xfc\x06\xc5\x2c\xf2\x06\xf7\x2a\xed\x06\xc2\x2a\xf0\x06\xb2\x2c\xf2\x06\xd8\x2a\xe9\x06\xc2\x2a\xff\x06\x8a\x2c\xfb\x06\x0d\x2b\xfd\x06\xe6\x2a\xf0\x06\x90\x2c\xe1\x06\xd8\x2a\xea\x06\x79\x2a\xf4\x06\xc7\x2c\xed\x06\x49\x2b\xef\x06\xb4\x2a\xf2\x06\xb0\x2c\xe0\x06\x34\x2b\xe7\x06\xe5\x2a\xdb\x06\xb8\x2c\xd1\x06\xf3\x2a\xeb\x06\xa5\x2a\xd7\x06\xc7\x2c\xcb\x06\x63\x2b\xdd\x06\xad\x2a\xd4\x06\xce\x2c\xcf\x06\xa4\x2b\xd8\x06\xfe\x2a\xe5\x06\xca\x2c\xe0\x06\x18\x2b\xf3\x06\x4b\x2b\xf1\x06\xa5\x2c\xe8\x06\x14\x2b\xf1\x06\xdb\x2a\xf5\x06\xbe\x2c\xea\x06\x81\x2b\xf2\x06\xf9\x2a\xf2\x06\xa4\x2c\xe5\x06\x7b\x2b\xe2\x06\xfa\x2a\xfb\x06\x67\x2c\xf3\x06\x17\x2b\xf6\x06\xb9\x2a\xe7\x06\x5c\x2c\xdd\x06\x08\x2b\xeb\x06\x8d\x2a\xdd\x06\x1b\x2c\xdd\x06\x0f\x2b\xeb\x06\xe9\x2a\xf0\x06\xff\x2b\xf5\x06\x4f\x2b\xee\x06\xda\x2a\xeb\x06\x8c\x2b\xe1\x06\xce\x2a\xeb\x06\x9a\x2a\xe7\x06\xb1\x2b\xe0\x06\x8e\x2a\xef\x06\x79\x2a\xe4\x06\xb8\x2b\xd8\x06\x03\x2b\xe8\x06\xbc\x2a\xe6\x06\xf4\x2b\xe4\x06\xcd\x2a\xe5\x06\x90\x2a\xe4\x06\xc9\x2b\xe7\x06\xc7\x2a\xea\x06\x98\x2a\xe4\x06\x32\x2c\xe3\x06\xff\x2a\xef\x06\xb8\x2a\xd8\x06\x44\x2c\xe3\x06\xfa\x2a\xf0\x06\x83\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd1\x06\x6c\x2c\xd4\x06\x2e\x2b\xdf\x06\xfe\x2a\xee\x06\x16\x2c\xec\x06\xd6\x2a\xf6\x06\xb4\x2a\xf3\x06\x6c\x2c\xeb\x06\xc3\x2a\xf0\x06\xeb\x2a\xf2\x06\x73\x2c\xf5\x06\x0f\x2b\xee\x06\x3f\x2b\x00\x07\x37\x2c\xf1\x06\x10\x2b\xf2\x06\xe7\x2a\xf5\x06\x1b\x2c\xeb\x06\xa4\x2a\xec\x06\xb0\x2a\xe7\x06\x6a\x2c\xe8\x06\xf5\x2a\xe9\x06\xa7\x2a\xfa\x06\x4d\x2c\xe6\x06\x48\x2b\xf1\x06\xb3\x2a\xe6\x06\x7d\x2c\xde\x06\xd4\x2a\xea\x06\x94\x2a\xe2\x06\x7a\x2c\xd8\x06\xd2\x2a\xe5\x06\xad\x2a\xf0\x06\x2c\x2c\xde\x06\x2e\x2b\xe8\x06\xdf\x2a\xe7\x06\x4d\x2c\xdc\x06\x75\x2b\xe6\x06\xeb\x2a\xe5\x06\xb5\x2c\xd1\x06\x10\x2b\xed\x06\xd2\x2a\xf5\x06\x7d\x2c\xec\x06\xef\x2a\xf4\x06\xa8\x2a\xf4\x06\xc3\x2c\xe7\x06\xb3\x2a\xf0\x06\xe2\x2a\xf3\x06\x7d\x2c\xf1\x06\xb6\x2a\xec\x06\x81\x2a\xeb\x06\x29\x2c\xd9\x06\xb8\x2a\xdf\x06\x31\x2a\xeb\x06\x3b\x2c\xe4\x06\x1d\x2b\xef\x06\xca\x2a\xec\x06\x1f\x2c\xdc\x06\xfb\x2a\xea\x06\xa1\x2a\xee\x06\x10\x2c\xf3\x06\x3f\x2c\xeb\x06\x85\x2a\xed\x06\xf4\x2b\xdf\x06\xbe\x2a\xea\x06\x6a\x2a\xee\x06\x73\x2c\xec\x06\x0c\x2b\xf3\x06\x8e\x2a\xe2\x06\x4d\x2c\xd8\x06\xb2\x2a\xdd\x06\x48\x2a\xe7\x06\x0b\x2c\xd1\x06\xe2\x2a\xe8\x06\x0f\x2a\xf2\x06\x28\x2c\xe8\x06\xff\x2a\xeb\x06\x40\x2a\xe9\x06\x2d\x2c\xd9\x06\xc8\x2a\xef\x06\x64\x2a\xef\x06\x13\x2c\xe2\x06\xe6\x2a\xe3\x06\x64\x2a\xf8\x06\xd7\x2b\xfa\x06\xb2\x2a\xec\x06\x21\x2a\xea\x06\xcf\x2b\xea\x06\xb8\x2a\xf1\x06\x2a\x2a\xb3\x06\x67\x2c\xb1\x06\xa1\x2a\xe5\x06\x31\x2a\xee\x06\xd9\x2b\xec\x06\x8b\x2a\xef\x06\xe9\x29\xcf\x06\x7d\x2c\xbe\x06\x09\x2b\xe5\x06\x0b\x2a\xf0\x06\x85\x2c\xe7\x06\xf3\x2a\xe6\x06\x6b\x2a\xfc\x06\x71\x2c\xf3\x06\xd9\x2a\xed\x06\xa8\x2a\xf1\x06\x3e\x2c\xe3\x06\xbd\x2a\xf2\x06\x89\x2a\xe9\x06\x6c\x2c\xe4\x06\x48\x2b\xf2\x06\x92\x2a\xe3\x06\x10\x2c\xe0\x06\x42\x2b\xe6\x06\xa5\x2a\xf0\x06\x45\x2c\xec\x06\x11\x2b\xe7\x06\x63\x2a\xdb\x06\x75\x2c\xdf\x06\x0b\x2b\xea\x06\x5b\x2a\xf8\x06\xc0\x2c\xe9\x06\x48\x2b\xec\x06\xb0\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf4\x06\xa2\x2c\xec\x06\xfb\x2a\xf1\x06\x9e\x2a\xf9\x06\x49\x2c\xf0\x06\xe7\x2a\xee\x06\xab\x2a\xeb\x06\x73\x2c\xe1\x06\x04\x2b\xec\x06\x82\x2a\xe7\x06\x4e\x2c\xe8\x06\x15\x2b\xef\x06\x73\x2a\xe5\x06\x3b\x2c\xe8\x06\x0c\x2b\xea\x06\x8a\x2a\xe0\x06\x0f\x2c\xd6\x06\xc6\x2a\xed\x06\x2a\x2a\xd8\x06\x8d\x2c\xd2\x06\x1c\x2b\xef\x06\x94\x2a\xeb\x06\xb3\x2c\xe3\x06\x21\x2b\xe7\x06\xd2\x2a\xe9\x06\xb0\x2c\xe7\x06\x1c\x2b\xeb\x06\x95\x2a\xc2\x06\xc6\x2c\xa8\x06\x3a\x2b\xe4\x06\x44\x2a\xef\x06\xbe\x2c\xd8\x06\x0a\x2b\xe3\x06\x81\x2a\xf6\x06\x14\x2d\xeb\x06\xc8\x2a\xee\x06\x4c\x2a\xe9\x06\x39\x2c\xe0\x06\xb5\x2a\xe8\x06\x7e\x2a\xf4\x06\x86\x2c\xe6\x06\xe4\x2a\xea\x06\x70\x2a\xf4\x06\x65\x2c\xec\x06\x33\x2b\xf0\x06\xa0\x2a\xf3\x06\xc1\x2c\xe7\x06\x32\x2b\xf2\x06\x77\x2a\xef\x06\xb0\x2c\xe7\x06\xfd\x2a\xe5\x06\x2d\x2a\xf2\x06\xcf\x2c\xec\x06\x12\x2b\xfc\x06\xb5\x2a\xf9\x06\xb4\x2c\xe3\x06\x12\x2b\xe8\x06\x6e\x2a\xf4\x06\x81\x2c\xdf\x06\xae\x2a\xe0\x06\x03\x2a\xe2\x06\x77\x2c\xe3\x06\x17\x2b\xf3\x06\x7a\x2a\xf0\x06\xb0\x2c\xea\x06\xef\x2a\xf9\x06\x81\x2a\xec\x06\x4e\x2c\xe6\x06\x71\x2b\xee\x06\x73\x2a\xe0\x06\x32\x2c\xde\x06\x68\x2b\xea\x06\x90\x2a\xe9\x06\x7d\x2c\xe6\x06\xfd\x2a\xe4\x06\xa9\x2a\xe8\x06\x90\x2c\xde\x06\xf7\x2a\xe8\x06\x82\x2a\xec\x06\x6a\x2c\xe5\x06\xc9\x2a\xe2\x06\x25\x2a\xea\x06\x76\x2c\xdc\x06\x5b\x2b\xe8\x06\x7d\x2a\xfb\x06\x24\x2d\xea\x06\x28\x2b\xf7\x06\xd3\x2a\x02\x07\xd8\x2c\xf3\x06\x33\x2b\xfb\x06\xe5\x2a\x00\x07\xa6\x2c\xf3\x06\x49\x2b\xf7\x06\x03\x2b\xf3\x06\x73\x2c\xf3\x06\xaf\x2b\xf4\x06\xc8\x2a\xe0\x06\xc0\x2c\xe7\x06\xc9\x2b\xf4\x06\xff\x2a\xf5\x06\xc2\x2c\xf7\x06\x77\x2b\xee\x06\xee\x2a\x00\x07\x79\x2d\xf0\x06\x8b\x2b\xf9\x06\x0f\x2b\xf5\x06\x03\x2d\xed\x06\xa6\x2b\xf4\x06\x23\x2b\xf9\x06\xb0\x2c\xf4\x06\xd4\x2b\x01\x07\x15\x2b\xf9\x06\x08\x2d\xf5\x06\xed\x2b\x00\x07\x1a\x2b\xf7\x06\x12\x2d\xe9\x06\xcc\x2b\xfb\x06\xcf\x2a\xf1\x06\xbb\x2c\xfe\x06\xd8\x2b\xfc\x06\x2b\x2b\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xde\x06\xb3\x2c\xe0\x06\xbd\x2b\xf2\x06\xe6\x2a\xf8\x06\xc5\x2c\xf2\x06\x8d\x2b\xf3\x06\xc3\x2a\xe6\x06\x16\x2d\xec\x06\xe9\x2b\xfe\x06\x56\x2b\xe5\x06\x06\x2d\xe2\x06\xac\x2b\xe4\x06\x00\x2b\xdd\x06\xfa\x2c\xdb\x06\x85\x2b\xf0\x06\x15\x2b\xe3\x06\x2b\x2d\xd7\x06\x63\x2b\xeb\x06\xf7\x2a\xe6\x06\xfe\x2c\xf2\x06\xb7\x2b\xf6\x06\xd4\x2a\xfa\x06\x88\x2c\xe6\x06\x9c\x2b\xeb\x06\x00\x2b\xea\x06\xa8\x2c\xe6\x06\x3e\x2b\xeb\x06\x84\x2a\x01\x07\x69\x2d\xf8\x06\x50\x2b\xfb\x06\x21\x2b\xeb\x06\xb3\x2d\xda\x06\x6f\x2b\xf4\x06\x28\x2b\x01\x07\x81\x2d\xff\x06\xbf\x2b\xfe\x06\xf7\x2a\xeb\x06\x44\x2d\xe3\x06\x88\x2b\xf6\x06\xee\x2a\xf8\x06\x16\x2d\xf1\x06\xa1\x2b\xfd\x06\xf0\x2a\xf6\x06\xea\x2c\xf3\x06\x87\x2b\xf4\x06\x17\x2b\xfb\x06\x19\x2d\xe9\x06\x68\x2b\xf0\x06\xc6\x2a\xf0\x06\xdb\x2c\xea\x06\xc7\x2b\xef\x06\x12\x2b\xf4\x06\x06\x2d\xe8\x06\xe7\x2b\xf9\x06\x21\x2b\xed\x06\xa9\x2d\xde\x06\x6b\x2b\xfa\x06\x0d\x2b\x03\x07\x4d\x2d\xf8\x06\x75\x2b\x05\x07\x31\x2b\xe8\x06\x73\x2d\xe4\x06\x8e\x2b\xfc\x06\xd7\x2a\xf1\x06\x3b\x2d\xea\x06\xa5\x2b\xea\x06\xce\x2a\xef\x06\x16\x2d\xd6\x06\x56\x2b\xe8\x06\xb6\x2a\xe3\x06\x36\x2d\xdc\x06\x9a\x2b\xf1\x06\xf1\x2a\xf4\x06\x21\x2d\xec\x06\xad\x2b\xeb\x06\xf6\x2a\xf7\x06\x16\x2d\xed\x06\x73\x2b\xf0\x06\xf6\x2a\xf1\x06\x90\x2d\xe3\x06\x5c\x2b\xf2\x06\x04\x2b\xfb\x06\x1b\x2e\xe9\x06\x00\x2b\xdc\x06\x28\x2b\xf9\x06\x08\x2e\xf1\x06\x4f\x2b\xef\x06\x0c\x2b\xfa\x06\x5c\x2d\xea\x06\x25\x2b\x04\x07\xd2\x2a\xee\x06\x9e\x2c\xe8\x06\x9d\x2a\xe4\x06\x5c\x2a\xf1\x06\xeb\x2c\xdc\x06\x0d\x2b\xeb\x06\xd1\x2a\xf0\x06\x62\x2c\xe5\x06\x45\x2b\xeb\x06\x9b\x2a\xe7\x06\x42\x2c\xe3\x06\x3e\x2b\xeb\x06\x9e\x2a\xee\x06\x6d\x2c\xf0\x06\x79\x2b\xe4\x06\xca\x2a\xf5\x06\xbf\x2c\xda\x06\x70\x2b\xf0\x06\xd2\x2a\xf5\x06\xfc\x2c\xed\x06\x78\x2b\xe9\x06\xcf\x2a\xee\x06\xe1\x2c\xe2\x06\x21\x2b\xee\x06\x7c\x2a\xf2\x06\x63\x2d\xe0\x06\x70\x2b\xf4\x06\x10\x2b\xf2\x06\xde\x2c\xed\x06\x52\x2b\xed\x06\xf2\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xea\x06\xb4\x2c\xeb\x06\x3e\x2b\xe8\x06\xaf\x2a\xd9\x06\x78\x2c\xd9\x06\x59\x2b\xe9\x06\xb7\x2a\xea\x06\x42\x2c\xea\x06\x63\x2b\xf0\x06\xa6\x2a\xea\x06\x5c\x2c\xea\x06\x01\x2b\xe4\x06\xa6\x2a\xea\x06\xf4\x2b\xed\x06\xee\x2a\xea\x06\x49\x2a\xee\x06\x68\x2c\xf7\x06\x43\x2b\xeb\x06\x83\x2a\xe0\x06\xc9\x2c\xd7\x06\x64\x2b\xf0\x06\xb0\x2a\xfd\x06\xa3\x2c\xef\x06\x0a\x2b\xfd\x06\x87\x2a\xe1\x06\x89\x2c\xe2\x06\x27\x2b\xe4\x06\x67\x2a\xdd\x06\x61\x2c\xdf\x06\x3b\x2b\xe1\x06\x5d\x2a\xec\x06\xf9\x2b\xe4\x06\x14\x2b\xdf\x06\x75\x2a\xee\x06\x1d\x2c\xe5\x06\xce\x2a\xe0\x06\x38\x2a\xff\x06\x6c\x2c\xe9\x06\x33\x2b\xfb\x06\x7e\x2a\xf1\x06\x41\x2c\xe9\x06\x16\x2b\xf5\x06\xae\x2a\xf4\x06\x27\x2c\xea\x06\x57\x2b\xf0\x06\x9c\x2a\xea\x06\xe1\x2b\xe3\x06\x19\x2b\xe8\x06\x99\x2a\xec\x06\xf8\x2b\xec\x06\x26\x2b\xec\x06\xa8\x2a\xe9\x06\x92\x2b\xdf\x06\xe2\x2a\xea\x06\x70\x2a\xec\x06\xba\x2b\xe0\x06\x88\x2a\xe9\x06\x2a\x2a\xf2\x06\xa1\x2b\xf0\x06\x85\x2a\xe4\x06\xf1\x29\xec\x06\xae\x2b\xea\x06\xb7\x2a\xe4\x06\x6b\x2a\xea\x06\x9b\x2b\xed\x06\x41\x2b\xe4\x06\x64\x2a\xed\x06\x11\x2c\xe4\x06\x25\x2b\xf1\x06\x5b\x2a\xea\x06\xc0\x2b\xe3\x06\xfb\x2a\xe9\x06\x71\x2a\xeb\x06\xa5\x2b\xed\x06\xd4\x2a\xeb\x06\x4f\x2a\xe0\x06\x24\x2b\xdf\x06\x43\x2a\xe2\x06\xe3\x29\xe5\x06\x2f\x2b\xe3\x06\x57\x2a\xe9\x06\xca\x29\xe9\x06\xe1\x2b\xe3\x06\xe9\x2a\xe6\x06\x09\x2a\xd9\x06\xb6\x2b\xd7\x06\x62\x2a\xde\x06\x47\x2a\xe6\x06\xcb\x2b\xe0\x06\x98\x2a\xf0\x06\x12\x2a\xd9\x06\x30\x2c\xd2\x06\x67\x2a\xf6\x06\x4d\x2a\xed\x06\x96\x2c\xe5\x06\x5a\x2a\xe6\x06\x71\x2a\xe4\x06\x3e\x2c\xe7\x06\xb9\x29\xe5\x06\xeb\x29\xf2\x06\x7d\x2b\xe3\x06\x65\x29\xec\x06\x92\x29\xdf\x06\x87\x2b\xd5\x06\x98\x2a\xdf\x06\xf0\x29\xe8\x06\xc6\x2b\xd5\x06\x4e\x2a\xe0\x06\x42\x2a\xe2\x06\x48\x2c\xe1\x06\x91\x2a\xe0\x06\xec\x29\xf3\x06\x31\x2c\xe2\x06\x80\x2a\xf0\x06\x01\x2a\xe2\x06\xef\x2b\xc9\x06\xe2\x2a\xe5\x06\x12\x2a\xf7\x06\x92\x2b\xeb\x06\x80\x2a\xe6\x06\x19\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe5\x06\x56\x2b\xe2\x06\x5b\x2a\xdf\x06\x9b\x29\xf4\x06\xa7\x2b\xea\x06\xad\x2a\xe9\x06\x2c\x2a\xdf\x06\xfc\x2b\xdb\x06\xe1\x2a\xdf\x06\x5c\x2a\xee\x06\x02\x2c\xf1\x06\xf7\x2a\xf3\x06\x73\x2a\xda\x06\xd7\x2b\xe2\x06\xab\x2a\xd9\x06\x0a\x2a\xeb\x06\x1f\x2c\xdf\x06\xb8\x2a\xea\x06\x47\x2a\xea\x06\x19\x2c\xe3\x06\xaa\x2a\xe5\x06\x70\x2a\xe4\x06\x56\x2b\xe5\x06\x5f\x2a\xdc\x06\xdc\x29\xe9\x06\xc4\x2b\xd6\x06\xb0\x2a\xe6\x06\x27\x2a\xe9\x06\xe2\x2b\xe9\x06\x98\x2b\xef\x06\x8c\x2a\xde\x06\x0a\x2c\xd7\x06\xd9\x2a\xea\x06\x7d\x2a\xe6\x06\xd8\x2b\xdc\x06\x74\x2a\xef\x06\x48\x2a\xe4\x06\x97\x2b\xd5\x06\x67\x2a\xeb\x06\x22\x2a\xef\x06\xc5\x2b\xed\x06\x78\x2a\xde\x06\xc1\x29\xe6\x06\x8e\x2b\xdb\x06\x08\x2a\xde\x06\x7a\x29\xe0\x06\x5e\x2b\xd5\x06\x09\x2a\xeb\x06\xba\x29\xe8\x06\xbf\x2b\xe6\x06\x4e\x2a\xed\x06\x1f\x2a\xe6\x06\xd0\x2b\xd7\x06\x83\x2a\xe0\x06\x13\x2a\xe3\x06\x1b\x2c\xe4\x06\xdc\x2a\xee\x06\x7b\x2a\xeb\x06\x44\x2c\xe4\x06\x02\x2b\xec\x06\xad\x2a\xf3\x06\x6a\x2c\xe9\x06\xef\x2a\xef\x06\xa9\x2a\xf5\x06\x23\x2c\xe1\x06\xc9\x2a\xf3\x06\x41\x2a\xdd\x06\x48\x2c\xce\x06\xd1\x2a\xee\x06\x3a\x2a\xea\x06\x7f\x2c\xe4\x06\x26\x2b\xe7\x06\x87\x2a\xe7\x06\x88\x2c\xee\x06\x53\x2b\xe5\x06\xa1\x2a\xf3\x06\x2d\x2c\xdf\x06\x40\x2b\xf1\x06\x7d\x2a\xe5\x06\x3a\x2c\xe4\x06\x3d\x2b\xe0\x06\x9d\x2a\xe3\x06\x77\x2c\xe7\x06\x1f\x2b\xdb\x06\x6c\x2a\xef\x06\x3b\x2c\xe9\x06\x0b\x2b\xe9\x06\x23\x2a\xec\x06\xeb\x2b\xee\x06\xb9\x2a\xe6\x06\xdc\x29\xe1\x06\x57\x2c\xde\x06\x11\x2b\xdf\x06\x9c\x2a\xcc\x06\x80\x2c\xc8\x06\x9c\x2b\xeb\x06\x7f\x2a\xe4\x06\x3f\x2c\xeb\x06\x1c\x2b\xed\x06\x77\x2a\xdc\x06\xe5\x2b\xe2\x06\x03\x2b\xed\x06\x5e\x2a\xd4\x06\x75\x2c\xcc\x06\x2e\x2b\xde\x06\x6e\x2a\xf3\x06\xff\x2b\xe5\x06\xcf\x2a\xee\x06\x92\x2a\xea\x06\x01\x2c\xe1\x06\x9b\x2a\xef\x06\x47\x2a\xea\x06\x31\x2c\xe7\x06\x2f\x2b\xe9\x06\x76\x2a\xdb\x06\x43\x2c\xe0\x06\x1c\x2b\xe5\x06\x9d\x2a\xf8\x06\xa7\x2c\xf3\x06\xdb\x2a\xee\x06\x51\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xef\x06\x44\x2c\xe7\x06\xc5\x2a\xec\x06\x1d\x2a\xf3\x06\x40\x2c\xef\x06\xe9\x2a\xed\x06\x59\x2a\xdb\x06\x3e\x2c\xcd\x06\xd5\x2a\xe9\x06\x66\x2a\xea\x06\xa9\x2b\xf1\x06\x6a\x2a\xe2\x06\xd5\x29\xdd\x06\x69\x2c\xdc\x06\xee\x2a\xea\x06\x1a\x2a\xe1\x06\x81\x2c\xe1\x06\xe5\x2a\xea\x06\x6e\x2a\xe5\x06\x36\x2c\xe9\x06\x1e\x2b\xeb\x06\x82\x2a\xe8\x06\xf8\x2b\xe5\x06\xd7\x2a\xe4\x06\x13\x2a\xf2\x06\x49\x2c\xe7\x06\x33\x2b\xe3\x06\x44\x2a\xf5\x06\x0a\x2c\xe0\x06\x8b\x2a\xf4\x06\x4b\x2a\xeb\x06\xe6\x2b\xde\x06\x4a\x2a\xd7\x06\xa4\x29\xcc\x06\x44\x2c\xc6\x06\xcb\x2a\xe8\x06\x2d\x2a\xe3\x06\x6f\x2c\xdc\x06\x09\x2b\xe2\x06\x73\x2a\xda\x06\x39\x2c\xd1\x06\xfd\x2a\xed\x06\x4c\x2a\xec\x06\xff\x2b\xf1\x06\x16\x2b\xe8\x06\x1e\x2a\xe3\x06\x01\x2c\xd7\x06\xbc\x2a\xe2\x06\x27\x2a\xe6\x06\x08\x2c\xda\x06\xc9\x2a\xe8\x06\x57\x2a\xf8\x06\x26\x2c\xe4\x06\x74\x2a\xef\x06\x16\x2a\xed\x06\xd0\x2b\xe3\x06\x70\x2a\xec\x06\x1f\x2a\xf5\x06\x5c\x2c\xf0\x06\x17\x2b\xf2\x06\x44\x2a\xf2\x06\x93\x2c\xe5\x06\xb1\x2a\xea\x06\x6c\x2a\xf1\x06\x23\x2c\xf2\x06\x9f\x2a\xed\x06\x3d\x2a\xdc\x06\x42\x2c\xce\x06\xd2\x2a\xe5\x06\x4b\x2a\xff\x06\x32\x2c\xf8\x06\x42\x2b\xea\x06\x50\x2a\xe7\x06\xc1\x2b\xe1\x06\x9b\x2a\xe6\x06\x06\x2a\xea\x06\x2e\x2b\xe6\x06\xf2\x29\xe3\x06\xd1\x29\x05\x07\x44\x2c\xf2\x06\x8c\x2a\xf3\x06\x44\x2a\xec\x06\x36\x2c\xed\x06\xcd\x2a\xe1\x06\x62\x2a\xe7\x06\x2f\x2c\xd9\x06\x0e\x2b\xf5\x06\x70\x2a\xf3\x06\xe7\x2b\xeb\x06\xa7\x2a\xe4\x06\x1a\x2a\xe8\x06\xdb\x2b\xde\x06\xab\x2a\xe9\x06\x36\x2a\xd0\x06\x1f\x2c\xc3\x06\xbc\x2a\xf8\x06\x21\x2a\xe8\x06\x69\x2b\xd9\x06\x29\x2a\xdf\x06\x82\x29\xe9\x06\xdb\x2b\xe7\x06\xf9\x2a\xda\x06\x16\x2a\xec\x06\xaf\x2b\xf3\x06\xea\x2a\xf0\x06\x0c\x2a\xec\x06\xc7\x2b\xdc\x06\x63\x2a\xeb\x06\xff\x29\xde\x06\xe9\x2b\xdf\x06\x9a\x2a\xf1\x06\x19\x2a\xe2\x06\x9b\x2b\xd6\x06\x5d\x2a\xf0\x06\x2d\x2a\xe3\x06\xa4\x2b\xd7\x06\x50\x2a\xdf\x06\xde\x29\xed\x06\x3a\x2b\xde\x06\x01\x2a\xdf\x06\x53\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf7\x06\x98\x2b\xe2\x06\xca\x29\xf0\x06\xd6\x29\xf7\x06\x06\x2c\xde\x06\xb1\x2a\xe1\x06\x12\x2a\xe7\x06\x9b\x2b\xed\x06\xcc\x2a\xed\x06\xd9\x29\xd2\x06\x23\x2c\xca\x06\xc2\x2a\xe2\x06\x21\x2a\xe3\x06\x23\x2c\xe9\x06\xef\x2a\xed\x06\x39\x2a\xca\x06\x63\x2c\xd8\x06\x12\x2b\xe9\x06\x0f\x2a\xf2\x06\xd9\x2b\xe6\x06\x14\x2a\xe5\x06\xa7\x29\xf3\x06\x7d\x2c\xdd\x06\x3d\x2a\xed\x06\x27\x2a\xf3\x06\x3f\x2c\xeb\x06\xbc\x2a\xf1\x06\x8d\x2a\xea\x06\x0d\x2c\xe8\x06\xbf\x2a\xe4\x06\x0f\x2a\xe7\x06\xeb\x2b\xed\x06\xa0\x2a\xe5\x06\x23\x2a\xf0\x06\x06\x2c\xf0\x06\x1b\x2b\xea\x06\x31\x2a\xe5\x06\x0d\x2c\xe5\x06\xbb\x2a\xed\x06\x1b\x2a\xf4\x06\xdc\x2b\xe8\x06\x94\x2a\xe8\x06\xfc\x29\xdc\x06\xad\x2b\xd2\x06\x43\x2a\xe6\x06\x78\x29\xe3\x06\x13\x2c\xe4\x06\xb1\x2a\xea\x06\x6b\x2a\xee\x06\x64\x2c\xdc\x06\xbd\x2a\xe8\x06\x44\x2a\xea\x06\x0b\x2c\xed\x06\xce\x2a\xf3\x06\x4b\x2a\xf1\x06\x2f\x2c\xde\x06\x96\x2a\xec\x06\x34\x2a\xef\x06\x3a\x2c\xf7\x06\xf0\x2a\xe9\x06\x1a\x2a\xee\x06\xeb\x2b\xe8\x06\xb5\x2a\xdf\x06\xc3\x29\xea\x06\xcf\x2b\xec\x06\x90\x2a\xe8\x06\xd2\x29\xca\x06\x45\x2c\xc9\x06\x23\x2b\xe2\x06\x82\x2a\xef\x06\x47\x2c\xf2\x06\x5e\x2b\xe2\x06\x5e\x2a\xe7\x06\x5b\x2c\xe9\x06\x1f\x2b\xeb\x06\x95\x2a\xf5\x06\x5c\x2c\xef\x06\x04\x2b\xeb\x06\x76\x2a\xe9\x06\x86\x2c\xec\x06\x60\x2b\xe5\x06\x53\x2a\xdd\x06\x35\x2c\xcd\x06\x08\x2b\xe7\x06\x6e\x2a\xec\x06\x31\x2c\xe8\x06\xd9\x2a\xe3\x06\xd9\x29\xfd\x06\xa0\x2c\xf3\x06\x38\x2b\xf4\x06\xa8\x2a\xda\x06\x71\x2c\xde\x06\x25\x2b\xf1\x06\x85\x2a\xe6\x06\xa6\x2c\xe0\x06\x2b\x2b\xec\x06\xcb\x2a\xf1\x06\xd4\x2c\xf1\x06\x8c\x2b\xe0\x06\x83\x2a\xe8\x06\xdd\x2c\xe7\x06\x52\x2b\xe8\x06\xeb\x2a\xd6\x06\xea\x2c\xd4\x06\x46\x2b\xe4\x06\x77\x2a\xeb\x06\xab\x2c\xd9\x06\xa5\x2a\xf1\x06\x72\x2a\xfa\x06\x36\x2d\xe3\x06\x06\x2b\xe7\x06\xad\x2a\xfc\x06\x4d\x2d\xe6\x06\x23\x2b\xea\x06\xcc\x2a\xe1\x06\xfe\x2c\xde\x06\x66\x2b\xe7\x06\xb3\x2a\xf7\x06\xfe\x2c\xee\x06\xf9\x2a\xeb\x06\xad\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xee\x06\x64\x2d\xed\x06\xf9\x2a\xeb\x06\xb0\x2a\xe8\x06\xe7\x2c\xd3\x06\xe0\x2a\xed\x06\x34\x2a\xfd\x06\xf8\x2b\xff\x06\x60\x2a\xf2\x06\xce\x29\xf2\x06\x8b\x2c\xe3\x06\x25\x2b\xe9\x06\x63\x2a\xed\x06\x8b\x2c\xda\x06\xbc\x2a\xee\x06\x83\x2a\xda\x06\xd4\x2b\xdf\x06\x5b\x2a\xd9\x06\x9c\x29\xbf\x06\x4a\x2b\xad\x06\xca\x29\xb6\x06\xd9\x28\x82\x06\xc4\x2b\x7d\x06\x8f\x29\x75\x06\xf1\x27\x47\x06\x73\x28\x46\x06\xcb\x26\x54\x06\x62\x24\xa6\x06\x4a\x28\x95\x06\x27\x27\xa3\x06\xb3\x25\xbf\x06\x9c\x28\xbb\x06\xc1\x27\xbd\x06\x88\x26\xe6\x06\xce\x28\xd8\x06\x7a\x27\xde\x06\xa5\x26\xea\x06\x20\x29\xd5\x06\x8a\x27\xe4\x06\x14\x27\xeb\x06\x6d\x29\xda\x06\xdf\x27\xe4\x06\x18\x27\xdb\x06\xab\x29\xdc\x06\x0b\x28\xda\x06\x16\x27\xe3\x06\xd2\x29\xde\x06\x1e\x28\xd8\x06\x55\x27\xed\x06\xea\x29\xd7\x06\x09\x28\xdc\x06\x5c\x27\xdf\x06\x2f\x2a\xcf\x06\x28\x28\xcb\x06\x8b\x27\xcd\x06\xb0\x29\xc9\x06\x50\x28\xd7\x06\x28\x27\xd4\x06\x6c\x29\xca\x06\xcb\x27\xd1\x06\xdb\x26\xd9\x06\xb0\x29\xdf\x06\x45\x28\xdd\x06\x47\x27\xe2\x06\x5c\x29\xd8\x06\x37\x28\xd5\x06\x27\x27\xf3\x06\xa3\x29\xd8\x06\x46\x28\xe2\x06\x30\x27\xe3\x06\x98\x29\xd8\x06\x11\x28\xde\x06\x33\x27\xd0\x06\x3e\x2a\xd2\x06\xc9\x28\xbb\x06\x7a\x27\xe5\x06\x5f\x29\xe0\x06\x2f\x28\xda\x06\x14\x27\xe3\x06\x5e\x29\xd9\x06\xcb\x27\xd4\x06\xac\x26\xdf\x06\x3e\x29\xd9\x06\x3a\x28\xd5\x06\x2e\x27\xdd\x06\x58\x29\xde\x06\x45\x28\xd6\x06\x08\x27\xe3\x06\x0e\x29\xd9\x06\x27\x28\xd3\x06\xe5\x26\xd3\x06\x2e\x29\xd5\x06\x2c\x28\xd8\x06\xd2\x26\xeb\x06\x0f\x29\xdd\x06\xf2\x27\xe6\x06\xe9\x26\xe6\x06\xf7\x28\xe3\x06\xb7\x27\xcb\x06\xa2\x26\xdc\x06\xd6\x28\xd0\x06\x68\x27\xd9\x06\x65\x26\xe1\x06\xcc\x28\xe2\x06\xb8\x27\xca\x06\x82\x26\xd1\x06\xe7\x28\xc9\x06\xca\x27\xcd\x06\x84\x26\xe6\x06\xf9\x28\xd5\x06\xba\x27\xe3\x06\x82\x26\xd9\x06\xbf\x28\xc9\x06\xa5\x27\xd4\x06\x9d\x26\xe1\x06\xec\x28\xd8\x06\xf1\x27\xd5\x06\x8f\x26\xe5\x06\x54\x29\xd5\x06\xad\x27\xda\x06\xbd\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xda\x06\x7f\x28\xd6\x06\x47\x27\xd9\x06\x1e\x26\xe2\x06\x9f\x28\xe2\x06\x60\x27\xcb\x06\x58\x26\xe1\x06\xee\x28\xde\x06\xd8\x27\xdc\x06\xa0\x26\xdd\x06\x1b\x29\xd3\x06\xd4\x27\xda\x06\x41\x26\xe4\x06\x1f\x29\xd9\x06\xbc\x27\xd9\x06\x7e\x26\xec\x06\x11\x29\xd8\x06\xd6\x27\xdd\x06\x75\x26\xc2\x06\x1c\x29\xb5\x06\x09\x28\xb9\x06\xa3\x26\xdb\x06\xbe\x28\xd2\x06\xa5\x27\xd7\x06\x19\x26\xe8\x06\xff\x28\xe5\x06\xac\x27\xe1\x06\x7c\x26\xdc\x06\x1f\x29\xd2\x06\xd9\x27\xd9\x06\xed\x26\xec\x06\xa6\x29\xdc\x06\xdd\x27\xc9\x06\x9b\x26\xd5\x06\xa2\x28\xd7\x06\x1e\x28\xde\x06\xca\x26\xde\x06\xa7\x28\xcd\x06\x8b\x27\xd1\x06\x61\x26\xde\x06\x22\x29\xde\x06\x83\x27\xd3\x06\x81\x26\xd5\x06\x61\x28\xc6\x06\xf0\x26\xd2\x06\x3c\x26\xb9\x06\x85\x28\xb4\x06\x1f\x27\xd8\x06\x06\x26\xe8\x06\xe3\x28\xdd\x06\x97\x27\xdd\x06\xac\x26\xe1\x06\xb3\x28\xd8\x06\xbf\x27\xd4\x06\x67\x26\xdf\x06\xb8\x28\xda\x06\x67\x27\xd5\x06\xab\x26\xde\x06\x74\x28\xe8\x06\xcd\x27\xe1\x06\xda\x26\xde\x06\xa0\x28\xda\x06\xe5\x27\xd7\x06\xe6\x26\xd0\x06\x8c\x28\xe4\x06\xbf\x27\xe2\x06\x6b\x26\xd7\x06\x2f\x28\xd4\x06\x1c\x27\xd6\x06\x2f\x26\xe3\x06\x75\x28\xd5\x06\x81\x27\xe6\x06\xbe\x26\xe8\x06\xba\x28\xe3\x06\x2c\x28\xe0\x06\xde\x26\xd5\x06\xba\x28\xcb\x06\x9a\x27\xd9\x06\xdd\x26\xe6\x06\xa0\x28\xda\x06\x19\x28\xd3\x06\xb3\x26\xda\x06\xc9\x28\xd8\x06\x1a\x28\xe1\x06\xd2\x26\xe8\x06\xbc\x28\xe2\x06\x22\x28\xe3\x06\xd9\x26\xe8\x06\x79\x28\xe4\x06\x77\x27\xdf\x06\x6b\x26\xe3\x06\xa5\x28\xdc\x06\xd9\x27\xe0\x06\xb4\x26\xdc\x06\xd2\x28\xd6\x06\xe0\x27\xe1\x06\xc2\x26\xe6\x06\xe1\x28\xdb\x06\xf9\x27\xdf\x06\xe8\x26\xd4\x06\xe8\x28\xd8\x06\x0d\x28\xdd\x06\xa2\x26\xe4\x06\xfc\x28\xe3\x06\x2b\x28\xdd\x06\x04\x27\xe3\x06\x43\x29\xd9\x06\x17\x28\xe5\x06\xfb\x26\xdd\x06\x13\x29\xd8\x06\x8c\x27\xd9\x06\x7f\x26\xdb\x06\x39\x29\xbf\x06\x96\x27\xd1\x06\xac\x26\xcd\x06\xf4\x28\xcd\x06\x15\x28\xd5\x06\xe2\x26\xe4\x06\xcf\x28\xe7\x06\x0a\x28\xe4\x06\xd6\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdf\x06\xf9\x28\xde\x06\xf6\x27\xda\x06\xb9\x26\xdd\x06\xcb\x28\xda\x06\xcc\x27\xdb\x06\x03\x27\xe5\x06\x9c\x28\xe3\x06\x05\x28\xd3\x06\xba\x26\xe0\x06\xae\x28\xdd\x06\xbb\x27\xd2\x06\x28\x26\xd5\x06\xe4\x28\xce\x06\xcd\x27\xdd\x06\x86\x26\xd9\x06\xa0\x28\xd5\x06\xef\x27\xd6\x06\xa7\x26\xdd\x06\x79\x28\xd4\x06\xda\x27\xd6\x06\x72\x26\xe0\x06\xd4\x28\xd8\x06\xad\x27\xd9\x06\x88\x26\xe0\x06\xb8\x28\xe1\x06\x1d\x28\xd4\x06\x6d\x26\xda\x06\x79\x28\xdd\x06\xf3\x27\xc7\x06\x32\x26\xd6\x06\x33\x28\xd4\x06\x4e\x27\xcb\x06\xf1\x25\xe4\x06\xea\x27\xdd\x06\x1f\x27\xdc\x06\x9a\x25\xe8\x06\x65\x28\xdf\x06\x75\x27\xd8\x06\xbd\x25\xcf\x06\x9a\x28\xca\x06\x5d\x27\xcd\x06\x9b\x25\xe2\x06\x87\x28\xd7\x06\x1f\x27\xd1\x06\x7e\x25\xd8\x06\xcd\x28\xd5\x06\x86\x27\xcd\x06\xfc\x25\xdf\x06\xba\x28\xcf\x06\xdb\x27\xcf\x06\x23\x26\xd5\x06\xb1\x28\xc8\x06\x04\x28\xce\x06\x5b\x26\xd8\x06\x80\x28\xc9\x06\x7c\x27\xdb\x06\x1e\x26\xd5\x06\x63\x28\xd2\x06\x87\x27\xd7\x06\x76\x26\xc8\x06\x73\x28\xb6\x06\xa9\x27\xd3\x06\x80\x26\xd3\x06\x67\x28\xcb\x06\x6e\x27\xce\x06\x46\x26\xde\x06\xb2\x28\xd1\x06\x6a\x27\xd7\x06\x54\x26\xd5\x06\xcc\x28\xd4\x06\x8e\x27\xce\x06\x59\x26\xda\x06\x6e\x28\xc8\x06\x88\x27\xd4\x06\x24\x26\xc3\x06\x37\x28\xc9\x06\x2e\x27\xcc\x06\xd6\x25\xd9\x06\x68\x28\xce\x06\x63\x27\xd6\x06\x54\x26\xd8\x06\x8c\x28\xd6\x06\xc1\x27\xda\x06\x3d\x26\xda\x06\x86\x28\xd6\x06\xb2\x27\xd7\x06\xa5\x26\xd1\x06\x69\x28\xce\x06\x9b\x27\xd6\x06\x44\x26\xd2\x06\xc7\x28\xc8\x06\xe7\x27\xd2\x06\x85\x26\xd1\x06\x9e\x28\xcb\x06\xdc\x27\xd1\x06\x7c\x26\xdf\x06\x5f\x28\xd5\x06\x6d\x27\xd5\x06\x46\x26\xcd\x06\x25\x28\xd2\x06\x67\x27\xcc\x06\x38\x26\xd2\x06\x84\x28\xd2\x06\xc7\x27\xd1\x06\x87\x26\xd8\x06\xc4\x28\xd4\x06\x31\x28\xda\x06\xb9\x26\xe1\x06\xde\x28\xe3\x06\x0e\x28\xce\x06\xaa\x26\xe2\x06\xd6\x28\xd3\x06\xa7\x27\xdf\x06\xc0\x26\xd5\x06\x99\x28\xce\x06\xcc\x27\xd6\x06\x9c\x26\xe4\x06\xcc\x28\xdf\x06\x0b\x28\xd6\x06\xb9\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd5\x06\xea\x28\xd8\x06\x0b\x28\xd3\x06\x82\x26\xce\x06\xab\x28\xce\x06\x28\x28\xd1\x06\xbc\x26\xe3\x06\xe2\x28\xde\x06\xf8\x27\xdd\x06\xab\x26\xdc\x06\xd8\x28\xd3\x06\x01\x28\xd6\x06\x84\x26\xde\x06\x0f\x29\xde\x06\x21\x28\xde\x06\xe4\x26\xde\x06\x00\x29\xe1\x06\xfa\x27\xd4\x06\xcb\x26\xe0\x06\xe9\x28\xdb\x06\x2d\x28\xdc\x06\xaa\x26\xcb\x06\x90\x28\xc4\x06\xa5\x27\xd8\x06\x52\x26\xe2\x06\xcc\x28\xd6\x06\xf6\x27\xdf\x06\xf0\x26\xe1\x06\x84\x28\xe4\x06\x1c\x28\xe2\x06\xbf\x26\xe5\x06\xc8\x28\xdf\x06\x06\x28\xd6\x06\x94\x26\xdb\x06\x92\x28\xd9\x06\xd6\x27\xdf\x06\x8f\x26\xdb\x06\xfa\x28\xd3\x06\xf6\x27\xd7\x06\xaf\x26\xe1\x06\xab\x28\xd9\x06\x02\x28\xd2\x06\xbf\x26\xd8\x06\xcf\x28\xcf\x06\xcb\x27\xd8\x06\x53\x26\xbc\x06\x52\x29\xb3\x06\xf0\x27\xcf\x06\xcf\x26\xcd\x06\x86\x28\xd7\x06\xd8\x27\xde\x06\x97\x26\xe1\x06\xa6\x28\xde\x06\xe8\x27\xe6\x06\xae\x26\xd9\x06\x21\x29\xcb\x06\x94\x27\xd7\x06\xa8\x26\xdb\x06\x52\x29\xca\x06\x99\x27\xde\x06\x8b\x26\xd9\x06\x3d\x29\xd4\x06\xeb\x27\xd4\x06\xae\x26\xce\x06\x93\x28\xca\x06\x58\x27\xe1\x06\x3a\x26\xdf\x06\x57\x29\xd6\x06\xbb\x27\xd8\x06\xae\x26\xe6\x06\x13\x2a\xd9\x06\x95\x27\xd9\x06\xd1\x26\xf4\x06\x0b\x2a\xe0\x06\x26\x28\xde\x06\x1c\x27\xd3\x06\x4a\x29\xc2\x06\x11\x28\xc4\x06\xd6\x26\xdb\x06\xbe\x28\xde\x06\xfc\x27\xd7\x06\xac\x26\xe4\x06\xfb\x28\xdd\x06\xe8\x27\xe2\x06\xc2\x26\xde\x06\x8f\x28\xdf\x06\xb0\x27\xd1\x06\x4a\x26\xdc\x06\xb5\x28\xcd\x06\xa6\x27\xd1\x06\x87\x26\xdb\x06\xb0\x28\xc4\x06\xdb\x27\xdd\x06\x03\x27\xd3\x06\xa9\x28\xd6\x06\x1a\x28\xdc\x06\xb7\x26\xe6\x06\x74\x28\xe2\x06\x49\x28\xd7\x06\xce\x26\xc6\x06\xe1\x28\xc1\x06\x37\x28\xe4\x06\xa4\x26\xdf\x06\xe9\x28\xd5\x06\xac\x27\xd7\x06\x89\x26\xc6\x06\x11\x29\xc2\x06\x28\x28\xc2\x06\x97\x26\xd3\x06\xcf\x28\xc3\x06\xe3\x27\xd6\x06\x75\x26\xe0\x06\xb0\x28\xdd\x06\x5a\x28\xdd\x06\xd6\x26\xe3\x06\xde\x28\xe0\x06\x1e\x28\xdd\x06\xb2\x26\xe5\x06\xca\x28\xe4\x06\x16\x28\xd5\x06\xd6\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe2\x06\xb7\x28\xd9\x06\x2b\x28\xde\x06\xcb\x26\xcb\x06\xa3\x28\xd2\x06\x29\x28\xd8\x06\xf9\x26\xd6\x06\xe9\x28\xcf\x06\xe7\x27\xd5\x06\xb7\x26\xdb\x06\xb5\x28\xd1\x06\xac\x27\xd2\x06\x79\x26\xe5\x06\xf7\x28\xd9\x06\xd3\x27\xcd\x06\xca\x26\xc7\x06\xe2\x28\xbd\x06\xeb\x27\xdc\x06\xd5\x26\xd5\x06\xc8\x28\xd7\x06\xf0\x27\xd0\x06\xae\x26\xd4\x06\x10\x29\xc6\x06\xf8\x27\xd6\x06\x95\x26\xdf\x06\x1b\x29\xe0\x06\xfc\x27\xd3\x06\xac\x26\xd5\x06\x16\x29\xca\x06\x29\x28\xe0\x06\xbb\x26\xdb\x06\x94\x28\xd8\x06\xfc\x27\xd0\x06\x93\x26\xd6\x06\xa3\x28\xd5\x06\x16\x28\xdb\x06\xf6\x26\xea\x06\xe8\x28\xe8\x06\x09\x28\xd1\x06\xcf\x26\xdb\x06\xcd\x28\xd6\x06\xe3\x27\xd5\x06\xa2\x26\xe4\x06\x44\x29\xe0\x06\x15\x28\xdb\x06\xc7\x26\xde\x06\x7e\x29\xdd\x06\x1b\x28\xd6\x06\xc2\x26\xe2\x06\xb4\x29\xd8\x06\x07\x28\xcc\x06\x6e\x26\xe1\x06\x2d\x29\xdd\x06\x6a\x27\xd4\x06\x68\x26\xe6\x06\x8f\x29\xd8\x06\x8d\x27\xce\x06\x85\x26\xdc\x06\x48\x29\xd9\x06\xe5\x27\xcc\x06\xc5\x26\xd6\x06\x07\x29\xce\x06\xe4\x27\xcd\x06\x89\x26\xe2\x06\x5f\x28\xe3\x06\xfe\x27\xdb\x06\x90\x26\xe6\x06\xf5\x28\xce\x06\xfa\x27\xd3\x06\x6d\x26\xeb\x06\x0c\x29\xec\x06\xeb\x27\xe0\x06\xfd\x26\xe9\x06\xab\x28\xd1\x06\x8d\x27\xd7\x06\x4d\x26\xda\x06\x28\x29\xcd\x06\x3c\x27\xcf\x06\x45\x26\xe7\x06\x62\x29\xdc\x06\xfa\x27\xd1\x06\xf3\x26\xe4\x06\xbe\x29\xcf\x06\xc8\x27\xd0\x06\x9e\x26\xf7\x06\xd0\x29\xe0\x06\xbb\x27\xcf\x06\xa6\x26\xbf\x06\xe4\x29\xa4\x06\xdf\x27\xd5\x06\xd7\x26\xcb\x06\x0c\x29\xc3\x06\xdb\x27\xd0\x06\xef\x26\xd1\x06\xe4\x28\xc1\x06\xdf\x27\xbf\x06\xc0\x26\xde\x06\xa6\x28\xce\x06\xe0\x27\xd4\x06\xa5\x26\xe2\x06\xdb\x28\xcc\x06\x9f\x27\xce\x06\x7b\x26\xe2\x06\xf5\x28\xd9\x06\xcf\x27\xd8\x06\xab\x26\xcf\x06\xd5\x28\xdd\x06\xbb\x27\xcb\x06\x13\x26\xe5\x06\x73\x29\xe0\x06\x9b\x27\xd1\x06\x65\x26\xd4\x06\xd8\x28\xd6\x06\x95\x27\xd6\x06\x53\x26\xda\x06\x7b\x28\xc8\x06\x27\x27\xd2\x06\xe7\x25\xd6\x06\xe7\x27\xd8\x06\xfd\x26\xcc\x06\xa2\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd3\x06\x24\x28\xd1\x06\x95\x27\xce\x06\xe3\x25\xe8\x06\xb8\x28\xcc\x06\x40\x27\xdc\x06\x44\x26\xdb\x06\xb3\x28\xd4\x06\x72\x27\xcc\x06\x63\x26\xdf\x06\xb7\x28\xdc\x06\x9f\x27\xe0\x06\x49\x26\xcf\x06\xe2\x28\xd2\x06\x93\x27\xc6\x06\x71\x26\xda\x06\x76\x28\xd0\x06\x05\x27\xc4\x06\x05\x26\xc6\x06\xa9\x28\xb1\x06\xb9\x26\xc0\x06\xe3\x25\xd3\x06\xf9\x27\xcc\x06\x50\x27\xd8\x06\x11\x26\xd7\x06\xb5\x28\xd5\x06\x9f\x27\xcf\x06\x3f\x26\xc7\x06\xab\x28\xbd\x06\x80\x27\xca\x06\x5e\x26\xcd\x06\xae\x28\xd4\x06\x6f\x27\xce\x06\x57\x26\xd5\x06\x9c\x28\xd2\x06\xa9\x27\xcd\x06\x4b\x26\xe1\x06\x34\x28\xd8\x06\x76\x27\xca\x06\x21\x26\xdb\x06\xca\x27\xd2\x06\xd3\x26\xd7\x06\xd0\x25\xd7\x06\xf3\x27\xda\x06\x82\x27\xd6\x06\x18\x26\xd8\x06\x51\x28\xe3\x06\xb3\x27\xcd\x06\x40\x26\xd0\x06\x81\x28\xbd\x06\x84\x27\xb8\x06\x2f\x26\xe4\x06\x7d\x28\xcd\x06\x9b\x27\xd1\x06\x82\x26\xd9\x06\x6d\x28\xda\x06\x90\x27\xd4\x06\x64\x26\xdb\x06\x5b\x28\xd7\x06\x88\x27\xd6\x06\x81\x26\xd5\x06\x24\x28\xd6\x06\x05\x27\xda\x06\x04\x26\xd2\x06\x40\x28\xd3\x06\xb1\x26\xd1\x06\x19\x26\xda\x06\x69\x28\xd2\x06\x6b\x27\xd0\x06\x75\x26\xd3\x06\x53\x28\xcf\x06\x98\x27\xd3\x06\x77\x26\xd9\x06\x50\x28\xd1\x06\x66\x27\xc5\x06\x46\x26\xe1\x06\x8e\x28\xdd\x06\x9b\x27\xd7\x06\x6f\x26\xcf\x06\x9b\x28\xd3\x06\x6a\x27\xd3\x06\x6d\x26\xd5\x06\x56\x28\xd0\x06\xf2\x26\xcc\x06\x14\x26\xe6\x06\x42\x28\xd6\x06\xea\x26\xce\x06\xee\x25\xdb\x06\xbc\x28\xde\x06\x63\x27\xdc\x06\x80\x26\xd3\x06\xcb\x28\xcb\x06\x5f\x27\xc4\x06\x95\x26\xde\x06\xec\x28\xd4\x06\x64\x27\xda\x06\x6f\x26\xd9\x06\xcf\x28\xcf\x06\xd0\x27\xcc\x06\x43\x26\xde\x06\x84\x28\xd9\x06\xd3\x27\xd7\x06\x88\x26\xd9\x06\x8a\x28\xcf\x06\x44\x27\xcd\x06\x46\x26\xe1\x06\xcd\x28\xd2\x06\x0d\x27\xd2\x06\x3d\x26\xea\x06\x31\x29\xd9\x06\xf6\x27\xd2\x06\x98\x26\xdb\x06\x54\x29\xcc\x06\xc6\x27\xd3\x06\x95\x26\xe0\x06\x31\x29\xd3\x06\xa7\x27\xdd\x06\x99\x26\xd5\x06\x04\x29\xcc\x06\xd3\x27\xda\x06\xc1\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe5\x06\xc2\x28\xd9\x06\x88\x27\xe3\x06\xa7\x26\xc5\x06\xb4\x28\xc8\x06\x38\x27\xd3\x06\x4b\x26\xdf\x06\x92\x28\xc4\x06\x28\x27\xce\x06\xfb\x25\xe0\x06\xc1\x28\xd3\x06\x55\x27\xcf\x06\x50\x26\xe2\x06\xd1\x28\xd9\x06\x9d\x27\xdd\x06\xa4\x26\xe1\x06\x4f\x29\xde\x06\x73\x27\xd1\x06\x7a\x26\xe2\x06\x52\x29\xcd\x06\x91\x27\xcd\x06\x88\x26\xdd\x06\x1b\x29\xd1\x06\xc1\x27\xce\x06\x67\x26\xea\x06\xcf\x28\xd2\x06\x78\x27\xdd\x06\x85\x26\xd3\x06\x1f\x28\xc9\x06\x0b\x27\xc6\x06\xbd\x25\xdb\x06\x39\x28\xcf\x06\x55\x27\xd4\x06\x3f\x26\xd1\x06\x05\x29\xc3\x06\xbe\x27\xd9\x06\x4a\x26\xe2\x06\x0e\x29\xd5\x06\x8b\x27\xd4\x06\x5a\x26\xd7\x06\xe1\x28\xcd\x06\x92\x27\xd6\x06\x58\x26\xd5\x06\x19\x29\xcc\x06\xf3\x27\xd2\x06\x75\x26\xd1\x06\x36\x29\xc7\x06\xe8\x27\xd8\x06\x79\x26\xdf\x06\xf5\x28\xd2\x06\x94\x27\xd6\x06\x66\x26\xd6\x06\x12\x29\xd4\x06\x8e\x27\xca\x06\x6f\x26\xde\x06\xcb\x28\xe1\x06\x00\x28\xd1\x06\xbb\x26\xdb\x06\xd1\x28\xd7\x06\x14\x28\xde\x06\xac\x26\xe6\x06\xd9\x28\xdd\x06\xd2\x27\xd8\x06\x99\x26\xd4\x06\x3f\x29\xcf\x06\xcd\x27\xd1\x06\x98\x26\xc1\x06\x1c\x29\xbf\x06\xb2\x27\xd0\x06\x81\x26\xd5\x06\xb5\x28\xcc\x06\xac\x27\xce\x06\x5d\x26\xe2\x06\xda\x28\xcc\x06\x4c\x27\xd8\x06\x2d\x26\xbf\x06\x03\x29\xb6\x06\xdb\x27\xd2\x06\xa2\x26\xda\x06\xf2\x28\xdf\x06\x37\x28\xdd\x06\x25\x27\xdb\x06\x28\x29\xd2\x06\x0c\x28\xe2\x06\xe9\x26\xc5\x06\x8e\x29\xbe\x06\x82\x28\xab\x06\x10\x27\xc6\x06\x80\x29\xb8\x06\x08\x28\xd6\x06\xe4\x26\xe6\x06\xd5\x28\xda\x06\xd7\x27\xdb\x06\xc9\x26\xd3\x06\xd5\x28\xd0\x06\x51\x27\xd3\x06\x71\x26\xe8\x06\x05\x29\xdf\x06\x27\x28\xd0\x06\xa3\x26\xca\x06\x0c\x29\xbc\x06\x2f\x28\xca\x06\xc2\x26\xd0\x06\x3f\x29\xc1\x06\x4e\x28\xc3\x06\xe9\x26\xce\x06\xf2\x28\xcb\x06\xe4\x27\xd2\x06\xae\x26\xca\x06\x04\x29\xbf\x06\x16\x28\xc8\x06\xa7\x26\xd7\x06\xa2\x28\xdb\x06\x2a\x28\xcf\x06\x69\x26\xeb\x06\x87\x28\xd8\x06\xc0\x27\xe2\x06\x1e\x26\xd3\x06\x4a\x29\xcd\x06\xe2\x27\xc6\x06\x94\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd8\x06\x60\x29\xc8\x06\xdc\x27\xdf\x06\xec\x26\xdf\x06\xb7\x28\xe0\x06\x3e\x28\xdb\x06\xa4\x26\xde\x06\x1e\x29\xdf\x06\xb1\x27\xd7\x06\xc9\x26\xdc\x06\x2c\x29\xd9\x06\x7c\x28\xdc\x06\xa7\x26\xcc\x06\xbe\x28\xc9\x06\xf9\x27\xc6\x06\x95\x26\xd9\x06\x69\x28\xd5\x06\xb0\x27\xd2\x06\x65\x26\xd6\x06\xf0\x28\xd3\x06\x05\x28\xcf\x06\x93\x26\xb9\x06\x03\x29\xc0\x06\x35\x28\xc3\x06\xba\x26\xda\x06\xd3\x28\xde\x06\x0b\x28\xd5\x06\xa4\x26\xd7\x06\xeb\x28\xd8\x06\xef\x27\xd9\x06\x7d\x26\xd4\x06\xcc\x28\xca\x06\xf5\x27\xdd\x06\x75\x26\xd5\x06\xff\x28\xd8\x06\xd8\x27\xcb\x06\x6e\x26\xdc\x06\x37\x28\xd2\x06\x55\x27\xd4\x06\xe1\x25\xd6\x06\xf8\x27\xca\x06\x0c\x27\xcd\x06\xf4\x25\xe7\x06\xa7\x28\xd9\x06\x6d\x27\xcd\x06\xe3\x25\xdd\x06\xd0\x28\xd6\x06\xa9\x27\xda\x06\x19\x26\xe4\x06\xf2\x28\xdd\x06\x0c\x28\xda\x06\xfa\x25\xe6\x06\xeb\x28\xe0\x06\x45\x28\xdc\x06\xb4\x26\xc5\x06\x37\x29\xcb\x06\x69\x28\xe6\x06\xf4\x26\xef\x06\x46\x29\xe4\x06\x2b\x28\xe3\x06\x10\x27\xe5\x06\x1a\x29\xe3\x06\x2f\x28\xd6\x06\xcf\x26\xbd\x06\x23\x29\xbe\x06\x7d\x28\xd9\x06\x02\x27\xdd\x06\x33\x29\xd6\x06\x97\x28\xd3\x06\x25\x27\xe5\x06\x20\x29\xe2\x06\x7f\x28\xe0\x06\x18\x27\xe2\x06\x05\x29\xe0\x06\x85\x28\xe0\x06\xd4\x26\xc6\x06\x0d\x29\xc0\x06\x69\x28\xd8\x06\x14\x27\xdb\x06\xfe\x28\xd8\x06\x15\x28\xdf\x06\xda\x26\xd4\x06\xe9\x28\xcd\x06\x1a\x28\xce\x06\xbe\x26\xe1\x06\x24\x29\xd1\x06\x61\x28\xd6\x06\xf0\x26\xd2\x06\x61\x29\xd1\x06\x93\x28\xe2\x06\x04\x27\xdf\x06\x96\x29\xda\x06\x53\x28\xd5\x06\xf5\x26\xe0\x06\xd0\x29\xd9\x06\x48\x28\xd3\x06\x16\x27\xe4\x06\xd2\x29\xe2\x06\x6d\x28\xd2\x06\x3a\x27\xd0\x06\xa8\x29\xbc\x06\x9c\x28\xd8\x06\x4f\x27\xbd\x06\x83\x29\xce\x06\x7d\x28\xc1\x06\xe9\x26\xe9\x06\xa4\x29\xe6\x06\x80\x28\xe3\x06\x3d\x27\xd8\x06\x79\x29\xd1\x06\x93\x28\xdb\x06\x59\x27\xe0\x06\xac\x29\xdf\x06\xce\x28\xd7\x06\x25\x27\xef\x06\xb6\x29\xdf\x06\x80\x28\xe7\x06\x8e\x27\xdc\x06\xde\x29\xcf\x06\xae\x28\xdb\x06\x5b\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe5\x06\x06\x2a\xe3\x06\x70\x28\xd3\x06\x29\x27\xe1\x06\xaf\x29\xd0\x06\xf9\x27\xda\x06\xda\x26\xdf\x06\xb8\x29\xe0\x06\x9f\x28\xd3\x06\xf1\x26\xdf\x06\xfc\x29\xcf\x06\x94\x28\xdb\x06\x40\x27\xd1\x06\x51\x2a\xc4\x06\xa3\x28\xd1\x06\x2b\x27\xd8\x06\x95\x2a\xce\x06\x96\x28\xe5\x06\x49\x27\xec\x06\x8f\x2a\xdc\x06\xb4\x28\xe7\x06\xa1\x27\xe5\x06\xba\x2a\xd1\x06\xb1\x28\xd8\x06\x6c\x27\xde\x06\x6d\x2a\xdb\x06\x5a\x28\xd7\x06\x64\x27\xdb\x06\x13\x2a\xdc\x06\x5b\x28\xe3\x06\x68\x27\xe7\x06\xf4\x29\xdf\x06\xda\x28\xdf\x06\x7b\x27\xef\x06\x3d\x2a\xd6\x06\x85\x28\xe2\x06\xc8\x27\xe4\x06\x49\x2a\xd8\x06\xaf\x28\xdf\x06\x89\x27\xd7\x06\x0b\x2a\xc6\x06\x9a\x28\xe0\x06\x62\x27\xc7\x06\xb3\x2a\xbc\x06\x28\x29\xc0\x06\xa4\x27\xd1\x06\x79\x2a\xbd\x06\x6f\x28\xe7\x06\x68\x27\xb0\x06\xb6\x2a\xa9\x06\x7d\x29\xb2\x06\xf6\x27\xed\x06\xd4\x29\xdd\x06\x96\x28\xdb\x06\x72\x27\xe6\x06\x82\x29\xe2\x06\xc0\x28\xdf\x06\x5c\x27\xe7\x06\x5f\x29\xdd\x06\x5e\x28\xdc\x06\x21\x27\xe9\x06\xb2\x29\xe0\x06\x4a\x28\xd8\x06\x12\x26\x61\x07\x43\xa3\x58\x07\x43\x9c\x7b\x07\x7b\x8f\x00\x00\x4c\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x4b\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\xf9\x14\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\xfb\x14\x00\x00\xa2\x15\x00\x00\x5a\x14\x00\x00\xfd\x14\x00\x00\xa2\x15\xbe\x06\x6a\x2c\xc1\x06\x60\x2a\xb8\x06\x4a\x28\xb9\x06\x88\x2b\xbd\x06\x9c\x2a\xcc\x06\x93\x29\xca\x06\xc2\x2b\xcd\x06\xde\x2a\xc3\x06\x87\x29\xc3\x06\x52\x2b\xaf\x06\x1a\x2a\xc4\x06\x40\x29\xc3\x06\x9f\x2b\xbf\x06\x2e\x2a\xc3\x06\x53\x29\xc2\x06\x4e\x2c\xb8\x06\xab\x2a\xbf\x06\x6d\x29\xb9\x06\x4e\x2c\xb8\x06\x8d\x2a\xc4\x06\x4c\x29\xb9\x06\x0c\x2c\xb7\x06\x56\x2a\xb8\x06\xdc\x28\xc5\x06\xc7\x2b\xb5\x06\x44\x2a\xb8\x06\x7c\x28\xd2\x06\x24\x2c\xc4\x06\x5a\x2a\xbc\x06\x8a\x28\xbd\x06\xc6\x2b\xbe\x06\x2c\x2a\xba\x06\xb0\x28\xb3\x06\x74\x2b\xc7\x06\x1a\x2b\xbc\x06\x6d\x28\xd0\x06\xf7\x2b\xc4\x06\x47\x2a\xc5\x06\x21\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc7\x06\x8a\x2c\xc4\x06\xb1\x2a\xc3\x06\x71\x29\xca\x06\xa7\x2c\xcd\x06\xce\x2a\xbd\x06\xbf\x29\xcf\x06\xc8\x2c\xc4\x06\xcf\x2a\xd3\x06\xd1\x29\xd0\x06\x6b\x2d\xc4\x06\x26\x2b\xc1\x06\x24\x2a\xcd\x06\x14\x2c\xc3\x06\xf9\x2a\xc0\x06\x97\x29\xc3\x06\x76\x2b\xbd\x06\xf2\x2a\xbd\x06\x28\x29\xcc\x06\xea\x2b\xcc\x06\xc6\x2a\xc4\x06\x90\x29\xcd\x06\x68\x2c\xc1\x06\x50\x2b\xc6\x06\xb5\x29\xd6\x06\xa0\x2c\xc7\x06\x20\x2b\xd1\x06\xcb\x29\xcb\x06\x8e\x2c\xce\x06\xba\x2b\xd3\x06\xc9\x29\xcf\x06\x36\x2c\xcf\x06\x5b\x2b\xc2\x06\xa3\x29\xc2\x06\x23\x2c\xbe\x06\x42\x2b\xc1\x06\xa6\x29\xc3\x06\xb6\x2b\xbd\x06\xf4\x2a\xca\x06\xcf\x29\xaa\x06\x40\x2c\xb3\x06\xb1\x2b\xc2\x06\xe3\x29\xce\x06\x57\x2c\xd3\x06\x67\x2b\xc8\x06\xe0\x29\xda\x06\x6e\x2c\xc4\x06\x08\x2b\xcc\x06\xed\x29\xce\x06\x49\x2c\xc8\x06\x2c\x2b\xcd\x06\x07\x2a\xbc\x06\x72\x2c\xc3\x06\x66\x2b\xc2\x06\xd7\x29\xd9\x06\x90\x2c\xd2\x06\xda\x2b\xd3\x06\x0f\x2a\xbe\x06\x88\x2b\xc2\x06\x0c\x2b\xc1\x06\x7c\x29\xc9\x06\xa4\x2b\xc2\x06\x29\x2b\xbf\x06\x4d\x29\xc7\x06\x49\x2c\xcb\x06\x50\x2b\xc8\x06\xdc\x29\xcd\x06\xf5\x2b\xc8\x06\x7b\x2b\xcb\x06\x1a\x2a\xc0\x06\xd2\x2b\xc3\x06\x64\x2b\xc2\x06\xde\x29\xc1\x06\xb1\x2b\xc0\x06\x3b\x2b\xc0\x06\xef\x29\xba\x06\xcb\x2b\xc1\x06\x5b\x2b\xc0\x06\xe3\x29\xcb\x06\x56\x2b\xce\x06\x81\x2b\xc5\x06\xaa\x29\xc1\x06\xa8\x2b\xb9\x06\xda\x2a\xbd\x06\xad\x29\xc1\x06\xae\x2b\xb5\x06\xbb\x2a\xc5\x06\xd4\x29\xcd\x06\xd8\x2b\xc6\x06\x11\x2b\xc3\x06\xa3\x29\xc8\x06\xf8\x2b\xc4\x06\x56\x2b\xc6\x06\xbf\x29\xcc\x06\xc6\x2b\xcf\x06\x05\x2b\xca\x06\xcb\x29\xc5\x06\xe9\x2b\xb7\x06\xc9\x2a\xb3\x06\x6f\x29\xc4\x06\x84\x2b\xbe\x06\xa5\x2a\xc8\x06\xff\x28\xc4\x06\x72\x2b\xba\x06\x34\x2a\xb1\x06\x98\x28\xbe\x06\x93\x2b\xbf\x06\x30\x2a\xb6\x06\xb2\x28\xc3\x06\x80\x2b\xb9\x06\x53\x2a\xba\x06\x3a\x28\xc9\x06\xd2\x2b\xc5\x06\x72\x2a\xbf\x06\x34\x28\xcb\x06\x88\x2b\xc0\x06\x90\x2a\xc4\x06\x87\x28\xc4\x06\xd2\x2b\xc4\x06\xa5\x2a\xa7\x06\xcd\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc4\x06\x4a\x2b\xbe\x06\xa0\x2a\xca\x06\xde\x28\xc2\x06\x06\x2b\xc3\x06\x04\x2a\xb6\x06\x94\x28\xb1\x06\x69\x2b\xa7\x06\xa2\x2a\xbf\x06\x0f\x29\xb5\x06\x20\x2b\xc3\x06\x07\x2b\xb9\x06\x11\x29\xcf\x06\xdc\x2b\xba\x06\x07\x2b\xc0\x06\x17\x29\xca\x06\xc7\x2b\xc2\x06\x87\x2a\xc2\x06\xf0\x28\xc8\x06\xf4\x2b\xc1\x06\xe3\x2a\xba\x06\x68\x29\xc0\x06\x79\x2b\xb9\x06\x32\x2a\xc3\x06\x3c\x29\xbd\x06\xfb\x2a\xb7\x06\x04\x2a\xb4\x06\xb9\x28\xbc\x06\x64\x2b\xb6\x06\x36\x2a\xbf\x06\x7c\x29\xc2\x06\x97\x2b\xc2\x06\xe0\x2a\xbd\x06\x89\x29\xbe\x06\x9a\x2b\xbf\x06\xf9\x2a\xc7\x06\xb2\x29\xcb\x06\xb7\x2b\xc5\x06\xeb\x2a\xbd\x06\x22\x2a\xbd\x06\xbb\x2b\xc5\x06\xe4\x2a\xb8\x06\x5f\x29\xc6\x06\xcd\x2b\xc6\x06\x22\x2b\xc8\x06\x07\x2a\xc0\x06\x31\x2b\xbd\x06\x6e\x2a\xb8\x06\x32\x29\xc6\x06\x7b\x2b\xc4\x06\x25\x2a\xbe\x06\x3e\x29\xc8\x06\x0d\x2c\xc7\x06\x8d\x2a\xc6\x06\xe2\x29\xc7\x06\xbc\x2b\xc7\x06\xa9\x2a\xc6\x06\xb2\x29\xcd\x06\xbd\x2b\xbd\x06\x83\x2a\xc3\x06\x95\x29\xb6\x06\x85\x2b\xb3\x06\xc6\x2a\xb9\x06\xaf\x29\xc8\x06\x88\x2b\xb3\x06\xaa\x2a\xc0\x06\x85\x29\xbf\x06\xfb\x2a\xbd\x06\x6e\x2a\xb9\x06\x51\x29\xba\x06\xcd\x2a\xb9\x06\xfa\x29\xb0\x06\xf5\x28\xbc\x06\x8c\x2b\xae\x06\x32\x2a\xb6\x06\x4a\x29\xbc\x06\x93\x2b\xbb\x06\x97\x2a\xb0\x06\xb7\x29\xbc\x06\xfa\x2b\xc2\x06\x21\x2b\xb6\x06\xd6\x29\xd1\x06\xd7\x2b\xca\x06\x26\x2b\xc8\x06\xcb\x29\xb8\x06\xa1\x2b\xbb\x06\xd5\x2a\xbf\x06\xf5\x29\xc3\x06\x60\x2b\xc1\x06\x4e\x2a\xb8\x06\x6c\x29\xc6\x06\x27\x2b\xc1\x06\xef\x29\xbc\x06\x03\x29\xbe\x06\xd5\x2b\xb8\x06\xd7\x2a\xbb\x06\xdc\x29\xcb\x06\x35\x2c\xc7\x06\x0b\x2b\xbf\x06\x6f\x2a\xc5\x06\xd5\x2b\xc2\x06\x14\x2b\xbc\x06\xf7\x29\xc6\x06\x63\x2c\xba\x06\x03\x2b\xb4\x06\x23\x2a\xc2\x06\x84\x2c\xbb\x06\xee\x2a\xb4\x06\xcd\x29\xc6\x06\x16\x2c\xc3\x06\x4a\x2b\xc1\x06\xde\x29\xbf\x06\x18\x2b\xb5\x06\x60\x2a\xc5\x06\x67\x29\xcf\x06\x7a\x2b\xcb\x06\xeb\x2a\xc7\x06\xc0\x29\xce\x06\xf4\x2b\xc0\x06\xd2\x2a\xc4\x06\xf3\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc3\x06\xf4\x2b\xc7\x06\x5c\x2b\xb4\x06\xca\x29\xbc\x06\x6e\x2c\xc1\x06\xf5\x2a\xbf\x06\x02\x2a\xcd\x06\x64\x2c\xc6\x06\xf8\x2a\xc4\x06\x9d\x29\xb7\x06\x40\x2c\xa2\x06\x14\x2b\xce\x06\xd6\x29\xec\x06\x96\x2b\xe4\x06\x18\x2b\xf9\x06\x76\x29\xd1\x06\xd3\x2b\xbf\x06\xb7\x2a\xc5\x06\x60\x29\xbd\x06\x08\x2c\xb8\x06\x0f\x2b\xc5\x06\x06\x2a\xbf\x06\x2d\x2c\xba\x06\x28\x2b\xb9\x06\xb2\x29\xc9\x06\x5c\x2c\xc8\x06\xd7\x2a\xbb\x06\x99\x29\xc6\x06\x69\x2c\xbf\x06\xe3\x2a\xbf\x06\x95\x2a\xc3\x06\x0a\x2c\xc8\x06\x56\x2b\xb9\x06\xa0\x29\xc0\x06\xb3\x2b\xaf\x06\x9e\x2a\xc0\x06\x91\x29\xc3\x06\xd5\x2b\xbc\x06\xbe\x2a\xbe\x06\x4f\x29\xc2\x06\x22\x2c\xc7\x06\x6c\x2b\xc4\x06\xe5\x29\xc0\x06\xdb\x2b\xcb\x06\x98\x2b\xbe\x06\x06\x2a\xbe\x06\xc9\x2b\xba\x06\x08\x2b\xc6\x06\x99\x29\xc9\x06\x0d\x2c\xc4\x06\x35\x2b\xc6\x06\xa8\x29\xc3\x06\x35\x2c\xbd\x06\x46\x2b\xbd\x06\xef\x29\xca\x06\x3b\x2c\xb3\x06\xdb\x2a\xb9\x06\x42\x29\xc3\x06\xbc\x2b\xb2\x06\x77\x2a\xb7\x06\x7a\x29\xb2\x06\xf4\x2b\xa3\x06\x2c\x2b\xbb\x06\xbb\x29\xb9\x06\x63\x2c\xb4\x06\x31\x2b\xcb\x06\x06\x2a\xc4\x06\xd0\x2b\xc6\x06\xc2\x2a\xc0\x06\xc2\x29\xbc\x06\x2b\x2b\xc3\x06\x2e\x2b\xc9\x06\xde\x29\xb5\x06\x90\x2b\xad\x06\xd2\x2a\xc0\x06\xba\x29\xbd\x06\x5b\x2b\xc2\x06\xb9\x2a\xb8\x06\x07\x29\xcc\x06\x33\x2b\xc4\x06\x41\x2a\xc0\x06\xdf\x28\xbe\x06\x84\x2b\xc2\x06\x7b\x2a\xb6\x06\x3d\x29\xb4\x06\xd2\x2b\xaa\x06\xdc\x2a\xbc\x06\x89\x29\xb8\x06\xa5\x2b\xac\x06\xad\x2a\xba\x06\xfa\x28\xc5\x06\x77\x2b\xbe\x06\xd7\x2a\xb7\x06\x1c\x29\xb0\x06\x71\x2b\xbc\x06\xfb\x2a\xbd\x06\x01\x29\xd2\x06\x63\x2b\xbc\x06\x4e\x2a\xb2\x06\x84\x28\xb6\x06\xd5\x2a\xaf\x06\xfb\x29\xb1\x06\xf2\x28\xc9\x06\x09\x2b\xb9\x06\x0b\x2a\xae\x06\x95\x28\xb7\x06\xcd\x2b\xb3\x06\xda\x2a\xa5\x06\xf6\x28\xa7\x06\x5d\x2b\xb3\x06\x50\x2b\xab\x06\xc8\x28\xaa\x06\x9a\x2b\xa1\x06\x81\x2a\xb5\x06\xc0\x28\xb4\x06\x80\x2b\xb2\x06\xc5\x2a\xa8\x06\xdf\x28\xbd\x06\xc8\x2a\xb6\x06\x2c\x2a\xaf\x06\xb1\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbd\x06\x7e\x2a\xb2\x06\xc3\x29\xab\x06\xad\x28\xc8\x06\x75\x2b\xb4\x06\xeb\x29\xb9\x06\xe5\x28\x9e\x06\x28\x2c\x91\x06\xe3\x2a\xbc\x06\x62\x29\xc8\x06\xf7\x2b\xba\x06\xbf\x2a\xb8\x06\x6e\x29\xc4\x06\xc1\x2b\xb9\x06\xf4\x2a\xba\x06\x53\x29\xbe\x06\x28\x2c\xbd\x06\xeb\x2a\xaf\x06\x94\x29\xbf\x06\xec\x2b\xba\x06\x81\x2a\xb8\x06\x94\x29\xc3\x06\xf8\x2a\xbb\x06\x5b\x2a\xaf\x06\x0d\x29\xc9\x06\xcc\x2a\xba\x06\xeb\x29\xbd\x06\x01\x29\xb4\x06\xb7\x2b\xb3\x06\x4e\x2a\xb6\x06\x6b\x29\xcc\x06\xde\x2b\xca\x06\xd2\x2a\xc4\x06\xc0\x29\xc3\x06\x18\x2c\xc5\x06\xf2\x2a\xc5\x06\xac\x29\xb9\x06\xc5\x2b\xb3\x06\xee\x2a\xbc\x06\x85\x29\xc2\x06\x43\x2c\xb3\x06\x05\x2b\xb3\x06\xe8\x29\xcf\x06\xa8\x2b\xbe\x06\x5f\x2a\xc2\x06\x3e\x29\xbc\x06\x67\x2b\xb8\x06\x18\x2a\xc0\x06\x62\x29\xa8\x06\x9c\x2b\xa5\x06\xcd\x2a\xc5\x06\xa0\x29\xc3\x06\xe7\x2b\xc5\x06\xff\x2a\xc1\x06\xbe\x29\xcb\x06\xb4\x2c\xc1\x06\xdc\x2a\xc1\x06\xf3\x29\xc2\x06\xb0\x2c\xbc\x06\xe4\x2a\xba\x06\xde\x29\xc1\x06\xbc\x2c\xae\x06\xe3\x2a\xc6\x06\x0b\x2a\xcb\x06\x4d\x2c\xb3\x06\x66\x2a\xb9\x06\x86\x29\xb5\x06\xfd\x2a\xb2\x06\x63\x2a\xb4\x06\xfd\x28\xbc\x06\x10\x2b\xb5\x06\xda\x2a\xbc\x06\x57\x29\xb5\x06\xf1\x2b\xb1\x06\x2c\x2b\xcf\x06\xb2\x29\xbe\x06\xbf\x2b\xaf\x06\xda\x2a\xbb\x06\xd9\x29\xd2\x06\xb3\x2b\xd1\x06\xe0\x2a\xbc\x06\xce\x29\xc2\x06\x01\x2c\xb2\x06\x1d\x2b\xb1\x06\xd3\x29\xc7\x06\x5f\x2c\xbc\x06\xe8\x2a\xba\x06\xf1\x29\xc7\x06\xdc\x2b\xb5\x06\x1c\x2a\xc1\x06\x3e\x29\xcc\x06\x0d\x2c\xc5\x06\x78\x2a\xb9\x06\x7e\x29\xcb\x06\x1e\x2c\xc8\x06\x68\x2b\xcb\x06\xe5\x29\xc0\x06\x01\x2c\xb4\x06\xda\x2a\xc5\x06\xc3\x29\xc8\x06\xec\x2b\xc5\x06\x2c\x2b\xbc\x06\x8b\x29\xb6\x06\x95\x2b\xb6\x06\x05\x2b\xb7\x06\x74\x29\xba\x06\x5b\x2b\xbb\x06\xfa\x2a\xbf\x06\x90\x29\xa7\x06\xda\x2a\xa0\x06\xb6\x2a\xb5\x06\x72\x29\xc2\x06\xfa\x2a\xc2\x06\x7d\x2a\xb5\x06\x0f\x29\xb8\x06\x9f\x2b\xb6\x06\xba\x2a\xab\x06\x50\x29\xc5\x06\xdc\x2b\xb6\x06\x83\x2a\xbd\x06\x6a\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbf\x06\x5c\x2b\xbf\x06\xb1\x2a\xbe\x06\x5f\x29\xc1\x06\x45\x2b\xbf\x06\xdf\x2a\xb2\x06\x19\x29\xc3\x06\x5e\x2b\xbf\x06\xe1\x2a\xb6\x06\x2f\x29\xac\x06\x2d\x2b\xae\x06\xa3\x2a\xc1\x06\xca\x28\xbb\x06\xd9\x2a\xbc\x06\x3a\x2a\xb9\x06\xc3\x28\xc6\x06\x62\x2b\xc4\x06\xc2\x2a\xc2\x06\xd5\x28\xb8\x06\x78\x2b\xb6\x06\xfc\x2a\xbd\x06\xbe\x28\xad\x06\x7c\x2b\xad\x06\xd3\x2a\xb6\x06\xda\x28\xb8\x06\x66\x2b\xb6\x06\x00\x2b\xb3\x06\x09\x29\xb3\x06\x25\x2b\xaf\x06\xd1\x2a\xbc\x06\xfc\x28\xbb\x06\xed\x2a\xbf\x06\x74\x2a\xbb\x06\x18\x29\xb2\x06\x8e\x2a\xad\x06\x32\x2a\xb9\x06\xde\x28\xae\x06\xc6\x2a\xb3\x06\x82\x2a\xb3\x06\x0c\x29\xbf\x06\x48\x2b\xbe\x06\xe3\x2a\xb5\x06\x8b\x29\xc3\x06\x81\x2b\xc3\x06\x21\x2b\xbe\x06\xc4\x29\xb9\x06\xc1\x2b\xb8\x06\x6f\x2b\xc7\x06\x89\x29\xc6\x06\x53\x2b\xd3\x06\x6b\x2b\xc8\x06\xb7\x29\xbb\x06\xbd\x2b\xb0\x06\x64\x2b\xc1\x06\xd3\x29\xc6\x06\x12\x2b\xbc\x06\xac\x2a\xbc\x06\x52\x29\xb8\x06\x62\x2b\xbc\x06\xd0\x2a\xb6\x06\xab\x29\xbb\x06\x42\x2c\xb7\x06\x89\x2b\xb5\x06\x0e\x2a\xc9\x06\x4f\x2c\xb3\x06\x6c\x2b\xc4\x06\x72\x2a\xc6\x06\xcb\x2c\xc8\x06\xd7\x2b\xb8\x06\x6c\x2a\xc9\x06\x67\x2d\xbc\x06\xbf\x2b\xb6\x06\xa9\x2a\xca\x06\xcc\x2d\xbd\x06\xb8\x2b\xb5\x06\xb4\x2a\xbf\x06\x73\x2c\xb9\x06\xff\x2a\xc2\x06\x26\x2a\xbc\x06\x33\x2c\xc4\x06\x19\x2c\xb9\x06\x78\x2a\xc4\x06\x95\x2c\xc2\x06\xba\x2b\xb5\x06\x86\x2a\xc8\x06\x00\x2d\xbd\x06\x66\x2b\xb8\x06\x75\x2a\xc3\x06\x97\x2c\xc0\x06\x0c\x2c\xb6\x06\x63\x2a\xc1\x06\x43\x2c\xbc\x06\xa5\x2b\xbb\x06\x56\x2a\xb4\x06\x0d\x2c\xb6\x06\x5d\x2b\xbb\x06\x5c\x2a\xac\x06\x59\x2b\xb5\x06\x38\x2b\xa9\x06\x86\x29\xad\x06\x61\x2b\xb5\x06\x3e\x2b\xb8\x06\xb5\x29\xc9\x06\x08\x2c\xbb\x06\x79\x2b\xc6\x06\x4a\x2a\xc7\x06\x18\x2c\xbe\x06\x4a\x2b\xc3\x06\x3d\x2a\xc2\x06\xf7\x2b\xc3\x06\xb6\x2b\xc1\x06\x03\x2a\xb6\x06\xfc\x2b\xb9\x06\xd0\x2b\xc0\x06\x2a\x2a\xcb\x06\x15\x2c\xd2\x06\xa5\x2b\xc2\x06\x81\x2a\xc1\x06\xc7\x2b\xbe\x06\x56\x2b\xbc\x06\xf5\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc0\x06\x79\x2b\xbb\x06\x05\x2b\xc0\x06\xc0\x29\xc6\x06\x0f\x2c\xc7\x06\x77\x2c\xbd\x06\x44\x2a\xbe\x06\x32\x2c\xc1\x06\xa8\x2b\xbd\x06\x46\x2a\xb9\x06\x4b\x2c\xb9\x06\x4c\x2b\xb5\x06\x04\x2a\xc4\x06\x56\x2c\xbb\x06\x4a\x2b\xbf\x06\x56\x2a\xac\x06\x0f\x2c\xb4\x06\x81\x2b\xb7\x06\x0e\x2a\xc3\x06\x72\x2b\xbc\x06\xf4\x2a\xc1\x06\xa8\x29\xc8\x06\xb4\x2b\xac\x06\xe8\x2a\xc3\x06\x8f\x29\xbd\x06\xe6\x2b\xb7\x06\xf4\x2a\xbd\x06\x99\x29\xc3\x06\xc3\x2b\xbe\x06\x58\x2b\xb4\x06\x3d\x2a\xc4\x06\x0e\x2c\xc8\x06\x67\x2b\xb4\x06\xe6\x29\xc8\x06\x23\x2c\xc6\x06\x98\x2b\xbc\x06\x25\x2a\xaf\x06\xbc\x2b\xbb\x06\xe4\x2b\xbf\x06\x3b\x2a\xb1\x06\xf1\x2b\xa3\x06\x44\x2b\xb4\x06\xd1\x29\xc2\x06\x2a\x2b\xc1\x06\x8c\x2a\xbf\x06\x5e\x29\xc0\x06\x97\x2b\xc1\x06\xf1\x2a\xbd\x06\xb3\x29\xbe\x06\xdc\x2b\xc5\x06\x91\x2b\xbb\x06\x13\x2a\xc4\x06\xe1\x2b\xc7\x06\x95\x2b\xb3\x06\xea\x29\xc6\x06\x76\x2c\xba\x06\xc2\x2b\xbb\x06\x0b\x2a\xae\x06\x4e\x2c\xa6\x06\x8c\x2b\xc0\x06\x2e\x2a\xc2\x06\xf1\x2b\xbe\x06\x82\x2b\xbb\x06\x6a\x2a\xcb\x06\xa5\x2c\xbc\x06\x21\x2b\xb7\x06\xf7\x29\xbe\x06\xb4\x2b\xc5\x06\x42\x2b\xbc\x06\xe8\x29\xcc\x06\x3a\x2c\xca\x06\xe4\x2b\xc4\x06\x74\x2a\xc9\x06\xa4\x2c\xc3\x06\xcb\x2b\xbf\x06\x75\x2a\xbc\x06\x23\x2c\xb2\x06\xb1\x2b\xc0\x06\x6e\x2a\xc0\x06\x56\x2c\xc1\x06\xa4\x2b\xb8\x06\x34\x2a\xbc\x06\x0e\x2c\xb9\x06\xb5\x2b\xc0\x06\x59\x2a\xbf\x06\xda\x2b\xb5\x06\x52\x2b\xb8\x06\x13\x2a\xad\x06\xd6\x2b\xb0\x06\x58\x2b\xb6\x06\x00\x2a\xbc\x06\x5a\x2c\xb7\x06\xd7\x2b\xcd\x06\xaa\x2a\xb3\x06\xa4\x2c\xbb\x06\x3e\x2c\xc0\x06\xc7\x2a\xc4\x06\x7d\x2c\xbd\x06\xef\x2b\xc4\x06\xb5\x2a\xb8\x06\x5d\x2c\xb7\x06\x00\x2c\xba\x06\xad\x2a\xc8\x06\x83\x2c\xba\x06\xdb\x2b\xbf\x06\x7f\x2a\xb6\x06\x1a\x2c\xaa\x06\x96\x2b\xc4\x06\x31\x2a\xcc\x06\xae\x2b\xcc\x06\x64\x2b\xbd\x06\x35\x2a\xbe\x06\x2e\x2c\xbe\x06\xb5\x2b\xba\x06\x51\x2a\xbb\x06\x88\x2c\xb0\x06\xe2\x2b\xb2\x06\x78\x2a\xc2\x06\x61\x2c\xc0\x06\xe8\x2b\xbb\x06\x26\x2a\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xca\x06\x94\x2c\xcd\x06\xf6\x2b\xcf\x06\x5f\x2a\xb3\x06\x76\x2c\xac\x06\x0c\x2c\xcd\x06\x5f\x2a\xb8\x06\xe4\x2b\xab\x06\x75\x2b\xbc\x06\x0b\x2a\xc2\x06\xbf\x2b\xcd\x06\x2a\x2b\xc6\x06\x04\x2a\xd1\x06\x2a\x2c\xc6\x06\x8d\x2b\xc7\x06\xe8\x29\xc8\x06\x68\x2c\xb6\x06\xe4\x2b\xbf\x06\x7f\x2a\xca\x06\x6e\x2c\xc8\x06\xe2\x2b\xb3\x06\x46\x2a\xac\x06\x6e\x2c\xac\x06\xee\x2b\xb9\x06\x5a\x2a\xbe\x06\x8a\x2c\xb9\x06\xc7\x2b\xbc\x06\x3f\x2a\xc7\x06\x25\x2c\xbb\x06\x95\x2b\xbc\x06\x47\x2a\xc0\x06\xd7\x2b\xbc\x06\xea\x2a\xae\x06\xac\x29\xbd\x06\x04\x2c\xbc\x06\x91\x2b\xc4\x06\x02\x2a\xd6\x06\x40\x2c\xd6\x06\xfb\x2b\xc1\x06\x64\x2a\xc0\x06\x3f\x2c\xbb\x06\x6b\x2b\xbb\x06\x5b\x2a\xcd\x06\x28\x2c\xcb\x06\x86\x2b\xc7\x06\x44\x2a\xab\x06\x04\x2c\xad\x06\xd2\x2b\xb7\x06\xb3\x2a\xc7\x06\x13\x2c\xc6\x06\x8e\x2b\xbf\x06\x52\x2a\xb3\x06\x7d\x2b\xb4\x06\x0d\x2b\xc0\x06\x0f\x2a\xc1\x06\x07\x2c\xc4\x06\x92\x2b\xb7\x06\x16\x2a\xbf\x06\x23\x2c\xb9\x06\xb7\x2b\xaf\x06\xaa\x2a\xc6\x06\x20\x2c\xc6\x06\xf5\x2b\xb5\x06\x8f\x2a\xbb\x06\x24\x2c\xc4\x06\xac\x2b\xc0\x06\x8e\x2a\xbd\x06\x1d\x2c\xbf\x06\xed\x2b\xc0\x06\x6d\x2a\xbe\x06\xff\x2b\xb2\x06\x91\x2b\xca\x06\x8d\x2a\xc5\x06\x7c\x2b\xc6\x06\xf9\x2a\xc8\x06\x07\x2a\xb9\x06\x4e\x2b\xbc\x06\x55\x2b\xc2\x06\xf5\x29\xc8\x06\xd9\x2b\xbd\x06\x8f\x2b\xbc\x06\x4a\x2a\xb0\x06\x63\x2c\xb0\x06\xe5\x2b\xc0\x06\x7a\x2a\xb9\x06\x0c\x2c\xb6\x06\xc7\x2b\xbd\x06\x88\x2a\x9a\x06\x94\x2c\x99\x06\xc7\x2b\xc7\x06\x96\x2a\xbd\x06\x48\x2c\xbd\x06\x2e\x2c\xc1\x06\xa9\x2a\xc5\x06\x00\x2c\xb8\x06\x8c\x2b\xbe\x06\x2a\x2a\xbf\x06\xc1\x2b\xc6\x06\x37\x2b\xc4\x06\xf9\x29\xb3\x06\x5c\x2c\xa7\x06\xb0\x2b\xb7\x06\x32\x2a\xb8\x06\x6b\x2c\xab\x06\xe6\x2b\xbf\x06\x48\x2a\xb8\x06\x50\x2c\xb9\x06\xa1\x2b\xc5\x06\x9d\x2a\xd3\x06\x80\x2c\xc6\x06\xac\x2b\xc7\x06\x83\x2a\xbb\x06\xda\x2b\xc0\x06\x95\x2b\xc8\x06\x45\x2a\xc3\x06\xc4\x2b\xc2\x06\x6d\x2b\xbc\x06\x4e\x2a\xb0\x06\x80\x2b\xab\x06\xd2\x2a\xb3\x06\xb8\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc1\x06\x0b\x2c\xb5\x06\x40\x2b\xc2\x06\x9e\x2a\xb0\x06\x6a\x2c\xad\x06\xa3\x2b\xc2\x06\xf8\x2a\xb9\x06\x63\x2c\xb6\x06\x96\x2b\xbb\x06\x2c\x2a\xa6\x06\x39\x2c\xb0\x06\x0e\x2c\xa2\x06\xf7\x2a\xd1\x06\x5e\x2c\xc5\x06\x5f\x2b\xc4\x06\x3d\x2a\xc7\x06\x18\x2c\xc8\x06\x23\x2b\xc8\x06\x21\x2a\xaf\x06\xa9\x2b\xae\x06\xb5\x2a\xbd\x06\xa4\x29\xbc\x06\xfd\x2b\xbc\x06\xd0\x2a\xb6\x06\xd4\x29\xbf\x06\x37\x2c\xb9\x06\x3e\x2b\xbc\x06\x0e\x2a\xc8\x06\x2c\x2c\xc2\x06\x81\x2b\xb9\x06\x01\x2a\xc8\x06\x69\x2c\xbd\x06\xb4\x2b\xb6\x06\x65\x2a\xc8\x06\x6d\x2c\xb6\x06\x6a\x2b\xbd\x06\x56\x2a\xbf\x06\x36\x2c\xbd\x06\xd5\x2b\xc2\x06\x96\x2a\xb0\x06\x16\x2c\xa1\x06\x17\x2b\xc3\x06\xf9\x29\xc3\x06\xdb\x2b\xc0\x06\x4b\x2b\xb6\x06\xef\x29\xc3\x06\x6d\x2c\xb9\x06\xa0\x2b\xc4\x06\xa2\x2a\xc6\x06\x82\x2c\xc5\x06\x55\x2b\xc8\x06\xaf\x2a\xc3\x06\x81\x2c\xbf\x06\x8d\x2b\xbc\x06\x45\x2a\xcb\x06\x79\x2c\xb5\x06\x91\x2b\xbe\x06\x81\x2a\xbf\x06\x64\x2c\xbc\x06\xb4\x2b\xc0\x06\xa8\x2a\xc9\x06\xf8\x2b\xbe\x06\x4e\x2b\xc6\x06\x1e\x2a\xbf\x06\xc3\x2b\xc9\x06\xe6\x2a\xbd\x06\x08\x2a\xc4\x06\x38\x2c\xb8\x06\x8c\x2b\xb2\x06\x5b\x2a\xc5\x06\x9a\x2c\xbd\x06\x08\x2c\xbc\x06\x99\x2a\xb8\x06\xae\x2c\xb8\x06\x08\x2c\xc4\x06\xe4\x2a\xcb\x06\x8e\x2c\xbe\x06\xa5\x2b\xc7\x06\xd5\x2a\xc2\x06\xfe\x2c\xb8\x06\xa4\x2b\xbe\x06\x87\x2a\xb3\x06\xb1\x2c\xa7\x06\x83\x2b\xba\x06\x4c\x2a\xcc\x06\x61\x2c\xbf\x06\x29\x2b\xc3\x06\x19\x2a\xb8\x06\x00\x2d\xba\x06\xac\x2b\xcf\x06\x8d\x2a\xc8\x06\x22\x2d\xb6\x06\xa8\x2b\xba\x06\xb9\x2a\xc3\x06\xf8\x2c\xca\x06\xaf\x2b\xc0\x06\xa2\x2a\xcb\x06\xf6\x2c\xc3\x06\x7d\x2b\xc6\x06\x7d\x2a\xca\x06\xba\x2c\xbf\x06\x81\x2b\xc7\x06\x52\x2a\xbf\x06\x38\x2c\xb4\x06\x39\x2b\xc1\x06\x2e\x2a\xe2\x06\xbe\x2b\xe5\x06\xa6\x2a\xe4\x06\xc0\x29\xdf\x06\xc4\x2b\xcb\x06\x87\x2a\xe0\x06\xd3\x29\xde\x06\xb0\x2b\xcd\x06\xa5\x2a\xd9\x06\xbb\x29\x9d\x06\x74\x2b\x93\x06\x30\x2a\x9b\x06\xa6\x28\x2d\x06\x8c\x2b\x32\x06\x26\x2a\x2b\x06\x92\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x3c\x06\xfc\x2a\x32\x06\x4e\x29\x34\x06\xc6\x26\x6d\x06\xe3\x2a\x62\x06\xcd\x29\x6e\x06\x6f\x28\xd4\x06\x29\x2b\xc0\x06\xcf\x29\xd0\x06\xe4\x28\xdb\x06\x1f\x2b\xce\x06\xf5\x29\xdd\x06\x88\x29\xca\x06\x2e\x2b\xba\x06\x1d\x2a\xc5\x06\xf7\x28\xd1\x06\xb2\x2b\xc6\x06\x97\x2a\xbe\x06\x79\x29\xcd\x06\xfa\x2b\xb6\x06\x93\x2a\xc8\x06\xa4\x29\xc5\x06\xc1\x2b\xb1\x06\x87\x2a\xc1\x06\x9a\x29\xbb\x06\xe4\x2b\xaf\x06\x86\x2a\xbb\x06\x67\x29\xc3\x06\x02\x2c\xba\x06\xa5\x2a\xc4\x06\x92\x29\xb5\x06\xe4\x2b\xb5\x06\x99\x2a\xbd\x06\x97\x29\xbf\x06\xb0\x2b\xb6\x06\x44\x2a\xbd\x06\x61\x29\xbb\x06\xd7\x2b\xbb\x06\xac\x2a\xc0\x06\x75\x29\xcc\x06\xd4\x2b\xb9\x06\xca\x2a\xc0\x06\x73\x29\xa9\x06\xc9\x2b\xa5\x06\xde\x2a\xc3\x06\x7a\x29\xb8\x06\x20\x2b\xc8\x06\x91\x2a\xca\x06\x7f\x29\xbe\x06\x61\x2b\xb9\x06\xab\x2a\xc0\x06\x58\x29\xc3\x06\x79\x2b\xc0\x06\x5f\x2a\xc6\x06\x65\x29\xb5\x06\x3f\x2b\xb0\x06\x53\x2a\xb1\x06\xf5\x28\xbc\x06\xd9\x2a\xba\x06\x29\x2a\xb8\x06\xd7\x28\xbe\x06\x28\x2b\xc1\x06\x77\x2a\xad\x06\x47\x29\xbf\x06\x2f\x2b\xb0\x06\x2f\x2a\xbf\x06\x02\x29\xcb\x06\x8e\x2b\xbb\x06\x31\x2a\xba\x06\x18\x29\xb6\x06\x15\x2b\xb8\x06\x8c\x2a\xbb\x06\x0e\x29\xbf\x06\x36\x2b\xba\x06\x37\x2a\xc1\x06\x4d\x29\xc0\x06\x0f\x2b\xbc\x06\x1b\x2a\xbc\x06\xfb\x28\xba\x06\xb8\x2a\xb8\x06\xa3\x29\xb6\x06\x9c\x28\xba\x06\xf9\x2a\xbb\x06\x23\x2a\xb4\x06\xfe\x28\xb9\x06\x10\x2b\xb2\x06\x2c\x2a\xb4\x06\x1a\x29\xb5\x06\xe8\x2a\xba\x06\x29\x2a\xb0\x06\x12\x29\xc9\x06\xee\x2a\xc3\x06\x18\x2a\xbb\x06\x0c\x29\xaf\x06\x2c\x2b\xad\x06\x38\x2a\xbb\x06\x0e\x29\xc7\x06\xfa\x2a\xc0\x06\xfa\x29\xc5\x06\x31\x29\xbe\x06\x08\x2b\xbd\x06\xc6\x29\xbb\x06\x91\x28\xbd\x06\xb8\x2a\xb8\x06\xc6\x29\xb7\x06\xf1\x28\xa9\x06\xc3\x2a\xa4\x06\x69\x2a\xb6\x06\xfe\x28\xb9\x06\xa7\x2a\xba\x06\x13\x2a\xc5\x06\xf9\x28\xc1\x06\xec\x2a\xc2\x06\xe8\x29\xc6\x06\xf8\x28\xb3\x06\xee\x2a\xaa\x06\x30\x2a\xc4\x06\x0f\x29\xc2\x06\xd6\x2a\xc4\x06\x09\x2a\xc3\x06\x07\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc4\x06\xd7\x2a\xb6\x06\xa2\x29\xbe\x06\xd8\x28\xb1\x06\x9a\x2a\xaf\x06\xf8\x29\xae\x06\xff\x28\x9d\x06\xc9\x2a\x9e\x06\x43\x2a\xb6\x06\xf8\x28\xbf\x06\x07\x2b\xc3\x06\x21\x2a\xb9\x06\xd2\x28\xaf\x06\xaa\x2a\xb2\x06\x1f\x2a\xac\x06\x0f\x29\xbf\x06\xb3\x2a\xbb\x06\x13\x2a\xbc\x06\xd9\x28\xb9\x06\xee\x2a\xb8\x06\xe3\x29\xbf\x06\x35\x29\xba\x06\x98\x2a\xb2\x06\x7a\x29\xbc\x06\x90\x28\xba\x06\xaa\x2a\xb8\x06\xbd\x29\xbc\x06\x9d\x28\xb4\x06\x70\x2a\xbc\x06\x07\x2a\xb6\x06\xef\x28\xbe\x06\x67\x2a\xab\x06\xa7\x29\xb2\x06\xcb\x28\xa3\x06\xf6\x2a\xa2\x06\x0d\x2a\xb3\x06\xe4\x28\xb2\x06\x57\x2a\xba\x06\xc6\x29\xbf\x06\xdb\x28\xa0\x06\x8f\x2a\x97\x06\xaf\x29\xbb\x06\x17\x29\xb6\x06\x2e\x2a\xb5\x06\x93\x29\xb9\x06\x62\x28\xb7\x06\x88\x2a\xac\x06\x3f\x29\xbe\x06\x6f\x28\xb4\x06\x60\x2a\xb6\x06\x8e\x29\xb7\x06\x5e\x28\x95\x06\x46\x2a\x99\x06\x50\x29\xbb\x06\x80\x28\xb7\x06\xee\x29\xb3\x06\x7e\x29\xb7\x06\x73\x28\xba\x06\x6e\x2a\xb7\x06\xc7\x29\xb4\x06\x42\x28\xc5\x06\x56\x2a\xc4\x06\xd8\x29\xb1\x06\x5a\x28\xb2\x06\x97\x2a\xb3\x06\xba\x29\xba\x06\x8d\x28\xb9\x06\x04\x2a\xba\x06\x26\x29\xb8\x06\x30\x28\xbb\x06\x90\x2a\xb3\x06\xd8\x29\xb5\x06\x7d\x28\xbf\x06\x83\x2a\xb1\x06\xc7\x29\xba\x06\xc0\x28\xbd\x06\x76\x2a\xbe\x06\xa0\x29\xbb\x06\x91\x28\xb5\x06\x92\x2a\xae\x06\x7d\x29\xb8\x06\xa0\x28\xbb\x06\x10\x2b\xa3\x06\xba\x29\xc1\x06\xd1\x28\xb5\x06\xa8\x2a\xbc\x06\xc7\x29\xbd\x06\xdc\x28\xa9\x06\x42\x2a\xa0\x06\x6b\x29\xac\x06\x60\x28\xb6\x06\x98\x2a\xc1\x06\xfc\x29\xbc\x06\xde\x28\xc1\x06\x92\x2a\xca\x06\xe8\x29\xb7\x06\x98\x28\xc0\x06\x99\x2a\xbf\x06\x0c\x2a\xb6\x06\xb3\x28\xaf\x06\x95\x2a\xb2\x06\xce\x29\xbd\x06\xa4\x28\xbe\x06\xa2\x2a\xb4\x06\x95\x29\xc4\x06\xba\x28\xbe\x06\x99\x2a\xc3\x06\xa9\x29\xc1\x06\xb4\x28\xb0\x06\x45\x2a\xac\x06\x8a\x29\xb3\x06\x52\x28\xad\x06\x71\x2a\xa8\x06\xae\x29\xb7\x06\x9c\x28\xa3\x06\x69\x2a\xa2\x06\x10\x2a\xbc\x06\x95\x28\xc1\x06\x7a\x2a\xbf\x06\xce\x29\xbe\x06\xb4\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbc\x06\x47\x2a\xb8\x06\x9e\x29\xbb\x06\x68\x28\xbb\x06\x5b\x2a\xb8\x06\xdb\x29\xc5\x06\xcf\x28\xbf\x06\x60\x2a\xc2\x06\xba\x29\xc3\x06\xb0\x28\xb3\x06\x1b\x2a\xad\x06\x27\x29\xb1\x06\x5a\x28\xc3\x06\x3e\x2a\xb9\x06\x84\x29\xbc\x06\x3f\x28\xc0\x06\x40\x2a\xb7\x06\xb6\x29\xb6\x06\xb3\x28\xb5\x06\x4d\x2a\xb4\x06\x67\x29\xaf\x06\x4e\x28\xc2\x06\x7b\x2a\xba\x06\x64\x29\xb7\x06\x65\x28\xc1\x06\x76\x2a\xb2\x06\x95\x29\xb4\x06\x6c\x28\xb1\x06\x7d\x2a\xb1\x06\xd3\x29\xc0\x06\xaf\x28\xb5\x06\x92\x2a\xb0\x06\x92\x29\xb7\x06\xb3\x28\xbd\x06\x3f\x2a\xc0\x06\x54\x29\xbf\x06\x6d\x28\xc4\x06\x88\x2a\xca\x06\x75\x29\xc6\x06\xa5\x28\xb1\x06\x45\x2a\xb7\x06\x79\x29\xbc\x06\x63\x28\xbc\x06\x5f\x2a\xb3\x06\xaa\x29\xba\x06\x7e\x28\xba\x06\x62\x2a\xb2\x06\xbd\x29\xad\x06\x87\x28\xac\x06\x36\x2a\xaf\x06\x3c\x29\xb2\x06\x51\x28\xbd\x06\x5f\x2a\xb8\x06\xa5\x29\xbc\x06\x92\x28\xb2\x06\x1e\x2a\xb2\x06\x1e\x29\xb4\x06\x07\x28\xb6\x06\x69\x2a\xbb\x06\x3b\x29\xb6\x06\x4d\x28\xa3\x06\x59\x2a\x9d\x06\x44\x29\xb6\x06\x25\x28\xb5\x06\x11\x2a\xb7\x06\x5b\x29\xbc\x06\x02\x28\xb5\x06\x5b\x2a\xa1\x06\x3b\x29\xaa\x06\x09\x28\xb9\x06\x47\x2a\xba\x06\x4b\x29\xb3\x06\x01\x28\xb6\x06\x29\x2a\xb6\x06\x25\x29\xb8\x06\x02\x28\xa8\x06\x06\x2a\x9f\x06\xda\x28\xb0\x06\x45\x27\xb5\x06\x4d\x2a\x97\x06\xc4\x28\xac\x06\x2e\x27\xaa\x06\xf5\x29\xa4\x06\xf6\x28\xa5\x06\x0d\x27\xb3\x06\x20\x2a\xb0\x06\x1b\x29\xb0\x06\x37\x27\xa1\x06\x21\x2a\x97\x06\x57\x29\xb8\x06\x59\x27\xc3\x06\xfa\x29\xc4\x06\x4a\x29\xc0\x06\xe0\x27\xb8\x06\xc4\x29\xb6\x06\xe1\x28\xb7\x06\xd5\x27\xbc\x06\xe0\x29\xb4\x06\xb7\x28\xad\x06\x5c\x27\xa4\x06\x08\x2a\xac\x06\x19\x29\xb4\x06\x12\x28\xb3\x06\xe9\x29\xb8\x06\x2f\x29\xba\x06\x36\x28\xbb\x06\x25\x2a\xac\x06\x0d\x29\xb0\x06\x29\x28\xb9\x06\x4e\x2a\xbc\x06\x36\x29\xc1\x06\x3a\x28\xc0\x06\x32\x2a\xbd\x06\x9e\x29\xbb\x06\x7e\x28\xbf\x06\x89\x2a\xb4\x06\x8b\x29\xb8\x06\x67\x28\xac\x06\x83\x2a\xb1\x06\x0a\x29\xb5\x06\x18\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xac\x06\x33\x2a\xac\x06\x3a\x29\xa7\x06\x01\x28\xbd\x06\x43\x2a\xbe\x06\x57\x29\xbd\x06\x28\x28\xb6\x06\xd8\x29\xb3\x06\x7a\x29\xb5\x06\x50\x28\xaf\x06\xf1\x29\xaf\x06\x4f\x29\xad\x06\x11\x28\xba\x06\x92\x2a\xbb\x06\x92\x29\xb1\x06\x3b\x28\xc0\x06\x1a\x2a\xb8\x06\xad\x29\xb9\x06\x87\x28\xc3\x06\x23\x2a\xbd\x06\x5b\x29\xc0\x06\x52\x28\x98\x06\x1f\x2a\x9c\x06\x7a\x29\xb0\x06\x8f\x28\xb5\x06\x44\x2a\xaa\x06\xac\x29\xae\x06\x63\x28\xbd\x06\x36\x2a\xac\x06\x98\x29\xb7\x06\x8a\x28\xc7\x06\x9b\x2a\xbc\x06\xc1\x29\xbe\x06\x8a\x28\xd2\x06\xe3\x2a\xb9\x06\xb7\x29\xc8\x06\x78\x28\xbb\x06\xa6\x2a\xbc\x06\x61\x29\xc5\x06\x78\x28\xb6\x06\x44\x2a\xb6\x06\x3c\x29\xc1\x06\x83\x28\xb8\x06\xc4\x2a\xba\x06\x06\x29\xba\x06\xa5\x28\xbf\x06\x82\x2b\xb7\x06\x78\x29\xc9\x06\xc9\x28\xbb\x06\xb8\x2b\xba\x06\x8f\x29\xb1\x06\x8a\x28\xc6\x06\xb5\x2a\xb9\x06\xa2\x29\xca\x06\x8d\x28\xaa\x06\x79\x2a\xa5\x06\xe0\x29\xbe\x06\x8d\x28\xb4\x06\xa4\x2a\xb8\x06\x8d\x29\xba\x06\xc2\x28\xbd\x06\x91\x2a\xbc\x06\x02\x2a\xbc\x06\xc3\x28\xbb\x06\x51\x2a\xbb\x06\xba\x29\xc3\x06\xa1\x28\xb3\x06\x91\x2a\xa7\x06\xfe\x29\xc2\x06\x9d\x28\xbe\x06\x55\x2a\xc4\x06\xf6\x29\xb6\x06\xa5\x28\xb6\x06\x91\x2a\xae\x06\xc0\x29\xbe\x06\x07\x29\xb9\x06\x72\x2a\xb9\x06\xdf\x29\xbd\x06\xbc\x28\xbf\x06\x92\x2a\xbe\x06\x13\x2a\xba\x06\xc5\x28\xc6\x06\xc6\x2a\xba\x06\x13\x2a\xc1\x06\xe5\x28\xb8\x06\x59\x2a\xb3\x06\xa1\x29\xbb\x06\xda\x28\xc3\x06\x8f\x2a\xc6\x06\xbf\x29\xca\x06\x11\x29\xb1\x06\x5c\x2a\xb4\x06\xca\x29\xbd\x06\xac\x28\xbd\x06\xa8\x2a\xc1\x06\xea\x29\xbc\x06\xdc\x28\xb4\x06\xd0\x2a\xb4\x06\x3e\x2a\xb4\x06\xf8\x28\xc4\x06\x75\x2a\xc2\x06\xf0\x29\xc7\x06\xd5\x28\xb7\x06\x67\x2a\xb8\x06\xe0\x29\xb2\x06\xdc\x28\xb8\x06\x51\x2a\xba\x06\xb1\x29\xb3\x06\x9d\x28\xb9\x06\x4b\x2a\xbd\x06\x93\x29\xbd\x06\xab\x28\xbb\x06\x86\x2a\xb3\x06\x6d\x29\xac\x06\x80\x28\xc0\x06\x67\x2a\xbb\x06\xaf\x29\xbc\x06\xba\x28\xc2\x06\x68\x2a\xb8\x06\xf6\x29\xb5\x06\x61\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb6\x06\x54\x2a\xb5\x06\xa5\x29\xb7\x06\x7e\x28\xc6\x06\x8c\x2a\xb6\x06\xd3\x29\xac\x06\x7a\x28\xa3\x06\xcf\x2a\x9e\x06\x09\x2a\xb4\x06\xe4\x28\xc1\x06\x3a\x2a\xb3\x06\xdb\x29\xc1\x06\x7e\x28\xc3\x06\x18\x2a\xcd\x06\x78\x2a\xc1\x06\x7c\x28\xb8\x06\x8b\x2a\xc4\x06\x35\x2a\xb3\x06\x76\x28\xb6\x06\xc3\x2a\xaf\x06\xa4\x29\xb7\x06\xb6\x28\xc0\x06\xfe\x2a\xb3\x06\x34\x2a\xbf\x06\x98\x28\xcd\x06\xf7\x2a\xc8\x06\xf8\x29\xc1\x06\xf6\x28\xd0\x06\xdc\x2a\xbc\x06\x9a\x29\xb9\x06\x89\x28\xbe\x06\xd4\x2a\xaf\x06\x4e\x29\xba\x06\x36\x28\xc1\x06\x94\x2a\xb9\x06\xa7\x29\xb7\x06\x63\x28\xa6\x06\x88\x2a\x9d\x06\xad\x29\xb5\x06\x3c\x28\xad\x06\x2c\x2a\xb7\x06\x8e\x29\xb8\x06\x5e\x28\xbd\x06\x30\x2a\xb7\x06\x60\x29\xc1\x06\x5e\x28\xc1\x06\x77\x2a\xbc\x06\x60\x29\xc8\x06\x48\x28\xb7\x06\x7b\x2a\xb3\x06\x2d\x29\xc4\x06\x62\x28\xaf\x06\x98\x2a\xaf\x06\x20\x29\xba\x06\x00\x28\xb6\x06\x32\x2b\xb4\x06\x8e\x29\xba\x06\x68\x28\xbb\x06\x8c\x2b\xa8\x06\x99\x29\xca\x06\x95\x28\xbc\x06\xdf\x2b\xa3\x06\x82\x29\xb3\x06\xcc\x28\xc6\x06\x54\x2b\xbf\x06\x8b\x29\xbb\x06\x84\x28\xc5\x06\xb8\x2a\xbe\x06\xf2\x29\xb7\x06\x69\x28\xac\x06\xd9\x2a\xb1\x06\xe6\x29\xbf\x06\x90\x28\xba\x06\xfe\x2a\xbb\x06\x9a\x29\xc2\x06\x72\x28\xbd\x06\xfa\x2a\xb2\x06\xc7\x29\xc2\x06\xce\x28\xc6\x06\xee\x2a\xb8\x06\xf6\x29\xc6\x06\xf1\x28\x8a\x06\x66\x2b\x8a\x06\x2d\x2a\xb6\x06\x90\x28\xc2\x06\xf8\x2a\xb8\x06\x9a\x29\xb7\x06\x58\x28\xce\x06\x39\x2b\xc2\x06\xdc\x29\xc5\x06\x78\x28\xcf\x06\x20\x2b\xc2\x06\x34\x2a\xc0\x06\x9e\x28\xa4\x06\xf5\x2a\xa2\x06\xc6\x29\xbe\x06\xe4\x28\xc6\x06\x0f\x2b\xb4\x06\x9a\x29\xc2\x06\xd6\x28\xcd\x06\x33\x2b\xc4\x06\xfe\x29\xc2\x06\xb7\x28\xc8\x06\x1f\x2b\xc1\x06\xe0\x29\xc4\x06\xc5\x28\xab\x06\x4f\x2b\xaa\x06\xf8\x29\xc1\x06\xa5\x28\xb8\x06\x56\x2b\xaf\x06\x09\x2a\xbb\x06\xdb\x28\xd5\x06\x70\x2b\xc8\x06\x0b\x2a\xc6\x06\xfd\x28\xd1\x06\x6b\x2b\xc7\x06\xcb\x29\xc9\x06\x14\x29\xbd\x06\x25\x2b\xac\x06\xc2\x29\xc3\x06\xe1\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcb\x06\xce\x2a\xc1\x06\x11\x2a\xc1\x06\x27\x29\xc4\x06\xb9\x2a\xc0\x06\xfc\x29\xc0\x06\xe0\x28\xbb\x06\x27\x2b\xb8\x06\x14\x2a\xc0\x06\x16\x29\xc9\x06\x34\x2b\xba\x06\xfe\x29\xc7\x06\xff\x28\xc6\x06\x2b\x2b\xcb\x06\x6e\x2a\xbf\x06\xeb\x28\xc9\x06\x7d\x2b\xc0\x06\x6c\x2a\xcb\x06\x77\x29\xc6\x06\x9e\x2b\xc2\x06\x40\x2a\xc3\x06\x1e\x29\xc1\x06\x22\x2b\xbb\x06\x52\x2a\xb9\x06\x33\x29\xd7\x06\x40\x2b\xd6\x06\x46\x2a\xd9\x06\x02\x29\xc0\x06\x3b\x2b\xb5\x06\xec\x29\xb8\x06\xe5\x28\xc8\x06\x03\x2b\xbb\x06\xe3\x29\xb2\x06\xd7\x28\xb6\x06\x22\x2b\xbb\x06\x54\x2a\xbd\x06\xe0\x28\xc2\x06\x32\x2b\xcb\x06\x3d\x2a\xc0\x06\x3d\x29\xa3\x06\x76\x2b\xa6\x06\xf2\x29\xc1\x06\x19\x29\xbc\x06\x4a\x2b\xb8\x06\x0c\x2a\xb6\x06\xed\x28\xc3\x06\x99\x2a\xc7\x06\xfb\x29\xc3\x06\xc3\x28\xbd\x06\xd1\x2a\xad\x06\xc3\x29\xb3\x06\xb7\x28\xbb\x06\xb8\x2a\xba\x06\xd7\x29\xb7\x06\x8c\x28\xb1\x06\x08\x2b\xaf\x06\xc4\x29\xc0\x06\x89\x28\xc1\x06\x0e\x2b\xc2\x06\xff\x29\xb3\x06\x8f\x28\xba\x06\xb8\x2a\xbb\x06\xc0\x29\xba\x06\x5e\x28\xbe\x06\xd9\x2a\xbf\x06\xb1\x29\xbe\x06\xad\x28\xc4\x06\x0b\x2b\xc0\x06\xcf\x29\xc2\x06\x91\x28\xcc\x06\xf2\x2a\xc5\x06\xc6\x29\xbf\x06\x76\x28\xc8\x06\xe7\x2a\xc1\x06\xce\x29\xc4\x06\x6d\x28\xb8\x06\xc4\x2a\xb7\x06\xc1\x29\xc7\x06\x7c\x28\xc3\x06\xfa\x2a\xb8\x06\xe6\x29\xbf\x06\xa8\x28\xaf\x06\x94\x2b\xb3\x06\x05\x2a\xc3\x06\xcc\x28\xc4\x06\xfd\x2a\xc1\x06\xa1\x29\xbc\x06\x8d\x28\xb5\x06\x6c\x2b\xb0\x06\xd2\x29\xc0\x06\xa9\x28\xc3\x06\x52\x2b\xbb\x06\xe2\x29\xbd\x06\x91\x28\xc4\x06\x54\x2b\xba\x06\xd8\x29\xbc\x06\x75\x28\xbb\x06\x03\x2b\xbc\x06\x6f\x29\xbb\x06\xa5\x28\xb7\x06\x97\x2a\xae\x06\xa3\x29\xba\x06\x95\x28\xaa\x06\x78\x2a\xa7\x06\x99\x29\xbe\x06\x9d\x28\xba\x06\xc5\x2a\xbc\x06\x4f\x29\xc3\x06\x6c\x28\xb9\x06\x03\x2b\xb4\x06\x99\x29\xb3\x06\xb8\x28\xcd\x06\x0e\x2b\xc2\x06\xac\x29\xcb\x06\x9e\x28\xd0\x06\x41\x2b\xc7\x06\x8b\x29\xbd\x06\x66\x28\xb6\x06\xe1\x2a\xb5\x06\x6c\x29\xc2\x06\x97\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xac\x06\x01\x2b\xa7\x06\x97\x29\xaf\x06\x5d\x28\xcd\x06\xd8\x2a\xc5\x06\xe4\x29\xbf\x06\x7f\x28\xc2\x06\x9c\x2a\xc3\x06\xd7\x29\xc3\x06\x81\x28\xb1\x06\xd0\x2a\xa8\x06\xd6\x29\xb1\x06\x9f\x28\xc5\x06\x08\x2b\xb6\x06\x8e\x29\xc6\x06\xa4\x28\xc5\x06\x0e\x2b\xb4\x06\xb4\x29\xd1\x06\xa1\x28\xb8\x06\x58\x2b\xb7\x06\xef\x2a\xc5\x06\x8e\x28\xcc\x06\x5a\x2b\xc6\x06\xd0\x29\xc8\x06\xbd\x28\xd7\x06\x2b\x2b\xc6\x06\xee\x29\xc4\x06\xcf\x28\xc6\x06\x85\x2b\xc0\x06\xe0\x29\xc2\x06\xe4\x28\xc9\x06\x36\x2b\xc5\x06\x27\x2a\xbb\x06\xe6\x28\xc2\x06\x12\x2b\xc4\x06\xf2\x29\xc0\x06\x68\x28\x99\x06\x5c\x2b\x9c\x06\xfc\x29\xa7\x06\x6b\x28\xc8\x06\xfe\x2a\xbd\x06\xae\x29\xc0\x06\x39\x28\xc5\x06\x31\x2b\xbb\x06\x59\x2a\xb8\x06\x23\x28\xc3\x06\x01\x2b\xae\x06\xb4\x29\xb8\x06\x37\x28\xc0\x06\x3f\x2b\xac\x06\xc0\x29\xc7\x06\x88\x28\xbd\x06\x4c\x2b\xae\x06\xf4\x29\xb2\x06\x4e\x28\xb8\x06\xa7\x2a\xb5\x06\xc2\x29\xbc\x06\x97\x28\xab\x06\xb9\x2a\xad\x06\x9a\x29\xc2\x06\x74\x28\xc0\x06\x7c\x2a\xbb\x06\xb7\x29\xc2\x06\x3a\x28\xab\x06\xb8\x2a\xac\x06\xcd\x29\xb6\x06\x1b\x28\xb4\x06\xfd\x2a\xb1\x06\xc2\x29\xbc\x06\x3b\x28\xa0\x06\x83\x2a\x98\x06\x72\x29\xb4\x06\x1f\x28\xb3\x06\xaa\x2a\xa9\x06\x3d\x29\xbb\x06\xd6\x27\xb4\x06\xd2\x2a\x9c\x06\x86\x29\xb2\x06\xeb\x27\xc3\x06\xcc\x2a\xc1\x06\x4c\x29\xbf\x06\x24\x28\xc0\x06\x71\x2a\xbd\x06\x7e\x29\xc3\x06\x35\x28\x8c\x06\x55\x2b\x88\x06\x24\x2a\x93\x06\x77\x28\xa7\x06\xf5\x2a\x9c\x06\xcc\x29\xba\x06\x31\x28\xbc\x06\xa8\x2a\xab\x06\xa7\x29\xaf\x06\x68\x28\xac\x06\xf1\x2a\xa7\x06\xa2\x29\xb3\x06\x8a\x28\xb8\x06\xac\x2a\xb3\x06\xbb\x29\xb8\x06\x77\x28\x95\x06\xd7\x2a\x95\x06\xd8\x29\xb4\x06\xad\x28\xb7\x06\x06\x2b\x9b\x06\xa2\x29\xac\x06\xb1\x28\xa2\x06\xf6\x2a\x9e\x06\xf1\x29\xb7\x06\x99\x28\xbf\x06\xed\x2a\xb0\x06\x8c\x29\xb5\x06\xbc\x28\xc0\x06\xc1\x2a\xbd\x06\xc9\x29\xb7\x06\xe5\x28\xaf\x06\xde\x2a\xb3\x06\x86\x29\xae\x06\x48\x28\xbb\x06\xae\x2a\xad\x06\x7a\x29\xb3\x06\xac\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xab\x06\xac\x2a\xa1\x06\xc3\x29\xba\x06\xc4\x28\xba\x06\x75\x2a\xb6\x06\x11\x2a\xca\x06\xb7\x28\xc1\x06\x29\x2b\xc2\x06\xec\x29\xb9\x06\xd3\x28\xbc\x06\x0a\x2b\xb7\x06\x81\x29\xbe\x06\xa1\x28\xb3\x06\xa8\x2a\xb7\x06\xc8\x29\xb5\x06\xba\x28\xbc\x06\x71\x2a\xb6\x06\x71\x29\xb6\x06\x5f\x28\xa8\x06\xad\x2a\xb1\x06\xd7\x29\xb7\x06\xa3\x28\xbf\x06\xe0\x2a\xbf\x06\xb9\x29\xc0\x06\xec\x28\xc7\x06\xa8\x2a\xae\x06\x7c\x29\xb3\x06\x5d\x28\xac\x06\x5b\x2a\xae\x06\xb4\x29\xb1\x06\x6e\x28\xa1\x06\x7c\x2a\x99\x06\x9a\x29\xb0\x06\x8f\x28\xc4\x06\xc0\x2a\xbe\x06\xa2\x29\xc2\x06\xae\x28\xa1\x06\x36\x2a\x9a\x06\x62\x29\xa5\x06\x5f\x28\xb2\x06\x56\x2a\xad\x06\x44\x29\xb7\x06\x56\x28\xb0\x06\xbc\x2a\x98\x06\x8d\x29\xb5\x06\xc2\x28\xb3\x06\x8b\x2a\xad\x06\xe9\x29\xb1\x06\xba\x28\xbc\x06\x39\x2a\xab\x06\x95\x29\xb0\x06\x84\x28\xc6\x06\xa4\x2a\xcc\x06\xb3\x29\xc3\x06\x91\x28\xb9\x06\xb4\x2a\xb3\x06\xcf\x29\xbb\x06\x9d\x28\xa9\x06\x9d\x2a\x98\x06\x0a\x2a\xbb\x06\x1a\x28\xbc\x06\x36\x2a\xbb\x06\x9c\x29\xb8\x06\xff\x27\xcd\x06\xc4\x2a\xbe\x06\xbf\x29\xb8\x06\x99\x28\xc6\x06\x0c\x2b\xbf\x06\xd3\x29\xbe\x06\x5e\x28\xb4\x06\x26\x2b\xa7\x06\x89\x29\xc4\x06\x81\x28\xb3\x06\xf9\x2a\xaf\x06\xd0\x29\xba\x06\x8c\x28\xb4\x06\xd9\x2a\xb2\x06\xb2\x29\xbc\x06\x7a\x28\xb5\x06\xe3\x2a\xab\x06\x71\x29\xb7\x06\x79\x28\xb4\x06\x83\x2a\xb9\x06\x45\x29\xaf\x06\x0d\x28\xab\x06\xce\x2a\xa5\x06\xa8\x29\xb7\x06\xb3\x28\xaf\x06\xb6\x2a\x99\x06\xb9\x29\xad\x06\x66\x28\xbf\x06\xe1\x2a\xbe\x06\x99\x29\xb6\x06\x7e\x28\xb7\x06\xfb\x2a\xaf\x06\xba\x29\xb6\x06\x6f\x28\xa8\x06\x18\x2b\xa8\x06\xcf\x29\xb0\x06\x7c\x28\xa4\x06\x47\x2b\xa0\x06\x05\x2a\xbc\x06\x8a\x28\xbc\x06\xf9\x2a\xa9\x06\x79\x29\xc1\x06\x54\x28\xb3\x06\x35\x2b\xae\x06\xbe\x29\xac\x06\x80\x28\xb2\x06\x53\x2b\xad\x06\xa3\x29\xb3\x06\x96\x28\xca\x06\x8e\x2b\xba\x06\xe6\x29\xbb\x06\xba\x28\xb6\x06\xc5\x2b\xa8\x06\xb3\x29\xbc\x06\x91\x28\xab\x06\x0a\x2c\xa1\x06\x04\x2a\xab\x06\xad\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x9a\x06\x84\x2c\x85\x06\xf3\x29\xaa\x06\xa6\x29\xaf\x06\xe3\x2b\x93\x06\x51\x29\xb5\x06\x81\x28\xa2\x06\x73\x2c\x94\x06\xeb\x29\x97\x06\x0f\x29\x9f\x06\x76\x2b\x94\x06\xa4\x29\xa5\x06\xcd\x28\xc7\x06\x81\x2b\xb0\x06\xf0\x29\xb4\x06\xbb\x28\x99\x06\x6d\x2b\x8e\x06\xbc\x29\xbc\x06\xb8\x28\xb5\x06\x7e\x2b\xa8\x06\xb3\x29\xb2\x06\xb7\x28\xaf\x06\x70\x2b\xa6\x06\xf3\x29\xb9\x06\xbc\x28\xc0\x06\x33\x2b\xbd\x06\x58\x29\xb1\x06\xcd\x28\xa6\x06\x2e\x2b\x9a\x06\xb1\x29\xb8\x06\xe6\x28\xae\x06\x02\x2b\xa7\x06\xef\x29\xb2\x06\xd0\x28\xb5\x06\x6a\x2a\xad\x06\xb7\x29\xae\x06\x79\x28\xba\x06\x38\x2b\xb2\x06\x9f\x29\xb4\x06\x92\x27\x00\x00\xb9\x14\x00\x00\x5d\x15\x00\x00\x0a\x16\x00\x00\xb9\x14\x00\x00\x5d\x15\x00\x00\x0b\x16\x00\x00\xb9\x14\x00\x00\x5d\x15\x00\x00\x0d\x16\x00\x00\x99\x14\x00\x00\x4c\x15\x00\x00\xe9\x15\x00\x00\x99\x14\x00\x00\x4c\x15\x00\x00\xe9\x15\x00\x00\x99\x14\x00\x00\x4c\x15\x00\x00\xe9\x15\xca\x06\xd6\x2c\xb2\x06\x2e\x2b\xbd\x06\xdd\x28\xd9\x06\x16\x2c\xcf\x06\x6c\x2b\xc0\x06\x65\x29\xcd\x06\x4b\x2c\xd2\x06\x69\x2b\xc9\x06\x21\x2a\xd4\x06\x80\x2c\xd7\x06\x99\x2b\xd3\x06\x3f\x2a\xc5\x06\x37\x2c\xc4\x06\xe2\x2a\xcb\x06\xa3\x29\xcb\x06\xd1\x2c\xc5\x06\x38\x2b\xcc\x06\x9f\x29\xcc\x06\xb6\x2c\xcb\x06\x79\x2b\xbe\x06\xdb\x29\xce\x06\xe4\x2c\xc0\x06\x4e\x2b\xc1\x06\xff\x29\xcf\x06\x0b\x2d\xd1\x06\x58\x2b\xca\x06\xc5\x29\xdc\x06\x29\x2d\xd8\x06\x86\x2b\xd1\x06\x20\x2a\xd1\x06\x22\x2d\xcb\x06\x1e\x2b\xcd\x06\x06\x2a\xcc\x06\x0b\x2d\xc3\x06\xf9\x2a\xc1\x06\xea\x29\xde\x06\x0b\x2d\xcf\x06\x21\x2b\xce\x06\x18\x2a\xdf\x06\x90\x2d\xc5\x06\x5a\x2b\xc5\x06\x9f\x2a\xd0\x06\x81\x2d\xd2\x06\x45\x2b\xcc\x06\x47\x2a\xd1\x06\x87\x2d\xd0\x06\x46\x2b\xc8\x06\xa6\x2a\xde\x06\x2c\x2d\xd7\x06\xf2\x2b\xce\x06\x1c\x2a\xd1\x06\x03\x2d\xcc\x06\x4c\x2b\xca\x06\xfe\x29\xce\x06\x76\x2c\xc9\x06\x05\x2b\xc7\x06\xa3\x29\xd7\x06\x1e\x2c\xc8\x06\xcc\x2a\xce\x06\x7b\x29\xb8\x06\x29\x2d\xac\x06\x8a\x2b\xce\x06\xe2\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdc\x06\x9e\x2c\xd4\x06\x92\x2b\xcd\x06\xfc\x29\xd3\x06\x31\x2c\xd3\x06\x1c\x2b\xc3\x06\x9c\x29\xd3\x06\xe9\x2b\xce\x06\xf0\x2a\xd1\x06\xfb\x29\xc3\x06\xf4\x2b\xb6\x06\x1d\x2b\xc0\x06\xdb\x29\xcf\x06\xc0\x2b\xcc\x06\xda\x2a\xc3\x06\x9e\x29\xc7\x06\x10\x2b\xcf\x06\xd0\x2a\xc4\x06\x36\x29\xb7\x06\x04\x2c\xb1\x06\xfc\x2a\xc3\x06\x45\x29\xd5\x06\xc8\x2b\xd2\x06\x75\x2b\xbf\x06\xb4\x29\xdb\x06\x06\x2c\xd4\x06\xd4\x2a\xd1\x06\xc1\x29\xd6\x06\xff\x2b\xc3\x06\xec\x2a\xc4\x06\xd4\x29\xd7\x06\x83\x2c\xc7\x06\x59\x2b\xc5\x06\xaa\x29\xc4\x06\xa8\x2b\xcf\x06\x02\x2b\xc9\x06\x59\x29\xbd\x06\x62\x2b\xbd\x06\xbb\x2a\xb1\x06\x13\x29\xbc\x06\x97\x2b\xbe\x06\xc5\x2a\xc0\x06\x55\x29\xc2\x06\xb7\x2b\xcb\x06\x38\x2b\xcd\x06\xc0\x29\xcd\x06\x54\x2b\xcd\x06\xf4\x2a\xd4\x06\xc7\x29\xd4\x06\x7e\x2b\xcd\x06\x32\x2b\xcf\x06\x0a\x2a\xd5\x06\xa5\x2b\xd5\x06\xfe\x2a\xd9\x06\xa7\x29\xca\x06\xad\x2b\xc0\x06\xd4\x2a\xd6\x06\x1c\x2a\xce\x06\x45\x2b\xcc\x06\xc0\x2a\xcf\x06\x13\x29\xd0\x06\x1d\x2c\xd4\x06\x08\x2b\xd0\x06\xb4\x29\xd7\x06\xde\x2b\xd3\x06\x0a\x2b\xd0\x06\x68\x29\xc0\x06\xc1\x2b\xc6\x06\x2a\x2b\xc7\x06\x46\x29\xb5\x06\xc5\x2b\xb1\x06\x05\x2b\xc8\x06\x8f\x29\xcf\x06\x10\x2c\xc0\x06\xd9\x2a\xca\x06\x88\x29\xcb\x06\x82\x2b\xc0\x06\xda\x2a\xc1\x06\x82\x29\xd6\x06\x58\x2b\xd4\x06\x85\x2a\xcd\x06\x12\x29\xc2\x06\x6c\x2b\xc5\x06\x04\x2a\xb7\x06\x94\x28\xcd\x06\x31\x2c\xcc\x06\x02\x2b\xc0\x06\x0e\x29\xbd\x06\xf5\x2b\xbc\x06\xa7\x2a\xd0\x06\x43\x29\xcf\x06\x92\x2b\xcc\x06\x85\x2a\xc0\x06\x81\x29\xd9\x06\x19\x2c\xd0\x06\xc3\x2a\xcd\x06\x4d\x29\xd4\x06\x2f\x2c\xce\x06\xd4\x2a\xcd\x06\x8c\x29\xcd\x06\xd6\x2b\xc9\x06\xee\x2a\xc9\x06\x67\x29\xca\x06\x74\x2b\xc9\x06\x90\x2a\xbd\x06\xd2\x28\xc3\x06\x99\x2b\xbc\x06\xed\x2a\xc6\x06\x61\x29\xcd\x06\xcd\x2b\xc2\x06\xd0\x2a\xaf\x06\x3a\x29\xc9\x06\xbe\x2b\xc6\x06\xbb\x2a\xd3\x06\x00\x2a\xdd\x06\x19\x2c\xd2\x06\xd8\x2a\xd5\x06\x9b\x29\xd5\x06\x80\x2b\xcb\x06\xec\x2a\xc6\x06\x7e\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd0\x06\x7c\x2b\xc6\x06\xea\x2a\xc9\x06\x54\x29\xbd\x06\x15\x2b\xba\x06\x37\x2a\xbf\x06\xec\x28\xcc\x06\xc9\x2a\xcd\x06\x5c\x2a\xcc\x06\x0b\x29\xbb\x06\x47\x2b\xbe\x06\x04\x2b\xd2\x06\x75\x29\xc8\x06\x1d\x2c\xb7\x06\xfa\x2a\xcc\x06\x56\x29\xca\x06\xa5\x2b\xce\x06\x9c\x2a\xc0\x06\x3a\x29\xcf\x06\xc9\x2b\xbf\x06\x94\x2a\xc6\x06\x41\x29\xdb\x06\x9b\x2b\xcc\x06\xf1\x2a\xc4\x06\x27\x29\xbb\x06\x26\x2b\xbc\x06\xc8\x2a\xb8\x06\xc8\x28\xbc\x06\x6b\x2b\xc3\x06\x7b\x2a\xc7\x06\x08\x29\xdc\x06\x90\x2b\xd0\x06\xac\x2a\xd0\x06\x42\x29\xcd\x06\xb7\x2b\xc3\x06\xfd\x2a\xc3\x06\x86\x29\xd2\x06\x09\x2c\xc8\x06\xf5\x2a\xcb\x06\x03\x2a\xd7\x06\xeb\x2b\xd4\x06\xe2\x2a\xc9\x06\x7b\x29\xc5\x06\x28\x2c\xc7\x06\xe5\x2a\xbe\x06\xb8\x29\xcf\x06\xa9\x2b\xca\x06\x49\x2a\xca\x06\x13\x29\xcd\x06\x48\x2b\xca\x06\x80\x2a\xc8\x06\x0e\x29\xd1\x06\xeb\x2b\xc0\x06\x19\x2b\xc7\x06\x56\x29\xcb\x06\x06\x2c\xc0\x06\xc5\x2a\xc8\x06\xd9\x29\xd6\x06\x1d\x2c\xcd\x06\xb3\x2a\xd8\x06\xd3\x29\xdd\x06\xc7\x2b\xcf\x06\x2c\x2b\xdb\x06\x0e\x2a\xd2\x06\x12\x2c\xcf\x06\xc7\x2a\xd3\x06\x08\x2a\xc7\x06\x31\x2c\xbc\x06\xf5\x2a\xce\x06\x77\x29\xd6\x06\x43\x2c\xd8\x06\xb8\x2a\xd1\x06\xa0\x29\xd5\x06\x50\x2c\xd6\x06\x08\x2b\xc0\x06\xcb\x29\xd1\x06\xfd\x2b\xca\x06\xcb\x2a\xd0\x06\x8a\x29\xd4\x06\xb3\x2b\xd5\x06\x3a\x2b\xcf\x06\x73\x29\xdc\x06\x04\x2c\xda\x06\xde\x2a\xd2\x06\xad\x29\xd3\x06\xcd\x2b\xcc\x06\xcd\x2a\xd3\x06\xd3\x29\xd6\x06\x5a\x2b\xcf\x06\x91\x2a\xcc\x06\x94\x29\xc5\x06\x24\x2b\xc4\x06\x67\x2a\xca\x06\x9e\x29\xde\x06\xec\x2b\xd6\x06\x65\x2a\xd0\x06\x5b\x29\xda\x06\x19\x2c\xd1\x06\xa5\x2a\xcf\x06\x8f\x29\xd6\x06\x1d\x2c\xcd\x06\x74\x2a\xd5\x06\x6c\x29\xd9\x06\x06\x2c\xcd\x06\x5c\x2a\xd1\x06\x9a\x29\xc8\x06\x18\x2c\xc9\x06\x49\x2b\xc3\x06\xab\x29\xd0\x06\xa8\x2b\xc9\x06\xc0\x2a\xcd\x06\x86\x29\xd3\x06\x0b\x2b\xd4\x06\x5d\x2a\xd0\x06\x21\x29\xc6\x06\x5c\x2b\xc5\x06\x77\x2a\xc8\x06\x46\x29\xd5\x06\xbe\x2b\xc8\x06\x25\x2b\xc7\x06\x56\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xca\x06\xb8\x2b\xcb\x06\xed\x2a\xcc\x06\x6f\x29\xdc\x06\xa0\x2b\xd0\x06\x77\x2a\xcf\x06\x20\x2a\xd4\x06\x66\x2b\xc5\x06\x5b\x2a\xcb\x06\x34\x29\xd1\x06\xfa\x2b\xcc\x06\x3f\x2a\xc5\x06\xf8\x28\xcb\x06\x79\x2b\xc9\x06\xc8\x29\xcc\x06\xf7\x28\xc5\x06\xcf\x2a\xc6\x06\xb6\x29\xba\x06\xf0\x28\xd1\x06\x92\x2b\xc3\x06\x79\x2a\xc4\x06\x1d\x29\xd4\x06\x82\x2b\xd6\x06\x91\x2a\xc5\x06\x61\x29\xd9\x06\x9c\x2b\xd5\x06\xd0\x2a\xd6\x06\xa7\x29\xdc\x06\xd9\x2b\xd0\x06\x9c\x2a\xd1\x06\x63\x29\xc2\x06\x93\x2b\xbd\x06\x6c\x2a\xcb\x06\x3c\x29\xcc\x06\x1f\x2b\xbf\x06\x0b\x2a\xc3\x06\xe6\x28\xc3\x06\xe8\x2a\xcf\x06\x68\x2a\xcd\x06\xec\x28\xc3\x06\x8a\x2b\xc0\x06\x41\x2a\xc5\x06\x5d\x29\xcb\x06\xc4\x2b\xc3\x06\x79\x2a\xc8\x06\x55\x29\xd2\x06\x1d\x2b\xcf\x06\x9d\x2a\xcf\x06\x7a\x29\xe0\x06\x04\x2b\xda\x06\xcc\x2a\xdb\x06\x3e\x29\xd4\x06\x48\x2b\xd3\x06\xb5\x2a\xcd\x06\x61\x29\xd0\x06\xd5\x2a\xce\x06\x35\x2a\xcd\x06\xf2\x28\xd6\x06\x28\x2b\xd4\x06\x1d\x2a\xd2\x06\xae\x28\xd2\x06\x8d\x2b\xde\x06\x2e\x2b\xd4\x06\x65\x29\xcb\x06\x6a\x2b\xca\x06\xbc\x2a\xd8\x06\x85\x29\xd1\x06\xac\x2b\xcd\x06\x1e\x2b\xc2\x06\x9c\x29\xd7\x06\xce\x2b\xc8\x06\x81\x2a\xd0\x06\xd6\x29\xcf\x06\x65\x2b\xcd\x06\xdc\x2a\xd0\x06\x5d\x29\xce\x06\x10\x2b\xc6\x06\xb8\x2a\xc1\x06\xd2\x28\xb6\x06\x8e\x2a\xbc\x06\x03\x2a\xbd\x06\xad\x28\xcd\x06\x61\x2b\xbd\x06\xa3\x2a\xc6\x06\xe6\x28\xd1\x06\x84\x2b\xcd\x06\x15\x2b\xce\x06\x2f\x29\xb6\x06\x81\x2b\xac\x06\x87\x2a\xc5\x06\x6f\x29\xcc\x06\x61\x2b\xce\x06\x10\x2b\xcb\x06\x38\x29\xc6\x06\x48\x2b\xc6\x06\x7f\x2a\xc3\x06\x8a\x29\xd2\x06\x2f\x2b\xce\x06\x23\x2a\xc5\x06\x49\x29\xca\x06\x8a\x2b\xbd\x06\xbe\x29\xbb\x06\xb9\x28\xd1\x06\xc1\x2b\xcc\x06\xef\x29\xd0\x06\xd6\x28\xd2\x06\x1d\x2c\xcb\x06\x4c\x2a\xcb\x06\x67\x29\xcb\x06\xd0\x2b\xbc\x06\xf0\x29\xca\x06\xdd\x28\xce\x06\x1f\x2b\xc3\x06\xc6\x29\xc0\x06\xaa\x28\xd3\x06\x93\x2b\xca\x06\xde\x29\xcc\x06\x0f\x29\xc6\x06\xcf\x2a\xb8\x06\xa3\x29\xcb\x06\x86\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc9\x06\x61\x2a\xca\x06\x68\x29\xc5\x06\x11\x28\xd3\x06\x98\x2a\xce\x06\x77\x29\xce\x06\x5d\x28\xe0\x06\xaa\x2b\xcd\x06\x08\x2a\xc7\x06\x02\x29\xd0\x06\x77\x2b\xc6\x06\x24\x2a\xcf\x06\x16\x29\xca\x06\xac\x2b\xc0\x06\x5f\x2a\xc9\x06\x11\x29\xec\x06\xce\x2b\xd3\x06\x35\x2a\xd0\x06\xc1\x29\xd8\x06\xdb\x2b\xc2\x06\x2b\x2a\xc9\x06\x31\x29\xd2\x06\x62\x2b\xd3\x06\xc7\x29\xd8\x06\xd2\x28\xda\x06\x1f\x2b\xdf\x06\x23\x2a\xcd\x06\x06\x29\xc9\x06\x9b\x2b\xc7\x06\x8f\x2a\xbb\x06\x07\x29\xdc\x06\x2e\x2c\xd8\x06\x85\x2a\xe1\x06\x7b\x29\xdd\x06\xbe\x2c\xd4\x06\x77\x2a\xd1\x06\x31\x29\xde\x06\x42\x2c\xd5\x06\x33\x2a\xcc\x06\x3c\x29\xd7\x06\x1e\x2c\xce\x06\x54\x2a\xc7\x06\x4e\x29\xc1\x06\x12\x2b\xbe\x06\x28\x2a\xd6\x06\xa7\x28\xbf\x06\xc5\x2a\xbc\x06\x03\x2a\xb3\x06\xa2\x28\xd2\x06\x0d\x2b\xcb\x06\x9f\x2a\xc8\x06\x15\x29\xcc\x06\xb4\x2a\xcd\x06\x9d\x2a\xca\x06\x81\x29\xd0\x06\xfe\x2a\xcd\x06\x5d\x2a\xca\x06\x0c\x29\xd5\x06\x8e\x2b\xcd\x06\x5c\x2a\xc2\x06\xe1\x28\xde\x06\x85\x2b\xd1\x06\x50\x2a\xce\x06\x36\x29\xbe\x06\x6e\x2b\xb2\x06\x3c\x2a\xbb\x06\x16\x29\xcb\x06\xc8\x2a\xcb\x06\xba\x29\xd3\x06\x94\x28\xce\x06\x42\x2b\xc0\x06\x15\x2a\xcb\x06\xfd\x28\xd5\x06\x58\x2b\xd2\x06\x87\x2a\xd9\x06\x34\x29\xcb\x06\x76\x2b\xb8\x06\x6f\x2a\xcd\x06\x85\x29\xdc\x06\xb3\x2a\xd9\x06\x60\x2a\xce\x06\x0f\x29\xcf\x06\x77\x2a\xcb\x06\x3e\x2a\xca\x06\x0b\x29\xdc\x06\xe1\x2a\xde\x06\x0c\x2a\xd2\x06\xee\x28\xc8\x06\x1c\x2a\xca\x06\xa9\x29\xc9\x06\x45\x28\xc8\x06\xc8\x2a\xcc\x06\x08\x2a\xc6\x06\xd4\x28\xd6\x06\xbd\x2b\xcb\x06\x3e\x2a\xd2\x06\xfb\x28\xc7\x06\xf7\x2a\xd1\x06\x73\x2a\xc5\x06\x88\x28\xce\x06\x4a\x2b\xca\x06\x49\x2a\xc0\x06\xa7\x28\xdb\x06\xfe\x2a\xd3\x06\x5c\x2a\xcd\x06\xbe\x28\xd1\x06\xa9\x2a\xcf\x06\x83\x2a\xd2\x06\xe6\x28\xca\x06\xa4\x2a\xc6\x06\xe8\x29\xd8\x06\x4b\x28\xcb\x06\xd0\x2a\xd0\x06\x29\x2a\xd0\x06\x7e\x28\xc7\x06\xb8\x2a\xc4\x06\x9b\x2a\xce\x06\x4a\x29\xbd\x06\xd4\x2a\xbf\x06\x85\x2a\xbe\x06\x98\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd8\x06\xd1\x2a\xd1\x06\xab\x2a\xcf\x06\x22\x29\xd2\x06\xd4\x2a\xd7\x06\x8e\x2a\xe2\x06\x06\x29\xd2\x06\x71\x2a\xd5\x06\x7f\x2a\xd7\x06\xf5\x28\xdc\x06\xb3\x2a\xd7\x06\x2e\x2a\xd2\x06\xf8\x28\xd3\x06\x8d\x2a\xd6\x06\x24\x2a\xc7\x06\x74\x28\xcf\x06\xf0\x2a\xd0\x06\x8f\x2a\xc8\x06\x37\x29\xce\x06\xef\x2a\xc4\x06\x95\x2a\xcb\x06\xde\x28\xb5\x06\xef\x2a\xb4\x06\x86\x2a\xd0\x06\xf5\x28\xc6\x06\xdf\x2a\xca\x06\x70\x2a\xc8\x06\x49\x29\xbb\x06\xcf\x2a\xc9\x06\x5d\x2a\xd1\x06\x04\x29\xd4\x06\xe0\x2a\xc8\x06\x58\x2a\xd4\x06\xd7\x28\xda\x06\x6c\x2a\xcc\x06\xa7\x29\xcf\x06\x61\x28\xc4\x06\x36\x2b\xbb\x06\x24\x2a\xc3\x06\xad\x28\xcf\x06\x84\x2b\xd2\x06\x52\x2a\xd6\x06\x55\x29\xca\x06\xdf\x2b\xb2\x06\x00\x2a\xc8\x06\x21\x29\xd1\x06\x21\x2c\xca\x06\x11\x2a\xd2\x06\x45\x29\xcc\x06\x39\x2c\xc2\x06\xe0\x29\xcc\x06\x7b\x29\xde\x06\x42\x2b\xe5\x06\x40\x2a\xd5\x06\xe9\x28\xce\x06\x92\x2a\xd1\x06\x27\x2a\xd4\x06\x76\x28\xd9\x06\x55\x2b\xdd\x06\x2d\x2a\xd1\x06\xba\x28\xca\x06\xfd\x2a\xcf\x06\x7a\x2a\xd7\x06\x1e\x29\xda\x06\x03\x2b\xcd\x06\x32\x2a\xc9\x06\x11\x29\xda\x06\x06\x2b\xd9\x06\x23\x2a\xcd\x06\x0a\x29\xd2\x06\xb7\x2a\xd5\x06\x52\x2a\xc7\x06\xa9\x28\xd7\x06\xa9\x2a\xcf\x06\xf9\x29\xd1\x06\xb1\x28\xd6\x06\x3d\x2a\xcd\x06\x89\x29\xc9\x06\x55\x28\xe0\x06\x88\x2a\xdc\x06\xff\x29\xd5\x06\x6b\x28\xd8\x06\xf5\x2a\xd9\x06\x3e\x2a\xd0\x06\xd7\x28\xce\x06\xb6\x2a\xda\x06\x70\x2a\xd1\x06\xc1\x28\xcd\x06\xe9\x2a\xca\x06\x20\x2a\xcd\x06\xaa\x28\xd3\x06\x3e\x2b\xd8\x06\x54\x2a\xd3\x06\x2f\x29\xdc\x06\x0d\x2b\xdd\x06\x79\x2a\xd8\x06\x24\x29\xeb\x06\xc2\x2a\xe1\x06\x48\x2a\xd7\x06\xb3\x28\xd1\x06\xdf\x2a\xd4\x06\x59\x2a\xd1\x06\xea\x28\xd9\x06\x79\x2b\xd6\x06\xaf\x2a\xc9\x06\x21\x29\xd2\x06\x1e\x2b\xcb\x06\x9c\x2a\xda\x06\x00\x29\xdf\x06\x44\x2b\xcf\x06\xa0\x2a\xda\x06\xe8\x28\xd3\x06\x46\x2b\xcd\x06\x5b\x2a\xcc\x06\x8d\x28\xd9\x06\xfd\x2a\xd7\x06\x5b\x2a\xcc\x06\xbe\x28\xca\x06\xee\x2a\xb9\x06\xc3\x29\xce\x06\x7d\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xaf\x06\xe8\x2a\xa4\x06\x9e\x2a\xce\x06\x6f\x28\xd0\x06\xff\x2a\xcc\x06\x87\x2a\xc4\x06\xb8\x28\xd2\x06\x31\x2b\xcb\x06\xab\x2a\xd2\x06\xe9\x28\xd1\x06\xc4\x2a\xd1\x06\x63\x2a\xd1\x06\xcf\x28\xce\x06\x0d\x2b\xce\x06\x32\x2a\xca\x06\xc3\x28\xca\x06\x5b\x2b\xcd\x06\x1a\x2a\xbe\x06\xd0\x28\xcb\x06\xa0\x2a\xc4\x06\xd5\x29\xc0\x06\x4b\x28\xcd\x06\x99\x2a\xc2\x06\xc9\x29\xb9\x06\x1e\x28\xcd\x06\xea\x2a\xc4\x06\x5f\x2a\xd0\x06\xe8\x28\xd7\x06\x03\x2b\xd2\x06\x5b\x2a\xcb\x06\x97\x28\xc6\x06\x8a\x2a\xc0\x06\x40\x2a\xbf\x06\xa4\x28\xc5\x06\xec\x2a\xc0\x06\x62\x2a\xc9\x06\xaf\x28\xcf\x06\x9c\x2a\xc7\x06\x5b\x2a\xcc\x06\xbe\x28\xd0\x06\x84\x2a\xc3\x06\xff\x29\xbd\x06\x49\x28\xb2\x06\x69\x2a\xa8\x06\xe3\x29\xc8\x06\x03\x28\xcd\x06\x9e\x2a\xc4\x06\xb8\x29\xbe\x06\x7b\x28\xc1\x06\xc2\x2a\xc6\x06\x2e\x2a\xc9\x06\x51\x28\xc6\x06\x95\x2a\xc2\x06\x0b\x2a\xc4\x06\x94\x28\xd7\x06\x93\x2a\xd0\x06\x0a\x2a\xc9\x06\x4d\x28\xc4\x06\x80\x2a\xbc\x06\xe3\x29\xb9\x06\x8a\x28\xcf\x06\x5c\x2a\xc0\x06\xb7\x29\xcb\x06\x35\x28\xc4\x06\xbf\x29\xcd\x06\x74\x29\xca\x06\xf4\x27\xc8\x06\x38\x2a\xc9\x06\x2a\x2a\xc1\x06\x0f\x28\xd6\x06\xbd\x2a\xce\x06\xfc\x29\xd5\x06\xab\x28\xcf\x06\xae\x2a\xc0\x06\xb1\x29\xc3\x06\x35\x28\xcf\x06\xd9\x2a\xbd\x06\xd7\x29\xd6\x06\x7f\x28\xc1\x06\x77\x2a\xc6\x06\x24\x2a\xcb\x06\x63\x28\xca\x06\x0b\x2a\xc9\x06\xb5\x29\xbf\x06\x1d\x28\x9e\x06\xf2\x29\x94\x06\x70\x29\xbf\x06\xb9\x27\xc6\x06\xfe\x29\xc1\x06\x91\x29\xcd\x06\xf4\x27\xc0\x06\x9f\x2a\xc0\x06\x28\x2a\xbe\x06\x24\x28\xd0\x06\x73\x2a\xc5\x06\xf4\x29\xb8\x06\x2b\x28\xcf\x06\x58\x2a\xcf\x06\xc9\x29\xc3\x06\x7d\x28\xc6\x06\x58\x2a\xc0\x06\xab\x29\xc3\x06\x16\x28\xcf\x06\x4a\x2a\xc4\x06\x5b\x29\xc7\x06\x24\x28\x9f\x06\xbb\x29\x98\x06\x1d\x29\xc9\x06\xaa\x27\xac\x06\x98\x29\xae\x06\x09\x29\xc1\x06\xa3\x27\xbd\x06\x30\x2a\xb3\x06\xbb\x29\xcd\x06\x33\x28\xd8\x06\x67\x2a\xd3\x06\xc4\x29\xcb\x06\x2b\x28\xcc\x06\xfd\x29\xc4\x06\xb9\x29\xc9\x06\x5c\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xae\x06\x46\x2a\xa6\x06\xc9\x29\xb7\x06\x6f\x28\xc9\x06\x60\x2a\xcd\x06\x2c\x2a\xc9\x06\x28\x28\xc5\x06\xc1\x29\xc0\x06\x73\x29\xb8\x06\xae\x27\xc2\x06\xad\x29\xbc\x06\x27\x29\xc5\x06\xc7\x27\xc6\x06\xfe\x29\xc5\x06\xd5\x29\xb6\x06\x24\x28\xc4\x06\x41\x2a\xbe\x06\xc4\x29\xbb\x06\x35\x28\xc5\x06\x34\x2a\xc0\x06\x8c\x29\xc2\x06\x29\x28\xb0\x06\xba\x2a\x9b\x06\xc7\x29\xcd\x06\x33\x28\xd2\x06\xad\x2a\xcf\x06\x04\x2a\xc5\x06\x2d\x28\xcb\x06\x2a\x2a\xc6\x06\x5f\x29\xbc\x06\xe1\x27\xd6\x06\xc9\x29\xcf\x06\x89\x29\xcb\x06\xcc\x27\xbd\x06\x76\x2a\xb9\x06\xd4\x29\xb8\x06\x7c\x28\xd6\x06\x37\x2a\xca\x06\xc4\x29\xd0\x06\x5c\x28\xc8\x06\x61\x2a\xc8\x06\xcb\x29\xc3\x06\x74\x28\xd1\x06\x50\x2a\xcd\x06\x0c\x2a\xcb\x06\x7b\x28\xcb\x06\x53\x2a\xce\x06\x4c\x2a\xd6\x06\x67\x28\xcb\x06\x5a\x2a\xd3\x06\xec\x29\xc2\x06\x7c\x28\xc9\x06\xea\x29\xcf\x06\x75\x29\xd3\x06\x2b\x28\xc6\x06\x30\x2a\xc2\x06\x10\x2a\xbc\x06\xde\x28\xcc\x06\xd1\x2a\xd1\x06\x6f\x2a\xd1\x06\xeb\x28\xc8\x06\x65\x2a\xc8\x06\x60\x2a\xbc\x06\xbf\x28\xc0\x06\x54\x2a\xb3\x06\xf5\x29\xc3\x06\xc2\x28\xcf\x06\x96\x2a\xc7\x06\xa9\x29\xcc\x06\xbb\x28\xcc\x06\x36\x2a\xce\x06\xc7\x29\xc6\x06\xa1\x28\xc4\x06\x2d\x2a\xc4\x06\x1d\x29\xc3\x06\x1c\x28\xcc\x06\x3c\x2a\xbc\x06\x35\x29\xc5\x06\x76\x28\xc2\x06\x8f\x2a\xc3\x06\xd7\x29\xb7\x06\x83\x28\xd2\x06\xa8\x2a\xce\x06\x02\x2a\xd0\x06\xa6\x28\xcf\x06\x8e\x2a\xd7\x06\xe3\x29\xc9\x06\x77\x28\xc6\x06\x83\x2a\xc6\x06\x16\x2a\xbf\x06\x85\x28\xcc\x06\x81\x2a\xca\x06\x9b\x29\xdc\x06\xb3\x28\xcb\x06\x40\x2a\xc0\x06\x87\x29\xcf\x06\x6b\x28\xc9\x06\x81\x2a\xbb\x06\xb3\x29\xc1\x06\x2e\x28\xc3\x06\x22\x2b\xc0\x06\xd9\x29\xc7\x06\xed\x28\xd3\x06\xf1\x2a\xc9\x06\xf1\x29\xc7\x06\x09\x29\xb1\x06\xd4\x2a\xb9\x06\x1c\x2a\xc7\x06\xab\x28\xd4\x06\xd4\x2a\xc8\x06\x0c\x2a\xc5\x06\xcd\x28\xd4\x06\xd4\x2a\xc6\x06\x08\x2a\xc6\x06\x0e\x29\xc9\x06\x03\x2b\xbc\x06\xe5\x29\xfc\x06\xb5\x28\xce\x06\x34\x2b\xd0\x06\xfb\x29\xcc\x06\x53\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdc\x06\x2a\x2b\xce\x06\x44\x2a\xd4\x06\x27\x29\xab\x06\x31\x2b\xb0\x06\x84\x2a\xc9\x06\xc4\x28\xd1\x06\xd2\x2a\xd1\x06\x77\x2a\xd2\x06\x05\x29\xc8\x06\x27\x2b\xd3\x06\x37\x2a\xce\x06\xd4\x28\xd1\x06\x3f\x2b\xc9\x06\x9b\x2a\xdd\x06\x17\x29\xd1\x06\xf5\x2a\xd6\x06\xb6\x2a\xc2\x06\xea\x28\xcd\x06\xf5\x2a\xc0\x06\x3c\x2a\xc9\x06\xc9\x28\xc9\x06\x24\x2b\xc7\x06\xea\x2a\xce\x06\x15\x29\xd5\x06\x44\x2b\xcf\x06\xa7\x2a\xd5\x06\x65\x29\xcb\x06\x4b\x2b\xd4\x06\x88\x2a\xce\x06\x7d\x29\xd8\x06\x68\x2b\xca\x06\x7b\x2a\xd8\x06\x6c\x29\xc2\x06\x57\x2b\xd2\x06\xa7\x2a\xc6\x06\x3d\x29\xce\x06\x17\x2b\xd1\x06\x8b\x2a\xc5\x06\xec\x28\xcf\x06\x35\x2b\xc7\x06\x24\x2a\xca\x06\x0a\x29\xd3\x06\x4f\x2b\xc3\x06\x88\x2a\xca\x06\xaf\x29\xca\x06\xbb\x2b\xcd\x06\xb4\x2a\xc1\x06\x91\x29\xd6\x06\x92\x2b\xcc\x06\x96\x2a\xd1\x06\x63\x29\xc5\x06\x8b\x2b\xd1\x06\xab\x2a\xc9\x06\x7a\x29\xd1\x06\xce\x2b\xd2\x06\x77\x2a\xcd\x06\x69\x29\xdf\x06\x7c\x2b\xd3\x06\xb2\x2a\xd3\x06\x9b\x29\xda\x06\xb8\x2b\xcc\x06\x56\x2a\xda\x06\x80\x29\xd1\x06\xe4\x2b\xc1\x06\x5a\x2a\xd3\x06\x93\x29\xd6\x06\x9d\x2b\xc9\x06\xd3\x2a\xc0\x06\x98\x29\xc6\x06\xd7\x2b\xbb\x06\xca\x2a\xc7\x06\xbe\x29\xde\x06\xca\x2b\xd9\x06\x4c\x2a\xd4\x06\x86\x29\xe0\x06\x08\x2c\xd4\x06\x83\x2a\xcb\x06\x94\x29\xdc\x06\xe0\x2b\xe1\x06\xb2\x2a\xd8\x06\x6f\x29\xf2\x06\x8e\x2b\xe7\x06\x47\x2a\xeb\x06\x38\x29\x07\x07\x80\x2b\xfa\x06\x08\x2a\xfe\x06\x0d\x29\xe4\x06\x08\x2b\xe4\x06\xf5\x29\xee\x06\xf9\x28\x92\x06\x58\x2a\x96\x06\x7f\x29\x94\x06\x32\x28\x58\x06\x8f\x2a\x4e\x06\x4c\x29\x4b\x06\xe1\x26\x2e\x06\x90\x2a\x2c\x06\xa8\x28\x37\x06\xb6\x26\x81\x06\x00\x2a\x7b\x06\xe0\x28\x78\x06\xff\x27\xd8\x06\xfa\x2a\xc4\x06\x6c\x29\xe7\x06\xb2\x28\xe1\x06\x46\x2b\xe7\x06\xcb\x29\xec\x06\x7d\x29\xe1\x06\xc2\x2b\xdf\x06\x67\x2a\xe7\x06\x1f\x2a\xe0\x06\x14\x2c\xd6\x06\x9c\x2a\xd2\x06\xd7\x29\xd7\x06\x87\x2b\xc9\x06\x28\x2a\xd8\x06\x72\x29\xc3\x06\x81\x2b\xc7\x06\x1c\x2a\xb6\x06\x37\x29\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd1\x06\x8f\x2b\xc1\x06\xd0\x29\xbf\x06\x4f\x29\xc5\x06\x44\x2b\xc4\x06\x27\x2a\xc6\x06\x37\x29\xc7\x06\x92\x2b\xb0\x06\xbb\x29\xd0\x06\x80\x29\xc1\x06\x6f\x2b\xc1\x06\x50\x2a\xc2\x06\x47\x29\xcd\x06\x06\x2c\xc6\x06\x3e\x2a\xc2\x06\x76\x29\xc4\x06\x9d\x2b\xb1\x06\x06\x2a\xd4\x06\x91\x29\xc9\x06\x30\x2b\xbb\x06\xf8\x29\xc3\x06\x4e\x29\xc8\x06\x10\x2b\xca\x06\x23\x2a\xbd\x06\x14\x29\xc8\x06\x36\x2b\xb7\x06\x10\x2a\xcb\x06\x46\x29\xc4\x06\x02\x2b\xba\x06\xe7\x29\xbe\x06\x44\x29\xcb\x06\xfb\x2a\xc7\x06\x20\x2a\xd0\x06\xae\x29\xce\x06\x70\x2b\xcd\x06\x06\x2a\xd5\x06\x57\x29\xd3\x06\xbc\x2a\xc6\x06\xe7\x29\xcd\x06\x28\x29\xae\x06\x96\x2a\xaf\x06\xec\x29\xca\x06\x06\x29\xc0\x06\xa3\x2a\xcb\x06\xcb\x29\xd1\x06\xe2\x28\xb5\x06\xd6\x2a\xb9\x06\x10\x2a\xb7\x06\x14\x29\xca\x06\xe5\x2a\xbb\x06\xa1\x29\xc8\x06\x15\x29\xc1\x06\xee\x2a\xbd\x06\xe0\x29\xc1\x06\x0c\x29\xbc\x06\xf7\x2a\xa9\x06\x2c\x2a\xba\x06\x0a\x29\xbc\x06\x91\x2a\xbd\x06\xd4\x29\xc2\x06\x08\x29\xb6\x06\x7e\x2a\xb6\x06\x95\x29\xbc\x06\xd3\x28\xb8\x06\x82\x2a\xbd\x06\x94\x29\xc2\x06\xb8\x28\xbb\x06\x4f\x2a\xba\x06\xa4\x29\xcb\x06\xab\x28\xcc\x06\x79\x2a\xcb\x06\xa8\x29\xcd\x06\xd6\x28\xab\x06\x7b\x2a\xaa\x06\x78\x29\xcb\x06\xed\x28\xc1\x06\xf1\x2a\xba\x06\x2b\x2a\xc2\x06\x18\x29\xb6\x06\x1e\x2b\xba\x06\x5a\x2a\xbf\x06\x46\x29\xc7\x06\x6f\x2a\xb5\x06\x8d\x29\xc0\x06\xb5\x28\xba\x06\x5b\x2a\xb8\x06\x5b\x29\xc0\x06\x98\x28\xc3\x06\x30\x2a\xbc\x06\x50\x29\xbf\x06\x7d\x28\xb4\x06\xb9\x29\xae\x06\x38\x29\xaf\x06\x30\x28\xa5\x06\x0a\x2a\xa3\x06\x22\x29\xbe\x06\x8f\x28\xc2\x06\x33\x2a\xb8\x06\xba\x28\xbf\x06\x7c\x28\xad\x06\x0e\x2a\xb6\x06\xea\x28\xb0\x06\x31\x28\xc3\x06\xb9\x29\xca\x06\xf1\x28\xbd\x06\x4b\x28\xce\x06\xc7\x29\xcd\x06\x04\x29\xc5\x06\x30\x28\xc7\x06\x7c\x29\xd1\x06\x09\x29\xcc\x06\x2e\x28\xcb\x06\x14\x2a\xbf\x06\x22\x29\xcf\x06\x1a\x28\xc9\x06\xd8\x29\xc3\x06\x2b\x29\xc8\x06\x35\x28\xd1\x06\x1a\x2a\xcc\x06\x0c\x29\xcb\x06\x62\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\x06\x45\x2a\xbd\x06\x35\x29\xbe\x06\x78\x28\xbd\x06\x16\x2a\xb5\x06\x18\x29\xc1\x06\x3c\x28\xbb\x06\xfa\x29\xb3\x06\xd5\x28\xb1\x06\x29\x28\xc6\x06\xcc\x29\xb5\x06\xe2\x28\xc8\x06\x2c\x28\xbb\x06\xe2\x29\xbb\x06\x18\x29\xc0\x06\xef\x27\xb2\x06\x03\x2a\xa2\x06\x18\x29\xc8\x06\x48\x28\xb6\x06\x14\x2a\xbd\x06\x10\x29\xb4\x06\x69\x28\xc0\x06\x4f\x2a\xb4\x06\x45\x29\xc7\x06\x88\x28\xba\x06\x52\x2a\xb9\x06\x1c\x29\xc1\x06\x6b\x28\xc5\x06\xce\x29\xbd\x06\x34\x29\xd4\x06\x70\x28\xae\x06\x03\x2a\xb3\x06\x40\x29\xd1\x06\x70\x28\xad\x06\x86\x29\xbb\x06\x4d\x29\xb7\x06\x15\x28\xbb\x06\xf2\x29\xc3\x06\x2d\x29\xd5\x06\x48\x28\xc3\x06\x3e\x2a\xc5\x06\x34\x29\xba\x06\x79\x28\xad\x06\x47\x2a\xaa\x06\x75\x29\xb0\x06\x68\x28\xb3\x06\x3e\x2a\xb7\x06\x5f\x29\xbd\x06\x7c\x28\xaf\x06\x22\x2a\xac\x06\x5c\x29\xb3\x06\x2e\x28\xc8\x06\xea\x29\xc3\x06\x30\x29\xba\x06\x31\x28\xbb\x06\xa7\x29\xc2\x06\xd8\x28\xc9\x06\xf2\x27\xba\x06\xb0\x29\xb7\x06\x1c\x29\xc1\x06\xce\x27\xb7\x06\xa7\x29\xb2\x06\xe0\x28\xbc\x06\xf9\x27\xc6\x06\x03\x2a\xbb\x06\xe4\x28\xb5\x06\xf9\x27\xb3\x06\x1a\x2a\xaa\x06\x01\x29\xb7\x06\x04\x28\xbb\x06\xad\x29\xb6\x06\xe8\x28\xbb\x06\x14\x28\xc4\x06\x91\x29\xcb\x06\xb6\x28\xb5\x06\xdd\x27\xa0\x06\xdc\x29\xa2\x06\x18\x29\xb3\x06\xe2\x27\xc9\x06\xf8\x29\xbe\x06\xd6\x28\xbc\x06\xd9\x27\xbe\x06\x9c\x29\xba\x06\xd4\x28\xb4\x06\xfd\x27\xab\x06\xea\x29\xa3\x06\xf2\x28\xb9\x06\x51\x28\xad\x06\xba\x29\xb8\x06\x34\x29\xb3\x06\x29\x28\xaa\x06\xdd\x29\xaa\x06\x30\x29\xaa\x06\x45\x28\xb1\x06\x8a\x29\xab\x06\xf5\x28\xc5\x06\x31\x28\xc4\x06\xad\x29\xc1\x06\x21\x29\xba\x06\x13\x28\xbe\x06\x9e\x29\xc0\x06\x14\x29\xbf\x06\xfa\x27\xb5\x06\xf3\x29\xbb\x06\x15\x29\xb4\x06\x55\x28\xd1\x06\xfc\x29\xc6\x06\x30\x29\xcd\x06\x4b\x28\xb6\x06\x16\x2a\xb8\x06\xb0\x29\xbf\x06\x54\x28\xae\x06\x2a\x2a\xb4\x06\x67\x29\xbc\x06\x45\x28\xc8\x06\xb8\x29\xc4\x06\x2b\x29\xc3\x06\xfe\x27\xbe\x06\xb2\x29\xc3\x06\x1e\x29\xbb\x06\x04\x28\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbd\x06\xd5\x29\xb8\x06\xfd\x28\xb4\x06\xf1\x27\xd2\x06\xd4\x29\xc1\x06\xa2\x28\xcb\x06\x1d\x28\xc0\x06\xd1\x29\xbe\x06\x06\x29\xbe\x06\x09\x28\xc5\x06\xd3\x29\xbd\x06\xd9\x28\xca\x06\xb3\x27\xc2\x06\x95\x29\xc7\x06\xc4\x28\xc5\x06\xcc\x27\xa2\x06\x80\x29\x99\x06\xf6\x28\xc0\x06\xb7\x27\xbb\x06\x6c\x29\xb7\x06\x05\x29\xab\x06\xce\x27\xc0\x06\x65\x29\xc0\x06\xc2\x28\xbe\x06\xcd\x27\xb4\x06\x66\x29\xb6\x06\xcd\x28\xc6\x06\xba\x27\xb6\x06\xdc\x29\xb0\x06\xdd\x28\xbd\x06\x9a\x27\xb9\x06\xee\x29\xae\x06\xf1\x28\xa9\x06\xed\x27\xb5\x06\xdd\x29\xb1\x06\x68\x29\xbb\x06\xe4\x27\xb5\x06\x9b\x29\xb2\x06\xf4\x28\xbb\x06\xfa\x27\xc2\x06\x8e\x29\xc1\x06\xfa\x28\xb5\x06\xbd\x27\xdb\x06\x9a\x29\xd5\x06\xb1\x28\xcb\x06\xa0\x27\xb8\x06\x88\x29\xae\x06\xd9\x28\xbf\x06\xbb\x27\xc6\x06\x82\x29\xb9\x06\xe2\x28\xbf\x06\xdf\x27\xc2\x06\x96\x29\xbb\x06\xe8\x28\xbf\x06\xea\x27\xbd\x06\xea\x29\xb9\x06\xd6\x28\xc0\x06\xd2\x27\xb5\x06\x5d\x29\xb0\x06\xd8\x28\xb5\x06\xd9\x27\xb8\x06\x6a\x29\xb3\x06\xca\x28\xba\x06\xa4\x27\xbe\x06\x5e\x29\xbd\x06\x95\x28\xca\x06\x88\x27\xaa\x06\x55\x29\xb1\x06\xa1\x28\xb6\x06\x7d\x27\xb9\x06\x95\x29\xbb\x06\x9a\x28\xbd\x06\xaf\x27\xbc\x06\xa8\x29\xbf\x06\xe2\x28\xb7\x06\x97\x27\xd8\x06\x00\x2a\xba\x06\xbc\x28\xce\x06\xfc\x27\xab\x06\x9c\x29\xbb\x06\xb6\x28\xb6\x06\xa8\x27\xbd\x06\x53\x29\xb1\x06\xa1\x28\xb2\x06\x8a\x27\x9f\x06\x32\x29\xaf\x06\x7d\x28\xb0\x06\x39\x27\xbc\x06\x5d\x29\xbb\x06\xba\x28\xb6\x06\x72\x27\xc3\x06\x21\x29\xc0\x06\xa1\x28\xbb\x06\x5f\x27\xba\x06\x5f\x29\xb7\x06\x76\x28\xb7\x06\x74\x27\xae\x06\x46\x29\xb2\x06\x42\x28\xba\x06\x3e\x27\xc0\x06\x25\x29\xb4\x06\x2d\x28\xbc\x06\x4a\x27\xad\x06\xbb\x28\xb7\x06\x89\x28\xbc\x06\x5f\x27\xab\x06\x3f\x29\xac\x06\x69\x28\xbc\x06\x33\x27\xb5\x06\x3a\x29\xb5\x06\x99\x28\xa9\x06\x41\x27\xb6\x06\x50\x29\xc0\x06\x9d\x28\xb1\x06\x48\x27\xbb\x06\x8d\x29\xb8\x06\x96\x28\xb1\x06\x30\x27\xbe\x06\xdd\x29\xaf\x06\x8e\x28\xbb\x06\x33\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\x06\xae\x29\xa5\x06\xb8\x28\xbf\x06\x2c\x27\xb5\x06\x24\x29\xb7\x06\xc2\x28\xbe\x06\xee\x26\xc0\x06\xbf\x29\xbb\x06\x5d\x28\xb3\x06\x97\x26\xb8\x06\xd0\x29\xab\x06\x21\x28\xb9\x06\x2d\x26\xc7\x06\xb0\x29\xbe\x06\x3b\x28\xb9\x06\x09\x26\xb9\x06\x6b\x29\xb2\x06\x6d\x28\xaf\x06\x10\x26\xb5\x06\x5c\x2a\xa7\x06\x33\x28\xb7\x06\x9c\x26\xcd\x06\x40\x2b\xbc\x06\x4d\x28\xbc\x06\xe6\x26\xbf\x06\xca\x2a\xa5\x06\x1d\x28\xbb\x06\x07\x27\xbb\x06\xa9\x29\xb5\x06\x89\x28\xb5\x06\x0e\x27\xbd\x06\x80\x29\xb7\x06\xa8\x28\xb1\x06\x0e\x27\xb3\x06\xa4\x29\xb6\x06\xbd\x28\xbc\x06\x78\x27\xcc\x06\xbd\x29\xbe\x06\xb9\x28\xc5\x06\xa4\x27\xb8\x06\x24\x2a\xb3\x06\x25\x29\xb6\x06\xb6\x27\xc2\x06\x47\x2a\xbb\x06\x4f\x29\xbd\x06\xf2\x27\xc4\x06\xc8\x29\xc4\x06\x10\x29\xb8\x06\xd5\x27\xb2\x06\xba\x29\xb3\x06\x21\x29\xab\x06\xdb\x27\xb0\x06\x8e\x29\xa9\x06\xd8\x28\xa6\x06\xc1\x27\xbe\x06\x8c\x29\xbb\x06\x35\x29\xba\x06\xe7\x27\xaf\x06\x9e\x29\xb0\x06\x08\x29\xc1\x06\xf5\x27\xb7\x06\x8d\x29\xab\x06\xb8\x28\xc0\x06\xe2\x27\xc8\x06\x62\x29\xb4\x06\xb9\x28\xc3\x06\xe3\x27\xbb\x06\x4f\x29\xa9\x06\xa1\x28\xb4\x06\xc1\x27\xad\x06\x63\x29\xa1\x06\xa1\x28\xaf\x06\x93\x27\xba\x06\xe6\x28\xbc\x06\xa9\x28\xb8\x06\x84\x27\xb0\x06\x21\x29\xb3\x06\xa9\x28\xa9\x06\x3e\x27\xa8\x06\x25\x29\xaf\x06\x92\x28\xac\x06\x83\x27\xc0\x06\x2e\x29\xb0\x06\x7e\x28\xb3\x06\x74\x27\xc2\x06\x72\x29\xb3\x06\x49\x28\xbc\x06\x80\x27\xa9\x06\x73\x29\xac\x06\x82\x28\xb5\x06\x50\x27\xac\x06\x21\x29\xb7\x06\x6d\x28\xad\x06\x97\x27\xbc\x06\x61\x29\xb3\x06\xe8\x28\xb4\x06\x39\x27\xab\x06\x1d\x29\xa9\x06\x26\x28\xb6\x06\x18\x27\xbc\x06\x0a\x29\xa8\x06\x1d\x28\xb5\x06\x41\x27\x9f\x06\xe1\x28\x9d\x06\x5c\x28\xa4\x06\x4c\x27\xbb\x06\x46\x29\xb7\x06\x74\x28\xbc\x06\x67\x27\xaf\x06\x44\x29\xa3\x06\x85\x28\xbd\x06\x7d\x27\x9a\x06\x24\x29\x96\x06\x7a\x28\xb7\x06\x60\x27\xb3\x06\x1c\x29\xa6\x06\x41\x28\xb2\x06\x54\x27\xb6\x06\x5e\x29\xb3\x06\x43\x28\xc2\x06\x24\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa8\x06\x80\x29\xa7\x06\x5e\x28\xb4\x06\x69\x27\xaf\x06\x20\x2a\xb2\x06\x7b\x28\xb0\x06\x91\x27\xbd\x06\x3d\x2a\xb3\x06\x80\x28\xb4\x06\x76\x27\xcd\x06\x22\x2a\xba\x06\xa8\x28\xb1\x06\x99\x27\xbb\x06\x73\x29\xb5\x06\x7f\x28\xb6\x06\x6d\x27\xbf\x06\x39\x29\xb7\x06\x7b\x28\xb0\x06\x70\x27\xac\x06\x13\x29\xa0\x06\x56\x28\xa8\x06\x22\x27\xb5\x06\x06\x29\xa3\x06\x4d\x28\xb2\x06\x56\x27\xb1\x06\x96\x29\x9b\x06\xa3\x28\xac\x06\x56\x27\xb7\x06\xc7\x29\xbb\x06\x67\x28\xbc\x06\x78\x27\xb7\x06\x1d\x2a\xa6\x06\x4d\x28\xab\x06\x4e\x27\xb7\x06\x49\x2a\xb6\x06\x57\x28\xa9\x06\x7b\x27\xb8\x06\x88\x2a\xa2\x06\x55\x28\xaf\x06\x4f\x27\xa5\x06\x27\x2a\x9f\x06\x2e\x28\xb9\x06\x03\x27\xc1\x06\x77\x29\xbe\x06\x5b\x28\xba\x06\xf0\x26\xb1\x06\x54\x29\xb0\x06\xb5\x28\xac\x06\x21\x27\xb6\x06\x6c\x29\xb8\x06\x70\x28\xa8\x06\x55\x27\xb0\x06\xf2\x29\xa8\x06\x48\x28\xab\x06\x99\x27\xaf\x06\xbf\x29\x9d\x06\x4c\x28\xb1\x06\xa6\x27\xaf\x06\x8d\x29\xb7\x06\xa5\x28\xb4\x06\x64\x27\xaa\x06\xbe\x29\x98\x06\x7e\x28\xaa\x06\x78\x27\xb3\x06\xc1\x29\xa9\x06\x95\x28\xac\x06\x92\x27\xb1\x06\x92\x29\xbd\x06\xbf\x28\xbc\x06\xaa\x27\xb8\x06\x48\x29\xb4\x06\xd1\x28\xb7\x06\xb4\x27\xb9\x06\x07\x2a\xac\x06\xa4\x28\xa8\x06\xba\x27\xbc\x06\x24\x2a\xb6\x06\x0c\x29\xb6\x06\x13\x28\xbb\x06\xca\x29\xb5\x06\xf7\x28\xb5\x06\xdd\x27\xc0\x06\x03\x2a\xc6\x06\xd7\x28\xc0\x06\xda\x27\xbc\x06\x31\x2a\xb3\x06\x9b\x28\xbc\x06\xd0\x27\xac\x06\x31\x2a\xaf\x06\xdc\x28\xb9\x06\xe5\x27\xa8\x06\x66\x2a\x99\x06\xf7\x28\xb0\x06\xe7\x27\xbd\x06\xfc\x29\xb2\x06\x0f\x29\xb5\x06\x06\x28\xb4\x06\x4a\x2a\xa6\x06\x49\x29\xb2\x06\x19\x28\xaf\x06\xcc\x29\xa8\x06\xa8\x28\xa4\x06\xd3\x27\xaf\x06\xce\x29\xac\x06\xc4\x28\xb4\x06\xd3\x27\xbd\x06\xcb\x29\xb0\x06\xc5\x28\xb0\x06\xa7\x27\xab\x06\xe7\x29\xa8\x06\xd0\x28\xb0\x06\x79\x27\xb4\x06\x9a\x29\xb1\x06\xf1\x28\xb8\x06\xb4\x27\xb7\x06\xad\x29\xb4\x06\x0d\x29\xb0\x06\xad\x27\xb1\x06\xb2\x29\xa3\x06\xb6\x28\xb2\x06\xa4\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xaa\x06\xab\x29\xa3\x06\xa4\x28\xa1\x06\x71\x27\xb4\x06\x7b\x29\xad\x06\xd6\x28\xaa\x06\x8d\x27\xaa\x06\x51\x29\xaa\x06\xcf\x28\xbb\x06\x9b\x27\xba\x06\x6e\x29\xc7\x06\xa2\x28\xb6\x06\x8a\x27\xa5\x06\x51\x29\xae\x06\xe6\x28\xac\x06\xb4\x27\xa5\x06\x92\x29\xaa\x06\x27\x29\xb6\x06\xb1\x27\xb3\x06\xad\x29\xc3\x06\xeb\x28\xb7\x06\xe3\x27\xb8\x06\x5f\x29\xc3\x06\x50\x29\xbc\x06\xc9\x27\xb6\x06\x17\x29\xaa\x06\xa5\x28\xb8\x06\xb9\x27\xa2\x06\x6e\x29\xa3\x06\xdc\x28\xc5\x06\xcf\x27\xb1\x06\x76\x29\xb7\x06\xab\x28\xae\x06\xae\x27\xaa\x06\x78\x29\xaf\x06\xae\x28\xb2\x06\x9c\x27\xbe\x06\xae\x29\xb6\x06\xcd\x28\xbf\x06\xda\x27\x8c\x06\x3c\x2a\x83\x06\x5c\x29\xab\x06\xdc\x27\xb8\x06\xad\x29\xad\x06\xe8\x28\xad\x06\xb1\x27\xa3\x06\x4d\x29\xae\x06\xec\x28\xb4\x06\x94\x27\xac\x06\xf8\x28\xae\x06\x89\x28\xae\x06\x95\x27\xb3\x06\x25\x29\xae\x06\xa6\x28\xb8\x06\x8f\x27\xb1\x06\x77\x29\xb1\x06\x95\x28\xa9\x06\x7b\x27\xb4\x06\xa7\x29\xb5\x06\x64\x28\xbc\x06\xae\x27\xc1\x06\xee\x29\xc0\x06\xb0\x28\xc2\x06\x97\x27\xb5\x06\xe2\x29\xa5\x06\xbe\x28\xae\x06\xd2\x27\xb0\x06\x9a\x29\xa7\x06\x69\x28\xc1\x06\xb4\x27\xb8\x06\xa3\x29\xb1\x06\x5e\x28\xb8\x06\xa3\x27\xb7\x06\x3f\x29\xbb\x06\x4c\x28\xac\x06\x48\x27\xa1\x06\x14\x29\xa2\x06\x47\x28\xb7\x06\x2d\x27\xa4\x06\x37\x29\xb1\x06\x5c\x28\xb0\x06\x3f\x27\xae\x06\x54\x29\xae\x06\xb2\x28\xbc\x06\x31\x27\x88\x06\x81\x29\x88\x06\x2c\x28\xa3\x06\x3a\x27\x96\x06\x1c\x29\x92\x06\x63\x28\x9f\x06\x29\x27\x9f\x06\x3d\x29\x90\x06\xfa\x27\xb2\x06\x0d\x27\xb4\x06\x10\x29\xb9\x06\x21\x28\xb7\x06\x29\x27\x9b\x06\x44\x29\x95\x06\x0f\x28\xb4\x06\xfc\x26\xb6\x06\x51\x29\xad\x06\x37\x28\xb2\x06\x38\x27\xba\x06\xd5\x28\xbc\x06\x8b\x28\xc2\x06\x6b\x27\xba\x06\x5a\x29\xab\x06\x6e\x28\xb2\x06\x6f\x27\xb1\x06\x5e\x29\xb0\x06\x4b\x28\xa9\x06\x1c\x27\xae\x06\x04\x29\xa3\x06\xeb\x27\xb2\x06\x4b\x27\xb2\x06\xd1\x28\xbd\x06\x20\x28\xb7\x06\xd9\x26\xc0\x06\x49\x29\xc1\x06\x38\x28\xc7\x06\x20\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbe\x06\x6b\x29\xaa\x06\x04\x28\xba\x06\x3a\x27\xa6\x06\x48\x29\xaa\x06\xfd\x27\xb1\x06\x64\x27\xb1\x06\x65\x29\xb2\x06\x07\x28\xb7\x06\x2b\x27\xb0\x06\xf7\x28\xa1\x06\xe3\x27\xb4\x06\x0e\x27\xb4\x06\xde\x28\xab\x06\x0b\x28\xb2\x06\x1e\x27\xb5\x06\x14\x29\xa8\x06\x18\x28\xbc\x06\xfb\x26\xa0\x06\xb3\x28\xa7\x06\x00\x28\xaf\x06\x01\x27\xaa\x06\xbf\x28\xaa\x06\x11\x28\x9e\x06\xec\x26\xb7\x06\xf4\x28\xb4\x06\x20\x28\xbb\x06\x26\x27\xad\x06\x3a\x29\x9c\x06\xce\x27\xaf\x06\x59\x27\xb7\x06\xeb\x28\xb0\x06\xee\x27\xbf\x06\x3c\x27\xae\x06\xd6\x28\xaf\x06\xfa\x27\xaa\x06\x2d\x27\xaa\x06\xf4\x28\xa1\x06\xe2\x27\xae\x06\x07\x27\x9d\x06\xf1\x28\x8f\x06\xec\x27\x9e\x06\xd3\x26\x86\x06\xa0\x29\x73\x06\x8d\x28\x90\x06\xbf\x27\xae\x06\xe3\x28\xa9\x06\xf5\x27\xaf\x06\x4a\x27\xbd\x06\x09\x29\xb5\x06\xbf\x27\xb2\x06\x2b\x27\xa9\x06\x05\x29\xae\x06\xbf\x27\xba\x06\x0e\x27\xb7\x06\xcd\x28\xb1\x06\x1e\x28\xc0\x06\x29\x27\xab\x06\xaa\x28\xa2\x06\x4b\x28\xa1\x06\xf4\x26\xb2\x06\x97\x28\xab\x06\x23\x28\xac\x06\x0a\x27\xad\x06\xc6\x28\xa2\x06\xfd\x27\xb0\x06\x13\x27\xb7\x06\xd5\x28\xb0\x06\x21\x28\xaa\x06\x09\x27\x9b\x06\x30\x29\x9b\x06\x33\x28\xaa\x06\x71\x27\xa0\x06\x46\x29\xa0\x06\x59\x28\xaa\x06\x55\x27\xa8\x06\x00\x29\xa5\x06\x09\x28\xae\x06\x29\x27\xa8\x06\x31\x29\xa9\x06\x05\x28\xb8\x06\x29\x27\xa8\x06\xcb\x28\xab\x06\xfa\x27\xac\x06\xfb\x26\x9a\x06\xf9\x28\xa2\x06\x22\x28\xb3\x06\x1e\x27\x9b\x06\x10\x29\x94\x06\x2b\x28\xb2\x06\x2b\x27\xb4\x06\x31\x29\xa6\x06\x27\x28\xb4\x06\x4b\x27\xad\x06\x6b\x29\xab\x06\x59\x28\xa5\x06\x4c\x27\xac\x06\x01\x29\xa3\x06\xef\x27\xb9\x06\x09\x27\xbf\x06\xcd\x28\xbf\x06\x23\x28\xad\x06\xc5\x26\x9f\x06\xcc\x28\xa0\x06\x4d\x28\x9d\x06\xe4\x26\x82\x06\x41\x29\x86\x06\x26\x28\x9d\x06\xe5\x26\xb8\x06\x0e\x29\xae\x06\xf2\x27\xac\x06\xd8\x26\xb4\x06\xca\x28\xaf\x06\x46\x28\xb9\x06\x0f\x27\xac\x06\x38\x29\xa4\x06\x4e\x28\xa2\x06\x28\x27\xa5\x06\x36\x29\x9a\x06\xfb\x27\xa4\x06\x08\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb1\x06\xe6\x28\xa3\x06\x33\x28\xab\x06\xec\x26\xb0\x06\x90\x28\xb2\x06\x3d\x28\xb8\x06\x14\x27\xb6\x06\x8a\x28\xb2\x06\x21\x28\xad\x06\xc6\x26\xac\x06\xf1\x28\xa2\x06\x39\x28\x93\x06\x1e\x27\xa5\x06\xf0\x28\xa1\x06\x4d\x28\xaa\x06\x2f\x27\xab\x06\x0c\x29\x9d\x06\x56\x28\xa8\x06\x01\x27\xb9\x06\xcc\x28\xb5\x06\x3d\x28\xb9\x06\x4e\x27\xb0\x06\xa5\x28\xb5\x06\x49\x28\xba\x06\x10\x27\xb2\x06\x89\x28\xb0\x06\x25\x28\xb3\x06\x11\x27\xa1\x06\x88\x28\xa7\x06\x50\x28\xb4\x06\xfc\x26\x85\x06\x05\x29\x8e\x06\x69\x28\x95\x06\x3c\x27\xa3\x06\xbe\x28\x99\x06\x58\x28\xa7\x06\x28\x27\xb9\x06\x29\x29\xa8\x06\x6c\x28\xa0\x06\x3c\x27\xab\x06\x10\x29\xac\x06\x81\x28\xac\x06\x37\x27\x90\x06\x7f\x29\x86\x06\x88\x28\x9c\x06\x30\x27\x9e\x06\xf6\x28\x9f\x06\x58\x28\xb7\x06\xc0\x26\xb0\x06\x0b\x29\xb5\x06\x35\x28\xae\x06\xb3\x26\xc3\x06\x07\x29\xb5\x06\x25\x28\xb1\x06\xd0\x26\xb3\x06\x38\x29\xac\x06\x32\x28\xa6\x06\xf2\x26\xa3\x06\x7c\x29\xa7\x06\x5a\x28\xcc\x06\x5e\x27\xb9\x06\x8d\x29\xab\x06\xf9\x27\xb2\x06\x2c\x27\xb0\x06\xde\x28\xb3\x06\x32\x28\xb4\x06\x1d\x27\xab\x06\xdd\x28\xa7\x06\x3a\x28\xb2\x06\xd1\x26\xb0\x06\x2d\x29\xb7\x06\x33\x28\xb1\x06\x14\x27\x9c\x06\x5f\x29\x8f\x06\x33\x28\xa8\x06\xf9\x26\xa5\x06\x78\x29\x9d\x06\x72\x28\xae\x06\x11\x27\xa9\x06\xb0\x29\xa9\x06\xe0\x28\xac\x06\x41\x27\xab\x06\x22\x2a\x9d\x06\xea\x28\xab\x06\x78\x27\xa9\x06\x3b\x2a\x9c\x06\xb1\x28\xa2\x06\x3e\x27\xba\x06\xf4\x29\xb6\x06\x72\x28\xc0\x06\x3b\x27\xae\x06\x22\x2a\x9e\x06\x79\x28\xa8\x06\x4a\x27\xa8\x06\xdb\x29\xa2\x06\x81\x28\x9c\x06\xff\x26\xab\x06\x9f\x29\xae\x06\x23\x28\xad\x06\x00\x27\xac\x06\xd9\x29\x95\x06\x29\x28\xa3\x06\x41\x27\xbd\x06\xe8\x29\xad\x06\x87\x28\xab\x06\x40\x27\xba\x06\xda\x29\xb6\x06\x71\x28\xb0\x06\xe7\x26\xb9\x06\x7d\x29\xb0\x06\x66\x28\xb4\x06\xe7\x26\xb2\x06\x88\x29\xa8\x06\x7a\x28\xb6\x06\x2d\x27\xb0\x06\x9b\x29\xad\x06\x47\x28\xa8\x06\x27\x27\xbf\x06\xda\x29\xae\x06\x2e\x28\xac\x06\x31\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xad\x06\x38\x2a\x96\x06\x7e\x28\xaa\x06\x5a\x27\xa1\x06\xe7\x29\x9b\x06\xff\x28\xba\x06\x9d\x27\xa7\x06\x50\x29\xa5\x06\xc9\x28\xac\x06\x5b\x27\xb0\x06\xf8\x28\x9c\x06\x54\x28\xb2\x06\x09\x27\xa2\x06\xe5\x29\x9e\x06\x3d\x28\xa6\x06\x10\x26\x49\x07\x92\x9f\x4d\x07\x2d\x97\x50\x07\xd8\x8e\x00\x00\xb8\x14\x00\x00\x6d\x15\x00\x00\x0b\x16\x00\x00\xb9\x14\x00\x00\x6e\x15\x00\x00\x0d\x16\x00\x00\xb9\x14\x00\x00\x6e\x15\x00\x00\x1f\x16\x00\x00\xb9\x14\x00\x00\x6e\x15\x00\x00\x1e\x16\x00\x00\xb9\x14\x00\x00\x6e\x15\x4c\x08\xff\xff\xd6\x06\x62\x29\xd7\x06\x26\x28\xc3\x06\xac\x25\xda\x06\xaf\x28\xda\x06\x61\x28\xcf\x06\x81\x26\xd5\x06\x29\x29\xc8\x06\x55\x28\xca\x06\xd3\x26\xdc\x06\x5f\x29\xd9\x06\x84\x28\xcd\x06\xeb\x26\xe3\x06\xa0\x29\xd3\x06\xd5\x28\xd1\x06\x09\x27\xcc\x06\x6c\x29\xd0\x06\x1e\x28\xc7\x06\xc6\x26\xd8\x06\x8a\x29\xcf\x06\x70\x28\xd6\x06\xd9\x26\xe1\x06\x43\x29\xd8\x06\x69\x28\xd6\x06\x33\x27\xd1\x06\x56\x29\xcf\x06\x3b\x28\xce\x06\xb6\x26\xca\x06\x81\x29\xcf\x06\x46\x28\xcc\x06\xae\x26\xdc\x06\x55\x29\xd0\x06\x29\x28\xd0\x06\xe1\x26\xd3\x06\x39\x29\xd0\x06\xf3\x27\xd3\x06\xbe\x26\xc3\x06\x72\x29\xbb\x06\xb4\x27\xc5\x06\x70\x26\xdc\x06\x85\x29\xc8\x06\x11\x28\xd3\x06\x6a\x26\xd4\x06\x56\x2a\xd8\x06\x64\x28\xcc\x06\x03\x27\xd4\x06\x7f\x29\xc6\x06\xef\x27\xce\x06\xc9\x26\xe3\x06\x97\x29\xd6\x06\x07\x28\xd8\x06\x14\x27\xd6\x06\x5a\x29\xcc\x06\x55\x28\xd5\x06\xe6\x26\xc5\x06\x01\x29\xce\x06\x19\x28\xc4\x06\x98\x26\xce\x06\xf0\x28\xcd\x06\xad\x27\xd0\x06\x03\x26\xd4\x06\xc1\x28\xd1\x06\x95\x27\xc8\x06\x36\x26\xcb\x06\xef\x28\xce\x06\x35\x28\xcc\x06\x6f\x26\xd4\x06\x39\x29\xcd\x06\x58\x28\xd2\x06\xc8\x26\xd8\x06\x2d\x29\xd1\x06\x12\x28\xcc\x06\x82\x26\xd0\x06\xf5\x28\xd9\x06\x7a\x28\xd2\x06\xb5\x26\xdc\x06\x35\x29\xd3\x06\x60\x28\xd3\x06\xae\x26\xe2\x06\xa6\x28\xea\x06\x74\x28\xcb\x06\x35\x26\xdc\x06\x7f\x28\xe2\x06\x3d\x28\xd0\x06\x0a\x26\xd1\x06\x02\x29\xc3\x06\x3e\x28\xd5\x06\xa6\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd5\x06\x13\x29\xcb\x06\x3d\x28\xc5\x06\x87\x26\xdc\x06\x0b\x29\xcc\x06\x36\x28\xcb\x06\x56\x26\xc8\x06\x8e\x28\xc5\x06\x19\x28\xd1\x06\x77\x26\xc7\x06\x72\x28\xd5\x06\x49\x28\xc6\x06\x32\x26\xd8\x06\x51\x28\xd4\x06\xe8\x27\xc8\x06\x6d\x26\xcf\x06\x5b\x28\xc8\x06\xc8\x27\xc5\x06\xf2\x25\xd0\x06\x37\x28\xc3\x06\x31\x28\xcf\x06\x82\x26\xd4\x06\x88\x28\xd4\x06\x32\x28\xcd\x06\x91\x26\xd5\x06\x60\x28\xd5\x06\x04\x28\xda\x06\x85\x26\xd1\x06\x5f\x28\xdf\x06\x78\x28\xca\x06\x9f\x26\xcd\x06\x7a\x28\xd5\x06\x76\x28\xd7\x06\xd0\x26\xca\x06\xc4\x28\xd2\x06\x5e\x28\xc7\x06\xe6\x26\xc5\x06\x5a\x28\xc5\x06\x1d\x28\xc8\x06\x73\x26\xd0\x06\xa4\x28\xcf\x06\x04\x28\xc1\x06\x9b\x26\xd4\x06\xb3\x28\xe2\x06\x84\x28\xd4\x06\xe8\x26\xd7\x06\x2d\x29\xc9\x06\x5e\x28\xd9\x06\x0e\x27\xcd\x06\xc1\x28\xc7\x06\x1f\x28\xd1\x06\x17\x27\xcf\x06\xec\x28\xc1\x06\xff\x27\xcc\x06\xf0\x26\xd1\x06\x3a\x29\xcf\x06\x8a\x28\xd0\x06\xe8\x26\xc5\x06\xad\x28\xcf\x06\xeb\x27\xcc\x06\x7b\x26\xcc\x06\xb7\x28\xd2\x06\x7c\x28\xc3\x06\xba\x26\xc9\x06\x28\x29\xc6\x06\x5e\x28\xc0\x06\xd9\x26\xce\x06\x07\x29\xcc\x06\x58\x28\xcc\x06\x1c\x27\xbc\x06\xf1\x28\xbc\x06\x54\x28\xcd\x06\xfa\x26\xd0\x06\x37\x29\xc5\x06\x7a\x28\xd0\x06\x24\x27\xc4\x06\x24\x29\xcb\x06\x79\x28\xbf\x06\x1f\x27\xc6\x06\x7c\x28\xc5\x06\x3b\x28\xd0\x06\xe0\x26\xc6\x06\xad\x28\xc5\x06\x6e\x28\xd0\x06\xb6\x26\xd6\x06\xf8\x28\xd5\x06\x54\x28\xd0\x06\xe1\x26\xd5\x06\x1a\x29\xdd\x06\x89\x28\xe0\x06\xd6\x26\xc9\x06\xe7\x28\xc6\x06\xab\x28\xd4\x06\xc5\x26\xd5\x06\xef\x28\xd2\x06\x25\x28\xc9\x06\xad\x26\xd4\x06\xf8\x28\xce\x06\xf3\x27\xcb\x06\xab\x26\xc5\x06\xb2\x28\xd1\x06\xf6\x27\xd5\x06\xb9\x26\xb9\x06\x8b\x28\xba\x06\xb7\x27\xc8\x06\x45\x26\xd1\x06\x5f\x28\xd0\x06\x52\x28\xca\x06\xa6\x26\xe0\x06\x9d\x28\xcc\x06\x35\x28\xd2\x06\xb3\x26\xd8\x06\x2d\x29\xca\x06\x27\x28\xca\x06\x1f\x27\xda\x06\xa2\x29\xd1\x06\x54\x28\xc9\x06\xd6\x26\xcf\x06\xe1\x28\xcf\x06\xfa\x27\xd4\x06\xce\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xdd\x06\xd9\x28\xd6\x06\x69\x28\xc5\x06\x9f\x26\xd0\x06\xfd\x28\xcd\x06\xfa\x27\xca\x06\x7f\x26\xc1\x06\xe3\x28\xd1\x06\xc3\x28\xce\x06\xf8\x26\xd2\x06\x3f\x29\xd6\x06\xcf\x28\xcc\x06\xc9\x26\xc3\x06\xec\x28\xb8\x06\x65\x28\xc9\x06\xe4\x26\xdf\x06\x30\x29\xd4\x06\x71\x28\xcf\x06\xdb\x26\xcf\x06\x00\x29\xc9\x06\x69\x28\xcd\x06\xd9\x26\xc9\x06\x00\x29\xc9\x06\x92\x28\xce\x06\x05\x27\xd5\x06\xea\x28\xcf\x06\x33\x28\xcc\x06\x73\x26\xc8\x06\x2c\x29\xc7\x06\x3d\x28\xcd\x06\xc7\x26\xd4\x06\x31\x29\xd9\x06\x4a\x28\xd8\x06\xef\x26\xd6\x06\x62\x29\xd2\x06\x4e\x28\xbb\x06\x9c\x26\xd7\x06\xd5\x28\xda\x06\x4e\x28\xd9\x06\xcf\x26\xcb\x06\x17\x29\xbe\x06\x04\x28\xd3\x06\xef\x26\xbb\x06\xe2\x28\xb9\x06\xfc\x27\xc5\x06\xc0\x26\xd0\x06\xa5\x28\xd4\x06\xa5\x27\xd3\x06\x7b\x26\xd4\x06\xa6\x28\xd2\x06\xff\x27\xcd\x06\x48\x26\xd7\x06\x09\x29\xc9\x06\xe6\x27\xcf\x06\xe9\x26\xd8\x06\x00\x29\xcd\x06\xd6\x27\xd5\x06\xc8\x26\xd4\x06\xc9\x28\xd2\x06\xfe\x27\xce\x06\x7e\x26\xd1\x06\xae\x28\xcd\x06\xd7\x27\xc6\x06\x94\x26\xda\x06\x5e\x28\xd1\x06\xbf\x27\xca\x06\x9c\x26\xd6\x06\x60\x28\xd2\x06\x85\x27\xc6\x06\x20\x26\xd2\x06\x71\x28\xca\x06\x89\x27\xcb\x06\x92\x26\xdf\x06\xe6\x28\xd5\x06\xfa\x27\xd8\x06\x98\x26\xcf\x06\x48\x29\xc9\x06\x6a\x28\xbb\x06\x7f\x26\xd1\x06\x33\x29\xd3\x06\x26\x28\xca\x06\xc5\x26\xe1\x06\xa3\x29\xc5\x06\xea\x27\xd6\x06\xcb\x26\xd1\x06\x21\x29\xcc\x06\x32\x28\xda\x06\xe9\x26\xd0\x06\xd5\x28\xc8\x06\x50\x28\xc7\x06\x95\x26\xce\x06\x9d\x28\xd9\x06\x5e\x28\xcc\x06\xc1\x26\xd0\x06\x5f\x29\xda\x06\x78\x28\xcb\x06\xda\x26\xbe\x06\xa5\x29\xb5\x06\x45\x28\xd0\x06\xf1\x26\xde\x06\x5d\x29\xc7\x06\x0b\x28\xd6\x06\x0a\x27\xdd\x06\x5f\x29\xdc\x06\x47\x28\xc9\x06\x0c\x27\xd9\x06\x9c\x29\xc7\x06\x6d\x28\xd1\x06\xdd\x26\xdb\x06\x5f\x29\xd9\x06\x81\x28\xd1\x06\x06\x27\xd2\x06\x36\x29\xd6\x06\x5d\x28\xcd\x06\xbc\x26\xd1\x06\x4f\x29\xc7\x06\x90\x28\xc5\x06\x20\x27\xcd\x06\x04\x29\xc2\x06\xb9\x28\xcb\x06\x1b\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd5\x06\x3d\x29\xc9\x06\x7c\x28\xd0\x06\xfb\x26\xdb\x06\x2a\x29\xd7\x06\xc3\x28\xd3\x06\xb5\x26\xc6\x06\x40\x29\xc9\x06\x42\x28\xc9\x06\xce\x26\xcd\x06\xe1\x28\xc4\x06\x6d\x28\xc5\x06\xaf\x26\xd8\x06\x62\x28\xdc\x06\x1f\x28\xc7\x06\x4d\x26\xd2\x06\xc8\x28\xda\x06\x41\x28\xc7\x06\xab\x26\xc8\x06\xf5\x28\xc9\x06\x84\x28\xc7\x06\xf4\x26\xd4\x06\xc1\x28\xce\x06\x6a\x28\xce\x06\xec\x26\xdb\x06\xd4\x28\xdf\x06\x76\x28\xd6\x06\xcc\x26\xce\x06\x1f\x29\xcc\x06\x8d\x28\xd1\x06\xf4\x26\xd0\x06\x13\x29\xcb\x06\x9b\x28\xd2\x06\x06\x27\xd7\x06\x3b\x29\xce\x06\x3a\x28\xc8\x06\xd4\x26\xc9\x06\x0b\x29\xd3\x06\xc2\x28\xca\x06\x1c\x27\xcc\x06\x21\x29\xc5\x06\xd4\x28\xca\x06\x03\x27\xb3\x06\x69\x29\xa7\x06\xe9\x28\xcb\x06\xe2\x26\xc8\x06\x77\x29\xc3\x06\xb3\x28\xc5\x06\x18\x27\xdc\x06\x27\x29\xd5\x06\xa6\x28\xdc\x06\x32\x27\xd2\x06\x13\x29\xd7\x06\xb7\x28\xcc\x06\x3a\x27\xd1\x06\xda\x28\xc4\x06\xe6\x28\xcd\x06\xba\x26\xbf\x06\x39\x29\xb8\x06\xa8\x28\xcc\x06\xb1\x26\xe5\x06\x53\x29\xe7\x06\xe0\x28\xce\x06\x1e\x27\xda\x06\x6f\x29\xd7\x06\x94\x28\xcd\x06\x22\x27\xbe\x06\x09\x29\xb9\x06\x6f\x28\xd5\x06\x2d\x27\xda\x06\x06\x29\xce\x06\x7d\x28\xcf\x06\xdd\x26\xce\x06\x1c\x29\xc6\x06\x46\x28\xc4\x06\xe8\x26\xd3\x06\xf1\x28\xcb\x06\x27\x28\xcf\x06\x9f\x26\xb6\x06\x67\x29\xa7\x06\x02\x28\xce\x06\xfc\x26\xd2\x06\x30\x29\xd8\x06\x90\x28\xc9\x06\x3c\x27\xd0\x06\x50\x29\xc6\x06\x84\x28\xce\x06\x53\x27\xcf\x06\x1f\x29\xd1\x06\x4d\x28\xcb\x06\x03\x27\xd5\x06\x1a\x29\xd3\x06\x4d\x28\xc8\x06\xd2\x26\xe1\x06\x55\x29\xd3\x06\x5f\x28\xe0\x06\xe0\x26\xcc\x06\xbb\x28\xcf\x06\x56\x28\xc4\x06\x8a\x26\xd9\x06\x97\x28\xd3\x06\xb1\x27\xca\x06\x00\x26\xa6\x06\x65\x29\x91\x06\xbb\x27\xc8\x06\x0b\x26\xe0\x06\x5a\x29\xda\x06\x26\x28\xcd\x06\x19\x26\xd5\x06\xdb\x28\xdf\x06\x5e\x28\xd4\x06\x47\x26\xdb\x06\x23\x29\xd9\x06\x23\x28\xc9\x06\x04\x26\xd7\x06\x6f\x29\xd4\x06\x52\x28\xd2\x06\x66\x26\xcf\x06\x4c\x29\xcd\x06\x3b\x28\xce\x06\x7a\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc0\x06\xb3\x28\xd0\x06\xe9\x27\xcc\x06\x45\x26\xdd\x06\x5d\x29\xcd\x06\x30\x28\xcf\x06\x73\x26\xe2\x06\xf8\x29\xcd\x06\x38\x28\xd8\x06\xba\x26\xc7\x06\x43\x2a\xbc\x06\x4a\x28\xd6\x06\xe9\x26\xe6\x06\x3c\x2a\xe2\x06\x55\x28\xd7\x06\xde\x26\xe4\x06\xd7\x29\xd8\x06\x63\x28\xd8\x06\xdd\x26\xd5\x06\x4b\x29\xcf\x06\x63\x28\xd3\x06\xc1\x26\xd1\x06\x1f\x29\xd0\x06\x25\x28\xc7\x06\x86\x26\xd1\x06\x04\x29\xd3\x06\x1b\x28\xda\x06\x7b\x26\xc9\x06\x00\x29\xc2\x06\x13\x28\xcd\x06\x96\x26\xdc\x06\xc4\x28\xdb\x06\x47\x28\xc8\x06\x5b\x26\xdc\x06\x5a\x29\xd4\x06\x4b\x28\xd2\x06\x37\x26\xdc\x06\x76\x29\xd9\x06\xd8\x27\xcb\x06\xed\x25\xe4\x06\xae\x29\xd4\x06\x3f\x28\xce\x06\x1f\x26\xe9\x06\xc6\x29\xe3\x06\x11\x28\xd6\x06\x3e\x26\xcf\x06\x32\x29\xcf\x06\x12\x28\xd2\x06\x11\x26\xdb\x06\x14\x29\xd4\x06\x89\x28\xce\x06\x91\x26\xde\x06\x3a\x29\xed\x06\x75\x28\xd2\x06\x9f\x26\xef\x06\xb8\x28\xe8\x06\x2a\x28\xdb\x06\xb8\x26\xd4\x06\x60\x28\xd2\x06\x35\x28\xcb\x06\x7f\x26\xdd\x06\xab\x28\xcf\x06\x78\x28\xd2\x06\xa6\x26\xc5\x06\x4c\x28\xcb\x06\xfd\x27\xd2\x06\x3c\x26\xc9\x06\x69\x28\xcc\x06\xc1\x27\xc4\x06\x18\x26\xbf\x06\xcb\x28\xc3\x06\x19\x28\xca\x06\x8a\x26\xc0\x06\xe2\x28\xbf\x06\x3f\x28\xd2\x06\x9b\x26\xe2\x06\xd0\x28\xd6\x06\x4a\x28\xd4\x06\xbd\x26\xd0\x06\xd5\x28\xd0\x06\x3d\x28\xd3\x06\xd3\x26\xd3\x06\x9c\x28\xd9\x06\x26\x28\xd2\x06\xde\x26\xe4\x06\x8c\x28\xe2\x06\x6c\x28\xd3\x06\xcf\x26\xe4\x06\x63\x28\xd7\x06\xd9\x27\xd2\x06\x3a\x26\xce\x06\x13\x28\xcf\x06\xd5\x27\xd1\x06\x63\x26\xd4\x06\x69\x28\xd8\x06\x7e\x28\xc5\x06\xcf\x26\xd8\x06\x79\x28\xd8\x06\x46\x28\xd8\x06\xd2\x26\xd3\x06\x79\x28\xd0\x06\x6e\x28\xc4\x06\xa7\x26\xd1\x06\xa1\x28\xdd\x06\x59\x28\xd1\x06\xd0\x26\xc7\x06\xc3\x28\xbf\x06\x76\x28\xd2\x06\xfb\x26\xce\x06\x69\x28\xcb\x06\x2a\x28\xd4\x06\xe5\x26\xcd\x06\x7f\x28\xcc\x06\x64\x28\xd3\x06\xd7\x26\xe5\x06\xcd\x28\xeb\x06\xad\x28\xdb\x06\xfb\x26\xd5\x06\xcd\x28\xd9\x06\x68\x28\xca\x06\x0c\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd1\x06\x90\x28\xd2\x06\x52\x28\xd4\x06\xec\x26\xc4\x06\xdf\x28\xc4\x06\x2d\x28\xd1\x06\xc1\x26\xc8\x06\xd9\x28\xcc\x06\x5d\x28\xd0\x06\x0d\x27\xd2\x06\x60\x28\xcb\x06\x09\x28\xc8\x06\x71\x26\xb8\x06\xdb\x28\xa4\x06\x9c\x28\xb1\x06\x02\x27\xc5\x06\x2d\x29\xc4\x06\x89\x28\xd4\x06\xd0\x26\xd9\x06\x27\x29\xd8\x06\x07\x28\xe2\x06\xe8\x26\xdc\x06\xef\x29\xd4\x06\x1f\x28\xd5\x06\x07\x27\xd9\x06\x2c\x2a\xd2\x06\x19\x28\xd3\x06\xf4\x26\xd7\x06\x42\x29\xd3\x06\x35\x28\xcc\x06\xf7\x26\xd3\x06\x60\x28\xd0\x06\x09\x28\xc7\x06\x3e\x26\xce\x06\x99\x28\xc1\x06\x96\x27\xca\x06\x62\x26\xe3\x06\xdd\x28\xde\x06\x35\x28\xd2\x06\xaa\x26\xd4\x06\xec\x28\xc0\x06\x85\x28\xc3\x06\xab\x26\xcc\x06\x18\x29\xc6\x06\x36\x28\xc2\x06\xad\x26\xc2\x06\xd7\x28\xb7\x06\x35\x28\xcf\x06\xc4\x26\xd0\x06\xae\x28\xd3\x06\x41\x28\xca\x06\xe8\x26\xd7\x06\x57\x28\xd4\x06\x0a\x28\xd0\x06\x71\x26\xd8\x06\x72\x28\xd5\x06\xf6\x27\xd0\x06\x5b\x26\xc9\x06\xa2\x28\xc6\x06\x7d\x28\xd2\x06\xd7\x26\xd5\x06\xaa\x28\xd0\x06\x1b\x28\xd3\x06\xc1\x26\xc3\x06\xd6\x28\xd7\x06\x4a\x28\xca\x06\xbd\x26\xcd\x06\xe8\x28\xd4\x06\x3d\x28\xd4\x06\xed\x26\xd7\x06\xc4\x28\xd7\x06\xba\x28\xd4\x06\x03\x27\xc4\x06\xa1\x28\xc8\x06\x71\x28\xd2\x06\xd9\x26\xd2\x06\x17\x28\xcf\x06\xe2\x27\xd3\x06\x69\x26\xba\x06\x9d\x28\xb8\x06\x64\x28\xd2\x06\xef\x26\xc8\x06\xf7\x28\xce\x06\x94\x28\xc2\x06\x05\x27\xc2\x06\xec\x28\xd1\x06\x72\x28\xcc\x06\xef\x26\xdb\x06\xd4\x28\xd3\x06\x1d\x28\xe0\x06\x01\x27\xd5\x06\xbb\x28\xd9\x06\x81\x28\xd6\x06\xb6\x26\xc1\x06\x22\x29\xbf\x06\x76\x28\xd3\x06\x94\x26\xd8\x06\x7d\x28\xcb\x06\x14\x28\xcb\x06\x49\x26\xd1\x06\xa2\x28\xcd\x06\x1e\x28\xce\x06\x7b\x26\xd1\x06\xca\x28\xd9\x06\xd9\x28\xd0\x06\xd7\x26\xc6\x06\xda\x28\xc7\x06\x80\x28\xc8\x06\xe1\x26\xcc\x06\x98\x28\xd3\x06\x56\x28\xc9\x06\xaa\x26\xd2\x06\xe8\x28\xd1\x06\x8b\x28\xca\x06\xeb\x26\xd9\x06\xbb\x28\xcc\x06\x4e\x28\xcb\x06\xb3\x26\xca\x06\x5c\x28\xd4\x06\x0f\x28\xc3\x06\x40\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd2\x06\xaf\x28\xda\x06\x57\x28\xc2\x06\x62\x26\xce\x06\xe5\x28\xca\x06\xa2\x28\xcc\x06\xbc\x26\xc5\x06\xe6\x28\xcc\x06\x54\x28\xc2\x06\xcc\x26\xe1\x06\xd3\x28\xdd\x06\xa3\x28\xe3\x06\x0d\x27\xd6\x06\xb0\x28\xde\x06\x8b\x28\xc7\x06\xb5\x26\xcd\x06\xa5\x28\xca\x06\x81\x28\xd9\x06\xf0\x26\xcd\x06\x98\x28\xd1\x06\x3c\x28\xcf\x06\x57\x26\xdc\x06\xb1\x28\xd1\x06\xdf\x27\xdc\x06\x92\x26\xdc\x06\xd7\x28\xdb\x06\x58\x28\xd0\x06\xc5\x26\xb7\x06\x34\x29\xb4\x06\xb0\x28\xd5\x06\x31\x27\xd0\x06\xcb\x28\xd8\x06\x89\x28\xd0\x06\xcf\x26\xd6\x06\x14\x29\xd5\x06\x6c\x28\xd4\x06\xef\x26\xc8\x06\x16\x29\xbd\x06\xb3\x28\xc8\x06\x1f\x27\xd5\x06\xf2\x28\xd9\x06\xc4\x28\xd2\x06\xe8\x26\xaa\x06\xe9\x28\xb2\x06\x8e\x28\xc4\x06\xb9\x26\xcf\x06\x0d\x29\xd6\x06\xcf\x28\xcc\x06\xf3\x26\xc7\x06\x12\x29\xc3\x06\x8e\x28\xc9\x06\xef\x26\xcb\x06\xd6\x28\xd4\x06\x83\x28\xc4\x06\xe8\x26\xc9\x06\x22\x29\xcc\x06\xb6\x28\xcb\x06\xe8\x26\xdc\x06\x3a\x29\xd8\x06\x92\x28\xd1\x06\x15\x27\xce\x06\x01\x29\xc8\x06\x8a\x28\xd1\x06\xde\x26\xdf\x06\xbb\x28\xd6\x06\x3f\x28\xcc\x06\xba\x26\xd3\x06\xeb\x28\xd1\x06\xb2\x28\xc8\x06\x15\x27\xd9\x06\x40\x29\xdb\x06\xbd\x28\xd1\x06\x46\x27\xd2\x06\x30\x29\xd4\x06\xde\x28\xe3\x06\x5d\x27\xda\x06\x12\x29\xd5\x06\x9f\x28\xc8\x06\x11\x27\xd3\x06\x1c\x29\xd5\x06\xb6\x28\xcb\x06\x3a\x27\xc4\x06\xfc\x28\xc4\x06\x6c\x28\xcb\x06\x26\x27\xc8\x06\xae\x28\xc8\x06\x60\x28\xc2\x06\x54\x26\xd4\x06\xe3\x28\xcf\x06\x9a\x28\xdd\x06\xf8\x26\xcb\x06\xec\x28\xca\x06\xbf\x28\xc2\x06\x14\x27\xc6\x06\xa0\x28\xca\x06\x9f\x28\xc4\x06\xfe\x26\xd4\x06\xd8\x28\xd3\x06\x7c\x28\xc3\x06\xa3\x26\xc9\x06\xf0\x28\xdc\x06\xb6\x28\xd3\x06\xde\x26\xc7\x06\xc9\x28\xcc\x06\x68\x28\xcc\x06\xba\x26\xc9\x06\x59\x28\xcc\x06\xd9\x27\xc7\x06\x4b\x26\xda\x06\x70\x28\xcb\x06\x1c\x28\xbe\x06\x45\x26\xd5\x06\xb2\x28\xcf\x06\x46\x28\xd2\x06\xd4\x26\xcd\x06\xb9\x28\xda\x06\xbe\x28\xcf\x06\xda\x26\xd7\x06\xc5\x28\xcf\x06\xcf\x28\xcd\x06\xed\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcf\x06\xba\x28\xd4\x06\x70\x28\xd2\x06\xc5\x26\xb4\x06\xc0\x28\xb7\x06\x97\x28\xca\x06\xe2\x26\xeb\x06\x7d\x28\xe0\x06\x20\x28\xe1\x06\x5e\x26\xcc\x06\x4f\x28\xdd\x06\x12\x28\xbf\x06\x49\x26\xc6\x06\x91\x28\xc8\x06\x33\x28\xc1\x06\xa2\x26\xcb\x06\xaa\x28\xd5\x06\x5e\x28\xcd\x06\xfb\x26\xdc\x06\xf5\x28\xd5\x06\xd7\x28\xd3\x06\xed\x26\xe9\x06\x10\x29\xde\x06\x9b\x28\xdf\x06\x01\x27\xd8\x06\x17\x29\xc7\x06\xb6\x28\xc7\x06\xbd\x26\xcf\x06\xc8\x28\xd5\x06\x58\x28\xc9\x06\x5e\x26\xcb\x06\x76\x28\xcd\x06\x3f\x28\xca\x06\x6c\x26\xd4\x06\xd9\x28\xd2\x06\x89\x28\xce\x06\xed\x26\xc0\x06\xe7\x28\xcd\x06\x9c\x28\xb9\x06\xe2\x26\xdc\x06\x51\x29\xd5\x06\xa8\x28\xcd\x06\xab\x26\xcf\x06\x31\x29\xcf\x06\x5a\x28\xce\x06\xc1\x26\xd9\x06\x32\x29\xd7\x06\x79\x28\xc9\x06\xab\x26\xd5\x06\xed\x28\xdf\x06\x42\x28\xd1\x06\x2b\x26\xd6\x06\xff\x28\xcd\x06\x0b\x28\xd4\x06\x36\x26\xd7\x06\x0a\x29\xd2\x06\x74\x28\xbe\x06\x8d\x26\xce\x06\x3a\x29\xd3\x06\xfa\x28\xce\x06\xd4\x26\xc8\x06\x38\x29\xc9\x06\x8f\x28\xbf\x06\xfe\x26\xdb\x06\x10\x29\xd9\x06\x7f\x28\xcf\x06\xce\x26\xe3\x06\x45\x29\xd7\x06\xa1\x28\xcf\x06\xd2\x26\xce\x06\x0c\x29\xd1\x06\x79\x28\xc9\x06\xe0\x26\xc3\x06\xce\x28\xc5\x06\x16\x28\xcb\x06\x8d\x26\xd0\x06\x17\x29\xd1\x06\xa4\x28\xc7\x06\xfb\x26\xda\x06\x7f\x29\xd7\x06\x6e\x28\xd7\x06\x27\x27\xca\x06\x2a\x29\xc6\x06\x9b\x28\xc3\x06\xf6\x26\xdc\x06\x4a\x29\xd8\x06\x87\x28\xd4\x06\x0e\x27\xe0\x06\x80\x29\xde\x06\x8f\x28\xd5\x06\xff\x26\xd0\x06\x4e\x29\xce\x06\xac\x28\xd6\x06\x10\x27\xd0\x06\xc6\x28\xd8\x06\x7b\x28\xca\x06\xe2\x26\xd7\x06\x15\x29\xdb\x06\x88\x28\xcd\x06\xcf\x26\xd4\x06\x6a\x29\xde\x06\xa8\x28\xd1\x06\x11\x27\xeb\x06\x1b\x29\xcd\x06\xd5\x28\xe2\x06\x20\x27\xd4\x06\x29\x29\xcf\x06\x75\x28\xd2\x06\x1e\x27\xd0\x06\x12\x29\xd8\x06\x7d\x28\xce\x06\x07\x27\xe3\x06\x08\x29\xd8\x06\x84\x28\xd3\x06\xf0\x26\xd6\x06\xad\x28\xda\x06\x2a\x28\xde\x06\xb3\x26\xda\x06\xa2\x28\xd3\x06\x3f\x28\xd8\x06\xb8\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe0\x06\xff\x28\xdd\x06\xa0\x28\xdd\x06\x22\x27\xd2\x06\x2a\x29\xd2\x06\xe3\x28\xc9\x06\xff\x26\xeb\x06\x81\x29\xe0\x06\x72\x28\xd0\x06\xf0\x26\xdc\x06\x40\x29\xcd\x06\x81\x28\xdd\x06\x41\x27\xd1\x06\x32\x29\xcd\x06\xbb\x28\xc9\x06\xd3\x26\xc4\x06\x90\x28\xca\x06\x12\x28\xc1\x06\x99\x26\xbe\x06\x78\x28\xbb\x06\x0a\x28\xc5\x06\x75\x26\xdb\x06\x30\x29\xd2\x06\x81\x28\xc0\x06\xf4\x26\xd7\x06\x37\x29\xce\x06\x97\x28\xcf\x06\x3f\x27\xcc\x06\x7c\x29\xb8\x06\xb4\x28\xc5\x06\x14\x27\xc7\x06\xbf\x29\xcf\x06\xf2\x28\xdc\x06\x86\x27\xd7\x06\x5f\x29\xde\x06\xfa\x28\xd3\x06\x2f\x27\xd5\x06\x87\x29\xc8\x06\xba\x28\xd8\x06\x3a\x27\xc3\x06\x5b\x29\xbf\x06\x97\x28\xd0\x06\xf7\x26\xdf\x06\xe6\x29\xd1\x06\xc3\x28\xd6\x06\x60\x27\xe0\x06\xd5\x29\xd3\x06\xdb\x28\xd0\x06\x65\x27\xc1\x06\xe7\x29\xc2\x06\xd3\x28\xc2\x06\x1f\x27\xdd\x06\xda\x29\xd1\x06\x89\x28\xc9\x06\x26\x27\xd7\x06\xc6\x29\xd8\x06\xe8\x28\xe3\x06\x89\x27\xf1\x06\x86\x29\xe7\x06\x61\x28\xfe\x06\x23\x27\x1c\x07\x82\x28\x17\x07\xe3\x27\x1a\x07\x7f\x26\x2b\x07\xa3\x28\x26\x07\x13\x28\x16\x07\x23\x26\x07\x07\xcb\x28\xf7\x06\x7b\x27\xf1\x06\xe2\x25\x18\x06\x70\x28\x2a\x06\x60\x27\x09\x06\x97\x24\x14\x06\xd7\x28\x18\x06\xaa\x27\xfc\x05\x10\x25\xa0\x06\x57\x28\x98\x06\x03\x28\x98\x06\x44\x26\x09\x07\xd5\x28\x0f\x07\x0b\x28\x1e\x07\x20\x27\x10\x07\x62\x29\xf0\x06\x70\x28\xed\x06\x44\x27\xdb\x06\xa4\x29\xd2\x06\xec\x28\xd0\x06\x9a\x27\xb6\x06\xf2\x29\xb1\x06\xec\x28\xc2\x06\xc1\x27\xb5\x06\x1a\x2a\xa7\x06\x51\x29\xa9\x06\xce\x27\xb5\x06\x34\x2a\xaa\x06\xd4\x28\xb0\x06\xd1\x27\xb9\x06\xd8\x29\xb0\x06\xed\x28\xb0\x06\xd5\x27\xae\x06\xd4\x29\xa3\x06\xe4\x28\xaf\x06\xb0\x27\xc7\x06\xbd\x29\xb7\x06\xec\x28\xbd\x06\xdf\x27\xbd\x06\x08\x2a\xb6\x06\x05\x29\xb5\x06\xef\x27\xbc\x06\x38\x2a\xad\x06\x63\x29\xb2\x06\xd9\x27\xb2\x06\x87\x2a\xa0\x06\x58\x29\xb1\x06\xe3\x27\xb9\x06\x9f\x29\xb2\x06\xea\x28\xae\x06\x96\x27\xb7\x06\x67\x29\xb5\x06\xfd\x28\xb6\x06\x95\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xaf\x06\x92\x29\xa1\x06\xaa\x28\xb1\x06\x87\x27\xb6\x06\x8c\x29\xb5\x06\x18\x29\xb6\x06\x97\x27\xb8\x06\x65\x29\xc0\x06\x1c\x29\xb9\x06\xba\x27\xba\x06\x85\x29\xbe\x06\x18\x29\xc1\x06\x03\x28\xb8\x06\xbd\x29\xb2\x06\x54\x29\xbd\x06\xae\x27\xb5\x06\x46\x29\xb3\x06\xe0\x28\xb5\x06\x70\x27\xc3\x06\x4b\x29\xbe\x06\x9a\x28\xc5\x06\x44\x27\xaf\x06\x20\x29\xb1\x06\xa2\x28\xbb\x06\x47\x27\xae\x06\x04\x29\xae\x06\xb6\x28\xb3\x06\x8b\x27\xb7\x06\x8a\x29\xa9\x06\x09\x29\xb7\x06\x7c\x27\xb3\x06\xde\x29\xb1\x06\x38\x29\xb5\x06\xe1\x27\xae\x06\x3e\x2a\xa8\x06\x74\x29\xad\x06\xcb\x27\xb3\x06\xab\x29\xad\x06\xb2\x28\xb4\x06\x8a\x27\xb3\x06\x23\x29\xb2\x06\x99\x28\xc3\x06\x5e\x27\xaa\x06\x27\x29\xa9\x06\xa8\x28\xae\x06\x35\x27\xb2\x06\x04\x29\xc0\x06\x76\x28\xb8\x06\x34\x27\xb5\x06\x04\x29\xb7\x06\x71\x28\xac\x06\x09\x27\xb0\x06\x62\x29\xb4\x06\x71\x28\xb2\x06\x8b\x27\xb7\x06\xd8\x29\xb2\x06\xfd\x28\xac\x06\x68\x27\x9a\x06\x8a\x29\x8c\x06\xa2\x28\xae\x06\x33\x27\xa6\x06\xee\x28\xaa\x06\x66\x28\xb6\x06\x0e\x27\xac\x06\x14\x29\xa8\x06\x76\x28\xa5\x06\x3d\x27\xb0\x06\xf3\x28\xad\x06\x6a\x28\xae\x06\xff\x26\x9f\x06\x0b\x29\x94\x06\x2b\x28\xab\x06\x0a\x27\xb4\x06\x76\x29\xb3\x06\x70\x28\xa9\x06\x2f\x27\xc0\x06\xe9\x29\xaf\x06\xa5\x28\xb5\x06\x8e\x27\xa8\x06\xb2\x29\xa1\x06\xb2\x28\xa5\x06\x93\x27\xa7\x06\x3a\x29\xa8\x06\x56\x28\xa7\x06\x38\x27\x9d\x06\xfc\x28\xa3\x06\x85\x28\xa8\x06\x0f\x27\xaf\x06\xfd\x28\xb5\x06\x69\x28\xb5\x06\x32\x27\xac\x06\x17\x29\xab\x06\x70\x28\xb4\x06\x24\x27\xae\x06\x0d\x29\xa9\x06\x85\x28\xab\x06\x1e\x27\x93\x06\x5c\x29\x95\x06\xcd\x28\xb3\x06\x8b\x27\xa8\x06\x2d\x29\x98\x06\x7e\x28\xa6\x06\x81\x27\xa0\x06\xbb\x28\xa6\x06\x54\x28\xb7\x06\x23\x27\xa1\x06\x7f\x28\xa5\x06\x41\x28\x9b\x06\xd8\x26\x9e\x06\x17\x29\x96\x06\x2b\x28\xb0\x06\xe0\x26\xb2\x06\xb8\x28\xb1\x06\x32\x28\xaf\x06\x33\x27\xad\x06\xeb\x28\xa7\x06\x4b\x28\xa2\x06\x0a\x27\xa6\x06\xd5\x28\xaf\x06\xad\x28\xb2\x06\x21\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x93\x06\xe7\x28\x8c\x06\x79\x28\xa3\x06\xee\x26\xc2\x06\x6c\x28\xb7\x06\x41\x28\xb1\x06\xe6\x26\x97\x06\x1d\x29\x90\x06\xee\x27\xa1\x06\xc5\x26\xb0\x06\x85\x28\xa8\x06\x26\x28\xb0\x06\xb2\x26\xb2\x06\x5e\x28\x9f\x06\xc7\x27\xa8\x06\xa5\x26\xa2\x06\xae\x28\x9b\x06\x17\x28\xad\x06\xb0\x26\xa6\x06\x9c\x28\xba\x06\x1b\x28\xa7\x06\x83\x26\xb1\x06\x3c\x28\xb2\x06\xca\x27\xa7\x06\x5c\x26\xaf\x06\xb5\x28\xa8\x06\x05\x28\xa5\x06\x9b\x26\xb5\x06\xa8\x28\xb4\x06\xcf\x27\xa0\x06\x7f\x26\xa0\x06\x76\x28\x96\x06\xad\x27\x9f\x06\x70\x26\xac\x06\xaf\x28\xb2\x06\x58\x28\xa7\x06\xaf\x26\xa3\x06\x9d\x28\x97\x06\x4a\x28\xa4\x06\xd4\x26\xb5\x06\xdb\x28\xae\x06\x42\x28\xb4\x06\xdb\x26\xad\x06\x31\x29\xa3\x06\x5c\x28\xad\x06\xcb\x26\xae\x06\xa0\x28\xa7\x06\x33\x28\xb2\x06\xd6\x26\xaf\x06\x7f\x28\xb0\x06\x2a\x28\xa4\x06\xb2\x26\xbc\x06\x9d\x28\xb2\x06\xbf\x27\xb6\x06\xaa\x26\xab\x06\xd5\x28\xa9\x06\x0f\x28\xa4\x06\xc8\x26\xae\x06\xad\x28\xb1\x06\x37\x28\x9e\x06\x99\x26\xad\x06\xc4\x28\xb3\x06\x56\x28\xad\x06\x2a\x27\xae\x06\x3d\x29\xa7\x06\x90\x28\xb3\x06\x1d\x27\xb4\x06\xea\x28\xb2\x06\x49\x28\xb3\x06\xe2\x26\xb4\x06\xe7\x28\xae\x06\x61\x28\xb8\x06\xdc\x26\x8d\x06\xfe\x28\x8b\x06\x11\x28\x9d\x06\xe6\x26\xa1\x06\xc4\x28\x99\x06\xff\x27\xa9\x06\xc5\x26\xaf\x06\xc0\x28\xb0\x06\x47\x28\xab\x06\xee\x26\xb1\x06\x06\x29\xad\x06\x85\x28\xb2\x06\xd6\x26\xae\x06\x51\x29\xa4\x06\x5c\x28\xa9\x06\xf0\x26\xb4\x06\x65\x29\xb3\x06\xda\x28\xaf\x06\xfc\x26\xb8\x06\x2d\x29\xad\x06\x64\x28\xb4\x06\xae\x26\xab\x06\xaf\x28\xb2\x06\xff\x27\xb4\x06\xb2\x26\xaa\x06\xcc\x28\xb5\x06\x2e\x28\xa6\x06\xac\x26\xa4\x06\xd0\x28\x9d\x06\x35\x28\xa9\x06\xd3\x26\xb4\x06\xef\x28\xb7\x06\x68\x28\xb7\x06\xd0\x26\xad\x06\x3d\x29\xad\x06\xa6\x28\xb6\x06\xd8\x26\xa9\x06\x54\x29\xa4\x06\x92\x28\xb1\x06\x08\x27\xb7\x06\x00\x29\xaa\x06\x3f\x28\xaa\x06\xb9\x26\xa1\x06\xbf\x28\xa7\x06\x79\x28\xae\x06\xd4\x26\xa9\x06\xa6\x28\xb0\x06\x68\x28\xac\x06\xbc\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb3\x06\xce\x28\xb0\x06\x1a\x28\xa4\x06\x94\x26\xb4\x06\xd5\x28\xb3\x06\x46\x28\xb6\x06\xe6\x26\x9c\x06\xee\x28\x92\x06\x29\x28\xaa\x06\xf5\x26\xa8\x06\x0b\x29\xa7\x06\x39\x28\xb0\x06\x12\x27\xb4\x06\xdd\x28\xa5\x06\x0a\x28\x9f\x06\xf2\x26\xb3\x06\xd0\x28\xad\x06\x52\x28\xb7\x06\x08\x27\xb6\x06\xdf\x28\xac\x06\x3e\x28\xa5\x06\xb5\x26\xa5\x06\xec\x28\xa6\x06\x82\x28\xa3\x06\xc9\x26\xb4\x06\x30\x29\xb2\x06\x3f\x28\xab\x06\x04\x27\xa0\x06\xad\x29\xa0\x06\xd2\x28\xb8\x06\x2f\x27\xbc\x06\xfa\x29\xad\x06\x4d\x29\xb3\x06\x99\x27\xaf\x06\x81\x29\xaf\x06\x9c\x28\xb6\x06\x42\x27\xb4\x06\x28\x29\xaa\x06\x8e\x28\xa3\x06\xee\x26\xae\x06\xea\x28\xae\x06\x81\x28\xaa\x06\xf6\x26\xbe\x06\x29\x29\xbe\x06\x95\x28\xb2\x06\xe0\x26\xa3\x06\x10\x29\xa5\x06\xdd\x28\xbc\x06\x0c\x27\xaf\x06\x69\x29\xaa\x06\xa1\x28\xae\x06\x0b\x27\xc6\x06\xa5\x29\xb9\x06\xf9\x28\xb1\x06\x68\x27\xab\x06\x21\x29\xa4\x06\xc1\x28\xaf\x06\xe2\x26\xb5\x06\xcc\x28\xb0\x06\x09\x28\xb7\x06\xc1\x26\xa9\x06\xab\x28\xaa\x06\x32\x28\xaf\x06\x97\x26\xaf\x06\xe6\x28\xb1\x06\x0b\x28\xae\x06\xab\x26\xbb\x06\xdd\x28\xb4\x06\xf7\x27\xb9\x06\xee\x26\xb2\x06\xc0\x28\xb9\x06\x43\x28\xb1\x06\xc2\x26\xb1\x06\x27\x29\xbc\x06\xb9\x28\xb8\x06\x40\x27\xb3\x06\x25\x29\xb1\x06\x62\x28\xb5\x06\x01\x27\xad\x06\xba\x28\xa3\x06\xf9\x27\xac\x06\xeb\x26\xaf\x06\x9f\x28\xb5\x06\x03\x28\xb7\x06\xba\x26\xa9\x06\xc5\x28\xb6\x06\x1d\x28\xad\x06\xb6\x26\xb3\x06\x6a\x28\xb7\x06\xdb\x27\xb0\x06\xb5\x26\x97\x06\xdd\x28\x8f\x06\xf9\x27\xba\x06\x85\x26\xac\x06\x00\x29\xaf\x06\x2a\x28\xb3\x06\xb3\x26\xa9\x06\x11\x29\xaa\x06\x3f\x28\xa4\x06\xb5\x26\xae\x06\x0d\x29\xab\x06\x13\x28\xb2\x06\x9b\x26\xa6\x06\xf6\x28\x9c\x06\xf6\x27\xbb\x06\xa7\x26\xab\x06\x18\x29\x97\x06\xd6\x27\xac\x06\x78\x26\xa8\x06\x3f\x29\xac\x06\x20\x29\xb3\x06\x98\x26\xab\x06\x30\x29\xa8\x06\x71\x28\xb1\x06\xd3\x26\xb9\x06\xe0\x29\xb6\x06\x69\x28\xad\x06\xff\x26\xb3\x06\xb8\x2a\xac\x06\x62\x28\xb1\x06\x38\x27\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb2\x06\x3b\x2a\xb2\x06\x6c\x28\xb4\x06\x35\x27\xbc\x06\x9a\x29\xb3\x06\x66\x28\xac\x06\xae\x26\xaa\x06\x10\x29\xb8\x06\x79\x28\xab\x06\xa7\x26\xab\x06\xd5\x28\xb0\x06\x5a\x28\xad\x06\x98\x26\xab\x06\xe0\x28\xaf\x06\x3b\x28\xac\x06\xa6\x26\xa9\x06\x17\x29\xb2\x06\x86\x28\xb2\x06\xe5\x26\xaf\x06\x5b\x29\xb1\x06\xbe\x28\xb2\x06\x42\x27\xb6\x06\x1a\x29\xb2\x06\x3d\x28\xb7\x06\xc0\x26\xa8\x06\xd9\x28\xb2\x06\x70\x28\xa9\x06\x91\x26\xab\x06\x88\x28\xaa\x06\xe8\x28\xb0\x06\x99\x26\xb1\x06\xc9\x28\xa7\x06\x4d\x28\xaa\x06\xd0\x26\xac\x06\xc5\x28\xab\x06\x6a\x28\xa9\x06\xbe\x26\xa1\x06\xf0\x28\xa1\x06\x84\x28\xb0\x06\xd3\x26\xb5\x06\x17\x29\xba\x06\x02\x29\xb8\x06\x31\x27\xa4\x06\x18\x29\x9a\x06\x52\x28\x95\x06\xf0\x26\xb7\x06\xba\x28\xb4\x06\x41\x28\xa7\x06\xaf\x26\xbb\x06\xf8\x28\xaf\x06\x52\x28\xa9\x06\xa8\x26\xbb\x06\xfb\x28\xb1\x06\xa1\x28\xae\x06\xae\x26\xa5\x06\xf3\x28\xa7\x06\x6c\x28\xb2\x06\x17\x27\xbd\x06\xd3\x28\xb7\x06\xa6\x28\xb9\x06\xdc\x26\xb8\x06\x92\x29\xb9\x06\xc0\x28\xbc\x06\x40\x27\xa4\x06\x52\x29\xa9\x06\x6d\x28\xb8\x06\x49\x27\xbc\x06\xb0\x28\xb1\x06\x3f\x28\xb9\x06\xf8\x26\xbb\x06\x0c\x29\xb5\x06\x32\x28\xb6\x06\xc0\x26\xa2\x06\xd5\x28\xa8\x06\x1b\x28\xb9\x06\x4e\x27\xc2\x06\x22\x29\xbb\x06\x37\x28\xb2\x06\xb1\x26\xb8\x06\xb2\x28\xb4\x06\xce\x28\xb4\x06\xe7\x26\xb4\x06\xfe\x28\xb4\x06\x7e\x28\xa7\x06\xf8\x26\xa3\x06\x0a\x29\xb3\x06\xa8\x28\xbd\x06\x46\x27\xb2\x06\xbf\x28\xae\x06\x7c\x28\xb5\x06\x0a\x27\xba\x06\xf8\x28\xbf\x06\x45\x28\xbd\x06\xdb\x26\xb0\x06\x10\x29\xa6\x06\x39\x28\xac\x06\xeb\x26\xb5\x06\x7b\x29\xb1\x06\x71\x28\xaa\x06\xeb\x26\xb6\x06\xeb\x29\xb2\x06\xa6\x28\xb8\x06\x0b\x27\xb7\x06\x50\x2a\x99\x06\xc4\x28\xb4\x06\x30\x27\xb5\x06\x15\x2a\xa6\x06\x07\x29\xb5\x06\x58\x27\xa6\x06\x3b\x29\xa9\x06\x7e\x28\xab\x06\xed\x26\xaf\x06\xac\x28\xaf\x06\x74\x28\xaf\x06\xb7\x26\xc1\x06\x9e\x28\xbf\x06\x42\x28\xb5\x06\xba\x26\xab\x06\xe1\x28\xaf\x06\x66\x28\xad\x06\xb6\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc0\x06\x38\x29\xb4\x06\x39\x28\xab\x06\xab\x26\xb4\x06\x6a\x29\xb9\x06\x38\x28\xad\x06\xaf\x26\x9c\x06\x04\x2a\x92\x06\x7c\x28\xa9\x06\x13\x27\xbc\x06\x11\x2a\xa4\x06\x03\x28\xb5\x06\xf1\x26\xb6\x06\xc7\x29\xb4\x06\x24\x28\xac\x06\xd1\x26\xaa\x06\xc2\x29\x9c\x06\x16\x28\xa4\x06\xaa\x26\xa2\x06\x4e\x29\x9b\x06\x24\x28\xb3\x06\x69\x26\xb7\x06\x10\x29\xb0\x06\x56\x28\xbd\x06\x7f\x26\xc5\x06\x56\x29\xaf\x06\x49\x28\xb2\x06\x91\x26\xba\x06\x3a\x2a\xb9\x06\x8e\x28\xae\x06\x13\x27\x93\x06\x01\x2a\x8c\x06\x7c\x28\xad\x06\x77\x26\x99\x06\x45\x29\xa2\x06\x61\x28\xaf\x06\x42\x26\xb7\x06\x4d\x29\xb0\x06\x1f\x28\xac\x06\x1b\x26\x98\x06\x1c\x29\x9a\x06\x29\x28\xaa\x06\xf8\x25\xaf\x06\xd3\x28\xa2\x06\x0b\x28\xae\x06\x16\x26\xa6\x06\xf7\x28\x9c\x06\x15\x28\xb6\x06\x55\x26\xa1\x06\xea\x28\xac\x06\x65\x28\xb5\x06\x78\x26\xa9\x06\x35\x29\xa8\x06\x29\x28\xa1\x06\x5c\x26\xb4\x06\x2e\x29\xa2\x06\xfa\x27\xa3\x06\xfc\x25\xb5\x06\x10\x29\xaf\x06\xf1\x27\xa9\x06\xbd\x25\xaa\x06\x1f\x29\xa4\x06\x9f\x27\xa1\x06\x5e\x25\xab\x06\xc4\x28\xae\x06\x69\x27\xa6\x06\x31\x25\xa9\x06\xfa\x28\x92\x06\x3f\x27\xa0\x06\x4b\x25\xaa\x06\x37\x29\xae\x06\x88\x27\xa2\x06\x99\x25\xa3\x06\xbf\x28\xa9\x06\xfc\x27\xa2\x06\x12\x26\xac\x06\x9c\x28\xa7\x06\xe9\x27\xa5\x06\x55\x26\xb4\x06\x8b\x28\xb1\x06\xde\x27\xb4\x06\x3c\x26\xa6\x06\xa5\x28\xa3\x06\xf0\x27\xa2\x06\x60\x26\xac\x06\x7b\x28\xae\x06\xdb\x27\xbb\x06\x4a\x26\xa4\x06\xe9\x28\x9b\x06\x23\x28\xb5\x06\x7f\x26\xbe\x06\x00\x29\xc4\x06\x66\x28\xb2\x06\xbd\x26\xbd\x06\x4b\x29\xb7\x06\xe5\x28\xb4\x06\xfc\x26\x91\x06\x75\x29\x8e\x06\x75\x28\xa9\x06\xf2\x26\x91\x06\x2b\x29\x7a\x06\x34\x28\xa0\x06\xab\x26\xaf\x06\xd6\x28\xad\x06\x43\x28\xa7\x06\x9b\x26\x9d\x06\xcf\x28\x9a\x06\x10\x28\xb3\x06\xac\x26\xb5\x06\x03\x29\xbb\x06\xfb\x27\xb6\x06\x99\x26\xbc\x06\x0d\x29\xbd\x06\x33\x28\xaa\x06\xb6\x26\xb7\x06\x37\x29\xb8\x06\x36\x28\xad\x06\xbd\x26\x85\x06\xc0\x28\x82\x06\x28\x28\xb1\x06\x98\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa8\x06\xb0\x28\xa8\x06\xf5\x27\xa9\x06\x5d\x26\xac\x06\x81\x28\xad\x06\xd8\x27\xad\x06\x72\x26\xa6\x06\xca\x28\xa3\x06\xa2\x27\xa7\x06\x6d\x26\xb6\x06\xe9\x28\xb0\x06\x9a\x27\xb5\x06\x86\x26\xae\x06\x09\x29\xa3\x06\x2d\x28\xad\x06\x7f\x26\xb4\x06\x6e\x29\xb7\x06\x8f\x28\xbd\x06\xe1\x26\xbb\x06\x5d\x29\xb8\x06\x0d\x28\xae\x06\xb6\x26\xb8\x06\xf2\x28\xad\x06\xdd\x27\xad\x06\x6e\x26\x9f\x06\x6c\x28\x9d\x06\x15\x28\xaa\x06\x7a\x26\xb0\x06\xc7\x28\xaf\x06\xf7\x27\xbb\x06\x7b\x26\xbb\x06\x02\x29\xb4\x06\x26\x28\xb1\x06\xb6\x26\xc0\x06\xb8\x29\xb0\x06\x0f\x28\xc2\x06\xeb\x26\xc3\x06\x16\x2a\xb5\x06\x94\x28\xb7\x06\x04\x27\xbd\x06\x08\x2a\xb7\x06\x98\x28\xc7\x06\x2b\x27\xa1\x06\xc9\x29\xa2\x06\x52\x28\xb4\x06\x8a\x26\xbc\x06\x01\x29\xb4\x06\x1d\x28\xac\x06\x7f\x26\xad\x06\xe2\x28\xae\x06\x18\x28\xb1\x06\x72\x26\x9e\x06\xe7\x28\xa1\x06\x4e\x28\xac\x06\xaf\x26\x9e\x06\x37\x29\x95\x06\x4f\x28\xa5\x06\x91\x26\xc2\x06\xe4\x29\xb2\x06\x57\x28\xbb\x06\xf8\x26\xc5\x06\x1e\x2a\xb2\x06\xc9\x28\xaf\x06\x0e\x27\xaa\x06\x67\x29\xa6\x06\x6e\x28\xb0\x06\xbb\x26\xb0\x06\xe7\x28\xa4\x06\x33\x28\xae\x06\x65\x26\xbd\x06\x05\x29\xbb\x06\x18\x28\xad\x06\x2d\x26\xae\x06\xf8\x28\xa1\x06\xe2\x27\xac\x06\x19\x26\x9f\x06\x5b\x28\x9a\x06\x0e\x28\xa3\x06\xea\x25\xb9\x06\xd8\x28\xad\x06\x13\x28\xa8\x06\x16\x26\xae\x06\xa8\x29\x96\x06\x18\x28\xa9\x06\x15\x26\xb5\x06\x0b\x29\xb7\x06\xe1\x27\xae\x06\xd9\x25\xb1\x06\xcd\x28\xa5\x06\xb7\x27\xa8\x06\x7a\x25\x9f\x06\xa4\x28\x94\x06\x90\x27\xa5\x06\x96\x25\xb6\x06\xf2\x28\xaf\x06\xdc\x27\xb1\x06\xec\x25\xb2\x06\x25\x29\xa1\x06\xef\x27\xa4\x06\xf8\x25\xb7\x06\x19\x29\xbd\x06\x1d\x28\xa8\x06\x1c\x26\xa5\x06\x31\x29\xa5\x06\x97\x28\xa7\x06\x8c\x26\xa0\x06\xe8\x28\xa6\x06\x58\x28\xa5\x06\x7c\x26\xb6\x06\xe2\x28\xb0\x06\xed\x27\xaf\x06\x4f\x26\xb2\x06\xd7\x28\xb0\x06\x07\x28\xa7\x06\x4b\x26\xab\x06\x90\x28\xb5\x06\xe1\x27\xb1\x06\x36\x26\xaf\x06\x90\x28\xa8\x06\xc6\x27\xb8\x06\x30\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa6\x06\xea\x28\xaa\x06\xec\x27\xb0\x06\x24\x26\xaa\x06\x1b\x29\x9f\x06\x27\x28\xb2\x06\x81\x26\xab\x06\x10\x29\xaf\x06\xdc\x27\xba\x06\x60\x26\xb1\x06\xa0\x28\x99\x06\x8f\x27\xb5\x06\x26\x26\xad\x06\x72\x28\xaf\x06\xa9\x27\xb7\x06\x1b\x26\xa1\x06\x9f\x28\x9e\x06\xcf\x27\xb9\x06\xf0\x25\xbc\x06\x96\x28\xbf\x06\xfa\x27\xc2\x06\x4c\x26\xad\x06\xa5\x28\x91\x06\x89\x27\xa3\x06\xf3\x25\xa8\x06\xcb\x28\xa6\x06\xfe\x27\xb6\x06\x4b\x26\xad\x06\xd3\x28\xae\x06\xbf\x27\xad\x06\x06\x26\xb5\x06\xef\x28\xad\x06\xaf\x27\xb1\x06\x18\x26\xae\x06\x86\x28\xaa\x06\xa1\x27\xa6\x06\xd8\x25\xb6\x06\x53\x28\xb5\x06\xa7\x27\xbd\x06\xe4\x25\xa0\x06\xb6\x28\x9c\x06\xd4\x27\x97\x06\xaa\x25\x98\x06\xa8\x28\xa3\x06\xa0\x27\xb1\x06\xfb\x25\xa3\x06\x02\x29\x9b\x06\x42\x28\xb4\x06\xf3\x25\x98\x06\xff\x28\x86\x06\x2d\x28\xa6\x06\x5a\x26\xa5\x06\xc1\x28\xa2\x06\x08\x28\xac\x06\x11\x26\x9b\x06\xb1\x28\x9a\x06\x17\x28\x98\x06\x2a\x26\xc5\x06\xc3\x28\xad\x06\xbc\x27\xad\x06\x01\x26\xa8\x06\x69\x28\xaf\x06\xc2\x27\xab\x06\xff\x25\xa5\x06\x9e\x28\xab\x06\xc5\x27\xa7\x06\x38\x26\xa8\x06\xd8\x28\xa5\x06\xd2\x27\xa5\x06\x62\x26\xad\x06\x45\x29\xac\x06\x06\x28\xa9\x06\x90\x26\xb7\x06\xc4\x28\xb4\x06\xa3\x27\xb3\x06\x48\x26\x95\x06\x51\x28\x99\x06\xbb\x27\xa4\x06\x27\x26\xa6\x06\x2b\x28\xac\x06\xc1\x27\xab\x06\x42\x26\xa7\x06\xb6\x28\xa2\x06\xaf\x27\x9e\x06\x1a\x26\xae\x06\xb2\x28\xa7\x06\xb2\x27\xb5\x06\x56\x26\x9b\x06\xe1\x28\x87\x06\xc3\x27\x99\x06\x86\x26\x93\x06\x43\x29\x90\x06\xfd\x27\xa9\x06\xf4\x26\xb0\x06\xbe\x28\xaf\x06\xed\x27\xae\x06\x69\x26\x96\x06\x5b\x28\x98\x06\x15\x28\xab\x06\x27\x26\xb0\x06\x3b\x28\xb0\x06\xb9\x27\xb5\x06\x4f\x26\x98\x06\x5e\x28\x92\x06\xe1\x27\x9a\x06\x63\x26\xac\x06\x5f\x28\xaa\x06\x04\x28\xae\x06\x6f\x26\xb3\x06\x9b\x28\xaf\x06\xf6\x27\xac\x06\x89\x26\xbc\x06\x23\x29\xb0\x06\x53\x28\xbd\x06\xed\x26\xac\x06\x14\x29\x9d\x06\x1c\x28\x9e\x06\xd1\x26\xa9\x06\xa8\x28\xb0\x06\x27\x28\xb1\x06\xa7\x26\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x9d\x06\x66\x28\xa2\x06\x3b\x28\x99\x06\x7b\x26\xb5\x06\x41\x28\xb9\x06\x1d\x28\xb9\x06\x4f\x26\xb0\x06\xcc\x28\xaf\x06\x53\x28\xb8\x06\x61\x26\xb6\x06\xbc\x28\xaa\x06\x36\x28\xa8\x06\x76\x26\xab\x06\x3f\x29\xa2\x06\xb6\x28\xa6\x06\xb8\x26\xbd\x06\x6f\x29\xb5\x06\xf7\x28\xbd\x06\x1a\x27\xa6\x06\x26\x29\x9a\x06\x5a\x28\xae\x06\xca\x26\xb1\x06\x42\x29\xb6\x06\x4b\x28\xb0\x06\x81\x26\xae\x06\x11\x29\xaf\x06\x46\x28\xad\x06\x7d\x26\xa2\x06\x35\x29\x9a\x06\x68\x28\xa9\x06\x83\x26\xb8\x06\xd7\x28\xbc\x06\x50\x28\xb5\x06\x99\x26\xaa\x06\x59\x29\xa9\x06\x73\x28\xa9\x06\xa7\x26\xb8\x06\xef\x29\xb7\x06\xf9\x28\xb3\x06\x44\x27\xaf\x06\x67\x29\xa9\x06\xa3\x28\xae\x06\x14\x27\xb2\x06\x45\x29\xae\x06\x5c\x28\xa7\x06\xb1\x26\xb7\x06\x82\x29\xad\x06\x74\x28\xb8\x06\x80\x26\xa6\x06\xa6\x29\xa9\x06\x7c\x28\xad\x06\xd6\x26\xb4\x06\xa6\x29\xa6\x06\x9f\x28\xac\x06\xb0\x26\xb4\x06\x19\x2a\xaf\x06\xdd\x28\xb9\x06\x0a\x27\xb7\x06\x7d\x2a\xab\x06\xf5\x28\xbd\x06\x82\x27\xb0\x06\x3f\x2a\xb1\x06\x98\x28\xb8\x06\xf0\x26\xc5\x06\xe8\x29\xbb\x06\x7d\x28\xb7\x06\xdb\x26\xb7\x06\xdd\x29\xac\x06\xa9\x28\xb6\x06\xbe\x26\xaa\x06\xf4\x29\x96\x06\x55\x28\xa9\x06\xa3\x26\xb9\x06\x2b\x2a\xb1\x06\x69\x28\xaf\x06\xdc\x26\xc4\x06\xd3\x29\xc3\x06\xb6\x28\xbb\x06\xed\x26\xc3\x06\x73\x2a\xb3\x06\x47\x29\xb1\x06\x48\x27\xb1\x06\x4c\x2a\xa5\x06\xc4\x28\xb7\x06\x17\x27\xba\x06\x95\x29\xae\x06\x5c\x28\xb4\x06\x98\x26\xa4\x06\x7f\x29\xaa\x06\x71\x28\xb5\x06\xb1\x26\xc6\x06\xb8\x29\xbd\x06\x7c\x28\xbd\x06\x98\x26\xb3\x06\xfc\x29\x9a\x06\x54\x28\xb5\x06\xe4\x26\xa3\x06\xcf\x29\x96\x06\x85\x28\xb2\x06\x24\x27\xbd\x06\xce\x29\xb3\x06\xa2\x28\xbf\x06\x39\x27\xa3\x06\x58\x29\xa1\x06\x5e\x28\xb6\x06\x21\x27\xb7\x06\xda\x28\xb9\x06\x17\x28\xb0\x06\x90\x26\xa4\x06\xa7\x29\x9a\x06\xf9\x27\xaa\x06\xda\x25\x00\x00\xa9\x14\x24\x08\xff\xff\x29\x08\xff\xff\x00\x00\xa9\x14\x00\x00\x5d\x15\x00\x00\xf9\x15\x00\x00\xa9\x14\x00\x00\x5d\x15\x00\x00\xfb\x15\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\xb9\x14\x00\x00\x5d\x15\x00\x00\x0d\x16\x00\x00\xb9\x14\x00\x00\x5e\x15\x00\x00\x0d\x16\x41\x08\xff\xff\x00\x00\x5f\x15\x44\x08\xff\xff\xb5\x06\x68\x28\xab\x06\xca\x26\x9e\x06\x85\x24\xc4\x06\xfd\x27\xb8\x06\xcb\x26\xa8\x06\x22\x25\xb6\x06\x43\x28\xb2\x06\x0b\x27\xb2\x06\x92\x25\xbd\x06\x5e\x28\xb4\x06\xd8\x26\xb1\x06\xb9\x25\xb9\x06\xba\x28\x97\x06\x15\x27\xb8\x06\xba\x25\xc0\x06\x59\x28\xaf\x06\x7a\x26\xb7\x06\x6a\x25\xb6\x06\xa9\x28\xa5\x06\xb3\x26\xa5\x06\x41\x25\xc2\x06\x75\x28\xbc\x06\xd5\x26\xbb\x06\x04\x26\xb4\x06\x50\x28\xad\x06\xac\x26\xbb\x06\xc5\x25\xb2\x06\x81\x28\xae\x06\xcb\x26\xb0\x06\x95\x25\xaa\x06\x72\x28\xa5\x06\x8c\x26\xbc\x06\x86\x25\xc0\x06\x9c\x28\xb2\x06\x7b\x26\xaa\x06\x75\x25\xb0\x06\x9d\x28\x9d\x06\x7d\x26\xb3\x06\x43\x25\xc5\x06\x79\x28\xaf\x06\x7f\x26\xb5\x06\x0e\x25\xc0\x06\x04\x29\xbd\x06\xe4\x26\xb7\x06\x6e\x25\xc8\x06\xb3\x28\xb2\x06\xa6\x26\xae\x06\x76\x25\xba\x06\x66\x28\xaf\x06\xe1\x26\xb1\x06\x76\x25\xa7\x06\x60\x28\x92\x06\x9b\x26\xb0\x06\x30\x25\xb5\x06\x34\x28\xa7\x06\xe1\x26\xb0\x06\x62\x25\xbd\x06\x33\x28\xb7\x06\x87\x26\xac\x06\x0a\x25\xae\x06\xc3\x27\xad\x06\x3e\x26\xb7\x06\xdc\x24\xc6\x06\x4d\x28\xbc\x06\xb6\x26\xb3\x06\x00\x25\xbc\x06\x5d\x28\xb1\x06\xa1\x26\xad\x06\x24\x25\xb8\x06\xd5\x27\xab\x06\x8a\x26\xa2\x06\x20\x25\xc4\x06\xe4\x27\xca\x06\xa1\x26\xbb\x06\x4e\x25\xbb\x06\xfa\x27\xb2\x06\xd8\x26\xb2\x06\x3a\x25\xb8\x06\xb4\x27\xad\x06\x9f\x26\xab\x06\x19\x25\xb2\x06\x67\x27\xb5\x06\x4a\x26\xb4\x06\xbb\x24\xbc\x06\x0d\x28\xa6\x06\xac\x26\xab\x06\x20\x25\xbe\x06\x30\x28\xb7\x06\xad\x26\xba\x06\x88\x25\xaf\x06\x04\x28\xa3\x06\xd9\x26\x9c\x06\x58\x25\xc0\x06\xe7\x27\xb1\x06\xc3\x26\xb8\x06\x3d\x25\xb8\x06\x82\x27\xbc\x06\xe7\x26\xa9\x06\x28\x25\xbf\x06\xea\x27\xb5\x06\xdd\x26\xb3\x06\x54\x25\xbf\x06\x72\x27\xaf\x06\x73\x26\xa7\x06\xc5\x24\xb9\x06\x39\x27\xac\x06\xb7\x26\xb1\x06\xf2\x24\xb7\x06\xbb\x27\xb6\x06\xe2\x26\xac\x06\x51\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb3\x06\x7d\x27\xb4\x06\xdc\x26\xbd\x06\x54\x25\xa1\x06\x3d\x27\x9f\x06\xe5\x26\xa1\x06\x60\x25\xc0\x06\x74\x27\xba\x06\xb3\x26\xce\x06\x69\x25\xb5\x06\x86\x27\xae\x06\xc4\x26\xaf\x06\x5b\x25\xad\x06\x41\x27\xa5\x06\x59\x26\x9a\x06\xac\x24\xb4\x06\x49\x27\xb3\x06\x91\x26\xaa\x06\x1a\x25\xb9\x06\xb3\x27\xa9\x06\xd9\x26\xae\x06\x7d\x25\xb1\x06\xd5\x27\xb9\x06\xcd\x26\xa6\x06\x62\x25\xbf\x06\x0e\x28\xb9\x06\x9f\x26\xb4\x06\x5c\x25\xb4\x06\xde\x27\xb7\x06\xf5\x26\xae\x06\x80\x25\xa9\x06\xb1\x27\xa5\x06\xed\x26\xb6\x06\xaf\x25\xbe\x06\x13\x28\xb0\x06\x9f\x26\xaf\x06\x70\x25\xba\x06\x49\x28\xb0\x06\xc5\x26\xb3\x06\x74\x25\xb9\x06\x28\x28\xa0\x06\xe4\x26\xb7\x06\xc6\x25\xad\x06\xfa\x27\xa4\x06\xc1\x26\xa9\x06\x81\x25\xbc\x06\xe2\x27\xba\x06\xdb\x26\xa9\x06\x88\x25\xb0\x06\xf6\x27\xaa\x06\xa9\x26\xaf\x06\xb4\x25\xae\x06\xcf\x27\xa8\x06\xa8\x26\xb0\x06\x88\x25\xb4\x06\x79\x27\xb4\x06\x95\x26\xa4\x06\x08\x25\xb4\x06\xc4\x27\xae\x06\x84\x26\x9e\x06\x34\x25\xb8\x06\xe4\x27\xa7\x06\x94\x26\xa9\x06\x75\x25\xb7\x06\x34\x28\xb1\x06\xb5\x26\xb4\x06\x86\x25\xb5\x06\xd7\x27\xad\x06\x10\x27\xa9\x06\x9e\x25\xb1\x06\xc8\x27\xb9\x06\xad\x26\xab\x06\x69\x25\xb6\x06\x03\x28\xad\x06\x64\x26\xae\x06\x66\x25\xcc\x06\x0e\x28\xb6\x06\x62\x26\xb5\x06\x1a\x25\xa9\x06\xa5\x27\x99\x06\x5b\x26\x9a\x06\x33\x25\xae\x06\x78\x27\xb5\x06\xe3\x26\xa5\x06\x4c\x25\xad\x06\x10\x28\x9c\x06\xc8\x26\x99\x06\x3c\x25\xb0\x06\x24\x28\xa9\x06\x90\x26\xad\x06\x6e\x25\xb0\x06\x32\x28\xa8\x06\x9f\x26\xb2\x06\x7b\x25\xc0\x06\xf9\x27\xbc\x06\xce\x26\xb2\x06\x8a\x25\xab\x06\x33\x28\x9b\x06\x9b\x26\xac\x06\x45\x25\xc3\x06\xe8\x27\xb7\x06\x61\x26\xa1\x06\x0a\x25\xb4\x06\x5a\x28\xb9\x06\xc2\x26\xaf\x06\x54\x25\xba\x06\xde\x27\xb8\x06\x8d\x26\xbb\x06\x8a\x25\xbd\x06\xd6\x27\xa9\x06\x95\x26\xb6\x06\x9a\x25\xb0\x06\x01\x28\xae\x06\xcf\x26\xb3\x06\xb4\x25\xb0\x06\x63\x28\xa5\x06\xae\x26\xaf\x06\x9c\x25\xc3\x06\x4d\x28\xb4\x06\x0e\x27\xb2\x06\xd4\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb2\x06\x50\x28\xb0\x06\xf8\x26\xaf\x06\x92\x25\xc2\x06\x98\x28\xb0\x06\xe0\x26\xb4\x06\xa5\x25\xb8\x06\x5e\x28\xa7\x06\xd8\x26\xb4\x06\xcb\x25\xbb\x06\xfd\x27\xb3\x06\xc7\x26\xa6\x06\x95\x25\xb5\x06\xf9\x27\xb9\x06\xa6\x26\xab\x06\x97\x25\xc0\x06\x33\x28\xc0\x06\xe8\x26\xba\x06\xd3\x25\xc6\x06\x51\x28\xb9\x06\xc3\x26\xae\x06\xc4\x25\xba\x06\xf9\x27\xb4\x06\xa3\x26\xb0\x06\x66\x25\xaf\x06\x0f\x28\xac\x06\xb4\x26\xa1\x06\x39\x25\xc7\x06\x33\x28\xb0\x06\xc8\x26\xac\x06\xac\x25\xb5\x06\x2b\x28\xa3\x06\x88\x26\xac\x06\xb1\x25\xbe\x06\x2d\x28\xba\x06\xb4\x26\xbc\x06\x92\x25\xb5\x06\x0a\x28\xb1\x06\xee\x26\xa4\x06\x7a\x25\xc6\x06\x2e\x28\xb3\x06\xb7\x26\xaf\x06\xc3\x25\xa8\x06\x0e\x28\x9f\x06\xdc\x26\xab\x06\xb8\x25\xaf\x06\x55\x28\xad\x06\xe7\x26\xa6\x06\x70\x25\xc3\x06\x6c\x28\xad\x06\xd7\x26\xb2\x06\x83\x25\xb6\x06\x4d\x28\xb5\x06\xb7\x26\xaa\x06\x72\x25\xa9\x06\x3a\x28\x9a\x06\x81\x26\xa9\x06\x44\x25\xc1\x06\x18\x28\xac\x06\x87\x26\xb4\x06\x6b\x25\xba\x06\xf5\x27\xb0\x06\x71\x26\xaf\x06\x66\x25\xb2\x06\xa6\x27\xa5\x06\x54\x26\xb6\x06\x42\x25\xb3\x06\x42\x27\xaa\x06\x1b\x26\xad\x06\xdd\x24\xaa\x06\xdf\x27\x9e\x06\x7f\x26\xa7\x06\x07\x25\xb5\x06\x6e\x28\xb5\x06\x41\x26\xab\x06\x46\x25\xbd\x06\x46\x28\xbd\x06\x7f\x26\xb4\x06\x25\x25\xad\x06\x1b\x28\xac\x06\x78\x26\xb1\x06\x60\x25\xc4\x06\xef\x27\xaf\x06\x5d\x26\xbc\x06\x7b\x25\xb4\x06\xc5\x27\xa7\x06\x4f\x26\xa9\x06\x1e\x25\xbc\x06\x8d\x27\xac\x06\xf0\x25\xab\x06\xd2\x24\xb5\x06\x64\x27\xa8\x06\x37\x26\xa0\x06\xde\x24\xb7\x06\xaa\x27\xae\x06\x6c\x26\x9f\x06\x18\x25\xc3\x06\xa8\x27\xb6\x06\x44\x26\xb6\x06\x12\x25\xbf\x06\xe3\x27\xae\x06\x35\x26\xa7\x06\x1b\x25\xb6\x06\x34\x28\xa4\x06\x44\x26\xa7\x06\x24\x25\xb2\x06\xd2\x27\xa0\x06\xa6\x26\xa9\x06\x29\x25\xb7\x06\xa5\x27\xae\x06\x33\x26\xb4\x06\xcb\x24\xbf\x06\xec\x27\xaf\x06\x48\x26\xad\x06\xef\x24\xb3\x06\xbe\x27\xb2\x06\x50\x26\xad\x06\xd8\x24\xb0\x06\x54\x27\xa5\x06\x64\x26\xa1\x06\xdc\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc2\x06\x18\x27\xb6\x06\x88\x26\xb6\x06\xd0\x24\xb3\x06\x5e\x27\xb5\x06\x59\x26\xae\x06\xdc\x24\xb3\x06\x93\x27\xb5\x06\x3d\x26\xae\x06\xe9\x24\xa4\x06\x7c\x27\xa5\x06\x31\x26\xb5\x06\xac\x24\xbc\x06\x93\x27\xb3\x06\x53\x26\xa6\x06\xbb\x24\xb9\x06\x47\x27\xbb\x06\xc2\x26\xba\x06\x1e\x25\xb6\x06\x70\x27\xa7\x06\x6d\x26\xa5\x06\x26\x25\xc3\x06\x8f\x27\xbb\x06\xaf\x26\xb6\x06\x00\x25\xb1\x06\x92\x27\xaf\x06\x70\x26\xaa\x06\x01\x25\xb9\x06\x62\x27\xb4\x06\x5b\x26\xa8\x06\xf2\x24\xbc\x06\x81\x27\xb2\x06\x2f\x26\xab\x06\xdf\x24\xbf\x06\x67\x27\xc2\x06\x58\x26\xb6\x06\xd0\x24\xb2\x06\xef\x27\xa5\x06\x40\x26\xa9\x06\x0f\x25\xc1\x06\x8e\x27\xbf\x06\x45\x26\xba\x06\xef\x24\xbe\x06\x43\x27\xbc\x06\x50\x26\xb9\x06\xeb\x24\xb3\x06\x3b\x27\xb7\x06\x4b\x26\xb2\x06\x08\x25\xaf\x06\x75\x27\xc5\x06\x04\x26\xb2\x06\x28\x25\xbf\x06\xb5\x27\xb0\x06\x2b\x26\xb6\x06\xee\x24\xb8\x06\x94\x27\xb5\x06\xdb\x25\xb8\x06\xbd\x24\xc0\x06\xc9\x27\xb8\x06\x5f\x26\xae\x06\xdb\x24\xb6\x06\xb6\x27\xa4\x06\x09\x26\xa3\x06\xef\x24\xc0\x06\x64\x27\xb8\x06\x38\x26\xb9\x06\xf1\x24\xbb\x06\x42\x27\xb5\x06\xf1\x25\xb1\x06\x07\x25\xb0\x06\x08\x27\xad\x06\x31\x26\x9e\x06\xd1\x24\xb1\x06\xf9\x26\xaa\x06\x50\x26\xaf\x06\xa7\x24\xbd\x06\x48\x27\xb8\x06\xd3\x25\xab\x06\x88\x24\xbd\x06\x5d\x27\xb0\x06\xec\x25\xac\x06\xb8\x24\xb5\x06\x50\x27\xa3\x06\x10\x26\xa1\x06\xb6\x24\xc5\x06\x24\x27\xa8\x06\xed\x25\xa5\x06\xb7\x24\xb7\x06\x3e\x27\xb4\x06\x45\x26\xa8\x06\x8f\x24\xb0\x06\x1d\x27\xb6\x06\x21\x26\xa4\x06\xb7\x24\xab\x06\x33\x27\xa7\x06\xe4\x25\xae\x06\xc5\x24\xb0\x06\x1b\x27\xa8\x06\xa6\x25\xa5\x06\xa2\x24\xb8\x06\x3a\x27\xb7\x06\xd9\x25\xaf\x06\x9a\x24\xc1\x06\x1c\x28\xba\x06\x08\x26\xc1\x06\xfa\x24\xa0\x06\x2d\x28\x9b\x06\x10\x26\xa9\x06\x45\x25\xc1\x06\xf8\x27\xbc\x06\xeb\x25\xb0\x06\x13\x25\xb5\x06\xa0\x27\xb1\x06\xd1\x25\xb0\x06\xdb\x24\xb2\x06\x35\x27\xaa\x06\xc1\x25\xb0\x06\xd4\x24\xaa\x06\x0f\x27\x9e\x06\xcd\x25\xa1\x06\x79\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb4\x06\xf8\x26\xa7\x06\xb4\x25\x9e\x06\x72\x24\xad\x06\xa3\x26\xb3\x06\x11\x26\xb5\x06\xd8\x24\xc3\x06\xea\x26\xc3\x06\x3c\x26\xbb\x06\x03\x25\xbf\x06\x6a\x27\xa9\x06\xe9\x25\xb3\x06\xcd\x24\xc3\x06\xb1\x27\xa6\x06\xd8\x25\xb3\x06\xd0\x24\xb1\x06\xd9\x27\xa7\x06\xf4\x25\xa3\x06\xbf\x24\xa9\x06\x37\x27\xa6\x06\xc1\x25\xa7\x06\x71\x24\xb7\x06\xfb\x26\xa9\x06\x91\x25\xb2\x06\x28\x24\xb4\x06\x40\x27\xa8\x06\xf1\x25\xae\x06\xba\x24\xac\x06\x24\x27\xa3\x06\x20\x26\xad\x06\xb2\x24\xc7\x06\x9b\x26\xbf\x06\xfd\x25\xc1\x06\x88\x24\xaa\x06\x38\x26\xa9\x06\xcf\x25\xb0\x06\x44\x24\xb3\x06\x5c\x26\xb3\x06\x1d\x26\xa7\x06\x7f\x24\xa6\x06\x69\x26\xa1\x06\xdf\x25\x9d\x06\x53\x24\xa4\x06\x74\x26\xa0\x06\x8e\x25\xa4\x06\x24\x24\xb8\x06\xfe\x26\xa8\x06\xb2\x25\xa5\x06\x79\x24\xbc\x06\xef\x26\xb2\x06\x09\x26\xa7\x06\x92\x24\xb5\x06\xb4\x26\xbb\x06\x21\x26\xb5\x06\xa7\x24\xbc\x06\xfc\x26\xa3\x06\x0c\x26\xbc\x06\xb7\x24\xc1\x06\xb2\x26\xb0\x06\xf0\x25\xb3\x06\x93\x24\xb3\x06\x96\x26\xae\x06\xdd\x25\xb3\x06\x8f\x24\xac\x06\x65\x26\xaa\x06\xe0\x25\x9f\x06\x3a\x24\xad\x06\x96\x26\xb0\x06\xd5\x25\xaa\x06\x1c\x24\xa7\x06\xa9\x26\xa4\x06\x05\x26\xa5\x06\x87\x24\xa9\x06\x76\x26\xab\x06\x13\x26\x9d\x06\x7c\x24\xa7\x06\xcc\x26\xab\x06\x49\x26\xae\x06\x8e\x24\xa8\x06\xc2\x26\xb2\x06\x3b\x26\xa8\x06\xaf\x24\xb8\x06\xf5\x26\xbc\x06\x7c\x26\xb5\x06\xcc\x24\xac\x06\xc2\x26\xad\x06\x2d\x26\xad\x06\x8c\x24\xa7\x06\xb7\x26\xb3\x06\x30\x26\xad\x06\x9a\x24\xb8\x06\xbe\x26\xab\x06\x5c\x26\xae\x06\xc9\x24\xb5\x06\xf0\x26\xaf\x06\x67\x26\xa3\x06\xb4\x24\xb8\x06\xca\x26\xba\x06\x14\x26\xaa\x06\xa2\x24\xaa\x06\xd1\x26\xb1\x06\x3f\x26\xa9\x06\xc1\x24\xa8\x06\xdd\x26\xa2\x06\x44\x26\x9e\x06\x93\x24\xbb\x06\xbe\x26\xb4\x06\x2f\x26\xad\x06\x7b\x24\xb6\x06\xd4\x26\xad\x06\x41\x26\xa0\x06\x78\x24\xb5\x06\xfb\x26\xa9\x06\x20\x26\xae\x06\xbd\x24\xb8\x06\x89\x27\xbd\x06\x47\x26\xaf\x06\xd4\x24\xb6\x06\xf9\x27\xa7\x06\x07\x26\xad\x06\xe6\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc6\x06\x3f\x28\xb0\x06\xe8\x25\xaa\x06\xfd\x24\xbe\x06\xac\x27\xad\x06\xf8\x25\xb6\x06\xea\x24\xab\x06\x1a\x27\xb3\x06\x39\x26\xa0\x06\xfa\x24\xad\x06\x25\x27\xa4\x06\x0d\x26\xa2\x06\x6e\x24\xb6\x06\xa0\x27\xb7\x06\x57\x26\xab\x06\xb6\x24\xb7\x06\x75\x27\xab\x06\x25\x26\xaf\x06\xee\x24\xa9\x06\xf9\x26\xa2\x06\x21\x26\xa7\x06\xc5\x24\xbc\x06\xea\x26\xc0\x06\x48\x26\xb2\x06\x4d\x25\xae\x06\xca\x26\xb4\x06\x5b\x26\xa5\x06\x95\x24\xc0\x06\xda\x26\xa7\x06\x54\x26\xac\x06\x8e\x24\xbd\x06\xfd\x26\xbe\x06\x49\x26\xb4\x06\xb3\x24\xb5\x06\x06\x27\xa7\x06\x43\x26\xb4\x06\xc2\x24\xb9\x06\x0b\x27\xb4\x06\x33\x26\xb9\x06\xb8\x24\xbb\x06\x02\x27\xb0\x06\x17\x26\xaa\x06\xab\x24\xba\x06\x0a\x27\xac\x06\xe1\x25\xae\x06\xb3\x24\xb4\x06\xd6\x26\xbe\x06\x5d\x26\xab\x06\xba\x24\xc1\x06\xcb\x26\xba\x06\x2f\x26\xb1\x06\xaf\x24\xb8\x06\xbe\x26\xb9\x06\xef\x25\xb4\x06\x79\x24\xa6\x06\xdf\x26\xa3\x06\x19\x26\xad\x06\xab\x24\xc2\x06\xf6\x26\xaa\x06\x0d\x26\xb2\x06\xb5\x24\xc6\x06\xe2\x26\xb1\x06\x3c\x26\xb2\x06\xa9\x24\xb5\x06\x03\x27\xab\x06\x01\x26\xaf\x06\x98\x24\xc9\x06\xe6\x26\xad\x06\x42\x26\xb1\x06\x7f\x24\xbc\x06\xff\x26\xa9\x06\xed\x25\xb4\x06\xbb\x24\xb3\x06\xd4\x26\xae\x06\x10\x26\xa9\x06\x82\x24\xb1\x06\xd2\x26\xa7\x06\xe5\x25\xa8\x06\x6e\x24\xb8\x06\x29\x27\xb1\x06\x52\x26\xb3\x06\xd5\x24\xb8\x06\xf3\x26\xbb\x06\x3b\x26\xb1\x06\xd7\x24\xb7\x06\xd7\x26\xb1\x06\x42\x26\xb0\x06\xca\x24\xab\x06\x14\x27\x9d\x06\x31\x26\xab\x06\xba\x24\xb6\x06\xfb\x26\xb7\x06\x4a\x26\xac\x06\x8f\x24\xbb\x06\xd6\x26\xb0\x06\x38\x26\xa9\x06\x8a\x24\xb8\x06\xdf\x26\xb7\x06\x0e\x26\x9f\x06\x8e\x24\xa9\x06\x61\x27\xa3\x06\xd7\x26\x89\x06\x2a\x25\xb4\x06\xd6\x26\xbc\x06\x4a\x26\xb3\x06\x7d\x24\xb7\x06\xb6\x26\xb7\x06\xf2\x25\xb5\x06\x3b\x24\xbc\x06\xc0\x26\xb7\x06\xfa\x25\xa5\x06\x4f\x24\xbd\x06\xb3\x26\xb4\x06\xdf\x25\xa5\x06\x71\x24\xb2\x06\x86\x26\xa7\x06\x25\x26\xa3\x06\x30\x24\xa8\x06\x36\x26\xa8\x06\xc3\x25\xa1\x06\x02\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa3\x06\x8e\x26\xa1\x06\x3c\x26\xa4\x06\x2d\x24\xb6\x06\xec\x26\xbd\x06\x19\x26\xac\x06\x54\x24\xb9\x06\xd9\x26\xb1\x06\xdc\x25\xa8\x06\x1f\x24\xba\x06\x8f\x26\xae\x06\xe9\x25\xb3\x06\x4e\x24\xb3\x06\x95\x26\xb1\x06\x28\x26\xb1\x06\x90\x24\xaa\x06\xe5\x26\xac\x06\x0a\x26\xad\x06\x8e\x24\x99\x06\xb5\x26\xa1\x06\x0a\x26\xad\x06\x37\x24\xbe\x06\xec\x26\xb7\x06\xfe\x25\xaf\x06\x56\x24\xa0\x06\xd9\x26\x91\x06\x0c\x26\xac\x06\x37\x24\xb5\x06\x97\x26\xbf\x06\x00\x26\xab\x06\x58\x24\xb9\x06\x53\x26\xb8\x06\xbb\x25\xb0\x06\x2a\x24\xb4\x06\x77\x26\xb6\x06\xbc\x25\xab\x06\x36\x24\xb5\x06\xa5\x26\xaf\x06\xc1\x25\xb4\x06\x59\x24\xb0\x06\x43\x26\x9d\x06\x90\x25\x9f\x06\xf3\x23\xa4\x06\x7d\x26\xa5\x06\xce\x25\x9d\x06\x21\x24\xb6\x06\x83\x26\xb5\x06\xb0\x25\xbf\x06\x35\x24\xc0\x06\x62\x26\xc1\x06\xcd\x25\xb6\x06\x43\x24\xac\x06\x40\x26\xb9\x06\xae\x25\xaf\x06\x2b\x24\xaf\x06\x48\x26\xb1\x06\x89\x25\xa7\x06\x20\x24\xa9\x06\x35\x26\xac\x06\xe2\x25\xab\x06\x20\x24\xc2\x06\x48\x26\xbe\x06\x7b\x25\xb7\x06\xc5\x23\xad\x06\xdd\x25\xa4\x06\x20\x25\xa2\x06\xb4\x23\xa8\x06\x1b\x26\xb3\x06\xe3\x25\xae\x06\x10\x24\xbe\x06\x2f\x26\xac\x06\x90\x25\xb6\x06\x29\x24\xa8\x06\xff\x25\xb2\x06\x80\x25\xa1\x06\xe7\x23\xb9\x06\x35\x26\xb1\x06\x85\x25\xae\x06\x31\x24\xb0\x06\x26\x26\xa8\x06\xb2\x25\xa6\x06\xd5\x23\xaf\x06\x14\x26\xa8\x06\x4b\x25\xa7\x06\xbf\x23\xaa\x06\xd9\x25\xa5\x06\x15\x25\x9a\x06\xa4\x23\x9a\x06\x0b\x26\x9c\x06\xca\x25\xa4\x06\xe0\x23\xbc\x06\x40\x26\xa4\x06\x98\x25\xb5\x06\x1b\x24\xb2\x06\x47\x26\xb1\x06\x9e\x25\xab\x06\x17\x24\xb1\x06\x5b\x26\xb7\x06\xab\x25\xb2\x06\x2c\x24\xb0\x06\x74\x26\xaf\x06\x7e\x25\x9e\x06\xfc\x23\xb6\x06\x1e\x26\xb8\x06\xc4\x25\xb2\x06\x2d\x24\x9d\x06\xd4\x25\xa7\x06\x50\x25\xa4\x06\xf3\x23\xbb\x06\x2e\x26\xbb\x06\xcd\x25\xae\x06\x2e\x24\xba\x06\x1f\x26\xc0\x06\x2c\x26\xb2\x06\x5a\x24\xbd\x06\x71\x26\xaf\x06\x01\x26\xb5\x06\x34\x24\xad\x06\x5c\x26\xb0\x06\xe0\x25\xae\x06\x47\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb6\x06\x5b\x26\xc6\x06\xf5\x25\xac\x06\x1b\x24\xa8\x06\x62\x26\xa8\x06\xae\x25\xad\x06\x3c\x24\xb6\x06\x11\x26\xb2\x06\x6a\x25\xb0\x06\xea\x23\xb5\x06\x66\x26\xb3\x06\xa4\x25\xba\x06\x5b\x24\xac\x06\x4f\x26\xaf\x06\xc2\x25\xac\x06\x9f\x24\xb7\x06\x6f\x26\xb6\x06\xe5\x25\xad\x06\x4a\x24\xb6\x06\x71\x26\xb4\x06\xd7\x25\xbb\x06\x4b\x24\xad\x06\xbb\x26\xb2\x06\xbc\x25\xad\x06\x47\x24\xbd\x06\x60\x26\xc1\x06\xc6\x25\xb3\x06\x26\x24\xbc\x06\x52\x26\xab\x06\x5c\x25\xa7\x06\xb4\x23\xa0\x06\x60\x26\xa5\x06\xc3\x25\xae\x06\x34\x24\xc0\x06\xba\x26\xbd\x06\xe0\x25\xb0\x06\x53\x24\xa4\x06\x6d\x26\xa2\x06\xd8\x25\xa3\x06\x5e\x24\xb2\x06\x96\x26\xb3\x06\xd0\x25\xb3\x06\x62\x24\xbd\x06\xa8\x26\xb9\x06\xcc\x25\xb1\x06\x68\x24\xac\x06\x5f\x26\xae\x06\xb5\x25\xab\x06\x7e\x24\xb7\x06\x91\x26\xa7\x06\x6b\x25\xaa\x06\x25\x24\xb7\x06\x4a\x26\xb0\x06\x7b\x25\xb0\x06\xf9\x23\xc5\x06\xb1\x26\xb4\x06\xd8\x25\xc2\x06\x83\x24\x9e\x06\xe1\x26\xa0\x06\x2a\x26\xa8\x06\x5b\x24\xb9\x06\xcf\x26\xba\x06\xc6\x25\xbf\x06\x77\x24\xd2\x06\x20\x27\xbe\x06\xef\x25\xb1\x06\x6c\x24\xb8\x06\xc2\x26\xb2\x06\xf5\x25\xba\x06\x90\x24\xba\x06\xcd\x26\xb2\x06\xf3\x25\xaa\x06\x6d\x24\xc3\x06\xab\x26\xb5\x06\xd5\x25\xb7\x06\x34\x24\xbd\x06\x0e\x27\xbb\x06\x37\x26\xba\x06\xa5\x24\xbd\x06\xdd\x26\xbb\x06\x0e\x26\xb8\x06\xcd\x24\xc6\x06\xe3\x26\xc4\x06\x3d\x26\xbf\x06\xab\x24\x9d\x06\xf3\x26\x97\x06\x3f\x26\xaa\x06\xcc\x24\xbf\x06\x14\x27\xbe\x06\x33\x26\xb0\x06\xb7\x24\xa1\x06\xfe\x26\x9d\x06\x83\x26\xa5\x06\xf6\x24\xcd\x06\x45\x27\xb8\x06\x39\x26\xb8\x06\x7e\x24\xbc\x06\x41\x27\xb5\x06\x38\x26\xae\x06\xfa\x24\xbf\x06\x39\x27\xba\x06\x21\x26\xb8\x06\xf8\x24\xbc\x06\x40\x27\xb7\x06\x5b\x26\xb1\x06\xde\x24\xba\x06\x24\x27\xb2\x06\x48\x26\xaa\x06\xd4\x24\xba\x06\x19\x27\xb5\x06\x87\x26\xae\x06\x03\x25\xbe\x06\x40\x27\xb0\x06\x65\x26\xbb\x06\xf1\x24\xba\x06\x3b\x27\xb4\x06\x61\x26\xb1\x06\xd7\x24\xc6\x06\x77\x27\xba\x06\x7f\x26\xb2\x06\xe4\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc2\x06\x98\x27\xbe\x06\xaa\x26\xaf\x06\xff\x24\xb5\x06\xac\x27\xbe\x06\x8f\x26\xb1\x06\x0a\x25\xc4\x06\x97\x27\xb8\x06\x79\x26\xbe\x06\x12\x25\xbe\x06\x6e\x27\xb1\x06\x3b\x26\xad\x06\x23\x25\xc9\x06\xa0\x27\xab\x06\x31\x26\xc3\x06\xe4\x24\xbf\x06\x62\x27\xac\x06\xdb\x25\xb1\x06\x9d\x24\xc3\x06\x49\x27\xb8\x06\xec\x25\xb6\x06\xca\x24\xb8\x06\xa8\x27\xab\x06\x09\x26\x9a\x06\x19\x25\xb1\x06\x52\x27\xb2\x06\x50\x26\xaf\x06\xfb\x24\xb1\x06\x97\x27\xb1\x06\x51\x26\xa4\x06\xf7\x24\xc0\x06\x80\x27\xa9\x06\x11\x26\xaa\x06\x2d\x25\xd4\x06\x2d\x27\xd4\x06\x29\x26\xc9\x06\xfc\x24\xf2\x06\x04\x27\xee\x06\x1d\x26\x00\x07\xc1\x24\x16\x07\x8a\x26\x17\x07\x8a\x25\x16\x07\x40\x24\xaa\x06\x3f\x26\x9a\x06\x2a\x25\x97\x06\xc6\x23\xf9\x05\x92\x26\xf4\x05\xe2\x24\x06\x06\x8f\x22\x01\x06\xb7\x27\xf9\x05\xdd\x25\xfc\x05\x9c\x23\x96\x06\xd1\x26\x9a\x06\x00\x26\x97\x06\xa2\x24\x0b\x07\x23\x27\x0a\x07\x64\x26\xff\x06\x08\x25\x00\x07\x94\x27\xfe\x06\xc3\x26\xfc\x06\x7a\x25\xc3\x06\x37\x28\xbb\x06\x06\x27\xd4\x06\xaa\x25\xbf\x06\x9a\x28\xad\x06\x54\x27\xbd\x06\x15\x26\xb6\x06\x18\x29\xaf\x06\x5f\x27\xb1\x06\x35\x26\xb2\x06\x5a\x28\xac\x06\x4c\x27\xb4\x06\xff\x25\xc2\x06\x3d\x28\xa8\x06\x00\x27\xae\x06\xe0\x25\xbd\x06\x45\x28\xad\x06\x37\x27\xb6\x06\x09\x26\xb2\x06\x20\x28\xb1\x06\x10\x27\xbe\x06\xce\x25\xb6\x06\xee\x27\xb7\x06\x1f\x27\xb8\x06\xe4\x25\xae\x06\x50\x28\xaa\x06\x2e\x27\xab\x06\x01\x26\xa3\x06\xd0\x28\x9b\x06\x42\x27\xba\x06\x32\x26\xc3\x06\x36\x28\xad\x06\x03\x27\xaf\x06\xc6\x25\xa5\x06\xe3\x27\x9d\x06\x07\x27\xb2\x06\x06\x26\xb5\x06\x04\x28\xb4\x06\xfa\x26\xaf\x06\xa3\x25\xa6\x06\x11\x28\xac\x06\xc2\x26\xb4\x06\xa8\x25\xa0\x06\xd4\x27\x98\x06\x23\x27\xa2\x06\xb5\x25\xc1\x06\x22\x28\xbc\x06\x1e\x27\xb4\x06\xc9\x25\xb0\x06\x68\x28\xb3\x06\x44\x27\xb0\x06\x39\x26\x9f\x06\xe9\x27\xa2\x06\xef\x26\xa4\x06\x92\x25\xae\x06\x8f\x27\xad\x06\xa8\x26\xab\x06\x97\x25\xb0\x06\x6c\x27\xa0\x06\xa2\x26\xb0\x06\x5f\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x9c\x06\x88\x27\xa4\x06\xb5\x26\xa1\x06\x38\x25\xad\x06\x94\x27\xa3\x06\x98\x26\xac\x06\x5b\x25\xb4\x06\x76\x27\xa8\x06\xb5\x26\xa1\x06\x2e\x25\xba\x06\xe1\x27\xad\x06\x10\x27\xaa\x06\x9f\x25\xa0\x06\xc9\x27\x9b\x06\xd5\x26\xae\x06\x88\x25\xa3\x06\x4b\x27\x9e\x06\xb7\x26\xa5\x06\x3b\x25\xb8\x06\xff\x26\xb4\x06\x95\x26\xb2\x06\x20\x25\x7c\x06\x71\x27\x76\x06\x8f\x26\xb3\x06\x2a\x25\xa8\x06\x1f\x27\xa4\x06\x69\x26\xae\x06\xe2\x24\xad\x06\x65\x27\xaf\x06\x72\x26\xb9\x06\x33\x25\xbb\x06\xfe\x27\xb0\x06\x25\x27\xb6\x06\xb7\x25\xac\x06\xec\x27\xa4\x06\x42\x27\xa8\x06\x73\x25\xa9\x06\x45\x27\xa6\x06\x60\x26\xa2\x06\x0f\x25\xb2\x06\xd9\x26\xb6\x06\x1e\x26\xb8\x06\xde\x24\xa5\x06\xd7\x26\x9a\x06\x3c\x26\xa3\x06\xbd\x24\xa8\x06\xce\x26\xa4\x06\xf8\x25\xa4\x06\xc6\x24\xb0\x06\x29\x27\x9d\x06\x12\x26\xb0\x06\xce\x24\x9b\x06\x68\x27\x97\x06\x7d\x26\xa2\x06\x1b\x25\xaa\x06\x1f\x27\xa4\x06\x18\x26\xa9\x06\xf3\x24\xa6\x06\xbe\x26\xa4\x06\x08\x26\xae\x06\xb5\x24\xa7\x06\xab\x26\xa5\x06\x21\x26\xa8\x06\xc0\x24\x8f\x06\xba\x26\x98\x06\x27\x26\xa2\x06\xb5\x24\xa2\x06\xfb\x26\x9e\x06\x1d\x26\xa9\x06\xe5\x24\xbd\x06\x08\x27\xa9\x06\x34\x26\xa5\x06\xbf\x24\xa2\x06\x33\x27\xa6\x06\x91\x26\xa6\x06\x13\x25\xa4\x06\xfb\x27\x9a\x06\xd9\x26\xa2\x06\xe9\x25\xad\x06\xf2\x26\x9d\x06\x63\x26\xa2\x06\x3f\x25\xa9\x06\xa7\x26\xaa\x06\x2f\x26\xa1\x06\xf0\x24\xa2\x06\xde\x26\x98\x06\x20\x26\x98\x06\xcf\x24\xa9\x06\xd5\x26\xb4\x06\x57\x26\xb1\x06\xcb\x24\xa9\x06\xf7\x26\x96\x06\x44\x26\xab\x06\xd6\x24\xa4\x06\x4e\x27\xa2\x06\xb8\x26\xa4\x06\xff\x24\xb5\x06\x9f\x27\xb6\x06\x1c\x27\xaf\x06\x73\x25\x9e\x06\x59\x27\xa0\x06\xb5\x26\x9b\x06\x1d\x25\xa8\x06\x30\x27\x9a\x06\x39\x26\xa4\x06\xf3\x24\xa4\x06\x05\x27\xa3\x06\x45\x26\xab\x06\xc9\x24\xa0\x06\x0c\x27\x9f\x06\x54\x26\xac\x06\xbe\x24\xa5\x06\x0e\x27\x98\x06\x55\x26\x95\x06\xf5\x24\x97\x06\x4c\x27\x8b\x06\x8a\x26\x9e\x06\xf2\x24\x8e\x06\x84\x27\x87\x06\xc5\x26\xaa\x06\x54\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbb\x06\x84\x27\xb0\x06\xc4\x26\xb0\x06\x66\x25\xa3\x06\x1d\x27\xac\x06\x5e\x26\xab\x06\x27\x25\xab\x06\x10\x27\x9a\x06\x28\x26\xa8\x06\xfa\x24\xa8\x06\x16\x27\xa3\x06\x6d\x26\xa8\x06\xf2\x24\xa9\x06\x10\x27\xaa\x06\x6f\x26\xa8\x06\xe7\x24\xb1\x06\x17\x27\xa8\x06\x8c\x26\xae\x06\xed\x24\xa6\x06\xa6\x27\xa7\x06\xd6\x26\xa9\x06\x3f\x25\xac\x06\x88\x27\xa0\x06\xe4\x26\x9f\x06\x45\x25\x9d\x06\xed\x26\x9e\x06\x36\x26\xa8\x06\x1a\x25\x9b\x06\xda\x26\x96\x06\x46\x26\xa3\x06\xca\x24\xad\x06\xd3\x26\xa5\x06\x0e\x26\xa9\x06\x90\x24\x9d\x06\xbe\x26\xad\x06\x35\x26\xad\x06\x85\x24\xa7\x06\xee\x26\xa5\x06\x81\x26\x98\x06\xba\x24\xa5\x06\x8b\x27\xaa\x06\x97\x26\x98\x06\xf5\x24\x9b\x06\xd6\x27\x9b\x06\x05\x27\xa7\x06\x63\x25\x79\x06\x41\x27\x7d\x06\xb0\x26\x9b\x06\xf4\x24\xa6\x06\xfa\x26\xa1\x06\x2a\x26\xab\x06\xba\x24\xa6\x06\xa3\x26\xab\x06\x07\x26\x9f\x06\x85\x24\xa2\x06\xbf\x26\xa4\x06\xff\x25\xa1\x06\x93\x24\xb9\x06\x17\x27\xa8\x06\x24\x26\xa2\x06\xcd\x24\x8e\x06\x15\x27\x82\x06\x61\x26\x9c\x06\xaf\x24\xa5\x06\x45\x27\xab\x06\xd0\x26\xb3\x06\xce\x24\x98\x06\x31\x27\xa1\x06\x56\x26\x8f\x06\x7e\x24\xa6\x06\xa4\x26\xa1\x06\xdf\x25\x9a\x06\x93\x24\x94\x06\x84\x26\x8e\x06\xe7\x25\x9c\x06\x6b\x24\xac\x06\x95\x26\xac\x06\x02\x26\xa1\x06\x88\x24\xaa\x06\xcc\x26\xa0\x06\xe5\x25\x98\x06\x63\x24\xa7\x06\xf2\x26\x9a\x06\x22\x26\xa4\x06\xb7\x24\xaa\x06\x1f\x27\x9f\x06\x7d\x26\xa2\x06\x1a\x25\xa5\x06\x38\x27\x9a\x06\x68\x26\xa2\x06\xf1\x24\x94\x06\xbf\x26\x8e\x06\x15\x26\xa1\x06\xa6\x24\xb3\x06\x73\x26\xb0\x06\xde\x25\xae\x06\xa8\x24\xa1\x06\x55\x26\xa5\x06\xd3\x25\xac\x06\x52\x24\x9f\x06\x9c\x26\xa3\x06\xca\x25\x96\x06\x3e\x24\xad\x06\x8f\x26\xa2\x06\xd1\x25\xa5\x06\x67\x24\x8c\x06\x30\x27\x8e\x06\x5c\x26\xa7\x06\x85\x24\x8d\x06\xcc\x26\x78\x06\x44\x26\x94\x06\x21\x24\xa6\x06\x66\x26\xa8\x06\xae\x25\xa1\x06\xb1\x23\x9b\x06\x4f\x26\x9d\x06\x84\x25\xa5\x06\xde\x23\xa3\x06\x29\x26\x9a\x06\x86\x25\xa5\x06\xe0\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa2\x06\x21\x26\x96\x06\x8a\x25\x99\x06\xe8\x23\x9d\x06\x31\x26\x9c\x06\xb3\x25\xa2\x06\xeb\x23\x9e\x06\x84\x26\xac\x06\xce\x25\xa1\x06\x44\x24\xaa\x06\xca\x26\xa4\x06\xf6\x25\xa3\x06\x67\x24\xab\x06\x5e\x26\xab\x06\x75\x25\xa4\x06\x1a\x24\xa2\x06\xe6\x25\xa3\x06\x80\x25\x9f\x06\xbf\x23\xa9\x06\xdd\x25\xa3\x06\x5d\x25\xae\x06\xb0\x23\xad\x06\x39\x26\xb0\x06\xa0\x25\xa9\x06\xde\x23\x8c\x06\x3a\x26\x9a\x06\xe6\x25\xa6\x06\xf9\x23\x9f\x06\x79\x26\xa5\x06\xcf\x25\xa9\x06\xeb\x23\xac\x06\x0a\x27\xa9\x06\x34\x26\xab\x06\x6b\x24\xa4\x06\x80\x26\xa7\x06\x8f\x25\xa2\x06\xf6\x23\x8a\x06\x4d\x26\x88\x06\x9b\x25\x87\x06\xf2\x23\x98\x06\xd5\x25\x90\x06\x7f\x25\x96\x06\xf7\x23\xa6\x06\x1f\x26\x93\x06\x71\x25\x9e\x06\xf8\x23\xab\x06\xec\x25\xad\x06\x75\x25\xb4\x06\xef\x23\xa4\x06\x2c\x26\xa2\x06\xc8\x25\xaa\x06\x0a\x24\xb5\x06\x25\x26\xb3\x06\xc8\x25\xaf\x06\x43\x24\xa8\x06\x24\x26\x9e\x06\x48\x25\xaa\x06\x28\x24\xa3\x06\xd3\x25\xa8\x06\x41\x25\xa7\x06\xea\x23\x8f\x06\xd9\x25\x93\x06\x6e\x25\xa3\x06\xfd\x23\xb1\x06\xe1\x25\xab\x06\x45\x25\xb5\x06\xf9\x23\x9a\x06\xd5\x25\xa1\x06\x58\x25\xa5\x06\x23\x24\xaa\x06\xe4\x25\xae\x06\x46\x25\xb7\x06\x19\x24\xa9\x06\x3f\x26\x9f\x06\x93\x25\x9d\x06\x62\x24\xad\x06\x0b\x26\xb6\x06\xce\x25\xba\x06\x2b\x24\x9e\x06\x35\x26\xa9\x06\x8f\x25\xa6\x06\xd3\x23\x9f\x06\x41\x26\x8f\x06\x27\x25\xa7\x06\xee\x23\x95\x06\x2b\x26\x95\x06\x4b\x25\xa7\x06\x39\x24\xad\x06\x1f\x26\xae\x06\x62\x25\xb2\x06\x3c\x24\xa9\x06\x8b\x26\xae\x06\x59\x25\xaf\x06\x4c\x24\xb3\x06\xe2\x27\x9d\x06\x35\x25\xb3\x06\x9b\x24\xb6\x06\x81\x27\x99\x06\x2a\x25\xa8\x06\x88\x24\xa1\x06\x60\x26\x93\x06\x30\x25\xa3\x06\x28\x24\xa0\x06\xcc\x25\x9b\x06\x6b\x25\xa6\x06\xfb\x23\x7d\x06\xd1\x25\x82\x06\x54\x25\xa7\x06\xff\x23\x9f\x06\xdc\x25\xa2\x06\x40\x25\xa9\x06\xed\x23\xa7\x06\xe8\x25\x9f\x06\x2d\x25\xa7\x06\x3b\x24\x9c\x06\xa6\x26\x96\x06\x6e\x25\xa7\x06\x36\x24\xa4\x06\x47\x26\xa5\x06\xc7\x25\x9e\x06\x66\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa4\x06\x0c\x26\xa8\x06\x87\x25\xa3\x06\x56\x24\xa9\x06\xd4\x25\xad\x06\x6e\x25\xa8\x06\x17\x24\xac\x06\xf3\x25\xa8\x06\x44\x25\xae\x06\x1a\x24\x9e\x06\xbc\x25\x9e\x06\xb8\x25\x9f\x06\x11\x24\x7a\x06\x07\x26\x6e\x06\x62\x25\x93\x06\x1c\x24\xa1\x06\x08\x26\xa4\x06\x8d\x25\xa7\x06\x31\x24\xad\x06\x4d\x26\xa9\x06\xce\x25\xad\x06\x51\x24\xac\x06\x1d\x26\xb2\x06\x9d\x25\xb2\x06\x22\x24\xa1\x06\x17\x26\x99\x06\x6a\x25\x9a\x06\x17\x24\xaa\x06\x03\x26\xab\x06\x98\x25\xa3\x06\x03\x24\x94\x06\xe3\x25\x9d\x06\x90\x25\x9a\x06\xd2\x23\xaa\x06\x42\x26\xa6\x06\x7f\x25\x99\x06\xea\x23\xa8\x06\x2e\x26\xa5\x06\xeb\x25\x9b\x06\xf3\x23\xa1\x06\xbf\x26\xa9\x06\x0e\x26\xa2\x06\xa8\x24\xa0\x06\x96\x26\xa8\x06\xf5\x25\x98\x06\x6b\x24\xa5\x06\x3e\x26\xa8\x06\xc3\x25\x9f\x06\x4a\x24\x87\x06\x1d\x26\x91\x06\x87\x25\x9c\x06\x2a\x24\x93\x06\x13\x26\x9c\x06\xfd\x25\x9d\x06\x29\x24\xa7\x06\xee\x25\xa2\x06\x98\x25\xa4\x06\x3a\x24\xa9\x06\x25\x26\xa3\x06\xc8\x25\xa7\x06\x73\x24\x9b\x06\xbc\x26\xa0\x06\x30\x26\xa1\x06\xda\x24\x9f\x06\xa3\x26\x9c\x06\x25\x26\x97\x06\xa6\x24\xad\x06\x8c\x26\xa7\x06\xce\x25\xa8\x06\x70\x24\x9b\x06\x6e\x26\x9b\x06\x83\x25\xa1\x06\x78\x24\xa8\x06\x82\x26\xa3\x06\x8f\x25\xa7\x06\x64\x24\xa3\x06\xad\x26\xa4\x06\x7b\x25\x9e\x06\x4b\x24\x99\x06\x36\x27\x9c\x06\xac\x25\x9e\x06\x68\x24\xa7\x06\x52\x27\xa9\x06\x42\x26\xa7\x06\xc6\x24\xa2\x06\x20\x27\x98\x06\x80\x26\xa9\x06\xbf\x24\x89\x06\x13\x26\x89\x06\xc8\x25\x9a\x06\x62\x24\x97\x06\x11\x26\xa3\x06\x91\x25\x9a\x06\x0d\x24\x9e\x06\x1a\x26\xaa\x06\x96\x25\xa2\x06\xf5\x23\x9a\x06\x1c\x26\xa0\x06\x72\x25\x97\x06\x06\x24\xa3\x06\x13\x26\x9f\x06\x63\x25\xaa\x06\x37\x24\x87\x06\xa5\x26\x79\x06\x3d\x25\x9d\x06\x0e\x24\xa6\x06\xfc\x26\x99\x06\x30\x25\x96\x06\x23\x24\x9f\x06\xe0\x26\x86\x06\xe6\x24\x9a\x06\x0a\x24\x93\x06\x79\x26\x85\x06\x16\x25\x91\x06\xfc\x23\x9e\x06\xc9\x25\x9a\x06\x09\x25\x9d\x06\xc5\x23\x9a\x06\xb6\x25\x8d\x06\x10\x25\x95\x06\xf6\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa9\x06\xcf\x25\x9f\x06\x3c\x25\x9c\x06\xf9\x23\x98\x06\x80\x26\x85\x06\x75\x25\x9c\x06\x1d\x24\xa5\x06\xd8\x26\x9f\x06\x76\x25\xa3\x06\x6c\x24\xa3\x06\x23\x26\x9e\x06\x4c\x25\x9a\x06\xd3\x23\xa4\x06\x11\x26\x96\x06\x0d\x25\x8d\x06\xbf\x23\x9a\x06\xd4\x25\x90\x06\xb7\x24\x99\x06\x8d\x23\x90\x06\xe4\x25\x8a\x06\xf1\x24\x8c\x06\xc6\x23\x82\x06\x72\x25\x85\x06\xd7\x24\xa0\x06\xaa\x23\x83\x06\x9a\x25\x85\x06\xd1\x24\xa7\x06\xd1\x23\x81\x06\xb5\x25\x7c\x06\xc4\x24\x90\x06\xa9\x23\xa0\x06\xd7\x25\x9c\x06\xce\x24\x9a\x06\x96\x23\x9c\x06\xc3\x25\x90\x06\x7f\x24\x8f\x06\x98\x23\x84\x06\xd4\x25\x82\x06\xcb\x24\x8d\x06\x75\x23\x9f\x06\x47\x26\x9a\x06\xbc\x24\x9c\x06\x93\x23\x9c\x06\x0f\x26\x96\x06\xe7\x24\x87\x06\xad\x23\x95\x06\x7b\x25\x88\x06\xe5\x24\x9f\x06\xc9\x23\x78\x06\xb6\x25\x75\x06\x10\x25\xa1\x06\xba\x23\x82\x06\x8a\x25\x87\x06\x1f\x25\x7f\x06\xd3\x23\xa0\x06\x6f\x25\xa2\x06\xcd\x24\xa0\x06\xc2\x23\x94\x06\x61\x25\x90\x06\xb0\x24\x92\x06\xbc\x23\xa3\x06\x7d\x25\xa4\x06\xfe\x24\xa3\x06\x70\x23\x9b\x06\x5b\x25\x93\x06\x0e\x25\xa0\x06\xb3\x23\x91\x06\x5a\x25\x9f\x06\x0a\x25\x9c\x06\x98\x23\x92\x06\x22\x26\x8d\x06\xd9\x24\x94\x06\xcd\x23\x97\x06\xd2\x25\x8e\x06\x25\x25\x8f\x06\xb7\x23\x98\x06\x7d\x25\x94\x06\xda\x24\x9a\x06\x90\x23\x9f\x06\x80\x25\x97\x06\x05\x25\x91\x06\x80\x23\x92\x06\x8d\x25\x8d\x06\xdf\x24\x98\x06\x96\x23\x9c\x06\x6b\x25\x9d\x06\xbb\x24\x94\x06\x7b\x23\x88\x06\x89\x25\x85\x06\xfc\x24\x8c\x06\xb7\x23\x97\x06\x9e\x25\x97\x06\x2b\x25\x98\x06\xb3\x23\xa1\x06\xe3\x25\xa6\x06\x35\x25\x9a\x06\xd3\x23\x9f\x06\x82\x25\xa1\x06\xe9\x24\x95\x06\xca\x23\x98\x06\x9e\x25\x95\x06\xc9\x24\x92\x06\x88\x23\xa0\x06\xca\x25\x95\x06\xc2\x24\x9b\x06\x96\x23\x93\x06\xb9\x25\x8b\x06\xc0\x24\x8d\x06\x82\x23\xa0\x06\xaf\x25\x9a\x06\xdd\x24\x97\x06\x81\x23\x98\x06\x16\x26\x86\x06\xda\x24\x8a\x06\x81\x23\x9b\x06\x7e\x26\x8f\x06\x50\x25\x96\x06\x0d\x24\x7e\x06\xfe\x25\x7b\x06\x16\x25\x8b\x06\xcd\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x98\x06\x62\x25\x8d\x06\xd7\x24\x97\x06\xa9\x23\x98\x06\x5e\x25\xa4\x06\xfd\x24\x9f\x06\x90\x23\xa7\x06\x6e\x25\xa7\x06\xaf\x24\x95\x06\x4e\x23\xa0\x06\x6e\x25\x98\x06\xaf\x24\x9c\x06\x85\x23\x93\x06\x8f\x25\x7f\x06\x71\x24\x97\x06\x85\x23\x9d\x06\xd7\x25\x97\x06\xa2\x24\x98\x06\x7e\x23\xa7\x06\xad\x25\x94\x06\xaa\x24\xa4\x06\x59\x23\x8a\x06\x80\x25\x85\x06\x9e\x24\x99\x06\x63\x23\x92\x06\x3e\x25\x8a\x06\x78\x24\x98\x06\x57\x23\x8f\x06\x17\x25\x8b\x06\xab\x24\xa1\x06\x88\x23\xa5\x06\x58\x25\xa8\x06\xc7\x24\xa1\x06\x85\x23\xa5\x06\x62\x25\xa6\x06\xf8\x24\x96\x06\x96\x23\xa4\x06\xfd\x25\xa7\x06\x0e\x25\xa0\x06\xdc\x23\xa0\x06\x22\x26\x95\x06\xc2\x24\xa3\x06\xc5\x23\x9c\x06\x74\x25\x9a\x06\x97\x24\x9e\x06\x40\x23\x97\x06\x68\x25\xa3\x06\x8b\x24\x93\x06\x2b\x23\x9d\x06\x43\x25\x9f\x06\x8b\x24\xa2\x06\x4c\x23\x99\x06\x37\x25\xa0\x06\x88\x24\xa3\x06\x51\x23\x89\x06\x1d\x25\x96\x06\x9f\x24\x95\x06\x61\x23\x94\x06\xab\x25\x8a\x06\xfe\x24\x95\x06\xac\x23\x9c\x06\x8f\x25\xa2\x06\xce\x24\xa3\x06\x5a\x23\x9b\x06\x37\x25\x9b\x06\x64\x24\x9c\x06\x06\x23\x9e\x06\x0d\x25\x9a\x06\x3b\x24\x94\x06\x18\x23\x89\x06\xdd\x24\x92\x06\x26\x24\x9b\x06\xdb\x22\x9c\x06\x38\x25\x96\x06\x58\x24\x9b\x06\xe9\x22\x8a\x06\x0b\x25\x8b\x06\x5d\x24\x8e\x06\xf7\x22\x94\x06\xee\x24\x8a\x06\x89\x24\x95\x06\x11\x23\x8e\x06\xe7\x24\x8c\x06\x59\x24\x9a\x06\x2a\x23\x8b\x06\x07\x25\x9b\x06\x65\x24\xa0\x06\xdb\x22\x7e\x06\x19\x25\x73\x06\x39\x24\x99\x06\xf7\x22\x96\x06\xe0\x24\x9b\x06\x3a\x24\x96\x06\xc9\x22\x85\x06\x14\x25\x85\x06\x48\x24\x8d\x06\x0a\x23\x8c\x06\xf0\x24\x8d\x06\x68\x24\x9e\x06\xee\x22\xa4\x06\x14\x25\xa1\x06\x39\x24\x9d\x06\x06\x23\x95\x06\xec\x24\xa3\x06\x3d\x24\x8f\x06\xde\x22\x94\x06\x85\x24\x9b\x06\x41\x24\x9a\x06\xe3\x22\x96\x06\x86\x24\x8f\x06\x22\x24\x92\x06\xdf\x22\x99\x06\xd7\x24\x8f\x06\xff\x23\x93\x06\xb0\x22\x86\x06\xd0\x24\x7b\x06\x17\x24\x99\x06\xe5\x22\x95\x06\xaf\x24\x92\x06\x2b\x24\x99\x06\xc1\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8c\x06\xe4\x24\x90\x06\x58\x24\x7f\x06\xab\x22\x86\x06\x34\x25\x7d\x06\x87\x24\x94\x06\xd6\x22\x8d\x06\x06\x25\x88\x06\x70\x24\x90\x06\xd0\x22\x71\x06\xb3\x24\x70\x06\x10\x24\x8b\x06\xa8\x22\x75\x06\x5f\x24\x71\x06\xe4\x23\x93\x06\x3d\x22\x96\x06\x58\x24\x96\x06\xe4\x23\x8c\x06\xbb\x21\x97\x06\x92\x24\x84\x06\x99\x23\x8d\x06\xa4\x21\x95\x06\x8c\x24\x95\x06\xd0\x23\x99\x06\xc3\x21\x95\x06\xe6\x24\x91\x06\x73\x24\x84\x06\x73\x22\x7e\x06\xe8\x24\x76\x06\x2d\x24\x91\x06\xcb\x22\x5a\x06\xb9\x24\x64\x06\x3f\x24\x7f\x06\x9b\x22\x98\x06\x69\x24\x93\x06\xfb\x23\x9b\x06\x9b\x22\x6e\x06\x57\x24\x70\x06\x2a\x24\x71\x06\xcf\x22\x85\x06\x67\x24\x8b\x06\xef\x23\x8d\x06\x97\x22\x6d\x06\xb0\x24\x6d\x06\x3d\x24\x8b\x06\xe4\x22\x89\x06\xe6\x24\x8b\x06\x61\x24\x96\x06\x04\x23\x8b\x06\x09\x25\x8c\x06\x55\x24\x95\x06\x15\x23\x7a\x06\xa4\x24\x80\x06\x1f\x24\x8e\x06\xae\x22\x5b\x06\xaa\x24\x59\x06\x07\x24\x7b\x06\x9b\x22\x90\x06\x9e\x24\x8c\x06\xdd\x23\x8c\x06\xaf\x22\x80\x06\xdf\x24\x7e\x06\x1a\x24\x73\x06\xf2\x22\x81\x06\x8b\x24\x87\x06\x49\x24\x9b\x06\x32\x23\x86\x06\x10\x25\x89\x06\x7b\x24\x7b\x06\x12\x23\x72\x06\x45\x25\x76\x06\x64\x24\xa3\x06\x59\x23\x93\x06\xc6\x24\x8b\x06\x0e\x24\x8d\x06\x08\x23\x86\x06\xb4\x24\x79\x06\x54\x24\x7d\x06\xd5\x22\x8b\x06\xa6\x24\x91\x06\x68\x24\x8b\x06\xd2\x22\x7c\x06\x92\x24\x7c\x06\x3b\x24\x8a\x06\xe4\x22\x86\x06\xd6\x24\x82\x06\x59\x24\x78\x06\xe6\x22\x9f\x06\xea\x24\x9b\x06\x70\x24\x9c\x06\x18\x23\x97\x06\x40\x25\x9a\x06\xee\x24\x90\x06\x32\x23\x7f\x06\x0d\x25\x7b\x06\x66\x24\x8f\x06\xd4\x22\x93\x06\xb9\x24\x8a\x06\x42\x24\x96\x06\xbc\x22\x85\x06\x90\x24\x8b\x06\x51\x24\x82\x06\xa8\x22\x91\x06\x7d\x24\x92\x06\x49\x24\x8c\x06\xa8\x22\x91\x06\xcc\x24\x8a\x06\x2d\x24\x84\x06\xc1\x22\x97\x06\x1f\x25\x8e\x06\x5d\x24\x85\x06\xeb\x22\x81\x06\x3d\x25\x89\x06\xd6\x24\x81\x06\x32\x23\x76\x06\x70\x25\x75\x06\x95\x24\x82\x06\xd0\x22\x8e\x06\x23\x25\x82\x06\x14\x24\x99\x06\xa8\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x93\x06\xf3\x24\x8f\x06\x17\x24\x93\x06\xcc\x22\x94\x06\xec\x24\x8a\x06\x29\x24\x8c\x06\x8d\x22\x77\x06\xb3\x24\x77\x06\x0f\x24\x8b\x06\x9f\x22\x67\x06\x16\x25\x68\x06\x46\x24\x7f\x06\xc8\x22\x8e\x06\x19\x25\x8b\x06\x4a\x24\x86\x06\xcd\x22\x73\x06\x3c\x25\x77\x06\x71\x24\x63\x06\xee\x22\x9c\x06\x4d\x25\x94\x06\x12\x24\x96\x06\x24\x23\x93\x06\xec\x24\x8f\x06\xfc\x23\x94\x06\xd1\x22\x89\x06\x4d\x25\x87\x06\x13\x24\x83\x06\xac\x22\x96\x06\x86\x25\x8b\x06\x1b\x24\x91\x06\xd2\x22\x98\x06\x52\x25\x9a\x06\x11\x25\x91\x06\x09\x23\xa6\x06\x16\x26\x9a\x06\x73\x24\x97\x06\x3d\x23\x81\x06\xfc\x25\x74\x06\x9b\x24\x93\x06\x40\x23\x95\x06\xa9\x25\x8e\x06\xe4\x23\x96\x06\x45\x23\x87\x06\xaa\x25\x6e\x06\x17\x24\x84\x06\x53\x23\x89\x06\x8d\x25\x75\x06\xec\x23\x8f\x06\xc3\x22\x88\x06\x88\x25\x7a\x06\x04\x24\x8c\x06\xd9\x22\x86\x06\x78\x25\x79\x06\xec\x23\x84\x06\x06\x23\x97\x06\xb9\x25\x88\x06\x02\x24\x99\x06\x4b\x23\x81\x06\xb3\x25\x77\x06\x6c\x24\x86\x06\x45\x23\x60\x06\x6f\x25\x4e\x06\x35\x24\x4d\x06\x04\x23\x7e\x06\x65\x25\x6c\x06\x21\x24\x57\x06\xcd\x22\x88\x06\x0b\x25\x7e\x06\xe5\x23\x86\x06\xcb\x22\x76\x06\x33\x25\x6e\x06\xd9\x23\x89\x06\xf9\x22\x86\x06\x50\x25\x89\x06\x10\x24\x81\x06\x10\x23\x8f\x06\x5b\x25\x7f\x06\x21\x24\x89\x06\xde\x22\x81\x06\xd9\x25\x7a\x06\xdd\x24\x9a\x06\x5e\x23\x93\x06\xc6\x24\x83\x06\x25\x24\x84\x06\x7d\x22\x7a\x06\x62\x25\x63\x06\xfe\x23\x8b\x06\xc2\x21\x4e\x07\x05\x8f\x49\x07\x91\x88\x46\x07\x78\x7f\x00\x00\xbb\x14\x00\x00\x80\x15\x00\x00\x20\x16\x00\x00\xb9\x14\x00\x00\x80\x15\x00\x00\x1f\x16\x00\x00\xd9\x14\x00\x00\x91\x15\x00\x00\x31\x16\x00\x00\xd8\x14\x00\x00\x91\x15\x00\x00\x31\x16\xf1\x08\xff\xff\xe9\x08\xff\xff\xee\x08\xff\xff\xa5\x06\x49\x25\x97\x06\x9d\x23\x88\x06\xb5\x21\xa0\x06\x59\x24\x9b\x06\xee\x23\x99\x06\x94\x22\xa4\x06\xad\x24\x96\x06\x02\x24\x9e\x06\xb8\x22\xab\x06\x9f\x24\x9c\x06\x0a\x24\xa5\x06\xd8\x22\xaa\x06\x4b\x25\x96\x06\xd8\x23\x9b\x06\xbf\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa4\x06\x20\x25\x9c\x06\xb1\x23\x96\x06\x95\x22\x9e\x06\xd1\x24\x94\x06\x7e\x23\x93\x06\x4f\x22\x8b\x06\xdc\x24\x83\x06\xd8\x23\xa8\x06\x71\x22\x97\x06\x0b\x25\x92\x06\xbf\x23\x99\x06\x8d\x22\xad\x06\x3c\x25\x9a\x06\xdf\x23\x98\x06\x9b\x22\xa3\x06\x03\x25\x95\x06\xcb\x23\x90\x06\xac\x22\xaa\x06\x4c\x25\x9e\x06\xd8\x23\xa5\x06\xbf\x22\x85\x06\xa6\x25\x79\x06\x3c\x24\x81\x06\xb2\x22\xa4\x06\xea\x25\x98\x06\x39\x24\x9d\x06\x94\x22\xaf\x06\xc6\x25\x98\x06\x2c\x24\x9d\x06\xac\x22\xa1\x06\x74\x25\x9c\x06\x2b\x24\x94\x06\xc0\x22\xa0\x06\x8b\x25\x92\x06\xd4\x23\x9a\x06\xd4\x22\x9e\x06\x4c\x25\x98\x06\xde\x23\xa4\x06\xc2\x22\x8b\x06\x1a\x25\x81\x06\xf6\x23\x97\x06\x8c\x22\xa5\x06\x41\x25\x8c\x06\xf9\x23\x91\x06\xa5\x22\xa4\x06\x6b\x25\x9b\x06\xf1\x23\x86\x06\x5f\x22\x89\x06\x4d\x25\x87\x06\x31\x24\x82\x06\xac\x22\xad\x06\xf0\x24\x96\x06\xf1\x23\x97\x06\xae\x22\xab\x06\xd3\x24\xa3\x06\x11\x24\xa5\x06\x86\x22\xa5\x06\xb9\x24\x93\x06\xe9\x23\x8f\x06\x71\x22\xa7\x06\xc9\x24\x8f\x06\xfb\x23\x94\x06\x65\x22\x74\x06\xa6\x24\x78\x06\xdf\x23\xa6\x06\x2b\x22\x91\x06\x92\x24\x92\x06\xa4\x23\x9d\x06\x5e\x22\xa2\x06\xda\x24\x90\x06\xfb\x23\xaa\x06\x03\x23\x9f\x06\xf5\x24\x85\x06\xf1\x23\x88\x06\x4f\x22\xa1\x06\xff\x24\x97\x06\xd8\x23\x7f\x06\x74\x22\xa2\x06\xc0\x24\x83\x06\x9a\x23\xa2\x06\x7f\x22\x95\x06\x81\x24\x9b\x06\xf1\x23\x93\x06\x77\x22\x9d\x06\x7f\x24\xa6\x06\xdb\x23\x98\x06\x6a\x22\x9c\x06\x9f\x24\x9a\x06\xc3\x23\x8c\x06\x83\x22\xa5\x06\x3c\x24\xa5\x06\xb8\x23\x99\x06\x57\x22\x9f\x06\x20\x24\x9a\x06\x1f\x24\x9f\x06\xc2\x22\xa0\x06\x7b\x24\x9a\x06\x0a\x24\xa1\x06\xd5\x22\x94\x06\x4b\x24\x9a\x06\xfd\x23\xa3\x06\xd8\x22\x8e\x06\x1c\x24\x8d\x06\xaf\x23\x97\x06\xb4\x22\x91\x06\x74\x24\x9c\x06\xf7\x23\x92\x06\xb9\x22\x9a\x06\x8e\x24\x92\x06\xf1\x23\x9c\x06\xdc\x22\x85\x06\x19\x25\x6f\x06\x4b\x24\x7e\x06\xcd\x22\x92\x06\xa6\x24\x85\x06\x20\x24\x92\x06\xbc\x22\x98\x06\xb6\x24\x9d\x06\x1d\x24\x9e\x06\xbe\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa3\x06\xc2\x24\xa0\x06\xef\x23\x91\x06\xbc\x22\xac\x06\x6a\x24\xa5\x06\xdb\x23\x9c\x06\xc3\x22\xac\x06\xc5\x24\x94\x06\xda\x23\x9f\x06\xad\x22\xaa\x06\xad\x24\x91\x06\xd2\x23\x99\x06\xc9\x22\xa1\x06\x88\x24\x95\x06\xa3\x23\x86\x06\x36\x22\x9f\x06\x85\x24\x9e\x06\xce\x23\x8c\x06\x8c\x22\x94\x06\x74\x24\x98\x06\xc7\x23\x8c\x06\x4c\x22\x98\x06\x89\x24\x92\x06\xad\x23\x88\x06\x90\x22\x97\x06\x7d\x24\x86\x06\x9d\x23\x8f\x06\x78\x22\x8d\x06\x8e\x24\x91\x06\xb9\x23\x8b\x06\xa9\x22\x9c\x06\x81\x24\x8f\x06\xc3\x23\x95\x06\xcb\x22\x96\x06\x63\x24\x93\x06\xd2\x23\x94\x06\x70\x22\x9e\x06\xb3\x24\x8f\x06\x8d\x23\x8f\x06\x73\x22\x95\x06\x6e\x24\x8e\x06\xdf\x23\x93\x06\x8e\x22\x97\x06\xb4\x24\x8f\x06\xe9\x23\x87\x06\x71\x22\x99\x06\x79\x24\x91\x06\xad\x23\x9e\x06\x6d\x22\x9f\x06\x7c\x24\x8f\x06\xc4\x23\x8f\x06\x89\x22\x7e\x06\x88\x24\x7b\x06\xb5\x23\x9c\x06\x83\x22\xa1\x06\x95\x24\x82\x06\xce\x23\x97\x06\x9a\x22\xa2\x06\x82\x24\x98\x06\xc6\x23\x99\x06\x89\x22\xa6\x06\x8c\x24\x9a\x06\xae\x23\x95\x06\xa9\x22\x9e\x06\x7b\x24\x94\x06\x7e\x23\x8e\x06\x44\x22\x94\x06\x5f\x24\x9e\x06\xac\x23\x9c\x06\x58\x22\x92\x06\x68\x24\x8c\x06\x79\x23\x87\x06\x33\x22\x9b\x06\x8a\x24\x90\x06\x7f\x23\x91\x06\x49\x22\xa4\x06\x72\x24\x99\x06\x8f\x23\x99\x06\x42\x22\xa4\x06\x78\x24\x9f\x06\x91\x23\x9c\x06\xfa\x21\xa4\x06\x3f\x24\x97\x06\x83\x23\x99\x06\x1d\x22\x93\x06\x45\x24\x97\x06\x5f\x23\x9b\x06\x2b\x22\x96\x06\x3f\x24\x8b\x06\x74\x23\x83\x06\x09\x22\x96\x06\x32\x24\x8a\x06\x39\x23\x90\x06\x1d\x22\x96\x06\x66\x24\x97\x06\x53\x23\x91\x06\x2f\x22\x95\x06\x61\x24\x9c\x06\x8e\x23\x83\x06\x54\x22\x8d\x06\x42\x24\x90\x06\x7d\x23\x8a\x06\xe4\x21\x98\x06\x6c\x24\x97\x06\x58\x23\x94\x06\x1a\x22\x9d\x06\x9e\x24\xa1\x06\x4b\x23\x97\x06\x81\x22\x99\x06\x26\x24\x8b\x06\x45\x23\x9b\x06\x54\x22\xa2\x06\x36\x24\x92\x06\x5d\x23\x91\x06\x41\x22\xa4\x06\x72\x24\x9c\x06\x60\x23\x9d\x06\x54\x22\x99\x06\x6a\x24\x91\x06\x55\x23\xa2\x06\x5c\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x9c\x06\x7b\x24\x87\x06\x15\x23\x8f\x06\x46\x22\x9a\x06\x9a\x24\x95\x06\x44\x23\x95\x06\x2c\x22\x99\x06\x74\x24\x93\x06\x6a\x23\x97\x06\x5a\x22\xa8\x06\x80\x24\x9a\x06\x5f\x23\xa5\x06\x89\x22\xa4\x06\x3b\x24\x96\x06\x6b\x23\x98\x06\x57\x22\x9e\x06\x1c\x24\x8f\x06\x63\x23\x90\x06\x2c\x22\xa0\x06\x42\x24\x8f\x06\x64\x23\x9c\x06\x3e\x22\xaa\x06\x44\x24\x9a\x06\x1d\x23\x95\x06\x08\x22\xab\x06\x86\x24\xa0\x06\xf3\x22\x98\x06\x0d\x22\xaa\x06\xaf\x24\x87\x06\x1e\x23\xac\x06\x61\x22\xa5\x06\x92\x24\x92\x06\x2c\x23\xa3\x06\x44\x22\xa3\x06\x68\x24\x9d\x06\x2d\x23\x96\x06\x41\x22\x9e\x06\x7c\x24\x9c\x06\x1d\x23\x8e\x06\x30\x22\xa5\x06\x3f\x24\xa7\x06\x11\x23\x9b\x06\x2d\x22\x97\x06\x10\x24\x8b\x06\x3f\x23\xa1\x06\xec\x21\x98\x06\x15\x24\x9d\x06\x0e\x23\x8d\x06\xf3\x21\xa9\x06\x9f\x24\xa0\x06\x16\x23\x97\x06\x53\x22\x9d\x06\x92\x24\x97\x06\x29\x23\x91\x06\x24\x22\xb1\x06\x9e\x24\x94\x06\x1a\x23\xa4\x06\xfe\x21\x9d\x06\x6e\x24\x90\x06\x36\x23\x9a\x06\x19\x22\xa4\x06\x5f\x24\xa3\x06\x45\x23\x9c\x06\x33\x22\x97\x06\x33\x24\x93\x06\xd8\x22\x93\x06\x14\x22\xa1\x06\x18\x24\x95\x06\xdf\x22\x91\x06\x91\x21\x9d\x06\xd4\x23\x91\x06\x1e\x23\x9c\x06\xe9\x21\x9c\x06\x44\x24\x8e\x06\xed\x22\x95\x06\x05\x22\x9f\x06\x2d\x24\x89\x06\xdb\x22\x99\x06\xfd\x21\x9e\x06\x35\x24\x93\x06\xd0\x22\x96\x06\xc9\x21\x9e\x06\xfd\x23\x85\x06\xc6\x22\x8a\x06\xd3\x21\x8c\x06\xb5\x23\x90\x06\xac\x22\x9c\x06\xce\x21\x9b\x06\xa3\x23\x88\x06\x60\x22\x95\x06\xa8\x21\xa0\x06\xb3\x23\x91\x06\x7a\x22\x8c\x06\xb0\x21\x84\x06\x8c\x23\x81\x06\xd2\x22\x98\x06\xde\x21\x95\x06\xe7\x23\x9d\x06\x00\x23\x94\x06\xd3\x21\xa3\x06\xe9\x23\x9e\x06\xef\x22\x92\x06\xfa\x21\xa9\x06\x11\x24\x9d\x06\x02\x23\x9b\x06\x00\x22\x93\x06\xee\x23\x9d\x06\x3e\x23\x9d\x06\xfb\x21\x99\x06\xea\x23\x90\x06\xe7\x22\x98\x06\xb9\x21\xa9\x06\xc7\x23\x99\x06\x12\x23\x92\x06\x98\x21\xa5\x06\x04\x24\x8c\x06\x19\x23\xa5\x06\x06\x22\x9e\x06\x37\x24\x8c\x06\x1d\x23\x96\x06\xd9\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa9\x06\x01\x24\xa8\x06\x27\x23\x8b\x06\xc0\x21\xab\x06\xf1\x23\xa6\x06\x0a\x23\x8b\x06\x98\x21\xa8\x06\x0a\x24\x8f\x06\xe7\x22\x9e\x06\xb2\x21\xac\x06\x1d\x24\x95\x06\xed\x22\xa1\x06\x38\x21\x8e\x06\x3a\x24\x97\x06\x05\x23\x9a\x06\x7d\x21\xac\x06\x85\x24\xa0\x06\x70\x23\xa5\x06\xde\x21\xb5\x06\xfd\x23\xa2\x06\x2c\x23\x9d\x06\xe7\x21\xaf\x06\x18\x24\xa3\x06\x59\x23\xa3\x06\xe2\x21\xa8\x06\x56\x24\x8e\x06\x41\x23\x99\x06\x25\x22\xa4\x06\xb9\x24\x94\x06\x36\x23\x9b\x06\x0f\x22\xaf\x06\xb5\x24\x9a\x06\x0d\x23\x92\x06\x04\x22\x9f\x06\x59\x24\x92\x06\x03\x23\x9c\x06\xf6\x21\xa8\x06\x97\x24\x97\x06\x55\x23\x9e\x06\x08\x22\xaf\x06\x2e\x24\xa4\x06\x3b\x23\xb6\x06\x4c\x22\xbe\x06\x35\x24\xb1\x06\x2f\x23\xb6\x06\x49\x22\xb3\x06\x5e\x24\xb0\x06\x73\x23\xaa\x06\x61\x22\xc3\x06\x70\x24\xc5\x06\x55\x23\xb1\x06\x5a\x22\xc2\x06\xd4\x24\xb8\x06\x60\x23\xbe\x06\x7e\x22\xc6\x06\xfa\x24\xba\x06\x79\x23\xb2\x06\x4f\x22\xb6\x06\xa0\x24\xb0\x06\x93\x23\xc1\x06\x9f\x22\xb3\x06\xb1\x24\xae\x06\xc1\x23\xb1\x06\x7e\x22\xd3\x06\xad\x24\xb9\x06\x6e\x23\xb8\x06\x9c\x22\xd1\x06\xad\x24\xb7\x06\x9d\x23\xc1\x06\x6d\x22\xcb\x06\xa3\x24\xda\x06\xc0\x23\xb9\x06\x8d\x22\xcb\x06\xcd\x24\xc8\x06\x9e\x23\xc1\x06\xaa\x22\xd8\x06\x19\x25\xcd\x06\xcf\x23\xb8\x06\x9b\x22\xc4\x06\x41\x25\xbc\x06\xbd\x23\xbc\x06\xb9\x22\xd3\x06\x92\x25\xd0\x06\xc4\x23\xc1\x06\xc7\x22\xc6\x06\x67\x25\xb9\x06\x72\x23\xbb\x06\x74\x22\xd2\x06\x18\x25\xc3\x06\x66\x23\xc0\x06\x28\x22\xb8\x06\xbe\x24\xb4\x06\xa3\x23\xb3\x06\xe7\x21\xd1\x06\xbe\x24\xc2\x06\x86\x23\xc6\x06\x14\x22\xc9\x06\x61\x24\xce\x06\x75\x23\xbe\x06\x0c\x22\xc3\x06\x89\x24\xbd\x06\xf1\x23\xc2\x06\x4f\x22\xc7\x06\x32\x24\xcd\x06\xb1\x23\xc0\x06\x4a\x22\xc6\x06\x74\x24\xbd\x06\xb3\x23\xd8\x06\x3f\x22\xce\x06\xd0\x24\xc3\x06\x77\x23\xc9\x06\x26\x22\xe2\x06\xdd\x24\xc7\x06\x5d\x23\xc4\x06\x62\x22\xd8\x06\xca\x24\xd6\x06\xc2\x23\xcd\x06\x6f\x22\xd5\x06\x85\x24\xc1\x06\x72\x23\xbc\x06\x3f\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd4\x06\x97\x24\xaf\x06\x84\x23\xbe\x06\x41\x22\xc5\x06\x3f\x24\xc3\x06\xb1\x23\xbb\x06\x23\x22\xcc\x06\xe2\x23\xca\x06\x74\x23\xc2\x06\x05\x22\xbb\x06\xc3\x23\xc3\x06\x84\x23\xc2\x06\xce\x21\xd4\x06\xdb\x23\xc5\x06\x62\x23\xbb\x06\xfa\x21\xc5\x06\xd0\x23\xb2\x06\x37\x23\xbe\x06\x21\x22\xb5\x06\xc4\x23\xa9\x06\x44\x23\xab\x06\xf8\x21\xc7\x06\x1c\x24\xc2\x06\x0e\x23\xc1\x06\xad\x21\xcc\x06\x1c\x24\xd3\x06\x71\x24\xbf\x06\xe9\x21\xbe\x06\x11\x24\xb8\x06\x41\x23\xa9\x06\xd8\x21\xc5\x06\xea\x23\xc3\x06\x3f\x23\xb0\x06\xca\x21\xbc\x06\xba\x23\xbc\x06\x34\x23\xbd\x06\x99\x21\xbf\x06\xcc\x23\xbe\x06\x16\x23\xba\x06\x88\x21\xc0\x06\x26\x24\xb7\x06\x4b\x23\xb0\x06\xc0\x21\xc5\x06\xe1\x23\xb2\x06\xbc\x23\xbe\x06\x1f\x22\xa9\x06\xfe\x23\xa4\x06\xdf\x23\xb0\x06\x32\x22\x9d\x06\xe9\x23\x8d\x06\x80\x23\xac\x06\x34\x22\xa0\x06\x99\x23\xb8\x06\x6a\x23\x9a\x06\xfa\x21\x92\x06\x80\x23\xa8\x06\x4f\x23\x8a\x06\xf9\x21\x88\x06\xb2\x23\x87\x06\x53\x23\x9f\x06\xfb\x21\xa7\x06\xa4\x23\x83\x06\x22\x23\x91\x06\x44\x22\x8e\x06\x7d\x23\x8e\x06\x21\x23\x9b\x06\xfa\x21\x8e\x06\x80\x23\x93\x06\x61\x23\x89\x06\xe1\x21\xa1\x06\xcc\x23\xa5\x06\xe8\x23\x9d\x06\xe0\x21\x94\x06\xd0\x23\x84\x06\x29\x23\x89\x06\xf4\x21\x9d\x06\x96\x23\x8f\x06\xfb\x22\xa0\x06\x18\x22\x9a\x06\xa7\x23\x95\x06\x0e\x23\x92\x06\x17\x22\x8d\x06\x9a\x23\x99\x06\xff\x22\x90\x06\x0c\x22\xa0\x06\xba\x23\x8f\x06\xfc\x22\x98\x06\x27\x22\x95\x06\x0a\x24\x9b\x06\x21\x23\x8c\x06\xef\x21\xa6\x06\x7b\x24\x99\x06\x12\x23\x9c\x06\x48\x22\xb0\x06\xfb\x24\x96\x06\x0d\x23\x94\x06\x2e\x22\xa1\x06\xfd\x24\x90\x06\x00\x23\x8a\x06\xf8\x21\x98\x06\x5f\x24\x90\x06\xf0\x22\x8e\x06\x0d\x22\xa8\x06\xf8\x23\x9b\x06\x20\x23\x98\x06\x0e\x22\x99\x06\xe6\x23\x88\x06\xb8\x22\x8a\x06\xd3\x21\x9a\x06\x0d\x24\x8b\x06\xe0\x22\x8d\x06\x94\x21\xa4\x06\x2a\x24\xa3\x06\xf2\x22\x91\x06\xeb\x21\xaa\x06\xd5\x23\x9a\x06\x1a\x23\x9a\x06\xf0\x21\x9a\x06\xb4\x23\x85\x06\x1a\x23\xa9\x06\x0d\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x92\x06\xa6\x23\x99\x06\x07\x23\x92\x06\xd9\x21\x95\x06\x7c\x23\xa3\x06\x28\x23\xa2\x06\xda\x21\x82\x06\xce\x23\x6c\x06\xf6\x22\x98\x06\x0c\x22\x96\x06\xda\x23\x87\x06\x05\x23\x96\x06\xe8\x21\x90\x06\x07\x24\x95\x06\x3f\x23\x8c\x06\xf9\x21\xa4\x06\xe4\x23\xa8\x06\x5a\x23\xa2\x06\x14\x22\x9b\x06\xf6\x23\xa0\x06\x41\x23\x95\x06\xdd\x21\x8f\x06\x8b\x23\x8a\x06\x1d\x23\x8a\x06\x00\x22\x96\x06\xc7\x23\x93\x06\x4b\x23\x94\x06\x2c\x22\xa8\x06\x0b\x24\x9b\x06\x4e\x23\x99\x06\x07\x22\x90\x06\x17\x24\x8c\x06\x48\x23\x95\x06\x07\x22\x87\x06\xef\x23\x91\x06\x1d\x23\x90\x06\xfa\x21\x9b\x06\x06\x24\x89\x06\x5e\x23\x94\x06\x19\x22\x91\x06\xf6\x23\x97\x06\x6d\x23\x93\x06\xfb\x21\xa3\x06\x38\x24\x89\x06\x13\x23\x8d\x06\x13\x22\x98\x06\x28\x24\x94\x06\x34\x23\x97\x06\xe6\x21\x97\x06\xf1\x23\x9f\x06\x77\x23\x8f\x06\xff\x21\x9b\x06\x86\x23\x94\x06\x3d\x23\x8a\x06\x0e\x22\xa0\x06\xca\x23\x98\x06\x32\x23\x98\x06\x10\x22\xa5\x06\xf5\x23\x93\x06\x72\x23\xa2\x06\x30\x22\xa4\x06\x1c\x24\x9b\x06\x56\x23\x8b\x06\x0c\x22\xa4\x06\xdd\x23\x9a\x06\x15\x23\x92\x06\xea\x21\x7d\x06\x1a\x24\x7b\x06\x6c\x23\x7f\x06\x08\x22\x9f\x06\xe9\x23\x9a\x06\x4d\x23\xa0\x06\x1c\x22\x9c\x06\x0a\x24\x90\x06\x16\x23\x96\x06\x08\x22\x93\x06\xe6\x23\x8d\x06\x5e\x23\x90\x06\xeb\x21\xa1\x06\x18\x24\x9d\x06\x73\x23\x95\x06\x2d\x22\x9f\x06\x08\x24\xa2\x06\x81\x23\xa4\x06\x0e\x22\xaa\x06\xfd\x23\xa5\x06\x4d\x23\xa1\x06\x20\x22\x90\x06\x08\x24\x91\x06\x65\x23\x9a\x06\x28\x22\x8e\x06\xef\x23\x91\x06\x45\x23\x85\x06\x36\x22\x91\x06\xfc\x23\x9c\x06\x53\x23\x99\x06\xe1\x21\x9a\x06\xd6\x23\x8e\x06\x2b\x23\x8e\x06\xeb\x21\xa4\x06\x06\x24\x94\x06\x66\x23\x98\x06\x51\x22\x9e\x06\x2a\x24\xa1\x06\xb4\x23\x91\x06\x4b\x22\x9b\x06\xf6\x23\x93\x06\x86\x23\x9e\x06\x4e\x22\x9a\x06\x34\x24\x91\x06\x8d\x23\x96\x06\x88\x22\x91\x06\x0b\x24\x9e\x06\xb4\x23\xa2\x06\x7a\x22\x98\x06\x32\x24\xa8\x06\xd8\x23\xa2\x06\x7f\x22\x93\x06\x50\x24\x9f\x06\xbb\x23\x9c\x06\x51\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa1\x06\x73\x24\x8f\x06\x83\x23\x8e\x06\x86\x22\xa0\x06\x32\x24\x90\x06\x65\x23\x9b\x06\x75\x22\xab\x06\x3a\x24\x99\x06\x7e\x23\xa2\x06\x69\x22\xa2\x06\xfd\x23\xa4\x06\x81\x23\x9a\x06\x74\x22\x96\x06\xe7\x23\x9f\x06\x69\x23\x9a\x06\x69\x22\x99\x06\x45\x24\x9b\x06\x62\x23\x9d\x06\x83\x22\xa3\x06\x5e\x24\x96\x06\x6a\x23\x98\x06\x3b\x22\x95\x06\x37\x24\xa0\x06\xd6\x23\x9e\x06\x4c\x22\xaa\x06\x35\x24\xa0\x06\x5a\x23\x9d\x06\x62\x22\x9d\x06\x1e\x24\xa6\x06\x3c\x23\x9c\x06\x88\x22\x98\x06\x0e\x24\x90\x06\x80\x23\x97\x06\x25\x22\xa7\x06\x10\x24\xa9\x06\x9a\x23\x94\x06\x36\x22\xaa\x06\xfa\x23\x9d\x06\x57\x23\x9b\x06\x4b\x22\x9b\x06\xf3\x23\x98\x06\x1e\x23\x94\x06\x01\x22\x9e\x06\x38\x24\x9a\x06\x2f\x23\x90\x06\x2f\x22\x99\x06\xff\x23\x98\x06\x71\x23\x9c\x06\x5b\x22\xaf\x06\x3c\x24\x99\x06\x60\x23\xa2\x06\x5f\x22\xa1\x06\x2e\x24\x99\x06\x73\x23\x98\x06\x3d\x22\xa3\x06\x36\x24\xa6\x06\x99\x23\xa7\x06\x4a\x22\xa4\x06\x38\x24\xa8\x06\xba\x23\xa7\x06\x62\x22\x9c\x06\x71\x24\x97\x06\xc4\x23\x90\x06\x6a\x22\x99\x06\x57\x24\x8e\x06\x92\x23\xa3\x06\x81\x22\x92\x06\xfe\x23\x93\x06\xcb\x23\xa2\x06\x71\x22\xa4\x06\x45\x24\xa4\x06\x84\x23\xaa\x06\x8b\x22\xa5\x06\x08\x24\xa8\x06\xc2\x23\xa6\x06\x6d\x22\x9a\x06\xfc\x23\x9e\x06\x99\x23\xa1\x06\x49\x22\xa8\x06\xd7\x23\xa7\x06\x92\x23\x97\x06\x7a\x22\x9e\x06\xff\x23\x95\x06\x34\x23\x9c\x06\x48\x22\xa6\x06\xf3\x23\x9c\x06\x2b\x23\x9a\x06\x42\x22\x91\x06\x22\x24\x95\x06\x44\x23\x96\x06\x6e\x22\x9f\x06\xf4\x23\xa7\x06\x6d\x23\x96\x06\x71\x22\x9b\x06\x1c\x24\x9f\x06\x7e\x23\x9c\x06\x8d\x22\x95\x06\x74\x24\x8d\x06\x7f\x23\xa0\x06\x65\x22\xaa\x06\x35\x24\x9f\x06\x98\x23\xa0\x06\xc1\x22\x97\x06\x2a\x24\x98\x06\xa7\x23\x9e\x06\x6b\x22\xaa\x06\x97\x24\x9a\x06\x7a\x23\x98\x06\x73\x22\x96\x06\x30\x24\x97\x06\x8f\x23\x97\x06\x97\x22\xb2\x06\x65\x24\xb4\x06\x95\x23\x9c\x06\xb5\x22\x9e\x06\x3a\x24\xb0\x06\x95\x23\x9c\x06\xa4\x22\xa8\x06\x6c\x24\xa8\x06\xa2\x23\x9c\x06\xaf\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xac\x06\x7d\x24\x83\x06\x76\x23\x9e\x06\xa8\x22\x93\x06\xa9\x24\x7f\x06\x96\x23\xa3\x06\xb0\x22\xa2\x06\xb6\x24\x95\x06\x96\x23\x98\x06\x85\x22\xac\x06\xd1\x24\x8d\x06\x80\x23\x95\x06\xb8\x22\x8a\x06\x9d\x24\x8d\x06\xc8\x23\xa0\x06\xcb\x22\x9b\x06\x5c\x24\x9e\x06\xb2\x23\x9b\x06\xcd\x22\xa5\x06\x74\x24\x9d\x06\x99\x23\x9e\x06\xd9\x22\x9f\x06\x94\x24\xa8\x06\xd5\x23\x96\x06\xb6\x22\x9e\x06\x3e\x24\xa4\x06\xda\x23\xaf\x06\xb3\x22\xa8\x06\x43\x24\x92\x06\x66\x23\x97\x06\x7e\x22\x9b\x06\x43\x24\x8b\x06\xb3\x23\xa2\x06\xbf\x22\x8d\x06\x6c\x24\x92\x06\xeb\x23\x9b\x06\xce\x22\x98\x06\x8e\x24\x96\x06\xbd\x23\xa6\x06\xa8\x22\xb1\x06\xab\x24\xa4\x06\xac\x23\xa3\x06\xc5\x22\xad\x06\xc0\x24\x98\x06\xf7\x23\xa0\x06\xc7\x22\xac\x06\xa5\x24\x9f\x06\xd6\x23\xa2\x06\xa7\x22\xac\x06\x77\x24\x99\x06\xb4\x23\x9a\x06\x6e\x22\xb5\x06\xc0\x24\xb3\x06\xc2\x23\x9c\x06\x98\x22\xa7\x06\xb6\x24\x99\x06\xef\x23\x97\x06\x61\x22\xad\x06\xd9\x24\x8e\x06\xc1\x23\xa2\x06\x96\x22\xa6\x06\xac\x24\x9a\x06\xb1\x23\xa0\x06\xb4\x22\xa9\x06\xb2\x24\xaf\x06\xef\x23\xa6\x06\xd6\x22\xae\x06\xf7\x24\xa4\x06\x22\x24\x97\x06\xcc\x22\xad\x06\xa3\x24\xa8\x06\x0d\x24\xa4\x06\xe6\x22\xab\x06\xcc\x24\xae\x06\x18\x24\xb1\x06\x0e\x23\xac\x06\xf2\x24\xa6\x06\x19\x24\xa4\x06\x33\x23\x9e\x06\xc2\x24\xaa\x06\x35\x24\xb2\x06\x31\x23\xa8\x06\xbc\x24\xa6\x06\x33\x24\xa1\x06\x1b\x23\xad\x06\xf7\x24\xa8\x06\x30\x24\xab\x06\x2a\x23\xba\x06\xfe\x24\xb9\x06\x16\x24\xb1\x06\x1f\x23\xae\x06\x05\x25\x99\x06\x38\x24\xa6\x06\x43\x23\x8e\x06\x70\x25\x9e\x06\x95\x24\x9e\x06\x5b\x23\xab\x06\x62\x25\xa6\x06\x3f\x24\xa0\x06\x65\x23\xb4\x06\x0f\x25\xb5\x06\x32\x24\xb1\x06\x50\x23\xab\x06\x3f\x25\xa5\x06\x24\x24\xa5\x06\x3d\x23\xa5\x06\x0b\x25\xa7\x06\x27\x24\xad\x06\x45\x23\xa6\x06\x29\x25\xa6\x06\x1a\x24\xa7\x06\x30\x23\xa8\x06\x16\x25\xa0\x06\xfb\x23\xa1\x06\x01\x23\xad\x06\xe1\x24\x9d\x06\xd5\x23\xb7\x06\xc8\x22\xa9\x06\x16\x25\xa3\x06\xdc\x23\xa4\x06\xd4\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa1\x06\x31\x25\x97\x06\xe9\x23\x9a\x06\xfe\x22\x89\x06\x14\x25\x7c\x06\xbe\x23\x7e\x06\x09\x23\x77\x06\x32\x25\x75\x06\x30\x24\x70\x06\x04\x23\xb4\x06\xa5\x24\xb4\x06\x96\x23\xc0\x06\xa8\x22\x0b\x07\x36\x24\x09\x07\x12\x23\x09\x07\x56\x22\x8b\x07\xde\x23\x82\x07\xb6\x22\x77\x07\xa8\x21\xb9\x07\x97\x23\xa3\x07\x6a\x22\x94\x07\x61\x21\x69\x06\x17\x24\x64\x06\x8a\x22\x55\x06\xa3\x20\x4b\x06\xd9\x22\x3e\x06\x95\x21\x3c\x06\x43\x1f\x52\x07\x87\x22\x3d\x07\xa8\x21\x4c\x07\x51\x20\x62\x07\xde\x22\x6a\x07\x35\x22\x54\x07\xca\x20\xda\x06\x19\x23\xe5\x06\x7e\x22\xd4\x06\x23\x21\x8f\x06\x73\x23\x9a\x06\xcd\x22\x8b\x06\x61\x21\x4d\x06\xc9\x23\x47\x06\xf4\x22\x62\x06\xaf\x21\x60\x06\x3f\x24\x47\x06\x13\x23\x63\x06\xdb\x21\x4c\x06\x31\x24\x46\x06\xeb\x22\x53\x06\x91\x21\x6a\x06\x87\x23\x76\x06\xb6\x22\x6b\x06\x56\x21\x82\x06\x95\x23\x65\x06\xce\x22\x75\x06\x55\x21\x7d\x06\xcd\x23\x73\x06\x92\x22\x87\x06\x8f\x21\x7e\x06\xac\x23\x6a\x06\xbf\x22\x6f\x06\x89\x21\x84\x06\xf0\x23\x7f\x06\xaa\x22\x6c\x06\x87\x21\x53\x06\x2a\x24\x4c\x06\xde\x22\x79\x06\xce\x21\x7f\x06\xb0\x23\x77\x06\xce\x22\x81\x06\xbf\x21\x71\x06\xb6\x23\x5a\x06\xbe\x22\x82\x06\xb1\x21\x72\x06\x57\x23\x66\x06\xaf\x22\x79\x06\xbb\x21\x5a\x06\x79\x23\x5b\x06\xcf\x22\x78\x06\x83\x21\x8f\x06\x71\x23\x86\x06\xc6\x22\x71\x06\x81\x21\x66\x06\x6f\x23\x4d\x06\x8f\x22\x84\x06\x9a\x21\x76\x06\x34\x23\x77\x06\x93\x22\x63\x06\x72\x21\x7b\x06\x84\x23\x78\x06\x9b\x22\x75\x06\x89\x21\x69\x06\x53\x23\x72\x06\x9e\x22\x6e\x06\x4a\x21\x7a\x06\x0c\x23\x72\x06\xba\x22\x79\x06\x77\x21\x72\x06\x57\x23\x62\x06\xd5\x22\x6f\x06\x55\x21\x5c\x06\x4b\x23\x62\x06\xbd\x22\x86\x06\x7b\x21\x72\x06\x27\x23\x6d\x06\xbf\x22\x5d\x06\x57\x21\x63\x06\x3a\x23\x76\x06\x97\x22\x6f\x06\x6b\x21\x71\x06\x3f\x23\x70\x06\xa9\x22\x7e\x06\x65\x21\x7b\x06\x05\x23\x7a\x06\xba\x22\x76\x06\x63\x21\x88\x06\x19\x23\x88\x06\xaf\x22\x7d\x06\x4e\x21\x71\x06\x14\x23\x79\x06\x9e\x22\x6b\x06\x5a\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x77\x06\x3c\x23\x7d\x06\xf1\x22\x7a\x06\x59\x21\x7b\x06\x77\x23\x73\x06\xa3\x22\x7a\x06\x68\x21\x7e\x06\x77\x23\x6a\x06\xaa\x22\x6f\x06\x94\x21\x83\x06\x44\x23\x7c\x06\x0e\x23\x6c\x06\xa0\x21\x7c\x06\x60\x23\x74\x06\xd0\x22\x75\x06\xa1\x21\x76\x06\x2e\x23\x86\x06\x9d\x22\x71\x06\x70\x21\x6e\x06\x18\x23\x66\x06\xab\x22\x78\x06\x87\x21\x7d\x06\x3f\x23\x66\x06\xe2\x22\x72\x06\x7a\x21\x6d\x06\xdf\x22\x69\x06\x70\x22\x77\x06\x6e\x21\x74\x06\xfd\x22\x78\x06\x5f\x22\x78\x06\x69\x21\x70\x06\xf7\x22\x68\x06\x68\x22\x74\x06\x2a\x21\x83\x06\x05\x23\x78\x06\xab\x22\x74\x06\x3a\x21\x74\x06\xe7\x22\x64\x06\x71\x22\x6b\x06\x27\x21\x59\x06\x0e\x23\x5e\x06\x8d\x22\x49\x06\x58\x21\x63\x06\x1f\x23\x62\x06\x83\x22\x67\x06\x1b\x21\x78\x06\xf3\x22\x72\x06\xa0\x22\x77\x06\x23\x21\x79\x06\xe6\x22\x7a\x06\x8c\x22\x71\x06\x2f\x21\x74\x06\x3f\x23\x68\x06\x7c\x22\x7e\x06\x36\x21\x65\x06\xce\x22\x69\x06\x94\x22\x6a\x06\x2e\x21\x67\x06\x1d\x23\x62\x06\x8b\x22\x6f\x06\x03\x21\x4c\x06\x05\x23\x4c\x06\x9a\x22\x50\x06\xe2\x20\x5e\x06\xce\x22\x61\x06\x5e\x22\x73\x06\x26\x21\x7c\x06\x00\x23\x72\x06\x6d\x22\x78\x06\xf7\x20\x75\x06\x3a\x23\x79\x06\x6e\x22\x6c\x06\x0f\x21\x4d\x06\x14\x23\x4e\x06\xad\x22\x66\x06\x1c\x21\x51\x06\x14\x23\x4a\x06\x96\x22\x67\x06\xfa\x20\x6f\x06\xf4\x22\x64\x06\xc7\x22\x7a\x06\x1a\x21\x75\x06\x23\x23\x76\x06\x73\x22\x71\x06\x0e\x21\x79\x06\x16\x23\x72\x06\x8a\x22\x64\x06\x06\x21\x7e\x06\x23\x23\x7a\x06\xb1\x22\x80\x06\x3a\x21\x62\x06\xf3\x22\x51\x06\xc7\x22\x77\x06\x27\x21\x5b\x06\x51\x23\x59\x06\xd4\x22\x6d\x06\x5a\x21\x65\x06\x87\x23\x5c\x06\xef\x22\x77\x06\x2d\x21\x5c\x06\x40\x23\x5f\x06\xa0\x22\x62\x06\x3c\x21\x72\x06\xce\x22\x6f\x06\x74\x22\x79\x06\x37\x21\x82\x06\x01\x23\x6d\x06\x9d\x22\x68\x06\x10\x21\x5c\x06\xca\x22\x5a\x06\x95\x22\x6d\x06\x1b\x21\x72\x06\xf4\x22\x72\x06\xb8\x22\x70\x06\x2e\x21\x6c\x06\x17\x23\x69\x06\xb8\x22\x73\x06\x41\x21\x72\x06\x2a\x23\x6b\x06\x99\x22\x7f\x06\x73\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x83\x06\x0b\x23\x62\x06\xac\x22\x6e\x06\x54\x21\x7c\x06\x09\x23\x76\x06\x88\x22\x6a\x06\x14\x21\x70\x06\xdc\x22\x70\x06\x8f\x22\x65\x06\x5c\x21\x66\x06\xc9\x22\x7d\x06\x9e\x22\x67\x06\x22\x21\x6f\x06\x0a\x23\x71\x06\x92\x22\x74\x06\x3c\x21\x82\x06\x18\x23\x7a\x06\xaa\x22\x78\x06\x50\x21\x73\x06\x96\x23\x6e\x06\xbc\x22\x70\x06\x4b\x21\x6e\x06\x50\x23\x6e\x06\x86\x22\x73\x06\x39\x21\x7a\x06\x03\x23\x67\x06\x8c\x22\x74\x06\x1e\x21\x66\x06\xe0\x22\x61\x06\x7b\x22\x76\x06\x04\x21\x65\x06\x1d\x23\x58\x06\x68\x22\x69\x06\x12\x21\x76\x06\x02\x23\x65\x06\x95\x22\x7a\x06\x18\x21\x67\x06\x18\x23\x76\x06\xc4\x22\x6e\x06\xfc\x20\x75\x06\x83\x23\x82\x06\xce\x22\x74\x06\x3b\x21\x82\x06\x53\x23\x82\x06\xb8\x22\x74\x06\x2f\x21\x72\x06\x3e\x23\x70\x06\xa2\x22\x76\x06\x29\x21\x7c\x06\x2c\x23\x74\x06\xa2\x22\x7e\x06\x1d\x21\x6e\x06\x15\x23\x7d\x06\xb3\x22\x7a\x06\x3f\x21\x80\x06\x27\x23\x7c\x06\xb7\x22\x7c\x06\x3d\x21\x74\x06\x35\x23\x7c\x06\xbf\x22\x77\x06\x32\x21\x7f\x06\x60\x23\x73\x06\xe6\x22\x76\x06\x5b\x21\x82\x06\xbc\x23\x76\x06\x26\x23\x76\x06\x45\x21\x5f\x06\x92\x23\x5e\x06\xb8\x22\x61\x06\x40\x21\x74\x06\x44\x23\x69\x06\xa8\x22\x7b\x06\x42\x21\x70\x06\x67\x23\x58\x06\xb8\x22\x66\x06\x3d\x21\x6d\x06\x4a\x23\x60\x06\xb7\x22\x77\x06\x46\x21\x78\x06\x6e\x23\x71\x06\xd3\x22\x65\x06\x49\x21\x77\x06\x83\x23\x77\x06\xf1\x22\x71\x06\x8f\x21\x71\x06\x8a\x23\x74\x06\x31\x23\x66\x06\x7f\x21\x75\x06\xf9\x23\x79\x06\xdf\x22\x75\x06\x3d\x21\x74\x06\x51\x23\x71\x06\xc7\x22\x74\x06\x2e\x21\x66\x06\x20\x23\x68\x06\x96\x22\x77\x06\x2d\x21\x72\x06\x1a\x23\x57\x06\xb9\x22\x70\x06\x15\x21\x72\x06\x4f\x23\x6c\x06\xa5\x22\x6e\x06\x42\x21\x64\x06\xf7\x23\x6a\x06\x68\x23\x69\x06\x29\x21\x58\x06\x30\x23\x4b\x06\xce\x22\x6a\x06\x2d\x21\x6c\x06\x4a\x23\x6b\x06\xd6\x22\x79\x06\x6e\x21\x75\x06\x0e\x23\x77\x06\x9d\x22\x7f\x06\x2a\x21\x67\x06\x21\x23\x60\x06\x91\x22\x6d\x06\x4c\x21\x72\x06\xe5\x22\x76\x06\x9f\x22\x73\x06\x10\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x76\x06\x2e\x23\x70\x06\x7f\x22\x73\x06\x27\x21\x6c\x06\x0d\x23\x71\x06\xb3\x22\x5f\x06\x25\x21\x7a\x06\x7c\x23\x6d\x06\xc3\x22\x7b\x06\x27\x21\x6c\x06\x67\x23\x6e\x06\x8a\x22\x63\x06\x19\x21\x76\x06\x0a\x23\x70\x06\x6f\x22\x71\x06\x36\x21\x62\x06\xd6\x22\x6d\x06\x93\x22\x73\x06\x4a\x21\x66\x06\xf9\x22\x6b\x06\xa6\x22\x67\x06\x43\x21\x79\x06\xd6\x22\x6f\x06\x8f\x22\x75\x06\x77\x21\x77\x06\x08\x23\x6c\x06\xb0\x22\x69\x06\x53\x21\x6f\x06\xe4\x22\x82\x06\xb1\x22\x6a\x06\x39\x21\x77\x06\xe9\x22\x79\x06\x8a\x22\x65\x06\x58\x21\x67\x06\xf0\x22\x65\x06\xd0\x22\x72\x06\x3e\x21\x72\x06\x0d\x23\x65\x06\xa1\x22\x77\x06\x42\x21\x79\x06\xcf\x22\x7b\x06\xb1\x22\x7f\x06\xa0\x21\x5c\x06\x40\x23\x4a\x06\xc6\x22\x71\x06\x5a\x21\x74\x06\x3e\x23\x74\x06\xe9\x22\x73\x06\x8b\x21\x75\x06\xd6\x23\x6c\x06\x44\x23\x78\x06\x9c\x21\x7e\x06\x1e\x24\x6b\x06\x19\x23\x81\x06\xf8\x21\x89\x06\x94\x23\x85\x06\x1b\x23\x83\x06\x87\x21\x79\x06\x87\x23\x74\x06\xe1\x22\x72\x06\x6c\x21\x6b\x06\x8d\x23\x77\x06\x08\x23\x71\x06\x7a\x21\x6f\x06\x70\x23\x6f\x06\xe8\x22\x74\x06\xa3\x21\x83\x06\x18\x24\x73\x06\x17\x23\x7d\x06\xd3\x21\x83\x06\xe0\x24\x62\x06\xce\x22\x7c\x06\xfe\x21\x80\x06\x0f\x25\x7a\x06\x10\x23\x7b\x06\xfe\x21\x78\x06\x04\x24\x73\x06\xee\x22\x76\x06\xf4\x21\x6c\x06\x71\x23\x7f\x06\x26\x23\x71\x06\xab\x21\x7b\x06\x7d\x23\x7c\x06\x06\x23\x86\x06\x93\x21\x7e\x06\x6d\x23\x7c\x06\xd7\x22\x7b\x06\x74\x21\x7a\x06\x58\x23\x78\x06\xce\x22\x6a\x06\x4c\x21\x77\x06\x8b\x23\x75\x06\xdb\x22\x66\x06\x65\x21\x64\x06\xe9\x23\x53\x06\xf2\x22\x73\x06\xc0\x21\x77\x06\x71\x23\x74\x06\xee\x22\x71\x06\x7e\x21\x77\x06\x48\x23\x78\x06\xbd\x22\x74\x06\x66\x21\x74\x06\x6e\x23\x74\x06\xd6\x22\x7f\x06\x8e\x21\x7b\x06\x60\x23\x7d\x06\xbf\x22\x7b\x06\x69\x21\x79\x06\x14\x23\x80\x06\xe5\x22\x7b\x06\x68\x21\x78\x06\x3f\x23\x71\x06\xbf\x22\x77\x06\x6c\x21\x72\x06\x6d\x23\x70\x06\xf9\x22\x78\x06\x81\x21\x71\x06\x71\x23\x82\x06\xea\x22\x70\x06\x79\x21\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x79\x06\x44\x23\x77\x06\xb8\x22\x73\x06\x5e\x21\x74\x06\x2d\x23\x73\x06\xdd\x22\x74\x06\x3b\x21\x6e\x06\x4d\x23\x6e\x06\xbb\x22\x6e\x06\x53\x21\x6e\x06\x22\x23\x6f\x06\xc2\x22\x6a\x06\x47\x21\x75\x06\x1a\x23\x73\x06\xa2\x22\x72\x06\x54\x21\x7a\x06\x40\x23\x84\x06\xb8\x22\x7c\x06\x4e\x21\x73\x06\x46\x23\x70\x06\x7c\x22\x71\x06\x23\x21\x55\x06\x1e\x23\x5b\x06\x91\x22\x68\x06\x20\x21\x78\x06\x0d\x23\x6f\x06\x60\x22\x76\x06\x21\x21\x5e\x06\x3b\x23\x6f\x06\x9b\x22\x61\x06\x47\x21\x7f\x06\xfd\x22\x7d\x06\xb1\x22\x78\x06\x62\x21\x7e\x06\x33\x23\x78\x06\xe5\x22\x7d\x06\x74\x21\x68\x06\x2d\x23\x78\x06\x0a\x23\x6a\x06\x58\x21\x6f\x06\x77\x23\x76\x06\x25\x23\x68\x06\x88\x21\x7d\x06\x61\x23\x80\x06\xc4\x22\x75\x06\x5c\x21\x7e\x06\x9b\x23\x7a\x06\x7f\x22\x7b\x06\x51\x21\x7e\x06\xd2\x23\x76\x06\xcc\x22\x76\x06\x43\x21\x6a\x06\xd4\x23\x6a\x06\x89\x22\x71\x06\x4e\x21\x85\x06\xea\x23\x77\x06\xc9\x22\x73\x06\x3d\x21\x82\x06\x16\x24\x72\x06\xdc\x22\x6b\x06\x61\x21\x71\x06\xf8\x23\x69\x06\x2a\x23\x73\x06\x6e\x21\x74\x06\x38\x23\x78\x06\xf0\x22\x78\x06\x66\x21\x6b\x06\x1d\x23\x58\x06\x90\x22\x62\x06\x47\x21\x7a\x06\x3a\x23\x6d\x06\x87\x22\x67\x06\x2e\x21\x67\x06\x36\x23\x63\x06\x8a\x22\x67\x06\x1c\x21\x6a\x06\x6b\x23\x5a\x06\x91\x22\x66\x06\x1d\x21\x7e\x06\xd5\x23\x73\x06\x82\x22\x65\x06\x34\x21\x6d\x06\x75\x24\x5f\x06\x99\x22\x68\x06\x6e\x21\x86\x06\xa2\x24\x7e\x06\xa1\x22\x6f\x06\x97\x21\x6f\x06\x05\x24\x5b\x06\x50\x22\x61\x06\x3e\x21\x59\x06\x0b\x23\x51\x06\x8d\x22\x5f\x06\x21\x21\x76\x06\x0f\x23\x6d\x06\x4d\x22\x66\x06\xf6\x20\x71\x06\xf1\x22\x7a\x06\x4f\x22\x71\x06\x12\x21\x50\x06\x55\x23\x55\x06\x1b\x22\x73\x06\x27\x21\x5e\x06\x93\x23\x5e\x06\x94\x22\x6b\x06\xf0\x20\x57\x06\x0c\x23\x4e\x06\x3d\x22\x6c\x06\xca\x20\x61\x06\x51\x23\x56\x06\x52\x22\x76\x06\xa7\x20\x7f\x06\x35\x23\x68\x06\x0f\x22\x65\x06\xcd\x20\x74\x06\x14\x23\x71\x06\x64\x22\x6d\x06\xf1\x20\x77\x06\xb0\x22\x64\x06\x5d\x22\x82\x06\xf5\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x55\x06\x02\x23\x55\x06\x4c\x22\x70\x06\x09\x21\x5e\x06\x87\x23\x48\x06\x8a\x22\x70\x06\x2d\x21\x6b\x06\x68\x23\x6c\x06\x85\x22\x6d\x06\x27\x21\x7d\x06\xaf\x23\x74\x06\x8e\x22\x67\x06\x13\x21\x78\x06\x7a\x23\x73\x06\xcf\x22\x79\x06\x32\x21\x74\x06\x9b\x23\x6c\x06\x71\x22\x7e\x06\x18\x21\x7d\x06\x62\x23\x6a\x06\x34\x22\x6b\x06\x09\x21\x6d\x06\x1a\x23\x64\x06\x3c\x22\x6d\x06\xe1\x20\x7c\x06\x09\x23\x70\x06\x6d\x22\x74\x06\xe7\x20\x82\x06\x5c\x23\x77\x06\x75\x22\x6b\x06\xfb\x20\x5c\x06\x28\x23\x5f\x06\x53\x22\x62\x06\xda\x20\x6d\x06\x0c\x23\x5e\x06\x61\x22\x63\x06\xd1\x20\x68\x06\xe4\x22\x68\x06\x80\x22\x65\x06\xd0\x20\x73\x06\xe7\x22\x73\x06\x7a\x22\x6a\x06\xe9\x20\x6e\x06\x07\x23\x60\x06\x60\x22\x6c\x06\xcc\x20\x79\x06\x26\x23\x73\x06\x52\x22\x74\x06\x0d\x21\x6c\x06\x60\x23\x64\x06\xe2\x22\x54\x06\xd8\x20\x50\x06\x10\x23\x63\x06\x22\x23\x72\x06\xe9\x20\x72\x06\xea\x22\x6f\x06\x7e\x22\x6a\x06\xd3\x20\x77\x06\xcc\x22\x7b\x06\x73\x22\x72\x06\xd0\x20\x5b\x06\xd6\x22\x5f\x06\x57\x22\x7a\x06\xec\x20\x58\x06\x11\x23\x53\x06\x41\x22\x6c\x06\xed\x20\x6e\x06\xfb\x22\x68\x06\x8a\x22\x6e\x06\xd7\x20\x78\x06\x94\x22\x6d\x06\x74\x22\x65\x06\xda\x20\x73\x06\x81\x22\x72\x06\x45\x22\x69\x06\xd4\x20\x6e\x06\xe9\x22\x63\x06\x40\x22\x5f\x06\xef\x20\x79\x06\xcc\x22\x6e\x06\x2e\x22\x79\x06\xd5\x20\x72\x06\xf4\x22\x72\x06\x3c\x22\x70\x06\xde\x20\x57\x06\x2c\x23\x58\x06\x3a\x22\x67\x06\xcb\x20\x5e\x06\x3b\x23\x59\x06\x5d\x22\x66\x06\xb4\x20\x79\x06\x08\x23\x69\x06\x2e\x22\x6d\x06\x9c\x20\x72\x06\xf1\x22\x68\x06\xfc\x21\x63\x06\xa2\x20\x7b\x06\x95\x22\x6f\x06\x33\x22\x72\x06\xa6\x20\x6f\x06\xd5\x22\x60\x06\x2f\x22\x76\x06\xbf\x20\x77\x06\x12\x23\x8b\x06\x28\x22\x6f\x06\x8d\x20\x3f\x06\x05\x23\x4b\x06\x57\x22\x5d\x06\xb9\x20\x56\x06\xfe\x22\x5c\x06\x32\x22\x6a\x06\xc7\x20\x6b\x06\x78\x23\x61\x06\x12\x22\x60\x06\xbb\x20\x66\x06\x71\x23\x53\x06\x20\x22\x6f\x06\xc0\x20\x88\x06\x44\x23\x72\x06\x2c\x22\x6f\x06\xaf\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x77\x06\xc4\x22\x73\x06\x27\x22\x62\x06\x9b\x20\x60\x06\xbb\x22\x6b\x06\x16\x22\x68\x06\xce\x20\x6d\x06\xec\x22\x66\x06\x3b\x22\x64\x06\xeb\x20\x53\x06\x26\x23\x51\x06\x39\x22\x76\x06\x01\x21\x74\x06\x38\x23\x79\x06\x59\x22\x69\x06\xdc\x20\x6c\x06\x04\x23\x72\x06\x27\x22\x69\x06\xf8\x20\x74\x06\x27\x23\x69\x06\x24\x22\x62\x06\xd7\x20\x56\x06\xfa\x22\x57\x06\x16\x22\x63\x06\xaf\x20\x6b\x06\xc4\x22\x6a\x06\x1b\x22\x71\x06\xae\x20\x5d\x06\xcb\x22\x4f\x06\x22\x22\x67\x06\xd5\x20\x5b\x06\x95\x22\x69\x06\x80\x22\x64\x06\xc9\x20\x6e\x06\xcd\x22\x78\x06\x59\x22\x6d\x06\xce\x20\x6b\x06\x28\x23\x66\x06\x66\x22\x6b\x06\xd8\x20\x5a\x06\x09\x23\x48\x06\x21\x22\x65\x06\xad\x20\x5d\x06\xd4\x22\x46\x06\x15\x22\x73\x06\x94\x20\x63\x06\xc6\x22\x6e\x06\x39\x22\x60\x06\x99\x20\x6d\x06\xd1\x22\x69\x06\xf4\x21\x73\x06\x89\x20\x70\x06\xbf\x22\x5d\x06\xe6\x21\x71\x06\x71\x20\x76\x06\x8e\x22\x6b\x06\x39\x22\x5f\x06\x7c\x20\x51\x06\xd5\x22\x4e\x06\x6d\x22\x60\x06\x77\x20\x61\x06\xb0\x22\x76\x06\x22\x22\x63\x06\x6b\x20\x6c\x06\xe1\x22\x5b\x06\xd8\x21\x67\x06\x79\x20\x5c\x06\xa9\x22\x50\x06\xfa\x21\x5a\x06\x58\x20\x67\x06\x9a\x22\x62\x06\x10\x22\x6c\x06\x80\x20\x70\x06\xb3\x22\x65\x06\xf5\x21\x6d\x06\x92\x20\x5f\x06\xdc\x22\x55\x06\xfa\x21\x6e\x06\xbb\x20\x62\x06\x1a\x23\x55\x06\xf7\x21\x5e\x06\x8f\x20\x66\x06\xb7\x22\x6d\x06\x2b\x22\x70\x06\xb9\x20\x67\x06\x80\x22\x68\x06\xfb\x21\x77\x06\x91\x20\x67\x06\x9b\x22\x66\x06\xc1\x21\x6e\x06\x40\x20\x6b\x06\xa7\x22\x63\x06\xbb\x21\x63\x06\x5c\x20\x5b\x06\xae\x22\x55\x06\xcd\x21\x63\x06\x58\x20\x4d\x06\xed\x22\x39\x06\xde\x21\x60\x06\x86\x20\x70\x06\xe8\x22\x63\x06\xc3\x21\x64\x06\x64\x20\x5c\x06\x01\x23\x6a\x06\xca\x21\x6a\x06\xb2\x20\x41\x06\x84\x22\x41\x06\xe3\x21\x3f\x06\x74\x20\x6e\x06\x61\x22\x65\x06\xd2\x21\x6c\x06\x49\x20\x78\x06\xa5\x22\x67\x06\xb0\x21\x67\x06\x67\x20\x5d\x06\x6d\x22\x58\x06\x95\x21\x65\x06\x25\x20\x66\x06\xaa\x22\x61\x06\xac\x21\x58\x06\x3e\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x50\x06\xde\x22\x46\x06\xe6\x21\x54\x06\x61\x20\x58\x06\xe1\x22\x63\x06\x04\x22\x66\x06\x51\x20\x64\x06\x73\x22\x5d\x06\x7b\x21\x53\x06\x51\x20\x5e\x06\x4e\x22\x62\x06\xab\x21\x5f\x06\x41\x20\x69\x06\x3b\x22\x68\x06\xc3\x21\x66\x06\x3b\x20\x36\x06\x56\x22\x3e\x06\x08\x22\x53\x06\x4d\x20\x5f\x06\x74\x22\x62\x06\x0b\x22\x66\x06\x4c\x20\x55\x06\x1d\x23\x5b\x06\xd5\x21\x52\x06\x5b\x20\x51\x06\xc3\x22\x52\x06\xc7\x21\x64\x06\x62\x20\x6d\x06\x4a\x22\x6c\x06\xe2\x21\x6e\x06\x30\x20\x6e\x06\x6f\x22\x69\x06\xcb\x21\x6b\x06\x4d\x20\x5e\x06\x49\x22\x5c\x06\xab\x21\x59\x06\x12\x20\x66\x06\x55\x22\x64\x06\xa8\x21\x68\x06\x38\x20\x41\x06\x4b\x22\x42\x06\xda\x21\x61\x06\x49\x20\x62\x06\x3f\x22\x6a\x06\x13\x22\x69\x06\x48\x20\x44\x06\x32\x23\x3c\x06\x3b\x22\x6d\x06\x6b\x20\x4b\x06\xc5\x22\x46\x06\x77\x22\x38\x06\xbb\x20\x57\x06\x81\x22\x6e\x06\xe6\x21\x5a\x06\x3b\x20\x68\x06\x05\x22\x6c\x06\x80\x21\x5e\x06\x33\x20\x4d\x06\x56\x22\x54\x06\xcd\x21\x5a\x06\x38\x20\x75\x06\x6d\x22\x5e\x06\xcd\x21\x6f\x06\x3b\x20\x6b\x06\x34\x22\x69\x06\xca\x21\x6b\x06\x77\x20\x64\x06\x3c\x22\x5a\x06\xb8\x21\x5b\x06\x1b\x20\x63\x06\x38\x22\x61\x06\xb3\x21\x5d\x06\x4f\x20\x72\x06\xfb\x21\x6c\x06\xcb\x21\x60\x06\x25\x20\x60\x06\x14\x22\x63\x06\xff\x21\x6c\x06\x27\x20\x6a\x06\x2a\x22\x6a\x06\xe1\x21\x72\x06\x08\x20\x61\x06\x41\x22\x64\x06\xd2\x21\x69\x06\x0d\x20\x5f\x06\x68\x22\x4f\x06\xd3\x21\x64\x06\x3f\x20\x58\x06\x90\x22\x4a\x06\xde\x21\x6b\x06\x9b\x20\x60\x06\x9f\x22\x53\x06\xc6\x21\x6a\x06\x22\x20\x6b\x06\x99\x22\x5e\x06\x13\x22\x5b\x06\x0e\x20\x67\x06\x9c\x22\x58\x06\xd2\x21\x6e\x06\x51\x20\x73\x06\x27\x23\x6a\x06\xc7\x21\x72\x06\x14\x20\x73\x06\xc2\x22\x6a\x06\x1e\x22\x71\x06\x85\x20\x73\x06\xa2\x22\x67\x06\xdc\x21\x6f\x06\x4a\x20\x71\x06\xf2\x22\x5c\x06\x0a\x22\x5e\x06\x62\x20\x6f\x06\x1a\x23\x76\x06\x69\x22\x5b\x06\x48\x20\x63\x06\xca\x22\x6f\x06\x16\x22\x61\x06\x49\x20\x62\x06\x48\x23\x4d\x06\xe0\x21\x73\x06\x64\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x60\x06\xc4\x22\x55\x06\xc8\x21\x6c\x06\x3c\x20\x70\x06\xbe\x22\x63\x06\xd7\x21\x63\x06\x76\x20\x5b\x06\xb6\x22\x53\x06\xbe\x21\x5c\x06\x59\x20\x5b\x06\x83\x22\x57\x06\xb5\x21\x6a\x06\x25\x20\x6d\x06\x36\x23\x58\x06\xa2\x21\x65\x06\x3f\x20\x5c\x06\x11\x23\x42\x06\x9d\x21\x62\x06\x2e\x20\x3e\x06\x71\x23\x26\x06\xe1\x21\x5c\x06\x91\x20\x6d\x06\x11\x23\x5f\x06\xb4\x21\x66\x06\x5e\x20\x87\x06\x2e\x23\x72\x06\x64\x21\x6f\x06\x46\x20\x4b\x06\xf8\x22\x3b\x06\xba\x21\x61\x06\x1c\x20\x64\x06\x73\x22\x6a\x06\xab\x21\x63\x06\x03\x20\x5c\x06\xc3\x22\x5a\x06\x7e\x21\x4e\x06\x76\x1f\x65\x06\xe8\x22\x58\x06\x87\x21\x60\x06\x3e\x1f\x60\x06\x27\x22\x47\x06\x53\x21\x5b\x06\x6e\x1f\x4e\x06\x7c\x22\x50\x06\x80\x21\x67\x06\x7d\x1f\x65\x06\xd3\x22\x64\x06\x9a\x21\x63\x06\x07\x20\x69\x06\x49\x23\x61\x06\x16\x22\x5f\x06\x68\x20\x73\x06\xcd\x22\x77\x06\x4a\x22\x67\x06\x4a\x20\x6d\x06\x21\x23\x6e\x06\xd1\x21\x66\x06\x0b\x20\x56\x06\x52\x22\x5d\x06\xab\x21\x6e\x06\x29\x20\x4c\x06\xdc\x22\x3a\x06\xad\x21\x5e\x06\x41\x1f\xb1\x08\xff\xff\xbb\x08\xff\xff\xb7\x08\xff\xff\x00\x00\x0a\x15\x00\x00\xc5\x15\x00\x00\x7b\x16\x00\x00\x0a\x15\x00\x00\xc5\x15\x00\x00\x7b\x16\x00\x00\x1a\x15\x00\x00\xd7\x15\x00\x00\x7b\x16\x00\x00\x1a\x15\x00\x00\xd7\x15\x00\x00\x7e\x16\xd4\x08\xff\xff\xdd\x08\xff\xff\xdd\x08\xff\xff\x8e\x06\xf0\x24\x78\x06\x0f\x23\x7b\x06\x4c\x21\x60\x06\x1b\x24\x55\x06\x7d\x23\x80\x06\xe1\x21\x88\x06\x92\x24\x7b\x06\x6e\x23\x8b\x06\x53\x22\x8a\x06\x72\x24\x80\x06\x68\x23\x8c\x06\x57\x22\x74\x06\x07\x25\x55\x06\x74\x23\x8f\x06\x62\x22\x95\x06\x2b\x25\x91\x06\x8e\x23\x81\x06\x60\x22\xa2\x06\x7a\x26\x83\x06\xbc\x23\x9f\x06\xab\x22\x8a\x06\x48\x25\x8a\x06\xda\x23\x79\x06\xec\x22\x87\x06\xbf\x24\x85\x06\x5e\x23\x84\x06\x87\x22\x87\x06\xfb\x24\x72\x06\xc2\x23\x9f\x06\x86\x22\x83\x06\x06\x25\x77\x06\x91\x23\x95\x06\x95\x22\x9d\x06\xf9\x24\x8d\x06\x8e\x23\x8f\x06\xa1\x22\x95\x06\x3b\x25\x77\x06\x93\x23\x8f\x06\xcf\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x99\x06\xe2\x25\x87\x06\xb8\x23\x8c\x06\x28\x23\xa3\x06\x1a\x26\x8b\x06\xda\x23\x89\x06\x41\x23\xa3\x06\x82\x25\x82\x06\x86\x23\x90\x06\xe0\x22\x9c\x06\x3d\x25\x8d\x06\xa8\x23\x90\x06\xc8\x22\x9a\x06\xd4\x24\x91\x06\x8e\x23\x95\x06\xb5\x22\x6e\x06\xc1\x24\x66\x06\x8c\x23\x95\x06\xb5\x22\x89\x06\x12\x25\x75\x06\x8a\x23\x8f\x06\x93\x22\x92\x06\x50\x25\x89\x06\xb5\x23\x86\x06\xc2\x22\x90\x06\x72\x25\x99\x06\xf4\x23\x91\x06\xdf\x22\x80\x06\xd9\x24\x8c\x06\xb1\x23\x8a\x06\x96\x22\x6d\x06\x9a\x24\x58\x06\xb0\x23\x96\x06\x55\x22\x8f\x06\xb2\x24\x7d\x06\x84\x23\x96\x06\x60\x22\x72\x06\xc8\x24\x67\x06\x9d\x23\x77\x06\x33\x22\x7d\x06\x9b\x24\x7a\x06\x84\x23\x8b\x06\xe2\x21\x81\x06\xbf\x24\x7f\x06\x99\x23\x7c\x06\xdb\x21\x94\x06\x02\x25\x85\x06\xec\x23\x7e\x06\xd7\x21\x9b\x06\xb0\x24\x7e\x06\x4c\x23\x7b\x06\x4d\x21\x80\x06\x82\x24\x7a\x06\x34\x23\x80\x06\x41\x21\x86\x06\x0b\x24\x96\x06\x53\x23\x86\x06\x75\x21\x89\x06\x61\x24\x88\x06\x8e\x23\x8b\x06\xc4\x21\x97\x06\x5a\x24\x8d\x06\xa1\x23\x92\x06\x2e\x22\x90\x06\xc1\x24\x79\x06\x7f\x23\x89\x06\x45\x22\x96\x06\xf5\x24\x80\x06\x2f\x24\x9e\x06\xd0\x22\x91\x06\x81\x24\x8a\x06\x05\x24\x8d\x06\x82\x22\x87\x06\x3b\x24\x8b\x06\xe2\x23\x89\x06\x86\x22\x8d\x06\x28\x24\x86\x06\x91\x23\x8c\x06\x72\x22\x8a\x06\x20\x24\x7a\x06\x6a\x23\x8a\x06\x3e\x22\x90\x06\x59\x24\x8b\x06\x5e\x23\x91\x06\x58\x22\x76\x06\x1e\x24\x7c\x06\x95\x23\x91\x06\x2e\x22\x8b\x06\xcb\x24\x75\x06\x99\x23\x74\x06\x66\x22\x85\x06\xf4\x24\x91\x06\xb7\x23\x89\x06\x7a\x22\x94\x06\x89\x24\x8c\x06\x70\x23\x97\x06\x34\x22\x88\x06\x72\x24\x85\x06\x62\x23\x7f\x06\x17\x22\x8b\x06\x45\x24\x8b\x06\x87\x23\x8b\x06\x4f\x22\x98\x06\x4b\x24\x8b\x06\x7f\x23\x89\x06\x2f\x22\x8f\x06\x9f\x24\x84\x06\x4c\x23\x92\x06\x51\x22\x94\x06\xfb\x24\x9c\x06\xda\x23\x97\x06\x7a\x22\x9a\x06\xdd\x24\x91\x06\xb3\x23\x91\x06\x86\x22\x8e\x06\x41\x24\x8b\x06\x69\x23\x81\x06\x4f\x22\x98\x06\x3c\x24\x90\x06\x4f\x23\x83\x06\x1d\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8c\x06\x5e\x24\x8a\x06\x50\x23\x7d\x06\x01\x22\x95\x06\x3b\x24\x87\x06\x1d\x23\x8d\x06\xa7\x21\x73\x06\x5e\x24\x75\x06\x88\x23\x7e\x06\xac\x21\x91\x06\x79\x24\x91\x06\xe1\x23\x74\x06\xbd\x21\x81\x06\x2f\x25\x72\x06\x0d\x24\x91\x06\x2c\x22\x79\x06\xa2\x24\x75\x06\xc0\x23\x92\x06\x35\x22\x89\x06\x92\x24\x7a\x06\x59\x23\x82\x06\x18\x22\x89\x06\x45\x24\x7d\x06\x6e\x23\x8b\x06\x1e\x22\x81\x06\x7e\x24\x79\x06\x83\x23\x8f\x06\x0e\x22\x85\x06\x2f\x24\x81\x06\x6c\x23\x84\x06\x1b\x22\x97\x06\x69\x24\x82\x06\x50\x23\x8a\x06\x35\x22\x83\x06\xa3\x24\x7f\x06\x97\x23\x98\x06\x6d\x22\x96\x06\xa0\x24\x86\x06\x9f\x23\x93\x06\x7d\x22\x93\x06\x3c\x24\x8c\x06\x70\x23\x91\x06\x54\x22\x97\x06\x7d\x24\x85\x06\x68\x23\x95\x06\x50\x22\x92\x06\x99\x24\x92\x06\x7d\x23\x83\x06\x5d\x22\x7a\x06\xd8\x24\x67\x06\xc5\x23\x61\x06\x92\x22\x90\x06\xc0\x24\x8c\x06\xaf\x23\x86\x06\x91\x22\x9a\x06\x3a\x25\x9a\x06\x33\x24\x97\x06\xf7\x22\xa3\x06\xd2\x24\x7b\x06\x07\x24\x8e\x06\xe4\x22\x8a\x06\x6c\x24\x86\x06\x75\x23\x93\x06\x72\x22\x77\x06\xab\x24\x71\x06\x92\x23\x8c\x06\x84\x22\x86\x06\xb7\x24\x7c\x06\x88\x23\x94\x06\x63\x22\x89\x06\xd3\x24\x74\x06\xb1\x23\x7b\x06\xab\x22\x9d\x06\xb2\x24\x8b\x06\xae\x23\x91\x06\x6f\x22\x8a\x06\x32\x25\x7c\x06\xf1\x23\x92\x06\xb7\x22\x99\x06\x4f\x25\x8f\x06\xe3\x23\x93\x06\xc0\x22\x7f\x06\xcf\x24\x73\x06\x93\x23\x81\x06\x8b\x22\x9b\x06\x73\x24\x83\x06\x87\x23\x8a\x06\x78\x22\x90\x06\x8c\x24\x91\x06\xa5\x23\x8a\x06\x61\x22\x85\x06\x86\x24\x92\x06\x66\x23\x8e\x06\x6d\x22\x9c\x06\xcd\x24\x92\x06\x70\x23\x93\x06\x43\x22\x9a\x06\x21\x25\x7f\x06\xe4\x23\x8f\x06\xad\x22\x9e\x06\x4c\x25\x87\x06\xbe\x23\x8c\x06\x51\x22\x8b\x06\x81\x24\x7e\x06\x76\x23\x88\x06\x48\x22\x99\x06\xaa\x24\x91\x06\x75\x23\x94\x06\x43\x22\x80\x06\x9c\x24\x74\x06\x85\x23\x78\x06\x3c\x22\x93\x06\x37\x24\x81\x06\x6e\x23\x8a\x06\x17\x22\x89\x06\x7c\x24\x97\x06\x6b\x23\x89\x06\x2a\x22\x96\x06\xdf\x24\x8a\x06\xbf\x23\x94\x06\x7d\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff", 0x000f000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x000f000, 4686);
printf("1199 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(87*1000);
memcpy(buf, "\x6c\x1c\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("1200 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x9a\x06\x2d\x25\x96\x06\x05\x24\x9f\x06\xba\x22\x96\x06\x06\x25\x88\x06\xc0\x23\x94\x06\xae\x22\x87\x06\xd9\x24\x8b\x06\x62\x23\x86\x06\x4c\x22\x95\x06\xb5\x24\x79\x06\x57\x23\x95\x06\x54\x22\x8e\x06\x7f\x24\x82\x06\x5f\x23\x88\x06\x38\x22\x9b\x06\x67\x24\x91\x06\x9f\x23\x94\x06\x5f\x22\x9d\x06\x85\x24\x8a\x06\xad\x23\x9c\x06\x73\x22\x99\x06\x29\x25\x71\x06\xc2\x23\x89\x06\x96\x22\x96\x06\x06\x25\x82\x06\x91\x23\x8e\x06\xbc\x22\x83\x06\xba\x24\x73\x06\x4c\x23\x82\x06\x4b\x22\x90\x06\xaa\x24\x7d\x06\x4b\x23\x85\x06\x7d\x22\x9b\x06\x8c\x24\x9c\x06\x99\x23\x95\x06\x7c\x22\x6c\x06\xdd\x24\x5b\x06\x97\x23\x7c\x06\x96\x22\x7b\x06\x9a\x24\x8b\x06\xbf\x23\x8e\x06\xb0\x22\x94\x06\xe6\x24\x89\x06\x02\x24\x90\x06\xd5\x22\x92\x06\xd4\x24\x97\x06\x15\x24\x9d\x06\x11\x23\x95\x06\x8b\x24\x83\x06\xa8\x23\x9b\x06\xbd\x22\x93\x06\xd7\x24\x90\x06\x99\x23\x97\x06\xbc\x22\x8b\x06\xa0\x24\x8d\x06\x7c\x23\x96\x06\x8f\x22\x8f\x06\x97\x24\x85\x06\x94\x23\x77\x06\x60\x22\x8f\x06\xc6\x24\x7a\x06\x78\x23\x8e\x06\x7b\x22\x88\x06\x4a\x25\x71\x06\xcd\x23\x81\x06\xe6\x22\x8b\x06\xe6\x24\x7f\x06\xcb\x23\x8c\x06\xf3\x22\x98\x06\x96\x24\x91\x06\xb1\x23\x87\x06\xc8\x22\x8b\x06\x7d\x24\x87\x06\xd1\x23\x83\x06\xda\x22\x83\x06\xcd\x24\x7c\x06\xcb\x23\x8c\x06\x04\x23\xa0\x06\xf2\x24\x8b\x06\xa1\x23\x8f\x06\x06\x23\x9b\x06\x12\x25\x81\x06\xb1\x23\x8d\x06\xda\x22\x91\x06\x68\x25\x8b\x06\x8a\x24\x90\x06\x4d\x23\x95\x06\x2a\x25\x8f\x06\x9d\x24\x9a\x06\x65\x23\x8b\x06\x17\x25\x83\x06\x31\x24\x89\x06\xde\x22\x98\x06\xfb\x24\x84\x06\xf9\x23\x8f\x06\xe8\x22\x81\x06\xe0\x24\x81\x06\x0f\x24\x84\x06\xbd\x22\x92\x06\xc1\x24\x8b\x06\xdb\x23\x8a\x06\xd3\x22\x8d\x06\x08\x25\x7a\x06\xd9\x23\x76\x06\xbc\x22\x8b\x06\x3d\x25\x87\x06\x34\x24\x8d\x06\x2c\x23\xa2\x06\xb2\x25\x7c\x06\x7c\x24\x95\x06\x7f\x23\x92\x06\x2b\x25\x8f\x06\x2a\x24\x9b\x06\x35\x23\x8d\x06\xdb\x24\x8b\x06\xce\x23\x8c\x06\xe8\x22\x83\x06\x72\x24\x78\x06\x1b\x24\x7f\x06\xdf\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x98\x06\xba\x24\x85\x06\xb8\x23\x88\x06\xb6\x22\x9b\x06\x4b\x25\x7d\x06\x9f\x23\x8e\x06\xbe\x22\x95\x06\x63\x25\x8a\x06\x0c\x24\x94\x06\xf3\x22\x88\x06\x8d\x25\x83\x06\x0e\x24\x89\x06\x21\x23\x84\x06\x2b\x25\x93\x06\x39\x24\x9a\x06\x02\x23\x8c\x06\xfb\x24\x81\x06\xda\x23\x8e\x06\xda\x22\xa3\x06\xc3\x24\x9b\x06\xba\x23\x96\x06\xcc\x22\x86\x06\x64\x24\x91\x06\xd0\x23\x93\x06\xd8\x22\x95\x06\xae\x24\x8e\x06\x98\x23\x87\x06\xc2\x22\x7f\x06\x15\x25\x73\x06\x16\x24\x8c\x06\xd4\x22\x98\x06\x6c\x25\x7f\x06\xfc\x23\x91\x06\x03\x23\x90\x06\x0a\x25\x83\x06\xc0\x23\x8a\x06\xb7\x22\x76\x06\xeb\x24\x6d\x06\xe7\x23\x8f\x06\xc4\x22\x7b\x06\x77\x24\x8f\x06\xbc\x23\x82\x06\x9c\x22\x90\x06\xc6\x24\x94\x06\xc6\x23\x97\x06\xe5\x22\x96\x06\xc3\x24\x8d\x06\xa3\x23\x8c\x06\xda\x22\x9f\x06\xb2\x24\x93\x06\xe2\x23\x8b\x06\xd8\x22\x98\x06\x6e\x25\x82\x06\x54\x24\x97\x06\x7f\x23\xa7\x06\x02\x26\x95\x06\x8b\x24\x9d\x06\x56\x23\x97\x06\xfb\x25\x96\x06\x8f\x23\x87\x06\xf1\x22\x9e\x06\x81\x25\x8c\x06\xb8\x23\x96\x06\x03\x23\x9a\x06\x32\x25\x97\x06\x9f\x23\x9f\x06\xe6\x22\x90\x06\xe9\x24\x84\x06\xe6\x23\x85\x06\xd9\x22\x88\x06\xe0\x24\x8b\x06\xdb\x23\x81\x06\xe9\x22\x92\x06\x50\x25\x99\x06\x76\x24\x8c\x06\x39\x23\x9b\x06\x5a\x25\x91\x06\x78\x24\x93\x06\x5d\x23\x92\x06\x8f\x24\x8b\x06\x19\x24\x94\x06\x05\x23\x83\x06\xc1\x24\x7c\x06\xdd\x23\x91\x06\xd3\x22\x95\x06\x40\x25\x86\x06\xd4\x23\x98\x06\xfe\x22\x9f\x06\x49\x25\x8c\x06\xd2\x23\x8c\x06\xd3\x22\x99\x06\x45\x25\x87\x06\xf8\x23\x87\x06\xd8\x22\x9e\x06\x81\x25\x8b\x06\x55\x24\x8a\x06\x08\x23\xa1\x06\xe6\x25\x98\x06\x84\x24\x9b\x06\xc3\x23\x92\x06\x55\x25\x8d\x06\x3d\x24\x8c\x06\x21\x23\x95\x06\xd1\x24\x85\x06\xed\x23\x98\x06\xf1\x22\x9b\x06\x01\x25\x92\x06\x14\x24\x99\x06\xfc\x22\xa0\x06\x97\x24\x9c\x06\x23\x24\x9c\x06\x3a\x23\x86\x06\x9e\x24\x83\x06\x1c\x24\x90\x06\x1a\x23\x9a\x06\x2a\x25\x9b\x06\x52\x24\x9a\x06\x37\x23\xa7\x06\xb7\x25\x96\x06\xe6\x24\xa2\x06\xda\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa5\x06\x44\x25\xa1\x06\x57\x24\x9c\x06\x20\x23\x94\x06\xc4\x24\x79\x06\x2c\x24\x94\x06\xf7\x22\xa1\x06\xc0\x24\x94\x06\x1c\x24\x83\x06\xdc\x22\x96\x06\x8a\x24\x9c\x06\x48\x24\x97\x06\x19\x23\x8a\x06\xe4\x24\x82\x06\xef\x23\x97\x06\xff\x22\x9d\x06\x05\x25\xa9\x06\x42\x24\xa7\x06\x1d\x23\x9d\x06\x71\x25\xae\x06\xf1\x24\xa0\x06\x83\x23\x8b\x06\x1f\x25\x9c\x06\x8e\x24\x94\x06\x25\x23\x75\x06\x31\x25\x74\x06\x18\x24\x92\x06\x30\x23\x88\x06\xae\x24\x87\x06\x23\x24\x7c\x06\x09\x23\x89\x06\x9b\x24\x94\x06\xfb\x23\x8b\x06\xe2\x22\x97\x06\x8a\x24\x8b\x06\xd1\x23\x83\x06\xcf\x22\x76\x06\xb0\x24\x7e\x06\x27\x24\x99\x06\x05\x23\x99\x06\x02\x25\x8e\x06\x63\x24\x86\x06\x60\x23\x95\x06\x16\x25\x71\x06\x0e\x24\x87\x06\x3c\x23\x78\x06\x96\x24\x72\x06\xf6\x23\x8d\x06\xc3\x22\x83\x06\x55\x24\x85\x06\xc4\x23\x81\x06\x8b\x22\x86\x06\x96\x24\x87\x06\xb7\x23\x8b\x06\xa2\x22\x80\x06\xcc\x24\x66\x06\x9e\x23\x8f\x06\xb9\x22\x7d\x06\x81\x24\x7c\x06\x20\x24\x89\x06\xa5\x22\x92\x06\xe9\x24\x85\x06\x63\x24\x8c\x06\xf7\x22\x92\x06\x6e\x25\x97\x06\xa6\x24\x98\x06\xab\x23\x9f\x06\x5d\x25\x87\x06\x5d\x24\x96\x06\x1e\x23\x97\x06\x07\x26\x7b\x06\xc4\x23\x8b\x06\x05\x23\xa7\x06\x12\x26\x91\x06\xec\x23\x85\x06\xfc\x22\x95\x06\x12\x25\x8c\x06\x23\x24\x93\x06\x05\x23\x93\x06\xab\x24\x9c\x06\x49\x24\x9b\x06\xfe\x22\x93\x06\x65\x25\x92\x06\x5c\x24\x8b\x06\x3e\x23\x79\x06\xa6\x25\x6b\x06\x51\x24\x94\x06\x97\x23\x8f\x06\x40\x25\x80\x06\x19\x24\x9b\x06\x06\x23\x88\x06\xb9\x24\x8e\x06\x09\x24\x87\x06\x1a\x23\x95\x06\xda\x24\xa3\x06\x20\x24\x99\x06\x27\x23\x8d\x06\xcb\x24\x7d\x06\x2e\x24\x85\x06\x13\x23\x9a\x06\xbf\x24\x9a\x06\x6c\x24\x8d\x06\x1d\x23\x98\x06\x3b\x25\x89\x06\x76\x24\xa3\x06\x75\x23\x9f\x06\x75\x25\x95\x06\x07\x25\x90\x06\x0d\x24\x9e\x06\x2e\x25\x98\x06\x7b\x24\xa1\x06\x66\x23\x8f\x06\x0e\x25\x8f\x06\x15\x24\xa2\x06\x4b\x23\x92\x06\xa4\x24\x89\x06\x16\x24\xa7\x06\x54\x23\x90\x06\xfb\x24\x96\x06\x5f\x24\xaa\x06\x7f\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x78\x06\xf1\x24\x91\x06\x7a\x24\x8a\x06\x41\x23\x81\x06\xa0\x25\x87\x06\x72\x24\xa0\x06\xa8\x23\x94\x06\x05\x26\x8d\x06\x36\x25\x91\x06\x0e\x24\x9a\x06\xcd\x25\x78\x06\x1b\x25\x9b\x06\xcf\x23\x94\x06\x65\x25\x9e\x06\xbb\x24\x97\x06\x70\x23\x9a\x06\x10\x25\x96\x06\x5a\x24\x90\x06\x64\x23\x9b\x06\x36\x25\x98\x06\xa5\x24\x99\x06\x6a\x23\x89\x06\x4e\x25\x8a\x06\x9c\x24\x90\x06\x6e\x23\x8e\x06\x8c\x25\x8b\x06\xaf\x24\x8f\x06\x98\x23\x8c\x06\xfc\x25\x94\x06\xba\x25\x91\x06\x52\x24\x9f\x06\xf1\x25\x92\x06\x32\x25\xa7\x06\x30\x24\x9e\x06\x6d\x25\x97\x06\xa2\x24\x93\x06\x8b\x23\x93\x06\x3e\x25\x84\x06\x52\x24\x98\x06\x56\x23\x91\x06\x00\x25\x80\x06\x54\x24\x90\x06\x57\x23\x7c\x06\xfb\x24\x70\x06\x3c\x24\x8b\x06\x2c\x23\x90\x06\x7a\x25\x8d\x06\x64\x24\x8b\x06\x65\x23\x9a\x06\xcb\x25\x83\x06\xec\x24\x98\x06\xdc\x23\x7f\x06\xf0\x25\x75\x06\xc6\x24\x97\x06\xdd\x23\x9e\x06\x48\x25\x88\x06\x49\x24\x8f\x06\x81\x23\x87\x06\x19\x25\x81\x06\x4c\x24\x90\x06\x75\x23\x88\x06\x51\x25\x8e\x06\x22\x24\x9e\x06\x37\x23\xa5\x06\x2d\x25\x97\x06\x61\x24\x95\x06\x62\x23\x9c\x06\x5b\x25\x85\x06\x35\x24\x98\x06\x2e\x23\xa2\x06\xea\x25\x94\x06\xa0\x24\x91\x06\x8c\x23\xa7\x06\x26\x26\x9d\x06\x15\x25\x96\x06\x61\x24\x98\x06\x99\x25\x9b\x06\x85\x24\x99\x06\xa3\x23\x96\x06\x65\x25\x7c\x06\x57\x24\x88\x06\x56\x23\x9c\x06\x92\x25\x89\x06\x1a\x24\x92\x06\x72\x23\x91\x06\x57\x25\x8e\x06\x71\x24\x94\x06\x89\x23\x7c\x06\x93\x25\x75\x06\xbd\x24\x81\x06\xbe\x23\xa7\x06\x04\x26\x89\x06\xa9\x24\xa4\x06\xf1\x23\xa0\x06\x57\x26\xa2\x06\x21\x25\xa3\x06\x34\x24\x7a\x06\xd3\x25\x69\x06\xeb\x24\xa1\x06\xe7\x23\x87\x06\x4b\x25\x96\x06\xaa\x24\x89\x06\x7f\x23\x92\x06\x6e\x25\x94\x06\x9a\x24\x9b\x06\xa8\x23\x9a\x06\x61\x25\x93\x06\x96\x24\x9d\x06\x97\x23\x89\x06\x88\x25\x92\x06\xc1\x24\x9b\x06\xcd\x23\x92\x06\xcf\x25\x82\x06\xd0\x24\x92\x06\xe3\x23\x96\x06\x08\x26\x92\x06\x6c\x25\x94\x06\x7b\x24\x96\x06\x05\x26\x96\x06\x57\x25\x9a\x06\x03\x24\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x8c\x06\xc1\x25\x95\x06\xd8\x24\x92\x06\xda\x23\x9d\x06\x89\x25\x95\x06\x9d\x24\x9e\x06\xce\x23\x9e\x06\x95\x25\x9d\x06\xa9\x24\x97\x06\xa1\x23\x98\x06\x82\x25\x99\x06\xc8\x24\x90\x06\xb1\x23\x97\x06\xbc\x25\x99\x06\xf1\x24\xa6\x06\xe3\x23\x97\x06\xa8\x26\x8f\x06\x89\x25\x9e\x06\x90\x24\xa0\x06\xe3\x26\xa2\x06\x97\x25\xa0\x06\x8d\x24\x8d\x06\xfa\x25\x8a\x06\xdd\x24\x9b\x06\x29\x24\x73\x06\x9f\x25\x7f\x06\x13\x25\x90\x06\x12\x24\x89\x06\xc6\x25\x93\x06\xf7\x24\x94\x06\xed\x23\xa5\x06\xae\x25\xa2\x06\xfa\x24\xa1\x06\xfb\x23\x8b\x06\xf5\x25\x82\x06\xf1\x24\x96\x06\x0e\x24\x9b\x06\x60\x26\x94\x06\xad\x25\xa7\x06\x83\x24\xa0\x06\x6e\x26\xa0\x06\x04\x26\xa4\x06\xbe\x24\xad\x06\x5c\x26\x9a\x06\x02\x25\xa5\x06\x85\x24\xad\x06\xfc\x25\x96\x06\xe9\x24\xa6\x06\x2d\x24\xa5\x06\xc9\x25\x98\x06\xba\x24\xa9\x06\x29\x24\x87\x06\x8f\x25\x95\x06\xc1\x24\xa5\x06\x09\x24\x95\x06\xc3\x25\x91\x06\x18\x25\x9f\x06\x25\x24\xa0\x06\x73\x26\x93\x06\x79\x25\xac\x06\x96\x24\x90\x06\x8f\x26\x99\x06\xe2\x25\xb5\x06\xf6\x24\x9a\x06\xf8\x25\x99\x06\x36\x25\x9f\x06\x50\x24\x8f\x06\xa4\x25\xa0\x06\xc4\x24\x9c\x06\xfb\x23\x8d\x06\x55\x25\x85\x06\x95\x24\xa6\x06\x0c\x24\x9d\x06\x92\x25\x91\x06\x98\x24\x9a\x06\x05\x24\xa1\x06\x9b\x25\x96\x06\x6d\x24\xa2\x06\xc3\x23\x9b\x06\xb0\x25\x98\x06\xc3\x24\xa3\x06\x0a\x24\xb0\x06\x51\x26\x9d\x06\x13\x25\x99\x06\x82\x24\x8b\x06\xe7\x25\x8b\x06\xf6\x24\x94\x06\x3f\x24\x95\x06\xb5\x25\x8f\x06\xa3\x24\xa4\x06\xe2\x23\x94\x06\x4a\x25\x91\x06\x6e\x24\xa6\x06\xcb\x23\x97\x06\xa0\x25\x97\x06\x87\x24\x94\x06\xe5\x23\x98\x06\x68\x25\x97\x06\x93\x24\xa5\x06\xec\x23\x69\x06\xb4\x25\x68\x06\xd1\x24\x9a\x06\xef\x23\x94\x06\x5a\x26\x96\x06\x42\x25\x9b\x06\x60\x24\x9c\x06\x31\x26\x92\x06\xc0\x24\xa2\x06\x3c\x24\x96\x06\xaf\x25\xa0\x06\xa4\x24\x99\x06\x25\x24\x93\x06\x74\x25\x97\x06\x91\x24\x91\x06\xfa\x23\xa1\x06\xcc\x25\x9c\x06\x7a\x24\x9e\x06\xca\x23\xa1\x06\x9d\x25\x8f\x06\x56\x24\xa0\x06\xc5\x23\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x98\x06\xcb\x25\x97\x06\x96\x24\x9e\x06\xce\x23\x93\x06\x23\x26\xa9\x06\x18\x25\x9c\x06\x40\x24\xab\x06\x18\x26\xa4\x06\x27\x25\xa6\x06\x9f\x24\xa2\x06\xc5\x25\xa3\x06\xc2\x24\xae\x06\x26\x24\x99\x06\x84\x25\x94\x06\xa4\x24\xa5\x06\xde\x23\x8e\x06\x91\x25\x8d\x06\xc2\x24\x97\x06\x12\x24\x93\x06\x9e\x25\x8a\x06\xbb\x24\xa6\x06\xf6\x23\x9d\x06\xc8\x25\x8a\x06\xdc\x24\x95\x06\x20\x24\x95\x06\x9d\x26\x94\x06\x63\x25\xa4\x06\xe0\x24\xa4\x06\xdb\x26\x96\x06\x84\x25\xaa\x06\x48\x25\x90\x06\x99\x26\x87\x06\x73\x25\x90\x06\xc3\x24\x94\x06\x06\x26\x9a\x06\xed\x24\xa3\x06\x42\x24\x99\x06\xcf\x25\x9c\x06\xe0\x24\xa2\x06\x4c\x24\xa4\x06\xdc\x25\xa1\x06\xe7\x24\xa6\x06\x65\x24\x9b\x06\x29\x26\x99\x06\x2e\x25\xa2\x06\xb8\x24\x96\x06\x80\x26\x95\x06\x8b\x25\x9e\x06\x00\x25\x9b\x06\xf9\x26\x93\x06\xfa\x25\x9f\x06\x9a\x25\xa1\x06\x63\x26\x8e\x06\x6d\x25\x9a\x06\x2f\x25\x96\x06\x32\x26\x9b\x06\x5d\x25\xa6\x06\xd1\x24\x95\x06\x15\x26\x91\x06\x27\x25\xa2\x06\xe1\x24\x9d\x06\x16\x26\x96\x06\x92\x25\xa3\x06\xb0\x24\x9f\x06\x0c\x26\x95\x06\x2f\x25\xa3\x06\xe4\x24\x95\x06\x03\x27\x8f\x06\xb1\x25\x9e\x06\x0b\x25\x83\x06\x9e\x27\x7d\x06\x5a\x26\xb3\x06\xd5\x25\x99\x06\x1d\x27\x93\x06\xc5\x25\x9f\x06\x1e\x25\x99\x06\x6d\x26\x92\x06\x75\x25\x9d\x06\xd1\x24\x94\x06\x63\x26\x92\x06\x25\x25\x9f\x06\x9e\x24\x8f\x06\x73\x26\x89\x06\x20\x25\x8e\x06\xba\x24\x9b\x06\x6c\x26\x90\x06\x38\x25\xa3\x06\xc3\x24\x9b\x06\xcf\x26\x9c\x06\x41\x25\xa4\x06\xdd\x24\xa5\x06\x40\x27\x9a\x06\xf3\x25\x9f\x06\x6e\x25\xa6\x06\x19\x27\xa4\x06\xcb\x25\x96\x06\xf4\x24\x95\x06\x9e\x26\x95\x06\x1c\x25\x91\x06\xd7\x24\x81\x06\x51\x26\x7d\x06\x00\x25\x8d\x06\xe3\x24\x81\x06\x5e\x26\x7d\x06\x00\x25\x8b\x06\xb2\x24\xb4\x06\x2c\x26\xad\x06\xe1\x24\xb5\x06\x8b\x24\x1a\x07\x6b\x26\x0d\x07\x15\x25\x0e\x07\x9c\x24\x8e\x07\xb2\x26\x77\x07\x75\x25\x93\x07\xd9\x24\x6f\x07\x38\x26\x5a\x07\x50\x25\x7e\x07\x74\x24\x67\x06\x53\x26\x62\x06\x71\x24\x72\x06\xc3\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x44\x06\x70\x22\x49\x06\xb7\x20\x38\x06\x3e\x1e\x21\x07\x45\x21\x1c\x07\x75\x20\x48\x07\xdd\x1e\x4c\x07\x64\x21\x4a\x07\x87\x20\x53\x07\x63\x1f\xe2\x06\xc7\x21\xd9\x06\xee\x20\xe0\x06\x8c\x1f\x7a\x06\xe5\x21\x8d\x06\x35\x21\x8a\x06\xd6\x1f\x58\x06\x09\x22\x67\x06\x68\x21\x58\x06\xbf\x1f\x45\x06\x65\x22\x48\x06\x7d\x21\x46\x06\x06\x20\x5d\x06\x77\x22\x68\x06\x69\x21\x64\x06\x24\x20\x6f\x06\x47\x22\x5f\x06\x33\x21\x68\x06\xb8\x1f\x6d\x06\x22\x22\x77\x06\x0c\x21\x76\x06\xbb\x1f\x67\x06\x42\x22\x58\x06\x0d\x21\x72\x06\xdf\x1f\x42\x06\x5e\x22\x4b\x06\x4b\x21\x72\x06\xd8\x1f\x68\x06\x36\x22\x5e\x06\x47\x21\x82\x06\x05\x20\x66\x06\xc4\x22\x5d\x06\x8d\x21\x61\x06\x63\x20\x77\x06\xd9\x22\x73\x06\xf6\x21\x7b\x06\x82\x20\x7d\x06\x4b\x22\x83\x06\xa7\x21\x77\x06\x38\x20\x7e\x06\xeb\x21\x6b\x06\x55\x21\x7e\x06\x0d\x20\x64\x06\xd2\x21\x56\x06\x21\x21\x6d\x06\xf0\x1f\x63\x06\xab\x21\x61\x06\x44\x21\x65\x06\xf7\x1f\x67\x06\xc2\x21\x6d\x06\x2c\x21\x6b\x06\xcf\x1f\x73\x06\xa6\x21\x7d\x06\xaa\x21\x78\x06\xe0\x1f\x6c\x06\xd5\x21\x7c\x06\x65\x21\x73\x06\xe8\x1f\x5f\x06\x9b\x21\x6a\x06\x70\x21\x70\x06\xf4\x1f\x3a\x06\xa6\x21\x3c\x06\x31\x21\x74\x06\xba\x1f\x69\x06\x90\x21\x59\x06\x03\x21\x84\x06\xce\x1f\x6a\x06\xa6\x21\x65\x06\x0f\x21\x79\x06\xc9\x1f\x56\x06\x7c\x21\x51\x06\xe6\x20\x6e\x06\x93\x1f\x75\x06\x8d\x21\x85\x06\xff\x20\x85\x06\x8f\x1f\x57\x06\xc9\x21\x47\x06\x3c\x21\x73\x06\xb4\x1f\x74\x06\xc3\x21\x74\x06\x37\x21\x73\x06\xaf\x1f\x66\x06\x4f\x21\x71\x06\x00\x21\x6f\x06\x7c\x1f\x43\x06\x90\x21\x3b\x06\xc4\x20\x78\x06\x9b\x1f\x7f\x06\x85\x21\x7b\x06\x14\x21\x81\x06\x9d\x1f\x71\x06\xcf\x21\x70\x06\x08\x21\x73\x06\x9b\x1f\x6c\x06\xd8\x21\x61\x06\x04\x21\x6c\x06\x92\x1f\x7f\x06\x28\x22\x71\x06\x85\x21\x7d\x06\xfa\x1f\x81\x06\x1d\x22\x77\x06\xc2\x21\x82\x06\xd6\x1f\x68\x06\xdb\x21\x75\x06\x39\x21\x74\x06\xbb\x1f\x76\x06\xb3\x21\x7a\x06\x19\x21\x81\x06\xcd\x1f\x6a\x06\xa4\x21\x6c\x06\x20\x21\x78\x06\xb1\x1f\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x77\x06\x85\x21\x6e\x06\xfb\x20\x80\x06\xba\x1f\x61\x06\xe2\x21\x65\x06\x1c\x21\x7e\x06\xb4\x1f\x7d\x06\x2f\x22\x7e\x06\x74\x21\x87\x06\x05\x20\x6c\x06\x5d\x22\x68\x06\xbd\x21\x7c\x06\x5e\x20\x78\x06\xc9\x21\x81\x06\x4c\x21\x8a\x06\x09\x20\x7a\x06\xba\x21\x7c\x06\x10\x21\x89\x06\xe4\x1f\x70\x06\xbe\x21\x76\x06\x06\x21\x86\x06\xf2\x1f\x56\x06\xe9\x21\x5d\x06\x1d\x21\x72\x06\xa9\x1f\x74\x06\xc3\x21\x78\x06\x3f\x21\x73\x06\xcb\x1f\x72\x06\xcf\x21\x5b\x06\x15\x21\x7f\x06\x10\x20\x77\x06\x4f\x22\x7f\x06\x9a\x21\x81\x06\x18\x20\x7b\x06\xd4\x21\x71\x06\x61\x21\x7f\x06\xe8\x1f\x61\x06\xaa\x21\x6a\x06\x15\x21\x6a\x06\xbe\x1f\x76\x06\x7e\x21\x71\x06\x1b\x21\x6c\x06\xe0\x1f\x58\x06\x94\x21\x5e\x06\xee\x20\x73\x06\xbe\x1f\x74\x06\xa7\x21\x6e\x06\x21\x21\x77\x06\xc3\x1f\x73\x06\xe8\x21\x5c\x06\x34\x21\x74\x06\xd4\x1f\x5a\x06\x09\x22\x59\x06\x9e\x21\x62\x06\xf2\x1f\x6b\x06\xeb\x21\x71\x06\x6c\x21\x72\x06\xec\x1f\x5b\x06\x90\x21\x61\x06\x33\x21\x6a\x06\xbe\x1f\x75\x06\xd8\x21\x82\x06\x2d\x21\x77\x06\xda\x1f\x67\x06\x90\x21\x79\x06\x3d\x21\x81\x06\x15\x20\x6f\x06\xa4\x21\x75\x06\x33\x21\x78\x06\xfe\x1f\x64\x06\xe6\x21\x6f\x06\x50\x21\x76\x06\x32\x20\x77\x06\xb6\x22\x81\x06\x0f\x22\x74\x06\x86\x20\x6f\x06\x8c\x22\x67\x06\xd2\x21\x80\x06\x82\x20\x6e\x06\xea\x21\x6c\x06\x39\x21\x71\x06\xf9\x1f\x31\x06\xe4\x21\x2f\x06\x37\x21\x72\x06\x10\x20\x5f\x06\xff\x21\x66\x06\x4f\x21\x6e\x06\x3d\x20\x7e\x06\xd9\x21\x77\x06\x79\x21\x7b\x06\x27\x20\x71\x06\x12\x22\x7a\x06\x82\x21\x80\x06\x57\x20\x55\x06\x60\x22\x53\x06\xce\x21\x83\x06\x4b\x20\x5a\x06\xb2\x22\x54\x06\x03\x22\x73\x06\x79\x20\x72\x06\x5c\x22\x78\x06\xc1\x21\x75\x06\x53\x20\x75\x06\x35\x22\x7b\x06\xae\x21\x74\x06\x32\x20\x55\x06\x00\x22\x5a\x06\xa6\x21\x76\x06\x4b\x20\x62\x06\x08\x22\x6d\x06\x8e\x21\x73\x06\x41\x20\x7d\x06\x36\x22\x75\x06\x91\x21\x78\x06\x52\x20\x75\x06\xbb\x22\x76\x06\xa9\x21\x6b\x06\x7f\x20\x69\x06\xc8\x22\x78\x06\x48\x22\x71\x06\xce\x20\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x5c\x06\x64\x22\x60\x06\xfa\x21\x7f\x06\xb4\x20\x5e\x06\xfc\x21\x60\x06\xab\x21\x70\x06\x3d\x20\x69\x06\x16\x22\x6c\x06\x95\x21\x72\x06\x4b\x20\x67\x06\xe2\x21\x7f\x06\xab\x21\x70\x06\x70\x20\x69\x06\x10\x22\x65\x06\xce\x21\x8b\x06\x83\x20\x7a\x06\x60\x22\x7a\x06\xe4\x21\x82\x06\xa8\x20\x60\x06\xcd\x22\x6d\x06\x63\x22\x7d\x06\xd5\x20\x45\x06\x83\x22\x4f\x06\x06\x22\x63\x06\xba\x20\x68\x06\x24\x22\x69\x06\xf6\x21\x6f\x06\x9e\x20\x65\x06\x48\x22\x5f\x06\x0b\x22\x7f\x06\xad\x20\x68\x06\x65\x22\x75\x06\x03\x22\x66\x06\xa1\x20\x6c\x06\x6d\x22\x6c\x06\x07\x22\x6d\x06\xa9\x20\x6d\x06\xac\x22\x73\x06\x1c\x22\x71\x06\xb3\x20\x82\x06\xf2\x22\x6e\x06\x60\x22\x70\x06\xdf\x20\x6d\x06\xf9\x22\x78\x06\x53\x22\x6e\x06\xf2\x20\x79\x06\xa2\x22\x86\x06\x0e\x22\x73\x06\xd1\x20\x60\x06\x72\x22\x6c\x06\xfb\x21\x68\x06\xb4\x20\x72\x06\x7d\x22\x72\x06\xda\x21\x76\x06\xc6\x20\x74\x06\xae\x22\x63\x06\x33\x22\x84\x06\x0d\x21\x82\x06\x89\x22\x79\x06\x4d\x22\x79\x06\xba\x20\x6c\x06\xfd\x22\x65\x06\x7e\x22\x74\x06\x05\x21\x79\x06\x42\x23\x81\x06\x7d\x22\x74\x06\xf3\x20\x72\x06\xbf\x22\x83\x06\x43\x22\x72\x06\xdf\x20\x60\x06\xbf\x22\x68\x06\x48\x22\x62\x06\xba\x20\x7a\x06\x92\x22\x77\x06\x31\x22\x6f\x06\x06\x21\x6c\x06\x9a\x22\x72\x06\x5d\x22\x6e\x06\x1a\x21\x7c\x06\xf7\x22\x82\x06\xa9\x22\x78\x06\xfe\x20\x78\x06\x49\x23\x8a\x06\xb5\x22\x74\x06\x23\x21\x70\x06\xaf\x23\x6d\x06\x13\x23\x7d\x06\x66\x21\x67\x06\x3c\x23\x68\x06\xdf\x22\x77\x06\x11\x21\x6a\x06\x32\x23\x6b\x06\x5f\x22\x69\x06\x15\x21\x80\x06\x13\x23\x85\x06\xb5\x22\x82\x06\x24\x21\x54\x06\x20\x23\x61\x06\xe5\x22\x7a\x06\x29\x21\x6e\x06\x75\x23\x69\x06\xef\x22\x78\x06\x31\x21\x4a\x06\xb3\x23\x4c\x06\x28\x23\x74\x06\x05\x21\x6e\x06\x0e\x24\x6c\x06\xc9\x23\x7a\x06\x75\x21\x81\x06\xfc\x23\x85\x06\x78\x23\x74\x06\x49\x21\x78\x06\xb5\x23\x7e\x06\x10\x23\x7b\x06\x83\x21\x57\x06\xbb\x23\x59\x06\x36\x23\x6f\x06\x8d\x21\x77\x06\xd5\x23\x7b\x06\x60\x23\x7d\x06\x00\x22\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x71\x06\xad\x23\x7c\x06\x77\x23\x88\x06\xfb\x21\x5f\x06\x3b\x24\x5f\x06\xb4\x23\x7e\x06\x3a\x22\x67\x06\x97\x24\x5c\x06\x06\x24\x7a\x06\x73\x22\x6d\x06\x5f\x24\x6f\x06\xa9\x23\x82\x06\x5b\x22\x71\x06\xf9\x23\x74\x06\x89\x23\x85\x06\x41\x22\x85\x06\xf0\x23\x84\x06\xb2\x23\x78\x06\x3a\x22\x75\x06\xfc\x23\x87\x06\xd5\x23\x7d\x06\x66\x22\x79\x06\x52\x24\x7c\x06\xae\x23\x78\x06\xa8\x22\x7a\x06\x46\x24\x67\x06\xf7\x23\x89\x06\x96\x22\x70\x06\xb7\x24\x6d\x06\x2a\x24\x85\x06\xbe\x22\x77\x06\x0c\x25\x81\x06\x2f\x24\x7b\x06\xe6\x22\x87\x06\xea\x24\x7b\x06\x07\x24\x84\x06\xf7\x22\x69\x06\xd7\x24\x73\x06\x50\x24\x84\x06\x25\x23\x80\x06\xea\x24\x7e\x06\x54\x24\x82\x06\x53\x23\x7a\x06\x85\x25\x78\x06\x99\x24\x86\x06\x91\x23\x86\x06\x1e\x26\x81\x06\x91\x24\x85\x06\xc2\x23\x8c\x06\x21\x27\x6d\x06\x06\x25\x8d\x06\xfc\x23\x99\x06\x88\x26\x9b\x06\x6a\x25\x93\x06\x13\x24\x8a\x06\xa6\x25\x87\x06\x3a\x25\x87\x06\xfa\x23\x87\x06\x71\x25\x88\x06\x26\x25\x82\x06\xea\x23\x91\x06\xcc\x25\x95\x06\x60\x25\x98\x06\x29\x24\x8f\x06\xd3\x25\x8a\x06\x6c\x25\x92\x06\x34\x24\x97\x06\x15\x26\x8f\x06\x85\x25\x91\x06\x48\x24\x7a\x06\x93\x26\x7f\x06\x1b\x26\x83\x06\x87\x24\x82\x06\xa7\x26\x84\x06\x78\x26\x89\x06\x18\x25\x8a\x06\x6b\x26\x90\x06\x3f\x26\x96\x06\xaf\x24\x7e\x06\x29\x26\x91\x06\x5a\x26\x91\x06\xe6\x24\x7f\x06\x4e\x26\x86\x06\x2d\x26\xa0\x06\xfc\x24\x94\x06\x58\x26\x9a\x06\x77\x26\x96\x06\xf9\x24\x97\x06\xab\x26\x99\x06\x63\x26\x92\x06\x1f\x25\x93\x06\xe7\x26\x97\x06\xb5\x26\x91\x06\x2e\x25\xa7\x06\x8a\x27\xab\x06\x79\x27\x9f\x06\xc6\x25\x9f\x06\x74\x27\x9b\x06\xbd\x26\x93\x06\xa6\x25\x94\x06\x20\x27\xa3\x06\xb1\x26\x93\x06\x64\x25\x92\x06\x61\x27\xa1\x06\xfa\x26\xa3\x06\x92\x25\x9c\x06\x29\x27\xa3\x06\xd5\x26\xa4\x06\x96\x25\x99\x06\x87\x27\x96\x06\xfe\x26\x96\x06\xc8\x25\x93\x06\xb8\x27\x8e\x06\xc3\x27\x9d\x06\xf5\x25\x91\x06\x7b\x28\x97\x06\x36\x28\x95\x06\x46\x26\x97\x06\x4a\x28\x91\x06\x7a\x27\x9e\x06\xdf\x25\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa6\x06\xac\x27\x9a\x06\x4b\x27\xa7\x06\xa1\x25\xab\x06\xcc\x27\xa9\x06\xbe\x27\x9f\x06\xf4\x25\xac\x06\xec\x27\xa9\x06\xfc\x27\xb4\x06\x94\x26\x91\x06\x43\x28\xa6\x06\x19\x28\xa8\x06\xc8\x26\x93\x06\x7a\x28\xa4\x06\x9b\x28\xb0\x06\x05\x27\xb0\x06\x41\x29\xb1\x06\x2a\x29\xaa\x06\xa3\x27\xa0\x06\x72\x29\x9e\x06\x18\x29\x9d\x06\x51\x27\xae\x06\x58\x29\x9e\x06\x9e\x28\x9e\x06\x29\x27\x90\x06\x52\x29\x87\x06\xa7\x28\x9c\x06\x68\x27\xa3\x06\xc7\x29\x95\x06\xe3\x28\xb1\x06\xbe\x27\xa9\x06\xc2\x29\xae\x06\x35\x29\xb7\x06\x97\x27\x9b\x06\xf7\x29\x98\x06\x4d\x29\xac\x06\x1b\x28\xa7\x06\x6d\x2a\xa1\x06\xf7\x29\xb5\x06\x7b\x28\xa8\x06\xfb\x2a\xad\x06\xf4\x2a\xa3\x06\x58\x29\xb9\x06\x2c\x2a\xb9\x06\x1b\x2a\xbe\x06\xcb\x28\xba\x06\x1e\x2a\xbd\x06\xe8\x29\xbf\x06\xc1\x28\xbc\x06\x7f\x2a\xaf\x06\x34\x2a\xbe\x06\xee\x28\x9b\x06\xcd\x2a\xa5\x06\xba\x2a\xa0\x06\x15\x29\xa5\x06\xbe\x2b\xaf\x06\xad\x2a\xbb\x06\x64\x29\xbe\x06\x90\x2c\xc8\x06\xf0\x2a\xbb\x06\xc7\x29\xd0\x06\x31\x2d\xc3\x06\x98\x2b\xba\x06\xdf\x29\x97\x06\xd4\x2c\x9b\x06\x48\x2b\xbb\x06\x0f\x2a\xc3\x06\xc5\x2b\xbc\x06\x17\x2b\xbe\x06\x03\x2a\xab\x06\xe8\x2b\xad\x06\x80\x2b\xcb\x06\xaa\x2a\xbd\x06\x2f\x2c\xb1\x06\x8c\x2b\xc2\x06\xa3\x2a\xc0\x06\x90\x2c\xbb\x06\xc9\x2b\xc3\x06\xdb\x2a\xa8\x06\xdc\x2c\xa4\x06\x49\x2c\xc3\x06\x29\x2b\xc3\x06\xb0\x2d\xc7\x06\xe6\x2c\xc5\x06\xc1\x2b\xc1\x06\x6a\x2d\xc6\x06\xb0\x2c\xc2\x06\xc7\x2b\x9b\x06\x84\x2d\x98\x06\x14\x2d\xb5\x06\xd3\x2b\xac\x06\x2a\x2d\xae\x06\x43\x2d\xc8\x06\x49\x2c\xbf\x06\x7f\x2d\xc5\x06\x6c\x2d\xc1\x06\x83\x2c\xbf\x06\xea\x2d\xb8\x06\xc8\x2d\xbc\x06\xad\x2c\xb6\x06\xa0\x2e\xbf\x06\xfe\x2d\xc0\x06\x5b\x2d\xc7\x06\xb3\x2f\xbb\x06\x6b\x2e\xc8\x06\x96\x2d\xcf\x06\x5f\x2f\xc8\x06\xe4\x2e\xc7\x06\xca\x2d\xa4\x06\xca\x2f\xa7\x06\x3b\x2f\xb2\x06\x87\x2d\xc1\x06\xc5\x2f\xce\x06\x23\x2f\xcf\x06\x1b\x2e\xcd\x06\x0e\x30\xce\x06\x4b\x2f\xd3\x06\x74\x2e\xd2\x06\x5e\x30\xc3\x06\xf4\x2f\xd6\x06\xa6\x2e\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd6\x06\xdb\x30\xc7\x06\x62\x30\xcd\x06\x1b\x2f\xcf\x06\x04\x32\xc3\x06\x3e\x31\xc4\x06\xeb\x2f\xb3\x06\xff\x31\xae\x06\x4f\x31\xc1\x06\x05\x30\xc1\x06\x7b\x31\xd3\x06\x82\x31\xd9\x06\x5e\x30\xdf\x06\xe9\x31\xdb\x06\xc6\x31\xd6\x06\x75\x30\xd3\x06\x59\x32\xd1\x06\x21\x32\xdf\x06\xeb\x30\xc7\x06\xba\x32\xcf\x06\xeb\x32\xda\x06\x40\x31\xbc\x06\x73\x33\xca\x06\x2b\x33\xdd\x06\xdb\x31\xcc\x06\x84\x34\xcf\x06\x95\x34\xd8\x06\x78\x32\xe0\x06\xe9\x34\xde\x06\xe3\x34\xe5\x06\x08\x33\xe3\x06\x75\x34\xe5\x06\x27\x34\xdc\x06\xa7\x32\xcf\x06\xa7\x34\xe5\x06\xa3\x34\xd8\x06\x52\x33\xda\x06\x4b\x35\xe0\x06\xaa\x34\xe1\x06\xbf\x33\xdf\x06\x85\x35\xe2\x06\xf0\x34\xec\x06\xae\x34\xce\x06\x91\x36\xc1\x06\x07\x36\xe2\x06\xcc\x34\xd3\x06\xc4\x36\xdc\x06\xd0\x36\xdf\x06\x4a\x35\xe5\x06\xd4\x37\xf6\x06\x89\x37\xf1\x06\x8d\x36\xdb\x06\x80\x37\xda\x06\x97\x37\xed\x06\x6b\x36\xbb\x06\x8f\x38\xba\x06\xe2\x37\xea\x06\x74\x36\xd8\x06\x9d\x38\xd8\x06\xda\x37\xec\x06\x10\x37\xe0\x06\x11\x39\xe4\x06\xa4\x38\xf8\x06\x51\x37\xe2\x06\x92\x39\xf3\x06\xd0\x38\xfb\x06\xdf\x37\xfc\x06\xcc\x3a\xf5\x06\xb0\x39\xeb\x06\xee\x38\xf6\x06\x6c\x3c\xee\x06\x39\x3b\xf3\x06\xbc\x39\xe6\x06\x20\x3b\xe8\x06\xdd\x3a\xe8\x06\x75\x39\xf0\x06\x6c\x3b\xe8\x06\xf5\x3a\xf5\x06\xe8\x39\xef\x06\xf9\x3b\xef\x06\x9d\x3b\xee\x06\x31\x3a\xec\x06\x0f\x3d\xf1\x06\xe9\x3b\xf9\x06\x16\x3b\xee\x06\x73\x3d\xf6\x06\x72\x3c\xf2\x06\x8c\x3b\xe6\x06\xae\x3e\xdf\x06\xc3\x3d\xf8\x06\x43\x3c\xf6\x06\x18\x40\xf2\x06\xac\x3e\xf5\x06\x50\x3d\xfc\x06\x74\x3f\xfc\x06\x84\x3e\xfa\x06\xaa\x3d\xdb\x06\x48\x3f\xda\x06\x26\x3f\x0f\x07\x02\x3e\xdf\x06\x4d\x41\xd1\x06\xe9\x40\xee\x06\x15\x40\xf3\x06\xab\x40\xf9\x06\x42\x40\x06\x07\xbf\x3f\x05\x07\x87\x41\xff\x06\xe5\x40\x03\x07\x28\x40\xef\x06\x3f\x42\xf8\x06\xd6\x41\xff\x06\xaf\x40\x00\x07\x8b\x43\x01\x07\xe1\x42\x0e\x07\x56\x42\xfe\x06\x90\x44\xfe\x06\xcf\x43\x0f\x07\xb6\x41\x04\x07\x9d\x43\x17\x07\x3e\x43\x07\x07\x08\x42\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x05\x07\x7d\x44\x12\x07\x6e\x43\x15\x07\xbb\x42\xfe\x06\x23\x45\xed\x06\x41\x45\xf6\x06\x1b\x44\x12\x07\x50\x45\x06\x07\x5c\x45\x10\x07\xd8\x44\x0c\x07\x0e\x46\x0d\x07\x51\x46\x0e\x07\x13\x45\x0a\x07\x2e\x48\x13\x07\x23\x47\x10\x07\xee\x45\x02\x07\x8f\x48\x0a\x07\x4b\x48\x12\x07\x1a\x46\x0b\x07\x21\x49\x00\x07\x2a\x48\x1a\x07\x38\x46\x07\x07\xdf\x48\x03\x07\x3b\x48\x10\x07\x43\x47\xee\x06\x85\x4a\xf6\x06\x79\x49\x12\x07\xc9\x47\x0c\x07\x1f\x4b\x0b\x07\x83\x4a\x1a\x07\x88\x49\xf7\x06\x44\x4c\x04\x07\x9f\x4c\x20\x07\x73\x4a\x04\x07\x64\x4d\x0b\x07\x7b\x4d\x19\x07\x15\x4c\x1a\x07\xaf\x4f\x1a\x07\xc5\x4f\x17\x07\x20\x4e\x06\x07\xdb\x50\x08\x07\xb6\x50\x0a\x07\xf6\x4d\xfa\x06\x9a\x50\x0f\x07\x6d\x50\x12\x07\x9d\x4e\x13\x07\x90\x50\x22\x07\xaf\x50\x1b\x07\xe9\x4e\x12\x07\x4f\x51\x13\x07\x2a\x51\x25\x07\xb7\x4f\x1d\x07\x4d\x53\x14\x07\xc2\x51\x1a\x07\x9e\x50\x16\x07\x6e\x54\x1b\x07\x66\x53\x1a\x07\xa0\x51\x22\x07\x88\x55\x1a\x07\x8f\x55\x22\x07\xd6\x52\x1d\x07\x76\x56\x1a\x07\xcf\x55\x27\x07\xab\x53\x2a\x07\x24\x56\x26\x07\x67\x55\x23\x07\x99\x54\x27\x07\x14\x57\x1e\x07\x42\x56\x26\x07\x39\x55\x1c\x07\xa6\x57\x21\x07\xa4\x57\x1b\x07\xb6\x55\x29\x07\xe7\x59\x27\x07\x71\x5a\x26\x07\x0e\x58\x28\x07\xe1\x5c\x1b\x07\x90\x5b\x29\x07\xf1\x59\x25\x07\x94\x5d\x23\x07\xbe\x5c\x26\x07\xe9\x5b\x27\x07\xd5\x5e\x25\x07\x8d\x5d\x2a\x07\x72\x5c\x1c\x07\x7e\x5d\x21\x07\x7f\x5e\x29\x07\xd7\x5c\x2e\x07\xf0\x5e\x30\x07\x19\x5f\x28\x07\x53\x5d\x34\x07\xaa\x60\x24\x07\xbe\x5f\x38\x07\x53\x5f\x22\x07\x74\x62\x1e\x07\x8a\x61\x32\x07\xc6\x60\x3e\x07\x72\x66\x2f\x07\xd2\x63\x35\x07\xa5\x62\x2e\x07\x97\x67\x3b\x07\x98\x66\x39\x07\x9c\x64\x26\x07\x3b\x67\x2f\x07\x72\x67\x2c\x07\xcc\x65\x34\x07\x71\x67\x39\x07\x80\x67\x37\x07\x05\x65\x30\x07\x70\x68\x40\x07\x49\x68\x3f\x07\xe3\x67\x2c\x07\x98\x6a\x27\x07\x51\x6a\x34\x07\x0a\x69\x36\x07\xf2\x6b\x31\x07\xfc\x6a\x3e\x07\x2c\x6a\x2b\x07\xbd\x6d\x3d\x07\x31\x6d\x3b\x07\x34\x6b\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x44\x07\x24\x71\x32\x07\x84\x71\x43\x07\x2b\x6f\x49\x07\xff\x73\x33\x07\xa8\x72\x3c\x07\xfe\x6f\x40\x07\x2e\x74\x42\x07\x8f\x72\x3c\x07\x36\x71\x4a\x07\xb7\x74\x42\x07\xf0\x71\x42\x07\x92\x71\x35\x07\x79\x76\x38\x07\xef\x75\x41\x07\x20\x74\x37\x07\xab\x7b\x3b\x07\xa2\x7b\x42\x07\x26\x78\x3c\x07\xe6\x79\x3e\x07\x0f\x79\x50\x07\x96\x75\x41\x07\x1b\x7b\x3a\x07\xca\x79\x47\x07\xbf\x77\x3a\x07\xee\x7d\x3c\x07\xbd\x7e\x3d\x07\x21\x7a\x3b\x07\x57\x7f\x3c\x07\xe3\x7d\x38\x07\x7d\x7a\x51\x07\x50\x7f\x43\x07\xc3\x7d\x53\x07\xce\x7b\x55\x07\x7a\x81\x44\x07\xb9\x7f\x4e\x07\x6f\x7e\x41\x07\xcd\x82\x42\x07\xe1\x7f\x51\x07\xcf\x7f\x4e\x07\x39\x84\x4d\x07\x53\x82\x54\x07\xa1\x80\x47\x07\x62\x87\x45\x07\xb7\x85\x51\x07\x9d\x85\x46\x07\x89\x8d\x41\x07\x47\x8d\x59\x07\x74\x87\x53\x07\xb7\x8b\x44\x07\xbf\x88\x54\x07\xe4\x87\x41\x07\x22\x8a\x4e\x07\x55\x8a\x4b\x07\x46\x88\x42\x07\xd0\x8d\x4a\x07\x2f\x8c\x47\x07\x2f\x8a\x4e\x07\xda\x8f\x4c\x07\x21\x8f\x49\x07\xce\x8d\x53\x07\x2c\x93\x5a\x07\xa6\x92\x59\x07\x6b\x8f\x57\x07\x51\x97\x58\x07\xd5\x95\x4c\x07\x7e\x90\x4f\x07\x90\x9c\x42\x07\x90\x96\x56\x07\xb3\x94\x55\x07\xd7\x9b\x5c\x07\x0c\x98\x55\x07\x66\x95\x52\x07\x55\x9a\x54\x07\x7d\x98\x4c\x07\x08\x95\x59\x07\x0c\x9f\x57\x07\x25\x9a\x5a\x07\x4c\x98\x5e\x07\xd3\xa1\x53\x07\xae\x9c\x52\x07\x58\x9a\x56\x07\xa5\xa2\x5d\x07\xb8\x9d\x53\x07\xc3\x9d\x52\x07\x5c\xa6\x5a\x07\xb4\xa1\x5c\x07\x9d\xa0\x64\x07\xd7\xad\x5d\x07\xb0\xa5\x60\x07\x15\xa6\x66\x07\x47\xb1\x64\x07\x4c\xad\x6d\x07\xbb\xa9\x5c\x07\xe6\xb2\x54\x07\xb5\xa9\x53\x07\x6c\xa7\x54\x07\x4d\xb0\x5a\x07\x8a\xab\x55\x07\x4e\xa8\x5f\x07\x68\xb1\x66\x07\x37\xae\x5e\x07\x28\xaa\x66\x07\xe8\xb3\x5c\x07\xae\xae\x69\x07\xc3\xad\x65\x07\x86\xb8\x70\x07\x63\xb4\x6a\x07\x3b\xb1\x61\x07\x9f\xc1\x5c\x07\x09\xb9\x6a\x07\x64\xba\x62\x07\x93\xc9\x5e\x07\x92\xc0\x63\x07\x9f\xc0\x67\x07\x89\xe1\x5d\x07\xf2\xd3\x6e\x07\x4e\xd7\x7d\x07\xb4\xf9\x7a\x07\x64\xea\x71\x07\x02\xe9\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x6f\x07\xff\xff\x79\x07\xff\xff\x6f\x07\xff\xff\x7e\x07\xff\xff\x72\x07\xff\xff\x81\x07\xff\xff\x80\x07\xff\xff\x78\x07\xff\xff\x7f\x07\xff\xff\x7b\x07\xff\xff\x81\x07\xff\xff\x84\x07\xff\xff\x97\x07\xff\xff\x96\x07\xff\xff\x96\x07\xff\xff\x8e\x07\xff\xff\x91\x07\xff\xff\x8d\x07\xff\xff\x8e\x07\xff\xff\x87\x07\xff\xff\x92\x07\xff\xff\x94\x07\xff\xff\x8f\x07\xff\xff\x8f\x07\xff\xff\x95\x07\xff\xff\x95\x07\xff\xff\x98\x07\xff\xff", 0x0001c6c);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001c6c, 1436);
printf("1201 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x6c\x6c\x6c\x6c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("1202 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x6c\x6c\x6c\x6c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("1203 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1204 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1205 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1206 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x25\x96\x25", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1207 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa1\xf4\xa2\x0f\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x10\x7e\x00\x7f\x00", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("1208 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(18*1000);
memcpy(buf, "\x00\x10\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000002, 0x0000000, buf, 0x0000004, 1000);
printf("1209 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\xd1\x0d\xb7\x0d\xa4\x0d\x93\x0d\x84\x0d\x77\x0d\x6b\x0d\x5f\x0d\x55\x0d\x4b\x0d\x41\x0d\x38\x0d\x2f\x0d\x27\x0d\x1e\x0d\x17\x0d\x0f\x0d\x07\x0d\x00\x0d\xf9\x0c\xf2\x0c\xec\x0c\xe5\x0c\xdf\x0c\xd8\x0c\xd2\x0c\xcc\x0c\xc6\x0c\xc0\x0c\xbb\x0c\xb5\x0c\xaf\x0c\xaa\x0c\xa5\x0c\x9f\x0c\x9a\x0c\x95\x0c\x90\x0c\x8b\x0c\x86\x0c\x81\x0c\x7c\x0c\x77\x0c\x73\x0c\x6e\x0c\x69\x0c\x65\x0c\x60\x0c\x5c\x0c\x57\x0c\x53\x0c\x4f\x0c\x4a\x0c\x46\x0c\x42\x0c\x3e\x0c\x3a\x0c\x36\x0c\x31\x0c\x2d\x0c\x29\x0c\x25\x0c\x22\x0c\x1e\x0c\x1a\x0c\x16\x0c\x12\x0c\x0e\x0c\x0b\x0c\x07\x0c\x03\x0c\xff\x0b\xfc\x0b\xf8\x0b\xf5\x0b\xf1\x0b\xed\x0b\xea\x0b\xe6\x0b\xe3\x0b\xdf\x0b\xdc\x0b\xd9\x0b\xd5\x0b\xd2\x0b\xce\x0b\xcb\x0b\xc8\x0b\xc4\x0b\xc1\x0b\xbe\x0b\xbb\x0b\xb7\x0b\xb4\x0b\xb1\x0b\xae\x0b\xab\x0b\xa7\x0b\xa4\x0b\xa1\x0b\x9e\x0b\x9b\x0b\x98\x0b\x95\x0b\x92\x0b\x8f\x0b\x8c\x0b\x89\x0b\x86\x0b\x83\x0b\x80\x0b\x7d\x0b\x7a\x0b\x77\x0b\x74\x0b\x71\x0b\x6e\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x71\x0b\x77\x0b\x7d\x0b\x82\x0b\x88\x0b\x8e\x0b\x94\x0b\x99\x0b\x9f\x0b\xa5\x0b\xab\x0b\xb0\x0b\xb6\x0b\xbc\x0b\xc1\x0b\xc7\x0b\xcd\x0b\xd3\x0b\xd8\x0b\xde\x0b\xe4\x0b\xea\x0b\xef\x0b\xf5\x0b\xfb\x0b\x00\x0c\x06\x0c\x0c\x0c\x12\x0c\x17\x0c\x1d\x0c\x23\x0c\x29\x0c\x2e\x0c\x34\x0c\x3a\x0c\x3f\x0c\x45\x0c\x4b\x0c\x51\x0c\x56\x0c\x5c\x0c\x62\x0c\x68\x0c\x6d\x0c\x73\x0c\x79\x0c\x7e\x0c\x84\x0c\x8a\x0c\x90\x0c\x95\x0c\x9b\x0c\xa1\x0c\xa7\x0c\xac\x0c\xb2\x0c\xb8\x0c\xbe\x0c\xc3\x0c\xc9\x0c\xcf\x0c\xd4\x0c\xda\x0c\xe0\x0c\xe6\x0c\xeb\x0c\xf1\x0c\xf7\x0c\xfd\x0c\x02\x0d\x08\x0d\x0e\x0d\x13\x0d\x19\x0d\x1f\x0d\x25\x0d\x2a\x0d\x30\x0d\x36\x0d\x3c\x0d\x41\x0d\x47\x0d\x4d\x0d\x52\x0d\x58\x0d\x5e\x0d\x64\x0d\x69\x0d\x6f\x0d\x75\x0d\x7b\x0d\x80\x0d\x86\x0d\x8c\x0d\x91\x0d\x97\x0d\x9d\x0d\xa3\x0d\xa8\x0d\xae\x0d\xb4\x0d\xba\x0d\xbf\x0d\xc5\x0d\xcb\x0d\xd0\x0d\xd6\x0d\xdc\x0d\xe2\x0d\xe7\x0d\xed\x0d\xf3\x0d\xf9\x0d\xfe\x0d\x04\x0e\x0a\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\xd1\x0d\xb7\x0d\xa4\x0d\x93\x0d\x84\x0d\x77\x0d\x6b\x0d\x5f\x0d\x55\x0d\x4b\x0d\x41\x0d\x38\x0d\x2f\x0d\x27\x0d\x1e\x0d\x17\x0d\x0f\x0d\x07\x0d\x00\x0d\xf9\x0c\xf2\x0c\xec\x0c\xe5\x0c\xdf\x0c\xd8\x0c\xd2\x0c\xcc\x0c\xc6\x0c\xc0\x0c\xbb\x0c\xb5\x0c\xaf\x0c\xaa\x0c\xa5\x0c\x9f\x0c\x9a\x0c\x95\x0c\x90\x0c\x8b\x0c\x86\x0c\x81\x0c\x7c\x0c\x77\x0c\x73\x0c\x6e\x0c\x69\x0c\x65\x0c\x60\x0c\x5c\x0c\x57\x0c\x53\x0c\x4f\x0c\x4a\x0c\x46\x0c\x42\x0c\x3e\x0c\x3a\x0c\x36\x0c\x31\x0c\x2d\x0c\x29\x0c\x25\x0c\x22\x0c\x1e\x0c\x1a\x0c\x16\x0c\x12\x0c\x0e\x0c\x0b\x0c\x07\x0c\x03\x0c\xff\x0b\xfc\x0b\xf8\x0b\xf5\x0b\xf1\x0b\xed\x0b\xea\x0b\xe6\x0b\xe3\x0b\xdf\x0b\xdc\x0b\xd9\x0b\xd5\x0b\xd2\x0b\xce\x0b\xcb\x0b\xc8\x0b\xc4\x0b\xc1\x0b\xbe\x0b\xbb\x0b\xb7\x0b\xb4\x0b\xb1\x0b\xae\x0b\xab\x0b\xa7\x0b\xa4\x0b\xa1\x0b\x9e\x0b\x9b\x0b\x98\x0b\x95\x0b\x92\x0b\x8f\x0b\x8c\x0b\x89\x0b\x86\x0b\x83\x0b\x80\x0b\x7d\x0b\x7a\x0b\x77\x0b\x74\x0b\x71\x0b\x6e\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x6c\x0b\x71\x0b\x77\x0b\x7d\x0b\x82\x0b\x88\x0b\x8e\x0b\x94\x0b\x99\x0b\x9f\x0b\xa5\x0b\xab\x0b\xb0\x0b\xb6\x0b\xbc\x0b\xc1\x0b\xc7\x0b\xcd\x0b\xd3\x0b\xd8\x0b\xde\x0b\xe4\x0b\xea\x0b\xef\x0b\xf5\x0b\xfb\x0b\x00\x0c\x06\x0c\x0c\x0c\x12\x0c\x17\x0c\x1d\x0c\x23\x0c\x29\x0c\x2e\x0c\x34\x0c\x3a\x0c\x3f\x0c\x45\x0c\x4b\x0c\x51\x0c\x56\x0c\x5c\x0c\x62\x0c\x68\x0c\x6d\x0c\x73\x0c\x79\x0c\x7e\x0c\x84\x0c\x8a\x0c\x90\x0c\x95\x0c\x9b\x0c\xa1\x0c\xa7\x0c\xac\x0c\xb2\x0c\xb8\x0c\xbe\x0c\xc3\x0c\xc9\x0c\xcf\x0c\xd4\x0c\xda\x0c\xe0\x0c\xe6\x0c\xeb\x0c\xf1\x0c\xf7\x0c\xfd\x0c\x02\x0d\x08\x0d\x0e\x0d\x13\x0d\x19\x0d\x1f\x0d\x25\x0d\x2a\x0d\x30\x0d\x36\x0d\x3c\x0d\x41\x0d\x47\x0d\x4d\x0d\x52\x0d\x58\x0d\x5e\x0d\x64\x0d\x69\x0d\x6f\x0d\x75\x0d\x7b\x0d\x80\x0d\x86\x0d\x8c\x0d\x91\x0d\x97\x0d\x9d\x0d\xa3\x0d\xa8\x0d\xae\x0d\xb4\x0d\xba\x0d\xbf\x0d\xc5\x0d\xcb\x0d\xd0\x0d\xd6\x0d\xdc\x0d\xe2\x0d\xe7\x0d\xed\x0d\xf3\x0d\xf9\x0d\xfe\x0d\x04\x0e\x0a\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x10\x0e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0001000);
ret = usb_bulk_write(devh, 0x00000001, buf, 0x0001000, 1245);
printf("1210 bulk write returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(10*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000005, 0x0000000, buf, 0x0000004, 1000);
printf("1211 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000c0, 0x0000000, buf, 0x0000004, 1000);
printf("1212 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(17*1000);
memcpy(buf, "\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xff\xa5\x0f\x7c\x00\x7d\x01\x7e\x00\x79\x40", 0x0000014);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000014, 1000);
printf("1213 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(19*1000);
memcpy(buf, "\x00\x02\x00\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1214 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000200, 1030);
printf("1215 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1216 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x01\xa0\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1217 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1218 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1219 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1220 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1221 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22\xa1\x00\xa2\x23\xa1\x00\xa2\x21\xa1\x00\xa2\x19\xa1\x00\xa2\x22", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1222 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1223 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1224 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xa0\x00\xa0\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1225 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1226 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1227 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x08\x61\x0b\x62\x0e\x63\x11\x64\x14\x65\x17\x66\x02\x67\x05\x68\x08\x69\x50\x6a\x01\x6b\x0c\x6d\x48\x6e\x94\x6f\x0e\x70\x50\x71\xbe\x72\x0e\x73\xe8\x74\x96\x75\x0e\x76\xf0\x77\xc0\x78\x0e\x79\x48\x7a\x2b\x7b\x0e\x7c\x50\x7d\x55\x7e\x0e\x7f\xe8\x80\x2d", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1228 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x81\x0e\x82\xf0\x83\x57\x84\x0e\x85\x48\x86\xfd\x87\x0e\x88\x50\x89\x3c\x8a\x0f\x8b\xe8\x8c\xff\x8d\x0e\x8e\xf0\x8f\x3e\x90\x0f\x9a\x00\x9b\x15\x9d\x04\x9e\x00\x9f\x00\xa0\x0e\xa1\x00\xa2\x69\xa3\x0e\xa4\x00\xa5\xd2\xa6\x0e\xa7\xff\xa8\x68\xa9\x0e\xaa\xff", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1229 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xab\xd1\xac\x0e\xad\xff\xae\x3a\xaf\x0f\xb0\x4b\xb1\x01\xb9\x57\xba\x0a\xcd\x00\xce\x0f\xd4\x00\xd5\x8e\xd6\xe3\xd7\x38\xec\x00\xed\x00\xee\xc0\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x30\xf4\x38\xf5\x00\xf6\x01\xf7\x0a\xf8\xaa\xf9\x00\xfa\x55\xfb\x00\xfc\x69", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1230 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xfd\x00\xfd\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1231 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1232 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x02\x5f\x02", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1233 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\x41\x61\x23\x62\x41\x63\x14\x64\x41\x65\x14\x66\x32\x67\x14\x68\x32\x69\x14\x6a\x32\x6b\x05\x6c\x32\x6d\x05\x6e\x32\x6f\x14\x70\x40\x71\x05\x72\x00\x73\x40\x74\x05\x75\x00\x76\x40\x77\x05\x78\x00\x79\x40\x7a\x05\x7b\x00\x7c\x80\x7d\x0a\x7e\x00\x7f\x80", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1234 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x80\x0a\x81\x00\x82\x80\x83\x0a\x84\x00\x85\x80\x86\x0a\x87\x00\x88\xc0\x89\x0f\x8a\x00\x8b\xc0\x8c\x0f\x8d\x00\x8e\xc0\x8f\x0f\x90\x00\x91\xc0\x92\x0f\x93\x00\xb0\x00\xb1\x00\xb2\x00\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x00\xb8\x00\xb9\x00\xba\x00\xbb\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1235 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xbc\x00\xbd\x00\xbe\x00\xbf\x00\xc0\x00\xc1\x00\xc2\x00\xc3\x00\xc4\x00\xc5\x00\xc6\x00\xc7\x00\xc8\x00\xc9\x00\xca\x00\xcb\x00\xcc\x00\xcd\x00\xce\x00\xcf\x00", 0x0000028);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000028, 1000);
printf("1236 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1237 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1238 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb3\x00\xb4\x00\xb5\x00\xb6\x00\xb7\x01\xb8\x00", 0x000000c);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000000c, 1000);
printf("1239 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1240 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x58\x01\x5e\x01\x82\x00\x83\x38\x84\x8e\x85\xe3\x8a\x03\x8e\x00\x90\x64\x91\x00\x94\x30\x95\xa7\x96\x25\x9b\x3d\x9d\x3f\x9e\x00\x9f\x40\xa0\x00\xa1\x00\xa2\x00\xa3\xff\xa4\xfe\xa5\x0d\xa6\x41\xab\x00\xae\xc3\xaf\x43\xb0\x08\xb1\x07\xb2\x14\xb3\x01\xb4\x7b", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1241 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xb5\x00\xb6\x70\xb7\x05\xc9\x00\xca\x00\xcb\x03\xcc\x00\xcd\x3c\xce\x3c\xcf\x3c\xd0\x07\xd8\x05\xd9\x3c\xda\x54\xdb\x00\xdc\x01\xde\x01\xdf\x17\xe0\x2c\xe1\x01\xe2\x00\xe3\x00\xe4\x00\xe5\xc8\xe6\x00\xe7\x02\xe8\x00\xe9\x02\xea\x2c\xeb\x01\xec\x80\xed\x00", 0x0000040);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000040, 1000);
printf("1242 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xee\x30\xef\x80\xf0\xb0\xf1\x71\xf2\x00\xf3\x0c\xf5\x10\xf6\x00\xf7\x03\xf8\x02\xf9\x0a\xfa\x37\xfb\x77\xfc\x00\xfd\x6c\xfe\x0b\xff\x40", 0x0000022);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000022, 1000);
printf("1243 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(147*1000);
memcpy(buf, "\xf8\x02\xf4\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1244 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");

wait();

memcpy(buf, "\x7c\x00\x7d\xbd\x7e\x03\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("1477 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(14*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1478 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1479 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(127*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1480 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1481 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1482 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1483 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1484 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(121*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1485 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1486 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(203*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1487 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1488 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(131*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1489 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1490 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1491 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1492 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1493 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1494 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1495 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(344*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1496 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1497 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1498 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1499 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1500 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1501 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1502 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1503 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1504 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(349*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1505 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1506 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1507 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1508 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1509 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1510 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1511 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1512 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1513 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(297*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1514 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1515 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1516 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1517 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1518 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1519 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1520 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1521 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(100*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1522 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(308*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1523 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1524 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1525 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1526 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1527 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1528 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1529 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1530 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1531 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(302*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1532 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1533 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(105*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1534 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1535 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1536 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1537 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1538 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1539 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1540 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(210*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1541 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1542 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1543 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1544 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1545 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1546 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1547 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1548 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1549 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(313*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1550 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(33*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1551 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1552 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1553 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(881*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1554 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1555 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1556 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1557 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1558 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(294*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1559 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1560 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1561 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1562 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1563 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1564 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1565 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(121*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1566 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1567 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(318*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1568 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(37*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1569 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1570 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1571 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1572 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1573 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1574 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1575 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1576 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(313*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1577 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1578 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1579 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1580 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1581 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1582 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1583 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1584 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1585 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(322*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1586 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1587 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1588 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1589 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1590 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1591 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1592 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1593 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(96*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1594 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(302*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1595 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1596 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1597 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1598 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1599 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1600 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1601 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1602 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(96*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1603 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(297*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1604 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1605 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1606 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1607 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1608 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1609 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1610 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(104*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1611 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1612 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(299*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1613 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(33*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1614 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1615 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1616 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1617 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1618 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1619 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1620 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1621 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(209*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1622 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1623 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1624 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1625 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1626 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1627 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1628 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(879*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1629 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1630 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(295*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1631 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1632 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1633 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1634 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1635 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1636 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1637 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1638 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1639 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(296*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1640 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1641 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1642 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1643 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1644 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1645 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1646 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(104*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1647 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(95*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1648 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(298*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1649 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1650 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1651 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1652 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1653 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1654 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1655 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1656 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1657 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(328*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1658 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(37*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1659 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1660 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1661 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1662 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1663 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1664 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1665 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1666 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(342*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1667 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1668 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1669 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1670 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1671 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1672 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1673 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1674 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(91*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1675 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(312*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1676 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1677 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1678 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1679 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(101*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1680 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1681 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1682 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1683 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(102*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1684 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(295*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1685 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1686 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1687 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1688 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1689 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1690 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1691 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1692 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1693 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(211*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1694 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(33*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1695 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1696 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1697 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1698 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1699 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1700 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(882*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1701 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1702 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(350*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1703 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1704 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1705 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1706 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1707 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1708 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1709 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1710 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1711 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(302*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1712 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1713 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1714 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1715 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1716 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1717 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1718 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1719 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1720 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(300*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1721 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(36*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1722 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(106*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1723 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1724 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1725 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1726 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1727 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1728 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1729 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(313*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1730 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1731 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1732 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1733 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1734 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1735 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1736 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1737 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1738 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(333*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1739 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1740 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1741 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1742 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1743 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1744 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1745 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1746 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(95*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1747 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(303*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1748 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1749 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1750 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1751 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1752 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1753 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1754 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1755 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(95*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1756 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(298*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1757 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1758 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1759 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1760 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1761 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1762 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1763 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(125*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1764 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1765 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(296*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1766 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1767 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1768 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1769 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1770 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1771 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1772 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(874*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1773 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(95*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1774 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(203*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1775 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1776 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1777 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1778 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1779 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1780 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1781 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1782 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1783 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(305*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1784 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1785 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1786 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1787 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1788 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1789 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1790 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1791 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1792 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(297*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1793 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1794 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1795 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(127*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1796 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1797 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1798 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1799 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1800 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1801 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(295*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1802 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1803 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1804 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1805 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1806 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1807 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1808 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1809 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1810 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(345*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1811 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1812 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1813 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1814 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1815 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1816 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1817 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1818 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1819 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(345*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1820 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1821 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1822 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1823 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1824 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1825 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1826 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1827 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(95*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1828 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(334*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1829 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1830 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1831 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1832 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1833 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1834 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1835 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1836 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1837 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(295*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1838 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1839 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1840 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1841 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1842 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1843 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1844 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(881*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1845 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1846 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(260*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1847 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1848 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1849 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1850 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(104*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1851 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1852 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1853 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1854 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1855 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(320*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1856 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1857 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1858 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1859 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(103*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1860 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(145*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1861 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1862 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1863 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1864 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(310*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1865 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1866 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1867 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1868 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1869 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1870 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1871 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1872 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1873 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(304*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1874 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(35*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1875 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1876 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1877 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(119*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1878 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1879 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(123*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1880 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1881 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(97*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1882 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(310*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1883 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(32*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1884 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1885 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1886 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1887 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1888 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1889 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1890 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(94*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1891 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(310*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1892 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1893 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1894 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1895 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1896 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1897 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1898 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(120*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1899 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(95*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1900 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(304*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1901 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1902 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1903 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1904 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1905 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1906 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1907 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1908 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(88*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1909 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(301*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1910 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1911 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1912 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1913 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1914 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1915 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(114*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1916 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(878*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1917 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1918 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(255*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1919 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1920 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(121*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1921 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(115*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1922 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1923 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1924 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1925 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1926 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1927 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(207*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1928 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1929 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1930 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1931 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1932 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1933 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(118*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1934 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1935 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(103*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1936 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(301*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1937 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(31*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1938 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1939 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(122*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1940 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(107*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1941 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1942 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1943 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1944 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(90*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1945 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(302*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1946 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(30*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1947 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1948 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1949 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1950 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1951 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(122*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1952 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(116*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1953 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1954 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(328*1000);
memcpy(buf, "\x00\x7a\x07\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1955 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(47*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1956 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1957 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(108*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1958 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(112*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1959 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(113*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1960 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1961 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1962 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(93*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0009600, 3304);
printf("1963 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(359*1000);
memcpy(buf, "\x7c\x70\x7d\x36\x7e\x03\x7f\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("1964 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(13*1000);
memcpy(buf, "\xe0\x6c\x06\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000003, 0x0000000, buf, 0x0000004, 1000);
printf("1965 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(34*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1966 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(111*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1967 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(109*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1968 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(117*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1969 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(110*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1970 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(122*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x000fc00, 4870);
printf("1971 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(92*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x00084c0, 3039);
printf("1972 bulk read returned %d, bytes: ", ret); buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(41*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("1973 bulk read returned %d, bytes: ", ret); //buff( buf, ret );
print_bytes(buf, ret);
printf("\n");
usleep(325*1000);
memcpy(buf, "\xf4\x00\x86\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1974 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1975 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1976 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x02\xa0\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("1977 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("1978 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x01\xa0\x00\x04\x00\x00\x01\x02\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("1979 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x02\xa0\x05\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("1980 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("1981 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x01\xa0\x05\x01\x81\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("1982 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(20*1000);
memcpy(buf, "\x02\xa0\x36\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("1983 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(6*1000);
ret = usb_bulk_read(devh, 0x00000082, buf, 0x0000040, 1003);
printf("1984 bulk read returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2*1000);
memcpy(buf, "\x01\xa0\x46\x02\x00\xc7\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("1985 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(23*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("1986 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("1987 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("1988 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("1989 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("1990 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("1991 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("1992 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("1993 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x94\x31\x92\x57", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1994 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(9*1000);
memcpy(buf, "\x8b\x0b\x8b\x0b", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1995 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1996 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x0a\x8b\x0a", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1997 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("1998 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x09\x8b\x09", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("1999 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("2000 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(501*1000);
memcpy(buf, "\x8b\x00\x8b\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2001 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("2002 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x96\x21\x96\x21", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2003 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\xf3\x22\xfd\xc4\xfe\x09\xa6\x41\xf6\x00\x96\x21\xe4\x01\xe2\x40\xe3\x1f\xe4\x00\x95\xa7\xf4\x01", 0x0000018);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000018, 1000);
printf("2004 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x00\x00\x86\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2005 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("2006 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(1295*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("2007 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2008 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("2009 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("2010 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(2500*1000);
memcpy(buf, "\x04\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("2011 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x1c\x8b\x1c", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2012 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("2013 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x01\x8b\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2014 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("2015 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x8b\x03\x8b\x03", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2016 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE + USB_ENDPOINT_IN, 0x000000c, 0x0000007, 0x0000000, buf, 0x0000001, 1000);
printf("2017 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x82\x00\x83\x00\x84\x00\x85\x00", 0x0000008);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000008, 1000);
printf("2018 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x01\x5f\x01", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2019 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x60\xff\x61\xff\x62\xff\x63\xff\x64\xff\x65\xff\x66\xff\x67\xff\x68\xff\xd4\xff\xd5\xff\xd6\xff\xd7\xff\xec\x00\xed\x00\xee\x00\xef\x00\xf0\x00\xf1\x00\xf2\x00\xf3\x00", 0x000002a);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x000002a, 1000);
printf("2020 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x5f\x00\x5f\x00", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2021 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("2022 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("2023 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x16\x16\x16\x16", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("2024 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x17\x17\x17\x17", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("2025 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(22*1000);
memcpy(buf, "\x64\x64\x64\x64", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("2026 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x65\x65\x65\x65", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("2027 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(5*1000);
memcpy(buf, "\x44\x44\x44\x44", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("2028 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(4*1000);
memcpy(buf, "\x45\x45\x45\x45", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x0000090, 0x0000000, buf, 0x0000004, 1000);
printf("2029 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(7*1000);
memcpy(buf, "\x94\x31\x92\x57", 0x0000004);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x00000b0, 0x0000000, buf, 0x0000004, 1000);
printf("2030 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
usleep(3*1000);
memcpy(buf, "\x04\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 0x0000010);
ret = usb_control_msg(devh, USB_TYPE_VENDOR + USB_RECIP_DEVICE, 0x0000004, 0x000000a, 0x0000000, buf, 0x0000010, 1000);
printf("2031 control msg returned %d, bytes: ", ret);
print_bytes(buf, ret);
printf("\n");
	fclose(file);
	ret = usb_release_interface(devh, 0);
	assert(ret == 0);
	ret = usb_close(devh);
	assert(ret == 0);
	return 0;
}
